Crate otter_nodejs_tests

Crate otter_nodejs_tests 

Otter game system (part thereeof)

https://www.chiark.greenend.org.uk/~ianmdlvl/otter/docs/README.html

This crate is intended for use only by other parts of Otter.

Modules

anyhow
githubcrates-iodocs-rs
async_condvar_fair
async-condvar-fair
authproofs
base64
Configs
base_misc
boolinator
Provides the Boolinator trait, which lets you use Option and Result-style combinators with bools.
btree_map
An ordered map based on a B-Tree.
btree_set
An ordered set based on a B-Tree.
bundles
cast
cast_trait_object
This crate offers functionality for casting between trait objects using only safe Rust and no platform specific code. If you want to downcast to concrete types instead of other trait objects then this crate can’t help you, instead use std::any or a crate like downcast-rs.
childio
chrono
Chrono: Date and Time for Rust
chrono_tz
Chrono-TZ 0.4.1
cmp
Utilities for comparing and ordering values.
delegate
This crate removes some boilerplate for structs that simply delegate some of their methods to one or more of their fields.
digest
This crate provides traits which describe functionality of cryptographic hash functions and Message Authentication algorithms.
digestrw
educe
Educe
either
The enum Either with variants Left and Right is a general purpose sum type with two cases.
env
Inspection and manipulation of the process’s environment.
env_logger
A simple logger that can be configured via environment variables, for use with the logging facade exposed by the log crate.
flexi_logger
A flexible and easy-to-use logger that writes logs to stderr and/or to files or other output streams.
fmt
Utilities for formatting and printing Strings.
fs
Filesystem manipulation operations.
fs2
Extended utilities for working with files and filesystems in Rust.
geometry
glob
Support for matching file paths against Unix shell style patterns.
hash_map
A hash map implemented with quadratic probing and SIMD lookup.
humantime
Human-friendly time parser and formatter
humantime_serde
Serde support for the humantime crate.
imp
index_vec
This crate helps with defining “newtype”-style wrappers around usize (or other integers), Vec<T>, and [T] so that some additional type safety can be gained at zero cost.
inventory
githubcrates-iodocs-rs
io
Traits, helpers, and type definitions for core I/O functionality.
iter
Composable external iteration.
lazy_init
A crate for things that are
lazy_regex
With lazy-regex macros, regular expressions
lazy_static
A macro for declaring lazily evaluated statics.
libc
libc - Raw FFI bindings to platforms’ system libraries
loaded_acl
log
A lightweight logging facade.
materials_format
movehist
mpsc
Multi-producer, single-consumer FIFO queue communication primitives.
nix
Rust friendly bindings to the various *nix system functions.
nwtemplates
once_cell
Overview
ordered_float
Wrappers for total order on Floats. See the OrderedFloat and NotNan docs for details.
organise
otter_base
Otter game system (part thereeof)
otter_support
parking_lot
This library provides implementations of Mutex, RwLock, Condvar and Once that are smaller, faster and more flexible than those in the Rust standard library. It also provides a ReentrantMutex type.
piece_specs
progress
pwd
Safe interface to <pwd.h>
rand
Utilities for random number generation
regex
This crate provides routines for searching strings for matches of a regular expression (aka “regex”). The regex syntax supported by this crate is similar to other regex engines, but it lacks several features that are not known how to implement efficiently. This includes, but is not limited to, look-around and backreferences. In exchange, all regex searches in this crate have worst case O(m * n) time complexity, where m is proportional to the size of the regex and n is proportional to the size of the string being searched.
rmp_serde
MessagePack + Serde
sha2
An implementation of the SHA-2 cryptographic hash algorithms.
shapelib
slotmap
slotmap
sshkeys
str
Utilities for the str primitive type.
tempfile
This is a library for creating temporary files and directories that are automatically deleted when no longer referenced (i.e., on drop).
tera
Tera
termprogress
thread
Native threads.
time
Temporal quantification.
timespec_serde
toml
A serde-compatible TOML-parsing library
toml_de
uds
A unix domain sockets library that supports abstract addresses, fd-passing, SOCK_SEQPACKET sockets and more.
unicode_width
Determine displayed width of char and str types according to Unicode Standard Annex #11 and other portions of the Unicode standard. See the Rules for determining width section for the exact rules.
unix
Platform-specific extensions to std for Unix platforms.
vecdeque_stableix
deque (double-ended queue) with stable element indices
zcoord
zipfile
A library for reading and writing ZIP archives. ZIP is a format designed for cross-platform file “archiving”. That is, storing a collection of files in a single datastream to make them easier to share between computers. Additionally, ZIP is able to compress and encrypt files in its archives.

Macros

anyhow
Construct an ad-hoc error from a string or existing non-anyhow error value.
chain
Chain zero or more iterators together into one sequence.
dbgc
debug
Logs a message at the debug level.
define_index_type
Generate the boilerplate for a newtyped index struct, for use with IndexVec.
delegate
deref_to_field
deref_to_field_mut
display_as_debug
display_consequential_impls
ensure
Return early with an error if a condition is not satisfied.
ensure_eq
env
Inspects an environment variable at compile time.
error
Logs a message at the error level.
error_from_losedetails
format_by_fmt_hex
hformat
hformat_as_display
hwrite
if_chain
Macro for writing nested if let expressions.
if_let
impl_downcast
Adds downcasting support to traits that extend downcast::Downcast by defining forwarding methods to the corresponding implementations on std::any::Any in the standard library.
impl_for_slotmap_key
impl_via_ambassador
index_vec
A macro equivalent to the stdlib’s vec![], but producing an IndexVec.
info
Logs a message at the info level.
iproduct
Create an iterator over the “cartesian product” of iterators.
izip
Create an iterator running multiple iterators in lockstep.
lazy_static
log
The standard logging macro.
log_enabled
Determines if a message logged at the specified level in that module will be logged.
matches_doesnot
paste
pos_zip_map
pos_zip_try_map
regex
Return a lazy static Regex checked at compilation time and built at first use.
regex_captures
Extract captured groups as a tuple of &str.
serde_with_compat
Allows the use of serde for a compat struct
throw
Throw an error.
trace
Logs a message at the trace level.
trace_dbg
visible_slotmap_key
want
want_failed_internal
want_let
wantok
wants
warn
Logs a message at the warn level.

Structs

AbbrevPresentationLayout
AccessRecord
Record of acess for a player. Newtype prevents mutable access without invalidating old tokens and permissions check.
AccessTokenInfo
AccessTokenReport
AccountId
AccountName
AccountNotFound
AccountRecord
AccountSshKey
Accounts
AccountsGuard
Acl
AclEntry
Alphanumeric
Sample a u8, uniformly distributed over ASCII letters and numbers: a-z, A-Z and 0-9.
AnyhowDisplay
ApiPieceOpArgs
Arc
A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically Reference Counted’.
ArrayVec
A vector with a fixed capacity.
AssetUrlToken
Authorisation
BTreeMap
An ordered map based on a B-Tree.
BTreeSet
An ordered set based on a B-Tree.
BadAssetUrlToken
BufReader
The BufReader<R> struct adds buffering to any reader.
BufWriter
Wraps a writer and buffers its output.
BundleMeta
Child
Representation of a running or exited child process.
CircleOutline
CircleShapeIndicator
Client
ClientId
ClientSequence
ColourSpec
Command
A process builder, providing fine-grained control over how a new process should be spawned.
CommittedLogEntry
CompassAngle
0 = unrotated, +ve is anticlockwise, units of 45deg
Condvar
Condition variable (for async)
CookedStdout
CoordinateOverflow
Data
DataLoadPlayer
DebugReader
DenseSlotMap
Dense slot map, storage with stable unique keys.
DigestRead
DigestWrite
Duration
A Duration type to represent a span of time, typically used for system timeouts.
EffectiveACL
EnumMap
An enum mapping.
ExecuteGameChangeUpdates
FaceId
FakeRngSpec
FakeTimeConfig
FakeTimeSpec
FastSplitId
Fd
File
An object providing access to an open file on the filesystem.
FixedToken
Formatter
Configuration for formatting.
FrameReader
FrameWriter
FutureInstant
FutureInstantOutOfRange
GLOBAL
GOccults
GPiece
GPieces
GPlayer
GameBeingDestroyed
GameSpec
GameState
Generation
GenericSimpleShape
Global
GlobalClock
GoodItemName
HashMap
A hash map implemented with quadratic probing and SIMD lookup.
HashSet
A hash set implemented as a HashMap where the value is ().
Html
HtmlLit
HtmlStr
IFastSplits
IOccults
IPiece
Strange ownership and serialisation rules, like OccultIlkOwningId
IPieceTraitObj
IPieces
IPlayer
IndexMap
A hash table where the iteration order of the key-value pairs is independent of the hash values of the keys.
IndexSet
A hash set where the iteration order of the values is independent of their hash values.
IndexSlice
A slice that only accepts indices of a specific type. Note that the intended usage is as IndexSlice<I, [T]>.
IndexVec
A Vec that only accepts indices of a specific type.
Instance
InstanceAccessDetails
InstanceBundles
InstanceContainer
InstanceGuard
InstanceName
InstanceOuter
InstanceRef
InstanceWeakRef
Instant
A measurement of a monotonically nondecreasing clock. Opaque and useful only with Duration.
InternalLogicError
InvalidAbbrevPresentationLayout
InvalidFakeTime
Ipv4Addr
An IPv4 address.
Ipv6Addr
An IPv6 address.
IsHtmlFormatted
ItemEnquiryData
ItemSpec
JsonString
LibraryEnquiryData
LinksTable
LoadedAcl
LogEntry
LogSpecification
Immutable struct that defines which loglines are to be written, based on the module, the log level, and the text.
MgmtChannel
MgmtChannelForGame
MgmtGamePieceInfo
ModifyingPieces
Proof token that it is OK to modify the array
NamedTempFile
A named temporary file.
NascentOccultation
Notch
Notches
OccId
OccultIlkData
OccultIlkId
OccultIlkOwningId
Does not impl Drop. Don’t just drop it.
OccultIlks
OccultView
Occultation
OccultationViews
OcculterRotationChecked
OldNew
OrderedFloat
A wrapper around floats providing implementations of Eq, Ord, and Hash.
OsStr
Borrowed reference to an OS string (see OsString).
OwnerOccultationView
PLA
PUOs_Simple_Modify
PathBuf
An owned, mutable path (akin to String).
PerPlayerIdMap
PermSet
PhantomData
Zero-sized type used to mark things that “act like” they own a T.
PieceAliases
PieceId
PieceLabelLoaded
PieceLoadArgs
PieceOccult
PieceRenderInstructions
PieceSpecialProperties
Special handling instructions for this piece
PieceTraitDowncastFailed
PieceUpdate
PiecesSpec
PlayerAccessUnset
PlayerId
PlayerNotFound
PlayerRecord
PlayerUpdates
PlayerUpdatesStartContext
PosC
PosOffTableError
PrepareUpdatesBuffer
PreparedPieceImage
PreparedPieceState
PreparedPieceUpdateGeneral
PreparedUpdate
PreparedUpdateEntry_Image
PreparedUpdateEntry_Piece
PrivateCaller
ProgressInfo
RawToken
RawTokenVal
ReadFrame
Record
RectC
RectOutline
RectShapeIndicator
Regex
A compiled regular expression for searching Unicode haystacks.
Rendered
ResponseWriter
RngIsReal
RngWrap
SVGWidthOrHeightIter
An iterator over the variants of Self
ServerConfig
ServerConfigSpec
ShapelibExplicit1
ShouldSetZLevel
Drop this only on errors; don’t just forget it
ShowUnocculted
Proof token.
SigPipeWriter
SimpleCommon
SparseSecondaryMap
Sparse secondary map, associate data with previously stored elements in a slot map.
SpecDepth
SpecLoaded
SpecLoadedInert
StableIndexVecDeque
Double-ended queue with stable indices
Stdio
Describes what to do with a standard I/O stream for a child process when passed to the stdin, stdout, and stderr methods of Command.
TablePermissionIter
An iterator over the variants of Self
TableSpec
Tera
Main point of interaction in this library.
TextOptions
TextOptionsSpec
Thunk
TimeIsReal
TimeSpec
TimedFd
TimedFdRead
TimedFdWrite
Timestamp
Timezone
ToRecalculate
TokenByEmail
TokenDeliveryError
TokenRegistry
TokenRevelationKey
TokenRevelationValue
TomlQuote
TransmitUpdate
TryFromIntError
The error type returned when a checked integral type conversion fails.
Uid
User identifier
Unauthorised
UniCase
Case Insensitive wrapper of strings.
UniformOccultationView
UniqueGenGen
UnixStream
A Unix stream socket.
UnsupportedColourSpec
UoDescription
UpdateId
Url
A parsed URL record.
UrlOnStdout
UrlSpec
VecDeque
A double-ended queue implemented with a growable ring buffer.
VisibleAngleTransform
VisiblePieceId
WholeServerConfig
Wrapping
Provides intentionally-wrapped arithmetic on T.
WriteFrame
ZCoord
ZLevel
Pieces on top have higher values than ones
ZipFile
A struct for reading a zip file

Enums

AccountScope
AccountsSaveError
AggregatedIE
ApiPieceOpError
AssetUrlKey
BigEndian
Defines big-endian serialization.
Cow
A clone-on-write smart pointer.
Either
The enum Either with variants Left and Right is a general purpose sum type with two cases.
EitherOrBoth
Value that either holds a single A or B, or both.
ErrorKind
A list specifying general categories of I/O error.
ErrorSignaledViaUpdate
Explode
Fatal
IOccultIlk
Strange ownership and serialisation rules, like OccultIlkOwningId
Inapplicable
Infallible
The error type for errors that can never happen.
InternalError
InvalidScopedName
IpAddr
An IP address, either IPv4 or IPv6.
LLE
LLMI
LOccultIlk
LibraryLoadError
LinkKind
LittleEndian
Defines little-endian serialization.
MFVE
MgmtCommand
MgmtError
MgmtGameInstruction
MgmtGameResponse
MgmtGameUpdateMode
MgmtResponse
OOTG
OccDisplacement
OccKA
OccKG
OccultationKindAlwaysOk
OccultationKindGeneral
OldNewIndex
OpOutcomeThunkGeneric
Ordering
An Ordering is the result of a comparison between two values.
Outline
PacketFrameReadError
PacketFrameWriteError
PathResolveContext
PathResolveMethod
PieceAngle
PieceAngleSpec
PieceMoveable
PieceOpErrorPartiallyProcessed
PieceUpdateOp
PieceUpdateOps
PreparedUpdateEntry
PresentationLayout
PriOG
PriOccultedGeneral
ProgressUpdateMode
SVGProcessingError
SVGSizeError
SVGWidthOrHeight
Shape
ShapelibConfig1
SocketAddr
An internet socket address, either IPv4 or IPv6.
SpecError
SpecialClientRendering
SvSE
TablePermission
TablePlayerSpec
UoKind
Void
The empty type for cases which can’t occur.
WhatResponseToClientOp
ZipError
Error type for Zip

Constants

CLOCK_MONOTONIC
CLOCK_REALTIME
DAEMON_STARTUP_REPORT
DEFAULT_CONFIG_DIR
DEFAULT_CONFIG_LEAFNAME
DEFAULT_EDGE_WIDTH
DEFAULT_SENDMAIL_PROGRAM
DEFAULT_SSH_PROXY_CMD
DEFAULT_TABLE_COLOUR
DEFAULT_TABLE_SIZE
EXIT_DISASTER
EXIT_NOTFOUND
EXIT_SITUATION
EXIT_SPACE
EXIT_USAGE
HELD_SURROUND_COLOUR
HTML_TEXT_LABEL_ELEM_START
INVISIBLE_EDGE_SENSITIVE
LABEL_FONT_SIZE
LOG_ENV_VAR
MS
NON_ALPHANUMERIC
Everything that is not an ASCII letter or digit.
SELECT_SCALE
SELECT_STROKE_WIDTH
SSH_PROXY_SUBCMD
SVG_FONT_Y_ADJUST_OF_FONT_SIZE
Fudge factor
SVG_SCALE
SYNCH_LOGENTRY_PREFIX
TAU
The full circle constant (τ)

Traits

AccessId
AccountNameOrId
Any
A trait to emulate dynamic typing.
AsRawFd
A trait to extract the raw file descriptor from an underlying object.
Borrow
A trait for borrowing data.
Bounded
Numbers which have upper and lower bounds
BufRead
A BufRead is a type of Reader which has an internal buffer, allowing it to perform extra ways of reading.
ById
ClampTable
CommandExt
Unix-specific extensions to the process::Command builder.
ConstDefault
Implements a compilation time default value for the implemented type.
ConstantTimeEq
An Eq-like trait that produces a Choice instead of a bool.
Context
Provides the context method for Result.
Debug
? formatting.
DebugExt
DebugIdentify
Deref
Used for immutable dereferencing operations, like *v.
DerefMut
Used for mutable dereferencing operations, like in *v = 1;.
Deserialize
A data structure that can be deserialized from any data format supported by Serde.
DeserializeOwned
A data structure that can be deserialized without borrowing any data from the deserializer.
Deserializer
A data format that can deserialize any data structure supported by Serde.
Digest
Convenience wrapper trait covering functionality of cryptographic hash functions with fixed output size.
Display
Format trait for an empty format, {}.
Downcast
Supports conversion to Any. Traits to be extended by impl_downcast! must extend Downcast.
DynCastExt
Simplifies the use of the DynCast trait by abstracting away the difference between different ways of storing trait objects.
Enum
Enum mapping type.
EnumCount
A trait for capturing the number of variants in Enum. This trait can be autoderived by strum_macros.
EnumMessage
Associates additional pieces of information with an Enum. This can be autoimplemented by deriving EnumMessage and annotating your variants with #[strum(message="...")].
EnumProperty
EnumProperty is a trait that makes it possible to store additional information with enum variants. This trait is designed to be used with the macro of the same name in the strum_macros crate. Currently, the only string literals are supported in attributes, the other methods will be implemented as additional attribute types become stabilized.
ExitStatusExt
Unix-specific extensions to process::ExitStatus and ExitStatusError.
FileExt
Extension trait for std::fs::File which provides allocation, duplication and locking methods.
FromPrimitive
A generic trait for converting a number to a value.
FromStr
Parse a value from a string
FusedIterator
An iterator that always continues to yield None when exhausted.
Hash
A hashable type.
Hasher
A trait for hashing an arbitrary stream of bytes.
HtmlFormat
HtmlFormatRef
HtmlIteratorExt
IdForById
Index
Used for indexing operations (container[index]) in immutable contexts.
IndexMut
Used for indexing operations (container[index]) in mutable contexts.
IndexVecITExt
InertPieceTrait
IntoEnumIterator
This trait designates that an Enum can be iterated over. It can be auto generated using strum_macros on your behalf.
IntoRawFd
A trait to express the ability to consume an object and acquire ownership of its raw file descriptor.
IoTryClone
IpAddress
Itertools
An Iterator blanket implementation that provides extra adaptors and methods.
KeyDataExt
Extension trait for slotmap::KeyData, providing get_idx_version.
LocalFileExt
MetadataExt
Unix-specific extensions to fs::Metadata.
MgmtBundleListExt
OccultationViewDef
OpenOptionsExt
Unix-specific extensions to fs::OpenOptions.
Optionpiece_specsPieceLabelExt
OrdExt
OsStrExt
Platform-specific extensions to OsStr.
OutlineTrait
PermissionsExt
Unix-specific extensions to fs::Permissions.
PieceBaseTrait
PieceSpec
PieceTrait
PieceXData
PieceXDataStateExt
PlayerAccessSpec
PosPromote
Read
The Read trait allows for reading bytes from a source.
ReadBytesExt
Extends Read with methods for reading numbers. (For std::io.)
ReadDebug
ReadExt
ResultVoidErrExt
Extensions to Result<Void, E>
ResultVoidExt
Extensions to Result<T, Void>
Rng
An automatically-implemented extension trait on RngCore providing high-level generic methods for sampling values and other convenience methods.
SeekExt
Serialize
A data structure that can be serialized into any data format supported by Serde.
SerializeTuple
Returned from Serializer::serialize_tuple.
Serializer
A data format that can serialize any data structure supported by Serde.
SimplePieceSpec
SliceRandom
Extension trait on slices, providing random mutation and sampling methods.
SlotmapSparseSecondaryEntryExt
SplitAtDelim
StableIndexOffset
Types that can be used as an index for a Deque.
StructOpt
A struct that is converted from command line arguments.
Timed
TimedFdReadWrite
TimedRead
TimedWrite
ToPrimitive
A generic trait for converting a value to a number.
ToSocketAddrs
A trait for objects which can be converted or resolved to one or more SocketAddr values.
TryFrom
Simple and safe type conversions that may fail in a controlled way under some circumstances. It is the reciprocal of TryInto.
TryInto
An attempted conversion that consumes self, which may or may not be expensive.
TupleOfLinkKindRefstrExt
UnauthorisedInstanceRefAExt
VecPieceIdPieceUpdateOpsExt
VecTExt
Write
A trait for objects which are byte-oriented sinks.
WriteBytesExt
Extends Write with methods for writing numbers. (For std::io.)
WriteDebug
_
A trait for writing or formatting into Unicode-accepting buffers or streams.
anyhowErrorExt

Functions

api_op_set_z
Prepare to set the z level of gpc to z
cast
Cast from one machine scalar to another.
chain
Takes two iterables and creates a new iterator over both in sequence.
client_periodic_expiry
clock_gettime
Get the time of the specified clock, (see clock_gettime(2)).
config
consistency_check
create_occultation
dbgc_helper
default
default_edge_width
die_cooldown_path
exit
Terminates the current process with the specified exit code.
fmt_hex
game_flush_task
games_lock
internal_error_bydebug
internal_logic_error
io_copy_interactive
is_default
keydata_extract
Underlying extraction function. Fails rather than panicing.
load_accounts
load_games
log_config
log_did_to_piece
log_did_to_piece_whoby
logs_periodic_expiry
lookup_token
max
Compares and returns the maximum of two values.
min
Compares and returns the minimum of two values.
monospace_font
occultation_notify_update_image
parse_fixed_hex
parse_slice_hex
percent_decode_str
Percent-decode the given string.
piece_make_heavy
piece_pri
None => do not render at all
player_dasharray
player_num_dasharray
process_all_players_for_account
program_name
raw_angle_transform
recalculate_occultation_general
recalculate_occultation_piece
record_token
remove_occultation
repeat_with
Creates a new iterator that repeats elements of type A endlessly by applying the provided closure, the repeater, F: FnMut() -> A.
savefilename
set_program_name
sleep
Puts the current thread to sleep for at least the specified amount of time.
slotkey_parse
slotkey_write
space_rect_attrs
space_table_attrs
svg_circle_path
svg_parse_size
svg_rectangle_path
svg_rescale_path
synch_logentry
thread_rng
Retrieve the lazily-initialized thread-local random number generator, seeded by the system. Intended to be used in method chaining style, e.g. thread_rng().gen::<i32>(), or cached locally, e.g. let mut rng = thread_rng();. Invoked by the Default trait, making ThreadRng::default() equivalent.
timestring_abbreviate
toml_merge
unreachable
A safe version of intrinsincs::unreachable.
usvg_default_args
utf8_percent_encode
Percent-encode the UTF-8 encoding of the given string.
vpiece_decode
xxx
zip_eq
Iterate i and j in lock step.

Type Aliases

AE
APOE
AS
ActualIPieces
AtomicBool
A boolean type which can be safely shared between threads.
AuthorisationSuperuser
BundlesGuard
ClientMgmtChannel
Colour
Coord
ESVU
FaceColourSpecs
GPlayers
GamesGuard
GamesTable
IE
IOI
Ia
LOI
MC
ME
MGI
MGR
MR
MgmtBundleList
MultigrabQty
Mutex
A mutual exclusion primitive useful for protecting shared data
MutexGuard
An RAII implementation of a “scoped lock” of a mutex. When this structure is dropped (falls out of scope), the lock will be unlocked.
NonZeroUsize
A usize that is known not to equal zero.
NotchNumber
OccK
OccultIlkName
OccultationKind
OpHookThunk
OpOutcomeThunk
POEPP
PUE
PUE_P
PUFOS
PUM
PUO
PUOs
ParseError
A type alias for Infallible.
PieceSpecLoadedOccultable
PieceUpdateFromOpSimple
PieceUpdateOps_PerPlayer
PieceUpdateResult
PieceXDataState
PlayerUpdatesLog
Pos
PreparedPieceUpdate
PriOcculted
RawAcl
RawClientSequence
RawFaceId
RawFd
Raw file descriptors.
RawStdout
Rect
Region
RwLock
A reader-writer lock
RwLockReadGuard
RAII structure used to release the shared read access of a lock when dropped.
RwLockWriteGuard
RAII structure used to release the exclusive write access of a lock when dropped.
SecondarySlotMap
Sha512
SHA-512 hasher.
Sha512_256
SHA-512/256 hasher.
SimpleShape
SomeUnpreparedUpdates
SpE
StartupError
SvgAttrs
SvgData
SvgE
TimedFdReader
TimedFdWriter
TokenTable
UnpreparedUpdates
UoKey
UpdateFromOpComplex
VisiblePieceAngle
WRC

Attribute Macros

dyn_upcast
enum_dispatch
Annotating a trait or enum definition with an #[enum_dispatch] attribute will register it with the enum_dispatch library, allowing it to be used to generate impl blocks elsewhere.
ext
See crate docs for more info.
throws

Derive Macros

AsRefStr
Converts enum variants to &'static str.
ConstDefault
Derives an implementation for the ConstDefault trait.
Debug
Derive macro generating an impl of the trait Debug.
Deserialize
DeserializeFromStr
Deserialize value by using its FromStr implementation
Educe
Enum
Derive macro generating an implementation of trait Enum.
EnumCount
Add a constant usize equal to the number of variants.
EnumDiscriminants
Generate a new type with only the discriminant names.
EnumIter
Creates a new type that iterates of the variants of an enum.
EnumMessage
Add a verbose message to an enum variant.
EnumProperty
Add custom properties to enum variants.
EnumString
Converts strings to enum variants based on their name.
Error
FromPrimitive
Derives num_traits::FromPrimitive for simple enums and newtypes.
Hash
Derive macro generating an impl of the trait Hash.
IntoOwned
IntoStaticStr
Implements From<MyEnum> for &'static str on an enum.
Serialize
SerializeDisplay
Serialize value by using it’s Display implementation
StructOpt
Generates the StructOpt impl.
ToPrimitive
Derives num_traits::ToPrimitive for simple enums and newtypes.