pub struct Waiter<'c, G>where
G: RelockMutexGuard,{ /* private fields */ }Expand description
Future for waiting, from wait_baton
See wait_baton for information about the results of awaiting this.
This type definition could be useful if a named type is wanted.