Implementations of io::Write to transparently handle base64.
Structs
- Encoder
String Writer - A
Writeimplementation that base64-encodes data using the provided config and accumulates the resulting base64 in memory, which is then exposed as a String viainto_inner(). - Encoder
Writer - A
Writeimplementation that base64 encodes data before delegating to the wrapped writer.