pub struct Cursor<'a, K, V>where
K: 'a,
V: 'a,{ /* private fields */ }๐ฌThis is a nightly-only experimental API. (
btree_cursors)Expand description
A cursor over a BTreeMap.
A Cursor is like an iterator, except that it can freely seek back-and-forth.
Cursors always point to a gap between two elements in the map, and can operate on the two immediately adjacent elements.
A Cursor is created with the BTreeMap::lower_bound and BTreeMap::upper_bound methods.
Implementations
Sourceimpl<'a, K, V> Cursor<'a, K, V>
impl<'a, K, V> Cursor<'a, K, V>
Sourcepub fn next(&mut self) -> Option<(&'a K, &'a V)>
๐ฌThis is a nightly-only experimental API. (btree_cursors)
pub fn next(&mut self) -> Option<(&'a K, &'a V)>
btree_cursors)Advances the cursor to the next gap, returning the key and value of the element that it moved over.
If the cursor is already at the end of the map then None is returned
and the cursor is not moved.
Sourcepub fn prev(&mut self) -> Option<(&'a K, &'a V)>
๐ฌThis is a nightly-only experimental API. (btree_cursors)
pub fn prev(&mut self) -> Option<(&'a K, &'a V)>
btree_cursors)Advances the cursor to the previous gap, returning the key and value of the element that it moved over.
If the cursor is already at the start of the map then None is returned
and the cursor is not moved.