CursorMutKey

Struct CursorMutKey 

pub struct CursorMutKey<'a, K, V, A = Global>
where K: 'a, V: 'a,
{ /* private fields */ }
๐Ÿ”ฌThis is a nightly-only experimental API. (btree_cursors)
A cursor over a BTreeMap with editing operations, and which allows mutating the key of elements.

A Cursor is like an iterator, except that it can freely seek back-and-forth, and can safely mutate the map during iteration. This is because the lifetime of its yielded references is tied to its own lifetime, instead of just the underlying map. This means cursors cannot yield multiple elements at once.

Cursors always point to a gap between two elements in the map, and can operate on the two immediately adjacent elements.

A CursorMutKey is created from a CursorMut with the CursorMut::with_mutable_key method.

Safety

Since this cursor allows mutating keys, you must ensure that the BTreeMap invariants are maintained. Specifically:

  • The key of the newly inserted element must be unique in the tree.
  • All keys in the tree must remain in sorted order.

Implementations

Source

impl<'a, K, V, A> CursorMutKey<'a, K, V, A>

pub fn next(&mut self) -> Option<(&mut K, &mut V)>

๐Ÿ”ฌThis is a nightly-only experimental API. (btree_cursors)

Advances the cursor to the next gap, returning the key and value of the element that it moved over.

If the cursor is already at the end of the map then None is returned and the cursor is not moved.

pub fn prev(&mut self) -> Option<(&mut K, &mut V)>

๐Ÿ”ฌThis is a nightly-only experimental API. (btree_cursors)

Advances the cursor to the previous gap, returning the key and value of the element that it moved over.

If the cursor is already at the start of the map then None is returned and the cursor is not moved.

pub fn peek_next(&mut self) -> Option<(&mut K, &mut V)>

๐Ÿ”ฌThis is a nightly-only experimental API. (btree_cursors)

Returns a reference to the key and value of the next element without moving the cursor.

If the cursor is at the end of the map then None is returned.

pub fn peek_prev(&mut self) -> Option<(&mut K, &mut V)>

๐Ÿ”ฌThis is a nightly-only experimental API. (btree_cursors)

Returns a reference to the key and value of the previous element without moving the cursor.

If the cursor is at the start of the map then None is returned.

pub fn as_cursor(&self) -> Cursor<'_, K, V>

๐Ÿ”ฌThis is a nightly-only experimental API. (btree_cursors)

Returns a read-only cursor pointing to the same location as the CursorMutKey.

The lifetime of the returned Cursor is bound to that of the CursorMutKey, which means it cannot outlive the CursorMutKey and that the CursorMutKey is frozen for the lifetime of the Cursor.

Source

impl<'a, K, V, A> CursorMutKey<'a, K, V, A>
where K: Ord, A: Allocator + Clone,

pub unsafe fn insert_after_unchecked(&mut self, key: K, value: V)

๐Ÿ”ฌThis is a nightly-only experimental API. (btree_cursors)

Inserts a new key-value pair into the map in the gap that the cursor is currently pointing to.

After the insertion the cursor will be pointing at the gap before the newly inserted element.

Safety

You must ensure that the BTreeMap invariants are maintained. Specifically:

  • The key of the newly inserted element must be unique in the tree.
  • All keys in the tree must remain in sorted order.
pub unsafe fn insert_before_unchecked(&mut self, key: K, value: V)

๐Ÿ”ฌThis is a nightly-only experimental API. (btree_cursors)

Inserts a new key-value pair into the map in the gap that the cursor is currently pointing to.

After the insertion the cursor will be pointing at the gap after the newly inserted element.

Safety

You must ensure that the BTreeMap invariants are maintained. Specifically:

  • The key of the newly inserted element must be unique in the tree.
  • All keys in the tree must remain in sorted order.
pub fn insert_after( &mut self, key: K, value: V, ) -> Result<(), UnorderedKeyError>

๐Ÿ”ฌThis is a nightly-only experimental API. (btree_cursors)

Inserts a new key-value pair into the map in the gap that the cursor is currently pointing to.

After the insertion the cursor will be pointing at the gap before the newly inserted element.

If the inserted key is not greater than the key before the cursor (if any), or if it not less than the key after the cursor (if any), then an UnorderedKeyError is returned since this would invalidate the Ord invariant between the keys of the map.

pub fn insert_before( &mut self, key: K, value: V, ) -> Result<(), UnorderedKeyError>

๐Ÿ”ฌThis is a nightly-only experimental API. (btree_cursors)

Inserts a new key-value pair into the map in the gap that the cursor is currently pointing to.

After the insertion the cursor will be pointing at the gap after the newly inserted element.

If the inserted key is not greater than the key before the cursor (if any), or if it not less than the key after the cursor (if any), then an UnorderedKeyError is returned since this would invalidate the Ord invariant between the keys of the map.

pub fn remove_next(&mut self) -> Option<(K, V)>

๐Ÿ”ฌThis is a nightly-only experimental API. (btree_cursors)

Removes the next element from the BTreeMap.

The element that was removed is returned. The cursor position is unchanged (before the removed element).

pub fn remove_prev(&mut self) -> Option<(K, V)>

๐Ÿ”ฌThis is a nightly-only experimental API. (btree_cursors)

Removes the preceding element from the BTreeMap.

The element that was removed is returned. The cursor position is unchanged (after the removed element).