OccupiedEntry

Struct OccupiedEntry 

pub struct OccupiedEntry<'a, T, A = Global>
where A: Allocator + Clone,
{ /* private fields */ }
๐Ÿ”ฌThis is a nightly-only experimental API. (btree_set_entry)
A view into an occupied entry in a BTreeSet. It is part of the Entry enum.

Examples

#![feature(btree_set_entry)]

use std::collections::btree_set::{Entry, BTreeSet};

let mut set = BTreeSet::new();
set.extend(["a", "b", "c"]);

let _entry_o = set.entry("a").insert();
assert_eq!(set.len(), 3);

// Existing key
match set.entry("a") {
    Entry::Vacant(_) => unreachable!(),
    Entry::Occupied(view) => {
        assert_eq!(view.get(), &"a");
    }
}

assert_eq!(set.len(), 3);

// Existing key (take)
match set.entry("c") {
    Entry::Vacant(_) => unreachable!(),
    Entry::Occupied(view) => {
        assert_eq!(view.remove(), "c");
    }
}
assert_eq!(set.get(&"c"), None);
assert_eq!(set.len(), 2);

Implementations

Source

impl<'a, T, A> OccupiedEntry<'a, T, A>
where T: Ord, A: Allocator + Clone,

pub fn get(&self) -> &T

๐Ÿ”ฌThis is a nightly-only experimental API. (btree_set_entry)

Gets a reference to the value in the entry.

Examples
#![feature(btree_set_entry)]

use std::collections::btree_set::{Entry, BTreeSet};

let mut set = BTreeSet::new();
set.entry("poneyland").or_insert();

match set.entry("poneyland") {
    Entry::Vacant(_) => panic!(),
    Entry::Occupied(entry) => assert_eq!(entry.get(), &"poneyland"),
}
pub fn remove(self) -> T

๐Ÿ”ฌThis is a nightly-only experimental API. (btree_set_entry)

Takes the value out of the entry, and returns it.

Examples
#![feature(btree_set_entry)]

use std::collections::BTreeSet;
use std::collections::btree_set::Entry;

let mut set = BTreeSet::new();
set.entry("poneyland").or_insert();

if let Entry::Occupied(o) = set.entry("poneyland") {
    assert_eq!(o.remove(), "poneyland");
}

assert_eq!(set.contains("poneyland"), false);