pub struct IndexedZip { /* private fields */ }Implementations
Methods from Deref<Target = ZipArchive<BufReader<File>>>
Sourcepub fn extract<P>(&mut self, directory: P) -> Result<(), ZipError>
pub fn extract<P>(&mut self, directory: P) -> Result<(), ZipError>
Extract a Zip archive into a directory, overwriting files if they
already exist. Paths are sanitized with ZipFile::enclosed_name.
Extraction is not atomic; If an error is encountered, some of the files may be left on disk.
Sourcepub fn offset(&self) -> u64
pub fn offset(&self) -> u64
Get the offset from the beginning of the underlying reader that this zip begins at, in bytes.
Normally this value is zero, but if the zip has arbitrary data prepended to it, then this value will be the size of that prepended data.
Sourcepub fn file_names(&self) -> impl Iterator<Item = &str>
pub fn file_names(&self) -> impl Iterator<Item = &str>
Returns an iterator over all the file and directory names in this archive.
Sourcepub fn by_name_decrypt<'a>(
&'a mut self,
name: &str,
password: &[u8],
) -> Result<Result<ZipFile<'a>, InvalidPassword>, ZipError>
pub fn by_name_decrypt<'a>( &'a mut self, name: &str, password: &[u8], ) -> Result<Result<ZipFile<'a>, InvalidPassword>, ZipError>
Search for a file entry by name, decrypt with given password
Warning
The implementation of the cryptographic algorithms has not gone through a correctness review, and you should assume it is insecure: passwords used with this API may be compromised.
This function sometimes accepts wrong password. This is because the ZIP spec only allows us to check for a 1/256 chance that the password is correct. There are many passwords out there that will also pass the validity checks we are able to perform. This is a weakness of the ZipCrypto algorithm, due to its fairly primitive approach to cryptography.
Sourcepub fn by_name<'a>(&'a mut self, name: &str) -> Result<ZipFile<'a>, ZipError>
pub fn by_name<'a>(&'a mut self, name: &str) -> Result<ZipFile<'a>, ZipError>
Search for a file entry by name
Sourcepub fn by_index_decrypt<'a>(
&'a mut self,
file_number: usize,
password: &[u8],
) -> Result<Result<ZipFile<'a>, InvalidPassword>, ZipError>
pub fn by_index_decrypt<'a>( &'a mut self, file_number: usize, password: &[u8], ) -> Result<Result<ZipFile<'a>, InvalidPassword>, ZipError>
Get a contained file by index, decrypt with given password
Warning
The implementation of the cryptographic algorithms has not gone through a correctness review, and you should assume it is insecure: passwords used with this API may be compromised.
This function sometimes accepts wrong password. This is because the ZIP spec only allows us to check for a 1/256 chance that the password is correct. There are many passwords out there that will also pass the validity checks we are able to perform. This is a weakness of the ZipCrypto algorithm, due to its fairly primitive approach to cryptography.