Struct otter_nodejs_tests::bundles::ZipIndex
source · [−]pub struct ZipIndex(pub usize);Tuple Fields
0: usizeTrait Implementations
sourceimpl Ord for ZipIndex
impl Ord for ZipIndex
sourceimpl PartialOrd<ZipIndex> for ZipIndex
impl PartialOrd<ZipIndex> for ZipIndex
sourcefn partial_cmp(&self, other: &ZipIndex) -> Option<Ordering>
fn partial_cmp(&self, other: &ZipIndex) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Copy for ZipIndex
impl Eq for ZipIndex
impl StructuralEq for ZipIndex
impl StructuralPartialEq for ZipIndex