pub struct ConcreteDynCastConfig<S, T>{ /* private fields */ }Expand description
This is an implementation detail for the macros that implement DynCast.
Used to create a specify a “config” type when only the source and target traits are known.
This type implements DynCastConfig and there is a blanket implementation
of DynCast so that if DynCast is implemented for
ConcreteDynCastConfig<dyn Source, dyn Target> then DynCast is implemented
for all “config” types that implement
DynCastConfig<Source = dyn Source, Target = dyn Target>.