pub struct DelayedFormat<I> { /* private fields */ }Expand description
A temporary object which can be used as an argument to format! or others.
This is normally constructed via format methods of each date and time type.
Implementations
Sourceimpl<'a, I, B> DelayedFormat<I>
impl<'a, I, B> DelayedFormat<I>
Sourcepub fn new(
date: Option<NaiveDate>,
time: Option<NaiveTime>,
items: I,
) -> DelayedFormat<I>
pub fn new( date: Option<NaiveDate>, time: Option<NaiveTime>, items: I, ) -> DelayedFormat<I>
Makes a new DelayedFormat value out of local date and time.
Sourcepub fn new_with_offset<Off>(
date: Option<NaiveDate>,
time: Option<NaiveTime>,
offset: &Off,
items: I,
) -> DelayedFormat<I>
pub fn new_with_offset<Off>( date: Option<NaiveDate>, time: Option<NaiveTime>, offset: &Off, items: I, ) -> DelayedFormat<I>
Makes a new DelayedFormat value out of local date and time and UTC offset.
Sourcepub fn write_to(&self, w: &mut (impl Write + ?Sized)) -> Result<(), Error>
pub fn write_to(&self, w: &mut (impl Write + ?Sized)) -> Result<(), Error>
Formats DelayedFormat into a core::fmt::Write instance.
Errors
This function returns a core::fmt::Error if formatting into the core::fmt::Write instance fails.
Example
Writing to a String
let dt = chrono::DateTime::from_timestamp(1643723400, 123456789).unwrap();
let df = dt.format("%Y-%m-%d %H:%M:%S%.9f");
let mut buffer = String::new();
let _ = df.write_to(&mut buffer);Trait Implementations
Sourceimpl<I> Debug for DelayedFormat<I>where
I: Debug,
impl<I> Debug for DelayedFormat<I>where
I: Debug,