Ord

Trait Ord 

1.0.0 (const: unstable) · Source
pub trait Ord: Eq + PartialOrd {
    // Required method
    fn cmp(&self, other: &Self) -> Ordering;

    // Provided methods
    fn max(self, other: Self) -> Self
       where Self: Sized { ... }
    fn min(self, other: Self) -> Self
       where Self: Sized { ... }
    fn clamp(self, min: Self, max: Self) -> Self
       where Self: Sized { ... }
}
Trait for types that form a total order.

Implementations must be consistent with the PartialOrd implementation, and ensure max, min, and clamp are consistent with cmp:

  • partial_cmp(a, b) == Some(cmp(a, b)).
  • max(a, b) == max_by(a, b, cmp) (ensured by the default implementation).
  • min(a, b) == min_by(a, b, cmp) (ensured by the default implementation).
  • For a.clamp(min, max), see the method docs (ensured by the default implementation).

Violating these requirements is a logic error. The behavior resulting from a logic error is not specified, but users of the trait must ensure that such logic errors do not result in undefined behavior. This means that unsafe code must not rely on the correctness of these methods.

Corollaries

From the above and the requirements of PartialOrd, it follows that for all a, b and c:

  • exactly one of a < b, a == b or a > b is true; and
  • < is transitive: a < b and b < c implies a < c. The same must hold for both == and >.

Mathematically speaking, the < operator defines a strict weak order. In cases where == conforms to mathematical equality, it also defines a strict total order.

Derivable

This trait can be used with #[derive].

When derived on structs, it will produce a lexicographic ordering based on the top-to-bottom declaration order of the struct’s members.

When derived on enums, variants are ordered primarily by their discriminants. Secondarily, they are ordered by their fields. By default, the discriminant is smallest for variants at the top, and largest for variants at the bottom. Here’s an example:

#[derive(PartialEq, Eq, PartialOrd, Ord)]
enum E {
    Top,
    Bottom,
}

assert!(E::Top < E::Bottom);

However, manually setting the discriminants can override this default behavior:

#[derive(PartialEq, Eq, PartialOrd, Ord)]
enum E {
    Top = 2,
    Bottom = 1,
}

assert!(E::Bottom < E::Top);

Lexicographical comparison

Lexicographical comparison is an operation with the following properties:

  • Two sequences are compared element by element.
  • The first mismatching element defines which sequence is lexicographically less or greater than the other.
  • If one sequence is a prefix of another, the shorter sequence is lexicographically less than the other.
  • If two sequences have equivalent elements and are of the same length, then the sequences are lexicographically equal.
  • An empty sequence is lexicographically less than any non-empty sequence.
  • Two empty sequences are lexicographically equal.

How can I implement Ord?

Ord requires that the type also be PartialOrd, PartialEq, and Eq.

Because Ord implies a stronger ordering relationship than PartialOrd, and both Ord and PartialOrd must agree, you must choose how to implement Ord first. You can choose to derive it, or implement it manually. If you derive it, you should derive all four traits. If you implement it manually, you should manually implement all four traits, based on the implementation of Ord.

Here’s an example where you want to define the Character comparison by health and experience only, disregarding the field mana:

use std::cmp::Ordering;

struct Character {
    health: u32,
    experience: u32,
    mana: f32,
}

impl Ord for Character {
    fn cmp(&self, other: &Self) -> Ordering {
        self.experience
            .cmp(&other.experience)
            .then(self.health.cmp(&other.health))
    }
}

impl PartialOrd for Character {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.cmp(other))
    }
}

impl PartialEq for Character {
    fn eq(&self, other: &Self) -> bool {
        self.health == other.health && self.experience == other.experience
    }
}

impl Eq for Character {}

If all you need is to slice::sort a type by a field value, it can be simpler to use slice::sort_by_key.

Examples of incorrect Ord implementations

use std::cmp::Ordering;

#[derive(Debug)]
struct Character {
    health: f32,
}

impl Ord for Character {
    fn cmp(&self, other: &Self) -> std::cmp::Ordering {
        if self.health < other.health {
            Ordering::Less
        } else if self.health > other.health {
            Ordering::Greater
        } else {
            Ordering::Equal
        }
    }
}

impl PartialOrd for Character {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.cmp(other))
    }
}

impl PartialEq for Character {
    fn eq(&self, other: &Self) -> bool {
        self.health == other.health
    }
}

impl Eq for Character {}

let a = Character { health: 4.5 };
let b = Character { health: f32::NAN };

// Mistake: floating-point values do not form a total order and using the built-in comparison
// operands to implement `Ord` irregardless of that reality does not change it. Use
// `f32::total_cmp` if you need a total order for floating-point values.

// Reflexivity requirement of `Ord` is not given.
assert!(a == a);
assert!(b != b);

// Antisymmetry requirement of `Ord` is not given. Only one of a < c and c < a is allowed to be
// true, not both or neither.
assert_eq!((a < b) as u8 + (b < a) as u8, 0);
use std::cmp::Ordering;

#[derive(Debug)]
struct Character {
    health: u32,
    experience: u32,
}

impl PartialOrd for Character {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
        Some(self.cmp(other))
    }
}

impl Ord for Character {
    fn cmp(&self, other: &Self) -> std::cmp::Ordering {
        if self.health < 50 {
            self.health.cmp(&other.health)
        } else {
            self.experience.cmp(&other.experience)
        }
    }
}

// For performance reasons implementing `PartialEq` this way is not the idiomatic way, but it
// ensures consistent behavior between `PartialEq`, `PartialOrd` and `Ord` in this example.
impl PartialEq for Character {
    fn eq(&self, other: &Self) -> bool {
        self.cmp(other) == Ordering::Equal
    }
}

impl Eq for Character {}

let a = Character {
    health: 3,
    experience: 5,
};
let b = Character {
    health: 10,
    experience: 77,
};
let c = Character {
    health: 143,
    experience: 2,
};

// Mistake: The implementation of `Ord` compares different fields depending on the value of
// `self.health`, the resulting order is not total.

// Transitivity requirement of `Ord` is not given. If a is smaller than b and b is smaller than
// c, by transitive property a must also be smaller than c.
assert!(a < b && b < c && c < a);

// Antisymmetry requirement of `Ord` is not given. Only one of a < c and c < a is allowed to be
// true, not both or neither.
assert_eq!((a < c) as u8 + (c < a) as u8, 2);

The documentation of PartialOrd contains further examples, for example it’s wrong for PartialOrd and PartialEq to disagree.

Required Methods

1.0.0 (const: unstable) · Source

fn cmp(&self, other: &Self) -> Ordering

This method returns an Ordering between self and other.

By convention, self.cmp(&other) returns the ordering matching the expression self <operator> other if true.

Examples
use std::cmp::Ordering;

assert_eq!(5.cmp(&10), Ordering::Less);
assert_eq!(10.cmp(&5), Ordering::Greater);
assert_eq!(5.cmp(&5), Ordering::Equal);

Provided Methods

1.21.0 (const: unstable) · Source

fn max(self, other: Self) -> Self
where Self: Sized,

Compares and returns the maximum of two values.

Returns the second argument if the comparison determines them to be equal.

Examples
assert_eq!(1.max(2), 2);
assert_eq!(2.max(2), 2);
use std::cmp::Ordering;

#[derive(Eq)]
struct Equal(&'static str);

impl PartialEq for Equal {
    fn eq(&self, other: &Self) -> bool { true }
}
impl PartialOrd for Equal {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> { Some(Ordering::Equal) }
}
impl Ord for Equal {
    fn cmp(&self, other: &Self) -> Ordering { Ordering::Equal }
}

assert_eq!(Equal("self").max(Equal("other")).0, "other");
1.21.0 (const: unstable) · Source

fn min(self, other: Self) -> Self
where Self: Sized,

Compares and returns the minimum of two values.

Returns the first argument if the comparison determines them to be equal.

Examples
assert_eq!(1.min(2), 1);
assert_eq!(2.min(2), 2);
use std::cmp::Ordering;

#[derive(Eq)]
struct Equal(&'static str);

impl PartialEq for Equal {
    fn eq(&self, other: &Self) -> bool { true }
}
impl PartialOrd for Equal {
    fn partial_cmp(&self, other: &Self) -> Option<Ordering> { Some(Ordering::Equal) }
}
impl Ord for Equal {
    fn cmp(&self, other: &Self) -> Ordering { Ordering::Equal }
}

assert_eq!(Equal("self").min(Equal("other")).0, "self");
1.50.0 (const: unstable) · Source

fn clamp(self, min: Self, max: Self) -> Self
where Self: Sized,

Restrict a value to a certain interval.

Returns max if self is greater than max, and min if self is less than min. Otherwise this returns self.

Panics

Panics if min > max.

Examples
assert_eq!((-3).clamp(-2, 1), -2);
assert_eq!(0.clamp(-2, 1), 0);
assert_eq!(2.clamp(-2, 1), 1);

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Ord for Kind

Source

impl Ord for Month

Source

impl Ord for AccountScope

Source

impl Ord for otter_nodejs_tests::BigEndian

1.0.0 · Source

impl Ord for ErrorKind

1.34.0 (const: unstable) · Source

impl Ord for Infallible

1.7.0 · Source

impl Ord for IpAddr

Source

impl Ord for LinkKind

Source

impl Ord for otter_nodejs_tests::LittleEndian

Source

impl Ord for OccultationKindGeneral<(OccDisplacement, ZCoord)>

1.0.0 (const: unstable) · Source

impl Ord for Ordering

Source

impl Ord for PieceMoveable

Source

impl Ord for ProgressUpdateMode

1.0.0 · Source

impl Ord for SocketAddr

Source

impl Ord for TablePermission

Source

impl Ord for otter_nodejs_tests::flexi_logger::Level

Source

impl Ord for otter_nodejs_tests::flexi_logger::LevelFilter

Source

impl Ord for AsciiChar

Source

impl Ord for CharCase

Source

impl Ord for Ipv6MulticastScope

Source

impl Ord for PosixFadviseAdvice

Source

impl Ord for AioFsyncMode

Source

impl Ord for LioMode

Source

impl Ord for LioOpcode

Source

impl Ord for MmapAdvise

Source

impl Ord for Event

Source

impl Ord for Request

Source

impl Ord for QuotaFmt

Source

impl Ord for QuotaType

Source

impl Ord for RebootMode

Source

impl Ord for Resource

Source

impl Ord for SigmaskHow

Source

impl Ord for Signal

Source

impl Ord for BaudRate

Source

impl Ord for FlowArg

Source

impl Ord for FlushArg

Source

impl Ord for SetArg

Source

impl Ord for SpecialCharacterIndices

Source

impl Ord for otter_nodejs_tests::nix::sys::timerfd::ClockId

Source

impl Ord for otter_nodejs_tests::nix::sys::wait::Id

Source

impl Ord for LineEnding

Source

impl Ord for console::utils::Attribute

Source

impl Ord for SectionId

Source

impl Ord for ColumnType

Source

impl Ord for ExtensionType

Source

impl Ord for GeneralCategory

Source

impl Ord for IpAddrRange

Source

impl Ord for IpNet

Source

impl Ord for IpSubnets

Source

impl Ord for RecursiveMode

Source

impl Ord for Sign

Source

impl Ord for StaticUser

Source

impl Ord for Encoding

Source

impl Ord for Algorithm

Source

impl Ord for Utf8Sequence

Source

impl Ord for Direction

Source

impl Ord for zerocopy::byteorder::BigEndian

Source

impl Ord for zerocopy::byteorder::LittleEndian

1.0.0 (const: unstable) · Source

impl Ord for bool

1.0.0 (const: unstable) · Source

impl Ord for char

1.0.0 (const: unstable) · Source

impl Ord for i8

1.0.0 (const: unstable) · Source

impl Ord for i16

1.0.0 (const: unstable) · Source

impl Ord for i32

1.0.0 (const: unstable) · Source

impl Ord for i64

1.0.0 (const: unstable) · Source

impl Ord for i128

1.0.0 (const: unstable) · Source

impl Ord for isize

Source

impl Ord for !

1.0.0 · Source

impl Ord for str

Implements ordering of strings.

Strings are ordered lexicographically by their byte values. This orders Unicode code points based on their positions in the code charts. This is not necessarily the same as “alphabetical” order, which varies by language and locale. Sorting strings according to culturally-accepted standards requires locale-specific data that is outside the scope of the str type.

1.0.0 (const: unstable) · Source

impl Ord for u8

1.0.0 (const: unstable) · Source

impl Ord for u16

1.0.0 (const: unstable) · Source

impl Ord for u32

1.0.0 (const: unstable) · Source

impl Ord for u64

1.0.0 (const: unstable) · Source

impl Ord for u128

1.0.0 (const: unstable) · Source

impl Ord for ()

1.0.0 (const: unstable) · Source

impl Ord for usize

Source

impl Ord for otter_nodejs_tests::bundles::Id

Source

impl Ord for Index

Source

impl Ord for LibInBundleI

Source

impl Ord for ZipIndex

Source

impl Ord for NaiveDateDaysIterator

Source

impl Ord for NaiveDateWeeksIterator

Source

impl Ord for Days

Source

impl Ord for IsoWeek

Source

impl Ord for Months

Source

impl Ord for NaiveDate

Source

impl Ord for NaiveDateTime

Source

impl Ord for NaiveTime

Source

impl Ord for TimeDelta

Source

impl Ord for WeekdaySet

Source

impl Ord for ATerm

Source

impl Ord for B0

Source

impl Ord for B1

Source

impl Ord for Equal

Source

impl Ord for Greater

Source

impl Ord for Less

Source

impl Ord for UTerm

Source

impl Ord for Z0

1.0.0 · Source

impl Ord for Error

Source

impl Ord for MatchOptions

Source

impl Ord for Pattern

Source

impl Ord for otter_nodejs_tests::humantime::Duration

Source

impl Ord for otter_nodejs_tests::humantime::Timestamp

1.0.0 · Source

impl Ord for TypeId

1.27.0 · Source

impl Ord for CpuidResult

Source

impl Ord for ByteStr

1.0.0 · Source

impl Ord for CStr

1.33.0 · Source

impl Ord for PhantomPinned

1.0.0 · Source

impl Ord for SocketAddrV4

1.0.0 · Source

impl Ord for SocketAddrV6

1.10.0 · Source

impl Ord for Location<'_>

Source

impl Ord for Unsupported

Source

impl Ord for otter_nodejs_tests::materials_format::Version

Source

impl Ord for AtFlags

Source

impl Ord for FallocateFlags

Source

impl Ord for otter_nodejs_tests::nix::fcntl::FdFlag

Source

impl Ord for OFlag

Source

impl Ord for RenameFlags

Source

impl Ord for SealFlag

Source

impl Ord for SpliceFFlags

Source

impl Ord for DeleteModuleFlags

Source

impl Ord for ModuleInitFlags

Source

impl Ord for MntFlags

Source

impl Ord for otter_nodejs_tests::nix::mount::MsFlags

Source

impl Ord for otter_nodejs_tests::nix::mqueue::FdFlag

Source

impl Ord for MQ_OFlag

Source

impl Ord for InterfaceFlags

Source

impl Ord for PollFlags

Source

impl Ord for CloneFlags

Source

impl Ord for EpollCreateFlags

Source

impl Ord for EpollFlags

Source

impl Ord for EfdFlags

Source

impl Ord for AddWatchFlags

Source

impl Ord for InitFlags

Source

impl Ord for WatchDescriptor

Source

impl Ord for MemFdCreateFlag

Source

impl Ord for MRemapFlags

Source

impl Ord for MapFlags

Source

impl Ord for MlockAllFlags

Source

impl Ord for otter_nodejs_tests::nix::sys::mman::MsFlags

Source

impl Ord for ProtFlags

Source

impl Ord for Persona

Source

impl Ord for Options

Source

impl Ord for QuotaValidFlags

Source

impl Ord for SaFlags

Source

impl Ord for SfdFlags

Source

impl Ord for MsgFlags

Source

impl Ord for SockFlag

Source

impl Ord for TimestampingFlag

Source

impl Ord for Mode

Source

impl Ord for SFlag

Source

impl Ord for FsFlags

Source

impl Ord for ControlFlags

Source

impl Ord for InputFlags

Source

impl Ord for LocalFlags

Source

impl Ord for OutputFlags

Source

impl Ord for TimeVal

Source

impl Ord for TimerFlags

Source

impl Ord for TimerSetTimeFlags

Source

impl Ord for WaitPidFlag

Source

impl Ord for otter_nodejs_tests::nix::time::ClockId

Source

impl Ord for AccessFlags

Source

impl Ord for Pid

Source

impl Ord for Alignment

Source

impl Ord for DescId

Source

impl Ord for SvgId

Source

impl Ord for DefaultKey

Source

impl Ord for KeyData

Source

impl Ord for Fingerprint

Source

impl Ord for otter_nodejs_tests::sshkeys::Id

Source

impl Ord for KeySpec

Source

impl Ord for Nonce

Source

impl Ord for AccountId

Source

impl Ord for AccountName

Source

impl Ord for AccountNotFound

Source

impl Ord for ClientId

1.3.0 · Source

impl Ord for otter_nodejs_tests::Duration

Source

impl Ord for FaceId

Source

impl Ord for FastSplitId

Source

impl Ord for FutureInstant

Source

impl Ord for Generation

Source

impl Ord for GoodItemName

Source

impl Ord for Html

Source

impl Ord for HtmlLit

Source

impl Ord for HtmlStr

Source

impl Ord for InstanceName

1.8.0 · Source

impl Ord for otter_nodejs_tests::Instant

1.0.0 (const: unstable) · Source

impl Ord for Ipv4Addr

1.0.0 (const: unstable) · Source

impl Ord for Ipv6Addr

Source

impl Ord for ItemEnquiryData

Source

impl Ord for LibraryEnquiryData

Source

impl Ord for Notch

Source

impl Ord for OccId

Source

impl Ord for OccultIlkId

1.0.0 · Source

impl Ord for OsStr

1.0.0 · Source

impl Ord for PathBuf

Source

impl Ord for PieceId

Source

impl Ord for PlayerId

Source

impl Ord for PlayerNotFound

Source

impl Ord for RawToken

Source

impl Ord for RawTokenVal

Source

impl Ord for SpecDepth

Source

impl Ord for TimeSpec

Source

impl Ord for otter_nodejs_tests::Timestamp

Source

impl Ord for TokenRevelationKey

Source

impl Ord for UpdateId

Source

impl Ord for Url

URLs compare like their serialization.

Source

impl Ord for UrlSpec

Source

impl Ord for VisiblePieceId

Source

impl Ord for ZCoord

Source

impl Ord for ZLevel

1.8.0 · Source

impl Ord for SystemTime

Source

impl Ord for LimbVal

Source

impl Ord for ByteString

1.64.0 · Source

impl Ord for CString

1.0.0 · Source

impl Ord for String

1.0.0 · Source

impl Ord for OsString

1.0.0 · Source

impl Ord for Components<'_>

1.0.0 · Source

impl Ord for Path

1.0.0 · Source

impl Ord for PrefixComponent<'_>

Source

impl Ord for aho_corasick::util::primitives::PatternID

Source

impl Ord for aho_corasick::util::primitives::StateID

Source

impl Ord for Base64Bcrypt

Source

impl Ord for Base64Crypt

Source

impl Ord for Base64Pbkdf2

Source

impl Ord for Base64ShaCrypt

Source

impl Ord for Base64

Source

impl Ord for Base64Unpadded

Source

impl Ord for Base64Url

Source

impl Ord for Base64UrlUnpadded

Source

impl Ord for BStr

Source

impl Ord for BString

Source

impl Ord for bytes::bytes::Bytes

Source

impl Ord for BytesMut

Source

impl Ord for FileTime

Source

impl Ord for Register

Source

impl Ord for DwAccess

Source

impl Ord for DwAddr

Source

impl Ord for DwAt

Source

impl Ord for DwAte

Source

impl Ord for DwCc

Source

impl Ord for DwCfa

Source

impl Ord for DwChildren

Source

impl Ord for DwDefaulted

Source

impl Ord for DwDs

Source

impl Ord for DwDsc

Source

impl Ord for DwEhPe

Source

impl Ord for DwEnd

Source

impl Ord for DwForm

Source

impl Ord for DwId

Source

impl Ord for DwIdx

Source

impl Ord for DwInl

Source

impl Ord for DwLang

Source

impl Ord for DwLle

Source

impl Ord for DwLnct

Source

impl Ord for DwLne

Source

impl Ord for DwLns

Source

impl Ord for DwMacinfo

Source

impl Ord for DwMacro

Source

impl Ord for DwOp

Source

impl Ord for DwOrd

Source

impl Ord for DwRle

Source

impl Ord for DwSect

Source

impl Ord for DwSectV2

Source

impl Ord for DwTag

Source

impl Ord for DwUt

Source

impl Ord for DwVirtuality

Source

impl Ord for DwVis

Source

impl Ord for ArangeEntry

Source

impl Ord for Range

Source

impl Ord for HeaderValue

Source

impl Ord for StatusCode

Source

impl Ord for http::version::Version

Source

impl Ord for ReasonPhrase

Source

impl Ord for Other

Source

impl Ord for icu_locale_core::extensions::private::other::Subtag

Source

impl Ord for Private

Source

impl Ord for Fields

Source

impl Ord for icu_locale_core::extensions::transform::key::Key

Source

impl Ord for icu_locale_core::extensions::transform::value::Value

Source

impl Ord for icu_locale_core::extensions::unicode::attribute::Attribute

Source

impl Ord for Attributes

Source

impl Ord for icu_locale_core::extensions::unicode::key::Key

Source

impl Ord for Keywords

Source

impl Ord for SubdivisionId

Source

impl Ord for SubdivisionSuffix

Source

impl Ord for icu_locale_core::extensions::unicode::value::Value

Source

impl Ord for Language

Source

impl Ord for Region

Source

impl Ord for icu_locale_core::subtags::script::Script

Source

impl Ord for icu_locale_core::subtags::Subtag

Source

impl Ord for Variant

Source

impl Ord for Variants

Source

impl Ord for GeneralCategoryULE

Source

impl Ord for BidiClass

Source

impl Ord for CanonicalCombiningClass

Source

impl Ord for EastAsianWidth

Source

impl Ord for GeneralCategoryOutOfBoundsError

Source

impl Ord for GraphemeClusterBreak

Source

impl Ord for HangulSyllableType

Source

impl Ord for IndicConjunctBreak

Source

impl Ord for IndicSyllabicCategory

Source

impl Ord for JoiningGroup

Source

impl Ord for JoiningType

Source

impl Ord for LineBreak

Source

impl Ord for NumericType

Source

impl Ord for icu_properties::props::Script

Source

impl Ord for SentenceBreak

Source

impl Ord for VerticalOrientation

Source

impl Ord for WordBreak

Source

impl Ord for DataMarkerId

Source

impl Ord for DataMarkerIdHash

Source

impl Ord for DataMarkerInfo

Source

impl Ord for DataMarkerAttributes

Source

impl Ord for DataRequestMetadata

Source

impl Ord for EventMask

Source

impl Ord for WatchMask

Source

impl Ord for Ipv4AddrRange

Source

impl Ord for Ipv6AddrRange

Source

impl Ord for Ipv4Net

Source

impl Ord for Ipv4Subnets

Source

impl Ord for Ipv6Net

Source

impl Ord for Ipv6Subnets

Source

impl Ord for Mime

Source

impl Ord for PollOpt

Source

impl Ord for mio::event_imp::Ready

Source

impl Ord for mio::interest::Interest

Source

impl Ord for mio::interest::Interest

Source

impl Ord for UnixReady

Source

impl Ord for mio::token::Token

Source

impl Ord for mio::token::Token

Source

impl Ord for mio::token::Token

Source

impl Ord for Op

Source

impl Ord for BigInt

Source

impl Ord for BigUint

Source

impl Ord for Asn1Integer

Source

impl Ord for Asn1IntegerRef

Source

impl Ord for BigNum

Source

impl Ord for BigNumRef

Source

impl Ord for CMSOptions

Source

impl Ord for OcspFlag

Source

impl Ord for Pkcs7Flags

Source

impl Ord for ExtensionContext

Source

impl Ord for ShutdownState

Source

impl Ord for SslMode

Source

impl Ord for SslOptions

Source

impl Ord for SslSessionCacheMode

Source

impl Ord for SslVerifyMode

Source

impl Ord for X509

Source

impl Ord for X509Ref

Source

impl Ord for X509CheckFlags

Source

impl Ord for X509VerifyFlags

Source

impl Ord for PIA

Source

impl Ord for PIB

Source

impl Ord for Transformations

Source

impl Ord for PotentialCodePoint

Source

impl Ord for PotentialUtf8

Source

impl Ord for PotentialUtf16

Source

impl Ord for LazyStateID

Source

impl Ord for Unit

Source

impl Ord for NonMaxUsize

Source

impl Ord for regex_automata::util::primitives::PatternID

Source

impl Ord for SmallIndex

Source

impl Ord for regex_automata::util::primitives::StateID

Source

impl Ord for regex_syntax::ast::Position

Source

impl Ord for Span

Source

impl Ord for Literal

Source

impl Ord for ClassBytesRange

Source

impl Ord for ClassUnicodeRange

Source

impl Ord for Utf8Range

Source

impl Ord for reqwest::tls::Version

Source

impl Ord for ByteBuf

Source

impl Ord for Timespec

Source

impl Ord for CommaSeparator

Source

impl Ord for SpaceSeparator

Source

impl Ord for time::date::Date

Source

impl Ord for time::duration::Duration

Source

impl Ord for time::instant::Instant

Source

impl Ord for OffsetDateTime

Source

impl Ord for PrimitiveDateTime

Source

impl Ord for Time

Source

impl Ord for UtcOffset

Source

impl Ord for AnyDelimiterCodec

Source

impl Ord for BytesCodec

Source

impl Ord for LinesCodec

Source

impl Ord for tokio::io::ready::Ready

Source

impl Ord for tokio::runtime::task::id::Id

Source

impl Ord for tokio::time::instant::Instant

Source

impl Ord for tracing_core::metadata::Level

Source

impl Ord for tracing_core::metadata::LevelFilter

Source

impl Ord for UncasedStr

Source

impl Ord for CharULE

Source

impl Ord for Index8

Source

impl Ord for Index16

Source

impl Ord for Index32

1.0.0 · Source

impl<'a> Ord for Component<'a>

1.0.0 · Source

impl<'a> Ord for Prefix<'a>

Source

impl<'a> Ord for PhantomContravariantLifetime<'a>

Source

impl<'a> Ord for PhantomCovariantLifetime<'a>

Source

impl<'a> Ord for PhantomInvariantLifetime<'a>

Source

impl<'a> Ord for Metadata<'a>

Source

impl<'a> Ord for MetadataBuilder<'a>

Source

impl<'a> Ord for Name<'a>

Source

impl<'a> Ord for Ident<'a>

Source

impl<'a> Ord for password_hash::value::Value<'a>

Source

impl<'a> Ord for rmp::decode::bytes::Bytes<'a>

Source

impl<'a, T> Ord for ZeroVec<'a, T>
where T: AsULE + Ord,

Source

impl<'a, T, F> Ord for VarZeroVec<'a, T, F>
where T: VarULE + Ord + ?Sized, F: VarZeroVecFormat,

Source

impl<'a, V> Ord for VarZeroCow<'a, V>
where V: VarULE + Ord + ?Sized,

Source

impl<'i> Ord for pest::position::Position<'i>

Source

impl<'s> Ord for TomlQuote<'s>

1.0.0 (const: unstable) · Source

impl<A> Ord for &A
where A: Ord + ?Sized,

1.0.0 (const: unstable) · Source

impl<A> Ord for &mut A
where A: Ord + ?Sized,

Source

impl<A> Ord for SmallVec<A>
where A: Array, <A as Array>::Item: Ord,

Source

impl<A, B> Ord for Tuple2ULE<A, B>
where A: Ord + ULE, B: Ord + ULE,

Source

impl<A, B> Ord for VarTuple<A, B>
where A: Ord, B: Ord,

Source

impl<A, B, C> Ord for Tuple3ULE<A, B, C>
where A: Ord + ULE, B: Ord + ULE, C: Ord + ULE,

Source

impl<A, B, C, D> Ord for Tuple4ULE<A, B, C, D>
where A: Ord + ULE, B: Ord + ULE, C: Ord + ULE, D: Ord + ULE,

Source

impl<A, B, C, D, E> Ord for Tuple5ULE<A, B, C, D, E>
where A: Ord + ULE, B: Ord + ULE, C: Ord + ULE, D: Ord + ULE, E: Ord + ULE,

Source

impl<A, B, C, D, E, F> Ord for Tuple6ULE<A, B, C, D, E, F>
where A: Ord + ULE, B: Ord + ULE, C: Ord + ULE, D: Ord + ULE, E: Ord + ULE, F: Ord + ULE,

Source

impl<A, B, C, D, E, F, Format> Ord for Tuple6VarULE<A, B, C, D, E, F, Format>
where A: Ord + VarULE + ?Sized, B: Ord + VarULE + ?Sized, C: Ord + VarULE + ?Sized, D: Ord + VarULE + ?Sized, E: Ord + VarULE + ?Sized, F: Ord + VarULE + ?Sized, Format: VarZeroVecFormat,

Source

impl<A, B, C, D, E, Format> Ord for Tuple5VarULE<A, B, C, D, E, Format>
where A: Ord + VarULE + ?Sized, B: Ord + VarULE + ?Sized, C: Ord + VarULE + ?Sized, D: Ord + VarULE + ?Sized, E: Ord + VarULE + ?Sized, Format: VarZeroVecFormat,

Source

impl<A, B, C, D, Format> Ord for Tuple4VarULE<A, B, C, D, Format>
where A: Ord + VarULE + ?Sized, B: Ord + VarULE + ?Sized, C: Ord + VarULE + ?Sized, D: Ord + VarULE + ?Sized, Format: VarZeroVecFormat,

Source

impl<A, B, C, Format> Ord for Tuple3VarULE<A, B, C, Format>
where A: Ord + VarULE + ?Sized, B: Ord + VarULE + ?Sized, C: Ord + VarULE + ?Sized, Format: VarZeroVecFormat,

Source

impl<A, B, Format> Ord for Tuple2VarULE<A, B, Format>
where A: Ord + VarULE + ?Sized, B: Ord + VarULE + ?Sized, Format: VarZeroVecFormat,

Source

impl<A, V> Ord for VarTupleULE<A, V>
where A: Ord + AsULE, V: Ord + VarULE + ?Sized, <A as AsULE>::ULE: Ord,

1.0.0 · Source

impl<B> Ord for Cow<'_, B>
where B: Ord + ToOwned + ?Sized,

Source

impl<Dyn> Ord for DynMetadata<Dyn>
where Dyn: ?Sized,

Source

impl<E> Ord for I16Bytes<E>
where E: Ord + Endian,

Source

impl<E> Ord for I32Bytes<E>
where E: Ord + Endian,

Source

impl<E> Ord for I64Bytes<E>
where E: Ord + Endian,

Source

impl<E> Ord for U16Bytes<E>
where E: Ord + Endian,

Source

impl<E> Ord for U32Bytes<E>
where E: Ord + Endian,

Source

impl<E> Ord for U64Bytes<E>
where E: Ord + Endian,

Source

impl<EntryData> Ord for VecList<EntryData>
where EntryData: Ord,

1.4.0 · Source

impl<F> Ord for F
where F: FnPtr,

Source

impl<I, T> Ord for IndexSlice<I, [T]>
where I: Idx, T: Ord,

Source

impl<I, T> Ord for IndexVec<I, T>
where I: Ord + Idx, T: Ord,

Source

impl<K, V> Ord for EnumMap<K, V>
where K: EnumArray<V>, V: Ord,

Source

impl<K, V> Ord for indexmap::map::slice::Slice<K, V>
where K: Ord, V: Ord,

1.0.0 · Source

impl<K, V, A> Ord for BTreeMap<K, V, A>
where K: Ord, V: Ord, A: Allocator + Clone,

Source

impl<K, V, S> Ord for LiteMap<K, V, S>
where K: Ord + ?Sized, V: Ord + ?Sized, S: Ord,

Source

impl<L, R> Ord for Either<L, R>
where L: Ord, R: Ord,

Source

impl<O> Ord for I16<O>
where O: ByteOrder,

Source

impl<O> Ord for I32<O>
where O: ByteOrder,

Source

impl<O> Ord for I64<O>
where O: ByteOrder,

Source

impl<O> Ord for I128<O>
where O: ByteOrder,

Source

impl<O> Ord for Isize<O>
where O: ByteOrder,

Source

impl<O> Ord for U16<O>
where O: ByteOrder,

Source

impl<O> Ord for U32<O>
where O: ByteOrder,

Source

impl<O> Ord for U64<O>
where O: ByteOrder,

Source

impl<O> Ord for U128<O>
where O: ByteOrder,

Source

impl<O> Ord for Usize<O>
where O: ByteOrder,

1.41.0 · Source

impl<Ptr> Ord for Pin<Ptr>
where Ptr: Deref, <Ptr as Deref>::Target: Ord,

Source

impl<S> Ord for Host<S>
where S: Ord,

Source

impl<Sep, T> Ord for StringWithSeparator<Sep, T>
where Sep: Ord, T: Ord,

Source

impl<Storage> Ord for __BindgenBitfieldUnit<Storage>
where Storage: Ord,

Source

impl<T> Ord for RegionC<T>
where T: Ord + Copy,

1.0.0 (const: unstable) · Source

impl<T> Ord for Option<T>
where T: Ord,

1.36.0 · Source

impl<T> Ord for Poll<T>
where T: Ord,

Source

impl<T> Ord for UnitSectionOffset<T>
where T: Ord,

1.0.0 · Source

impl<T> Ord for *const T
where T: ?Sized,

Pointer comparison is by address, as produced by the [<*const T>::addr](pointer::addr) method.

1.0.0 · Source

impl<T> Ord for *mut T
where T: ?Sized,

Pointer comparison is by address, as produced by the <*mut T>::addr method.

1.0.0 (const: unstable) · Source

impl<T> Ord for [T]
where T: Ord,

Implements comparison of slices lexicographically.

1.0.0 (const: unstable) · Source

impl<T> Ord for (T₁, T₂, …, Tₙ)
where T: Ord,

This trait is implemented for tuples up to twelve items long.

1.10.0 · Source

impl<T> Ord for Cell<T>
where T: Ord + Copy,

1.10.0 · Source

impl<T> Ord for RefCell<T>
where T: Ord + ?Sized,

Source

impl<T> Ord for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> Ord for PhantomCovariant<T>
where T: ?Sized,

Source

impl<T> Ord for PhantomInvariant<T>
where T: ?Sized,

1.28.0 (const: unstable) · Source

impl<T> Ord for NonZero<T>

1.74.0 · Source

impl<T> Ord for Saturating<T>
where T: Ord,

Source

impl<T> Ord for SyncView<T>
where T: Sync + Ord + ?Sized,

Source

impl<T> Ord for NotNan<T>
where T: Float,

Source

impl<T> Ord for CapacityError<T>
where T: Ord,

1.20.0 · Source

impl<T> Ord for ManuallyDrop<T>
where T: Ord + ?Sized,

Source

impl<T> Ord for IsHtmlFormatted<T>
where T: Ord + Display,

Source

impl<T> Ord for OrderedFloat<T>
where T: Float,

1.0.0 · Source

impl<T> Ord for PhantomData<T>
where T: ?Sized,

Source

impl<T> Ord for PosC<T>
where T: Ord,

Source

impl<T> Ord for RectC<T>
where T: Ord,

Source

impl<T> Ord for UniCase<T>
where T: AsRef<str>,

1.0.0 · Source

impl<T> Ord for Wrapping<T>
where T: Ord,

Source

impl<T> Ord for Spanned<T>
where T: Ord,

1.25.0 · Source

impl<T> Ord for NonNull<T>
where T: ?Sized,

Source

impl<T> Ord for Shared<'_, T>
where T: Pointable + ?Sized,

Source

impl<T> Ord for AllowStdIo<T>
where T: Ord,

Source

impl<T> Ord for DebugInfoOffset<T>
where T: Ord,

Source

impl<T> Ord for DebugTypesOffset<T>
where T: Ord,

Source

impl<T> Ord for UnitOffset<T>
where T: Ord,

Source

impl<T> Ord for indexmap::set::slice::Slice<T>
where T: Ord,

Source

impl<T> Ord for Ratio<T>
where T: Clone + Integer,

Source

impl<T> Ord for Ascii<T>
where T: AsRef<str>,

Source

impl<T> Ord for TryWriteableInfallibleAsWriteable<T>
where T: Ord,

Source

impl<T> Ord for WriteableAsTryWriteableInfallible<T>
where T: Ord,

Source

impl<T> Ord for Unalign<T>
where T: Unaligned + Ord,

Source

impl<T> Ord for ZeroSlice<T>
where T: AsULE + Ord,

1.19.0 (const: unstable) · Source

impl<T> Ord for Reverse<T>
where T: Ord,

1.0.0 · Source

impl<T, A> Ord for Arc<T, A>
where T: Ord + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for BTreeSet<T, A>
where T: Ord, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> Ord for VecDeque<T, A>
where T: Ord, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for Box<T, A>
where T: Ord + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for LinkedList<T, A>
where T: Ord, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for Rc<T, A>
where T: Ord + ?Sized, A: Allocator,

Source

impl<T, A> Ord for UniqueRc<T, A>
where T: Ord + ?Sized, A: Allocator,

Source

impl<T, A> Ord for UniqueArc<T, A>
where T: Ord + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Ord for Vec<T, A>
where T: Ord, A: Allocator,

Implements ordering of vectors, lexicographically.

Source

impl<T, B> Ord for Ref<B, T>

1.0.0 (const: unstable) · Source

impl<T, E> Ord for Result<T, E>
where T: Ord, E: Ord,

Source

impl<T, F> Ord for VarZeroSlice<T, F>
where T: VarULE + Ord + ?Sized, F: VarZeroVecFormat,

Source

impl<T, N> Ord for GenericArray<T, N>
where T: Ord, N: ArrayLength<T>,

Source

impl<T, const CAP: usize> Ord for ArrayVec<T, CAP>
where T: Ord,

1.0.0 (const: unstable) · Source

impl<T, const N: usize> Ord for [T; N]
where T: Ord,

Implements comparison of arrays lexicographically.

Source

impl<T, const N: usize> Ord for Simd<T, N>
where T: SimdElement + Ord,

Lexicographic order. For the SIMD elementwise minimum and maximum, use simd_min and simd_max instead.

Source

impl<T, const VARIANT: u32, const FIELD: u32> Ord for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,

Source

impl<Tz> Ord for otter_nodejs_tests::chrono::Date<Tz>
where Tz: TimeZone,

Source

impl<Tz> Ord for DateTime<Tz>
where Tz: TimeZone,

Source

impl<U> Ord for NInt<U>
where U: Ord + Unsigned + NonZero,

Source

impl<U> Ord for PInt<U>
where U: Ord + Unsigned + NonZero,

Source

impl<U> Ord for OptionVarULE<U>
where U: VarULE + Ord + ?Sized,

Source

impl<U, B> Ord for UInt<U, B>
where U: Ord, B: Ord,

Source

impl<U, const N: usize> Ord for NichedOption<U, N>
where U: Ord,

Source

impl<V> Ord for VecMap<V>
where V: Ord,

Source

impl<V, A> Ord for TArr<V, A>
where V: Ord, A: Ord,

Source

impl<Y, C> Ord for Yoke<Y, C>
where Y: for<'a> Yokeable<'a>, <Y as Yokeable<'a>>::Output: for<'a> Ord,

Source

impl<Y, R> Ord for CoroutineState<Y, R>
where Y: Ord, R: Ord,

Source

impl<const CAP: usize> Ord for ArrayString<CAP>

Source

impl<const N: usize> Ord for TinyAsciiStr<N>

Source

impl<const N: usize> Ord for UnvalidatedTinyAsciiStr<N>

Source

impl<const N: usize> Ord for RawBytesULE<N>