pub enum ErrorChannel {
StdErr,
StdOut,
File(PathBuf),
DevNull,
}Expand description
Enum for defining the output channel for flexi_logger’s own error messages.
These are only written if flexi_logger cannot do what it is supposed to do,
so under normal circumstances no single message shuld appear.
By default these error messages are printed to stderr.
Variants
StdErr
Write flexi_logger’s own error messages to stderr.
StdOut
Write flexi_logger’s own error messages to stdout.
File(PathBuf)
Write flexi_logger’s own error messages to the specified file.
DevNull
Don’t write flexi_logger’s own error messages.