pub enum FlexiLoggerError {
Show 15 variants
Reset,
NoFileLogger,
OutputBadDirectory,
OutputBadFile,
OutputCleanupThread(Error),
OutputIo(Error),
Notify(Error),
SpecfileToml(Error),
SpecfileIo(Error),
SpecfileExtension(&'static str),
LevelFilter(String),
Parse(String, LogSpecification),
Log(SetLoggerError),
Poison,
Palette(ParseIntError),
}Expand description
Describes errors in the initialization of flexi_logger.
Variants
Reset
Chosen reset not possible.
NoFileLogger
Method not possible because no file logger is configured.
OutputBadDirectory
Log file cannot be written because the specified path is not a directory.
OutputBadFile
Log file cannot be written because the specified path is a directory.
OutputCleanupThread(Error)
Spawning the cleanup thread failed.
This error can safely be avoided with Logger::cleanup_in_background_thread(false).
OutputIo(Error)
Log cannot be written, e.g. because the configured output directory is not accessible.
Notify(Error)
Filesystem notifications for the specfile could not be set up.
SpecfileToml(Error)
Parsing the configured logspec toml-file failed.
SpecfileIo(Error)
Specfile cannot be accessed or created.
SpecfileExtension(&'static str)
Specfile has an unsupported extension.
LevelFilter(String)
Invalid level filter.
Parse(String, LogSpecification)
Failed to parse log specification.
The String contains a description of the error, the second parameter
contains the resulting LogSpecification object
Log(SetLoggerError)
Logger initialization failed.
Poison
Some synchronization object is poisoned.
Palette(ParseIntError)
Palette parsing failed