pub struct DeferredNow(/* private fields */);Expand description
Deferred timestamp creation.
Is used to ensure that a log record that is sent to multiple outputs (in maybe different formats) always uses the same timestamp.
Implementations
Sourceimpl DeferredNow
impl DeferredNow
Sourcepub fn new() -> DeferredNow
pub fn new() -> DeferredNow
Constructs a new instance, but does not generate the timestamp.
Sourcepub fn now(&mut self) -> &OffsetDateTime
pub fn now(&mut self) -> &OffsetDateTime
Retrieve the timestamp.
Requires mutability because the first caller will generate the timestamp.
Sourcepub fn format(&mut self, fmt: &(impl Formattable + ?Sized)) -> String
pub fn format(&mut self, fmt: &(impl Formattable + ?Sized)) -> String
Sourcepub fn force_utc()
pub fn force_utc()
Enforce the use of UTC rather than local time.
By default, flexi_logger uses or tries to use local time.
By calling early in your program either Logger::use_utc() or directly this method,
you can override this to always use UTC.
Panics
Panics if called too late, i.e., if DeferredNow::now was already called before on
any instance of DeferredNow.