pub struct DefaultHasher(/* private fields */);Expand description
The default Hasher used by RandomState.
The internal algorithm is not specified, and so it and its hashes should not be relied upon over releases.
Implementations
Sourceimpl DefaultHasher
impl DefaultHasher
1.13.0 (const: unstable) · Sourcepub fn new() -> DefaultHasher
pub fn new() -> DefaultHasher
Creates a new DefaultHasher.
This hasher is not guaranteed to be the same as all other
DefaultHasher instances, but is the same as all other DefaultHasher
instances created through new or default.