pub struct VacantEntry<'a, K, V, A = Global>where
K: 'a,
V: 'a,
A: Allocator,{ /* private fields */ }Expand description
A view into a vacant entry in a HashMap.
It is part of the Entry enum.
Implementations
Sourceimpl<'a, K, V, A> VacantEntry<'a, K, V, A>where
K: 'a,
V: 'a,
A: Allocator,
impl<'a, K, V, A> VacantEntry<'a, K, V, A>where
K: 'a,
V: 'a,
A: Allocator,
1.10.0 · Sourcepub fn key(&self) -> &K
pub fn key(&self) -> &K
Gets a reference to the key that would be used when inserting a value
through the VacantEntry.
Examples
use std::collections::HashMap;
let mut map: HashMap<&str, u32> = HashMap::new();
assert_eq!(map.entry("poneyland").key(), &"poneyland");1.12.0 · Sourcepub fn into_key(self) -> K
pub fn into_key(self) -> K
Take ownership of the key.
Examples
use std::collections::HashMap;
use std::collections::hash_map::Entry;
let mut map: HashMap<&str, u32> = HashMap::new();
if let Entry::Vacant(v) = map.entry("poneyland") {
v.into_key();
}1.0.0 · Sourcepub fn insert(self, value: V) -> &'a mut V
pub fn insert(self, value: V) -> &'a mut V
Sets the value of the entry with the VacantEntry’s key,
and returns a mutable reference to it.
Examples
use std::collections::HashMap;
use std::collections::hash_map::Entry;
let mut map: HashMap<&str, u32> = HashMap::new();
if let Entry::Vacant(o) = map.entry("poneyland") {
o.insert(37);
}
assert_eq!(map["poneyland"], 37);1.83.0 · Sourcepub fn insert_entry(self, value: V) -> OccupiedEntry<'a, K, V, A>
pub fn insert_entry(self, value: V) -> OccupiedEntry<'a, K, V, A>
Sets the value of the entry with the VacantEntry’s key,
and returns an OccupiedEntry.
Examples
use std::collections::HashMap;
use std::collections::hash_map::Entry;
let mut map: HashMap<&str, u32> = HashMap::new();
if let Entry::Vacant(o) = map.entry("poneyland") {
o.insert_entry(37);
}
assert_eq!(map["poneyland"], 37);Trait Implementations