pub enum AtomicOrdering {
Relaxed = 0,
Release = 1,
Acquire = 2,
AcqRel = 3,
SeqCst = 4,
}๐ฌThis is a nightly-only experimental API. (
core_intrinsics)Expand description
A type for atomic ordering parameters for intrinsics. This is a separate type from
atomic::Ordering so that we can make it ConstParamTy and fix the values used here without a
risk of leaking that to stable code.
Variants
Relaxed = 0
๐ฌThis is a nightly-only experimental API. (
core_intrinsics)Release = 1
๐ฌThis is a nightly-only experimental API. (
core_intrinsics)Acquire = 2
๐ฌThis is a nightly-only experimental API. (
core_intrinsics)AcqRel = 3
๐ฌThis is a nightly-only experimental API. (
core_intrinsics)SeqCst = 4
๐ฌThis is a nightly-only experimental API. (
core_intrinsics)Trait Implementations
Sourceimpl Debug for AtomicOrdering
impl Debug for AtomicOrdering
Sourceimpl PartialEq for AtomicOrdering
impl PartialEq for AtomicOrdering
Sourcefn eq(&self, other: &AtomicOrdering) -> bool
fn eq(&self, other: &AtomicOrdering) -> bool
Tests for
self and other values to be equal, and is used by ==.impl ConstParamTy_ for AtomicOrdering
impl Eq for AtomicOrdering
impl StructuralPartialEq for AtomicOrdering