ErrorKind

Enum ErrorKind 

#[non_exhaustive]
pub enum ErrorKind {
Show 41 variants NotFound, PermissionDenied, ConnectionRefused, ConnectionReset, HostUnreachable, NetworkUnreachable, ConnectionAborted, NotConnected, AddrInUse, AddrNotAvailable, NetworkDown, BrokenPipe, AlreadyExists, WouldBlock, NotADirectory, IsADirectory, DirectoryNotEmpty, ReadOnlyFilesystem, FilesystemLoop, StaleNetworkFileHandle, InvalidInput, InvalidData, TimedOut, WriteZero, StorageFull, NotSeekable, QuotaExceeded, FileTooLarge, ResourceBusy, ExecutableFileBusy, Deadlock, CrossesDevices, TooManyLinks, InvalidFilename, ArgumentListTooLong, Interrupted, Unsupported, UnexpectedEof, OutOfMemory, InProgress, Other,
}
๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)
A list specifying general categories of I/O error.

This list is intended to grow over time and it is not recommended to exhaustively match against it.

It is used with the io::Error type.

Handling errors and matching on ErrorKind

In application code, use match for the ErrorKind values you are expecting; use _ to match โ€œall other errorsโ€.

In comprehensive and thorough tests that want to verify that a test doesnโ€™t return any known incorrect error kind, you may want to cut-and-paste the current full list of errors from here into your test code, and then match _ as the correct case. This seems counterintuitive, but it will make your tests more robust. In particular, if you want to verify that your code does produce an unrecognized error kind, the robust solution is to check for all the recognized error kinds and fail in those cases.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NotFound

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

An entity was not found, often a file.



PermissionDenied

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

The operation lacked the necessary privileges to complete.



ConnectionRefused

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

The connection was refused by the remote server.



ConnectionReset

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

The connection was reset by the remote server.



HostUnreachable

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

The remote host is not reachable.



NetworkUnreachable

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

The network containing the remote host is not reachable.



ConnectionAborted

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

The connection was aborted (terminated) by the remote server.



NotConnected

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

The network operation failed because it was not connected yet.



AddrInUse

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

A socket address could not be bound because the address is already in use elsewhere.



AddrNotAvailable

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

A nonexistent interface was requested or the requested address was not local.



NetworkDown

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

The systemโ€™s networking is down.



BrokenPipe

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

The operation failed because a pipe was closed.



AlreadyExists

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

An entity already exists, often a file.



WouldBlock

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

The operation needs to block to complete, but the blocking operation was requested to not occur.



NotADirectory

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

A filesystem object is, unexpectedly, not a directory.

For example, a filesystem path was specified where one of the intermediate directory components was, in fact, a plain file.



IsADirectory

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

The filesystem object is, unexpectedly, a directory.

A directory was specified when a non-directory was expected.



DirectoryNotEmpty

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

A non-empty directory was specified where an empty directory was expected.



ReadOnlyFilesystem

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

The filesystem or storage medium is read-only, but a write operation was attempted.



FilesystemLoop

๐Ÿ”ฌThis is a nightly-only experimental API. (io_error_more)

Loop in the filesystem or IO subsystem; often, too many levels of symbolic links.

There was a loop (or excessively long chain) resolving a filesystem object or file IO object.

On Unix this is usually the result of a symbolic link loop; or, of exceeding the system-specific limit on the depth of symlink traversal.



StaleNetworkFileHandle

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

Stale network file handle.

With some network filesystems, notably NFS, an open file (or directory) can be invalidated by problems with the network or server.



InvalidInput

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

A parameter was incorrect.



InvalidData

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

Data not valid for the operation were encountered.

Unlike InvalidInput, this typically means that the operation parameters were valid, however the error was caused by malformed input data.

For example, a function that reads a file into a string will error with InvalidData if the fileโ€™s contents are not valid UTF-8.



TimedOut

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

The I/O operationโ€™s timeout expired, causing it to be canceled.



WriteZero

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

An error returned when an operation could not be completed because a call to write returned Ok(0).

This typically means that an operation could only succeed if it wrote a particular number of bytes but only a smaller number of bytes could be written.



StorageFull

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

The underlying storage (typically, a filesystem) is full.

This does not include out of quota errors.



NotSeekable

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

Seek on unseekable file.

Seeking was attempted on an open file handle which is not suitable for seeking - for example, on Unix, a named pipe opened with File::open.



QuotaExceeded

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

Filesystem quota or some other kind of quota was exceeded.



FileTooLarge

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

File larger than allowed or supported.

This might arise from a hard limit of the underlying filesystem or file access API, or from an administratively imposed resource limitation. Simple disk full, and out of quota, have their own errors.



ResourceBusy

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

Resource is busy.



ExecutableFileBusy

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

Executable file is busy.

An attempt was made to write to a file which is also in use as a running program. (Not all operating systems detect this situation.)



Deadlock

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

Deadlock (avoided).

A file locking operation would result in deadlock. This situation is typically detected, if at all, on a best-effort basis.



CrossesDevices

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

Cross-device or cross-filesystem (hard) link or rename.

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

Too many (hard) links to the same filesystem object.

The filesystem does not support making so many hardlinks to the same file.



InvalidFilename

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

A filename was invalid.

This error can also occur if a length limit for a name was exceeded.



ArgumentListTooLong

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

Program argument list too long.

When trying to run an external program, a system or process limit on the size of the arguments would have been exceeded.



Interrupted

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

This operation was interrupted.

Interrupted operations can typically be retried.



Unsupported

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

This operation is unsupported on this platform.

This means that the operation can never succeed.



UnexpectedEof

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

An error returned when an operation could not be completed because an โ€œend of fileโ€ was reached prematurely.

This typically means that an operation could only succeed if it read a particular number of bytes but only a smaller number of bytes could be read.



OutOfMemory

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

An operation could not be completed, because it failed to allocate enough memory.



InProgress

๐Ÿ”ฌThis is a nightly-only experimental API. (io_error_inprogress)

The operation was partially successful and needs to be checked later on due to not blocking.



Other

๐Ÿ”ฌThis is a nightly-only experimental API. (core_io)

A custom error that does not fall under any other I/O error kind.

This can be used to construct your own Errors that do not match any ErrorKind.

This ErrorKind is not used by the standard library.

Errors from the standard library that do not fall under any of the I/O error kinds cannot be matched on, and will only match a wildcard (_) pattern. New ErrorKinds might be added in the future for some of those.