pub trait ToBytes: Sealed {
type Bytes: Copy + Unpin + Send + Sync + AsRef<[u8]> + AsMut<[u8]> + SimdUint<Scalar = u8> + 'static;
// Required methods
fn to_ne_bytes(self) -> Self::Bytes;
fn to_be_bytes(self) -> Self::Bytes;
fn to_le_bytes(self) -> Self::Bytes;
fn from_ne_bytes(bytes: Self::Bytes) -> Self;
fn from_be_bytes(bytes: Self::Bytes) -> Self;
fn from_le_bytes(bytes: Self::Bytes) -> Self;
}๐ฌThis is a nightly-only experimental API. (
portable_simd)Expand description
Converts SIMD vectors to vectors of bytes
Required Associated Types
Required Methods
Sourcefn to_ne_bytes(self) -> Self::Bytes
๐ฌThis is a nightly-only experimental API. (portable_simd)
fn to_ne_bytes(self) -> Self::Bytes
portable_simd)Returns the memory representation of this integer as a byte array in native byte order.
Sourcefn to_be_bytes(self) -> Self::Bytes
๐ฌThis is a nightly-only experimental API. (portable_simd)
fn to_be_bytes(self) -> Self::Bytes
portable_simd)Returns the memory representation of this integer as a byte array in big-endian (network) byte order.
Sourcefn to_le_bytes(self) -> Self::Bytes
๐ฌThis is a nightly-only experimental API. (portable_simd)
fn to_le_bytes(self) -> Self::Bytes
portable_simd)Returns the memory representation of this integer as a byte array in little-endian byte order.
Sourcefn from_ne_bytes(bytes: Self::Bytes) -> Self
๐ฌThis is a nightly-only experimental API. (portable_simd)
fn from_ne_bytes(bytes: Self::Bytes) -> Self
portable_simd)Creates a native endian integer value from its memory representation as a byte array in native endianness.
Sourcefn from_be_bytes(bytes: Self::Bytes) -> Self
๐ฌThis is a nightly-only experimental API. (portable_simd)
fn from_be_bytes(bytes: Self::Bytes) -> Self
portable_simd)Creates an integer value from its representation as a byte array in big endian.
Sourcefn from_le_bytes(bytes: Self::Bytes) -> Self
๐ฌThis is a nightly-only experimental API. (portable_simd)
fn from_le_bytes(bytes: Self::Bytes) -> Self
portable_simd)Creates an integer value from its representation as a byte array in little endian.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".