LocalWaker

Struct LocalWaker 

pub struct LocalWaker { /* private fields */ }
๐Ÿ”ฌThis is a nightly-only experimental API. (local_waker)
A LocalWaker is analogous to a Waker, but it does not implement Send or Sync.

This handle encapsulates a RawWaker instance, which defines the executor-specific wakeup behavior.

Local wakers can be requested from a Context with the local_waker method.

The typical life of a LocalWaker is that it is constructed by an executor, wrapped in a Context using ContextBuilder, then passed to Future::poll(). Then, if the future chooses to return Poll::Pending, it must also store the waker somehow and call LocalWaker::wake() when the future should be polled again.

Implements Clone, but neither Send nor Sync; therefore, a local waker may not be moved to other threads. In general, when deciding to use wakers or local wakers, local wakers are preferable unless the waker needs to be sent across threads. This is because wakers can incur in additional cost related to memory synchronization.

Note that it is preferable to use local_waker.clone_from(&new_waker) instead of *local_waker = new_waker.clone(), as the former will avoid cloning the waker unnecessarily if the two wakers wake the same task.

Examples

Usage of a local waker to implement a future analogous to std::thread::yield_now().

#![feature(local_waker)]
use std::future::{Future, poll_fn};
use std::task::Poll;

// a future that returns pending once.
fn yield_now() -> impl Future<Output=()> + Unpin {
    let mut yielded = false;
    poll_fn(move |cx| {
        if !yielded {
            yielded = true;
            cx.local_waker().wake_by_ref();
            return Poll::Pending;
        }
        return Poll::Ready(())
    })
}

yield_now().await;

Implementations

Source

impl LocalWaker

pub fn wake(self)

๐Ÿ”ฌThis is a nightly-only experimental API. (local_waker)

Wakes up the task associated with this LocalWaker.

As long as the executor keeps running and the task is not finished, it is guaranteed that each invocation of wake() (or wake_by_ref()) will be followed by at least one poll() of the task to which this LocalWaker belongs. This makes it possible to temporarily yield to other tasks while running potentially unbounded processing loops.

Note that the above implies that multiple wake-ups may be coalesced into a single poll() invocation by the runtime.

Also note that yielding to competing tasks is not guaranteed: it is the executorโ€™s choice which task to run and the executor may choose to run the current task again.

pub fn wake_by_ref(&self)

๐Ÿ”ฌThis is a nightly-only experimental API. (local_waker)

Wakes up the task associated with this LocalWaker without consuming the LocalWaker.

This is similar to wake(), but may be slightly less efficient in the case where an owned Waker is available. This method should be preferred to calling waker.clone().wake().

pub fn will_wake(&self, other: &LocalWaker) -> bool

๐Ÿ”ฌThis is a nightly-only experimental API. (local_waker)

Returns true if this LocalWaker and another LocalWaker would awake the same task.

This function works on a best-effort basis, and may return false even when the Wakers would awaken the same task. However, if this function returns true, it is guaranteed that the Wakers will awaken the same task.

This function is primarily used for optimization purposes โ€” for example, this typeโ€™s clone_from implementation uses it to avoid cloning the waker when they would wake the same task anyway.

pub const unsafe fn new( data: *const (), vtable: &'static RawWakerVTable, ) -> LocalWaker

๐Ÿ”ฌThis is a nightly-only experimental API. (local_waker)

Creates a new LocalWaker from the provided data pointer and vtable.

The data pointer can be used to store arbitrary data as required by the executor. This could be e.g. a type-erased pointer to an Arc that is associated with the task. The value of this pointer will get passed to all functions that are part of the vtable as the first parameter.

The vtable customizes the behavior of a LocalWaker. For each operation on the LocalWaker, the associated function in the vtable will be called.

Safety

The behavior of the returned Waker is undefined if the contract defined in RawWakerVTableโ€™s documentation is not upheld.

pub const unsafe fn from_raw(waker: RawWaker) -> LocalWaker

๐Ÿ”ฌThis is a nightly-only experimental API. (local_waker)

Creates a new LocalWaker from RawWaker.

The behavior of the returned LocalWaker is undefined if the contract defined in RawWakerโ€™s and RawWakerVTableโ€™s documentation is not upheld. Therefore this method is unsafe.

pub const fn noop() -> &'static LocalWaker

๐Ÿ”ฌThis is a nightly-only experimental API. (local_waker)

Returns a reference to a LocalWaker that does nothing when used.

This is mostly useful for writing tests that need a Context to poll some futures, but are not expecting those futures to wake the waker or do not need to do anything specific if it happens.

More generally, using LocalWaker::noop() to poll a future means discarding the notification of when the future should be polled again, So it should only be used when such a notification will not be needed to make progress.

If an owned LocalWaker is needed, clone() this one.

Examples
#![feature(local_waker)]
use std::future::Future;
use std::task::{ContextBuilder, LocalWaker, Waker, Poll};

let mut cx = ContextBuilder::from_waker(Waker::noop())
    .local_waker(LocalWaker::noop())
    .build();

let mut future = Box::pin(async { 10 });
assert_eq!(future.as_mut().poll(&mut cx), Poll::Ready(10));
pub fn data(&self) -> *const ()

๐Ÿ”ฌThis is a nightly-only experimental API. (local_waker)

Gets the data pointer used to create this LocalWaker.

pub fn vtable(&self) -> &'static RawWakerVTable

๐Ÿ”ฌThis is a nightly-only experimental API. (local_waker)

Gets the vtable pointer used to create this LocalWaker.

pub const fn from_fn_ptr(f: fn()) -> LocalWaker

๐Ÿ”ฌThis is a nightly-only experimental API. (waker_from_fn_ptr)

Constructs a LocalWaker from a function pointer.