pub struct LazyTransform<T, U> { /* private fields */ }Expand description
LazyTransform<T, U> is a synchronized holder type, that holds a value of
type T until it is lazily converted into a value of type U.
Implementations
Sourceimpl<T, U> LazyTransform<T, U>
impl<T, U> LazyTransform<T, U>
Sourcepub fn new(t: T) -> LazyTransform<T, U>
pub fn new(t: T) -> LazyTransform<T, U>
Construct a new, untransformed LazyTransform<T, U> with an argument of
type T.
Sourcepub fn into_inner(self) -> Result<U, T>
pub fn into_inner(self) -> Result<U, T>
Unwrap the contained value, returning Ok(U) if the LazyTransform<T, U> has been
transformed or Err(T) if it has not.
Sourceimpl<T, U> LazyTransform<T, U>
impl<T, U> LazyTransform<T, U>
Sourcepub fn get_or_create<F>(&self, f: F) -> &Uwhere
F: FnOnce(T) -> U,
pub fn get_or_create<F>(&self, f: F) -> &Uwhere
F: FnOnce(T) -> U,
Get a reference to the transformed value, invoking f to transform it
if the LazyTransform<T, U> has yet to be transformed. It is
guaranteed that if multiple calls to get_or_create race, only one
will invoke its closure, and every call will receive a reference to the
newly transformed value.
The closure can only ever be called once, so think carefully about what transformation you want to apply!