__Deref

Trait __Deref 

1.0.0 (const: unstable) · Source
pub trait __Deref {
    type Target: ?Sized;

    // Required method
    fn deref(&self) -> &Self::Target;
}
Used for immutable dereferencing operations, like *v.

In addition to being used for explicit dereferencing operations with the (unary) * operator in immutable contexts, Deref is also used implicitly by the compiler in many circumstances. This mechanism is called Deref coercion”. In mutable contexts, DerefMut is used and mutable deref coercion similarly occurs.

Warning: Deref coercion is a powerful language feature which has far-reaching implications for every type that implements Deref. The compiler will silently insert calls to Deref::deref. For this reason, one should be careful about implementing Deref and only do so when deref coercion is desirable. See below for advice on when this is typically desirable or undesirable.

Types that implement Deref or DerefMut are often called “smart pointers” and the mechanism of deref coercion has been specifically designed to facilitate the pointer-like behavior that name suggests. Often, the purpose of a “smart pointer” type is to change the ownership semantics of a contained value (for example, Rc or Cow) or the storage semantics of a contained value (for example, Box).

Deref coercion

If T implements Deref<Target = U>, and v is a value of type T, then:

  • In immutable contexts, *v (where T is neither a reference nor a raw pointer) is equivalent to *Deref::deref(&v).
  • Values of type &T are coerced to values of type &U
  • T implicitly implements all the methods of the type U which take the &self receiver.

For more details, visit the chapter in The Rust Programming Language as well as the reference sections on the dereference operator, method resolution, and type coercions.

When to implement Deref or DerefMut

The same advice applies to both deref traits. In general, deref traits should be implemented if:

  1. a value of the type transparently behaves like a value of the target type;
  2. the implementation of the deref function is cheap; and
  3. users of the type will not be surprised by any deref coercion behavior.

In general, deref traits should not be implemented if:

  1. the deref implementations could fail unexpectedly; or
  2. the type has methods that are likely to collide with methods on the target type; or
  3. committing to deref coercion as part of the public API is not desirable.

Note that there’s a large difference between implementing deref traits generically over many target types, and doing so only for specific target types.

Generic implementations, such as for Box<T> (which is generic over every type and dereferences to T) should be careful to provide few or no methods, since the target type is unknown and therefore every method could collide with one on the target type, causing confusion for users. impl<T> Box<T> has no methods (though several associated functions), partly for this reason.

Specific implementations, such as for String (whose Deref implementation has Target = str) can have many methods, since avoiding collision is much easier. String and str both have many methods, and String additionally behaves as if it has every method of str because of deref coercion. The implementing type may also be generic while the implementation is still specific in this sense; for example, Vec<T> dereferences to [T], so methods of T are not applicable.

Consider also that deref coercion means that deref traits are a much larger part of a type’s public API than any other trait as it is implicitly called by the compiler. Therefore, it is advisable to consider whether this is something you are comfortable supporting as a public API.

The AsRef and Borrow traits have very similar signatures to Deref. It may be desirable to implement either or both of these, whether in addition to or rather than deref traits. See their documentation for details.

Fallibility

This trait’s method should never unexpectedly fail. Deref coercion means the compiler will often insert calls to Deref::deref implicitly. Failure during dereferencing can be extremely confusing when Deref is invoked implicitly. In the majority of uses it should be infallible, though it may be acceptable to panic if the type is misused through programmer error, for example.

However, infallibility is not enforced and therefore not guaranteed. As such, unsafe code should not rely on infallibility in general for soundness.

Examples

A struct with a single field which is accessible by dereferencing the struct.

use std::ops::Deref;

struct DerefExample<T> {
    value: T
}

impl<T> Deref for DerefExample<T> {
    type Target = T;

    fn deref(&self) -> &Self::Target {
        &self.value
    }
}

let x = DerefExample { value: 'a' };
assert_eq!('a', *x);

Required Associated Types

1.0.0 (const: unstable) · Source

type Target: ?Sized

The resulting type after dereferencing.

Required Methods

1.0.0 (const: unstable) · Source

fn deref(&self) -> &Self::Target

Dereferences the value.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Deref for Error

Available on crate feature std or non-anyhow_no_core_error only.
Source

type Target = dyn Error + Send + Sync

Source

impl Deref for IndexedZip

Source

impl Deref for Duration

Source

impl Deref for Timestamp

Source

impl Deref for ByteStr

Source

impl Deref for Version

Source

impl Deref for AccessRecord

Source

impl Deref for GLOBAL

Source

impl Deref for GPieces

Source

impl Deref for Html

Source

impl Deref for HtmlLit

Source

impl Deref for IPiece

Source

impl Deref for InstanceGuard<'_>

Source

impl Deref for LinksTable

Source

impl Deref for MgmtChannelForGame

1.0.0 · Source

impl Deref for PathBuf

Source

impl Deref for PieceRenderInstructions

Source

impl Deref for TempPath

Source

impl Deref for ByteString

1.0.0 · Source

impl Deref for CString

1.0.0 · Source

impl Deref for String

1.0.0 · Source

impl Deref for OsString

Source

impl Deref for BStr

Source

impl Deref for BString

Source

impl Deref for BoxBytes

Source

impl Deref for Bytes

Source

impl Deref for BytesMut

Source

impl Deref for WakerRef<'_>

Source

impl Deref for Private

Source

impl Deref for Attributes

Source

impl Deref for CurrencyType

Source

impl Deref for NumberingSystem

Source

impl Deref for RegionOverride

Source

impl Deref for RegionalSubdivision

Source

impl Deref for TimeZoneShortId

Source

impl Deref for Variants

Source

impl Deref for DataMarkerAttributes

Source

impl Deref for IoVec

Source

impl Deref for UnixReady

Source

impl Deref for Asn1BitString

Source

impl Deref for Asn1Enumerated

Source

impl Deref for Asn1GeneralizedTime

Source

impl Deref for Asn1Integer

Source

impl Deref for Asn1Object

Source

impl Deref for Asn1OctetString

Source

impl Deref for Asn1String

Source

impl Deref for Asn1Time

Source

impl Deref for BigNum

Source

impl Deref for BigNumContext

Source

impl Deref for Cipher

Source

impl Deref for CipherCtx

Source

impl Deref for CmsContentInfo

Source

impl Deref for Conf

Source

impl Deref for DsaSig

Source

impl Deref for EcGroup

Source

impl Deref for EcPoint

Source

impl Deref for EcdsaSig

Source

impl Deref for DigestBytes

Source

impl Deref for LibCtx

Source

impl Deref for Md

Source

impl Deref for MdCtx

Source

impl Deref for OcspBasicResponse

Source

impl Deref for OcspCertId

Source

impl Deref for OcspOneReq

Source

impl Deref for OcspRequest

Source

impl Deref for OcspResponse

Source

impl Deref for Pkcs7

Source

impl Deref for Pkcs7Signed

Source

impl Deref for Pkcs7SignerInfo

Source

impl Deref for Pkcs12

Source

impl Deref for Provider

Source

impl Deref for SrtpProtectionProfile

Source

impl Deref for ConnectConfiguration

Source

impl Deref for SslAcceptorBuilder

Source

impl Deref for SslConnectorBuilder

Source

impl Deref for Ssl

Source

impl Deref for SslCipher

Source

impl Deref for SslContext

Source

impl Deref for SslSession

Source

impl Deref for OpensslString

Source

impl Deref for OpensslStringRef

Source

impl Deref for X509Store

Source

impl Deref for X509StoreBuilder

Source

impl Deref for AccessDescription

Source

impl Deref for DistPoint

Source

impl Deref for DistPointName

Source

impl Deref for GeneralName

Source

impl Deref for X509

Source

impl Deref for X509Algorithm

Source

impl Deref for X509Crl

Source

impl Deref for X509Extension

Source

impl Deref for X509Name

Source

impl Deref for X509NameEntry

Source

impl Deref for X509Object

Source

impl Deref for X509Req

Source

impl Deref for X509Revoked

Source

impl Deref for X509StoreContext

Source

impl Deref for X509VerifyParam

Source

impl Deref for OtterOutput

Source

impl Deref for PotentialUtf8

Source

impl Deref for EnteredSpan

1.36.0 · Source

impl<'a> Deref for IoSlice<'a>

1.36.0 · Source

impl<'a> Deref for IoSliceMut<'a>

Source

impl<'a> Deref for Ident<'a>

Source

impl<'a> Deref for socket2::MaybeUninitSlice<'a>

Source

impl<'a> Deref for socket2::MaybeUninitSlice<'a>

Source

impl<'a> Deref for StrSpan<'a>

Source

impl<'a, R> Deref for UnitRef<'a, R>
where R: Reader,

Source

impl<'a, R, G, T> Deref for MappedReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: 'a + ?Sized,

Source

impl<'a, R, G, T> Deref for ReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: 'a + ?Sized,

Source

impl<'a, R, T> Deref for otter_nodejs_tests::parking_lot::lock_api::MappedMutexGuard<'a, R, T>
where R: RawMutex + 'a, T: 'a + ?Sized,

Source

impl<'a, R, T> Deref for otter_nodejs_tests::parking_lot::lock_api::MappedRwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: 'a + ?Sized,

Source

impl<'a, R, T> Deref for otter_nodejs_tests::parking_lot::lock_api::MappedRwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: 'a + ?Sized,

Source

impl<'a, R, T> Deref for otter_nodejs_tests::parking_lot::lock_api::MutexGuard<'a, R, T>
where R: RawMutex + 'a, T: 'a + ?Sized,

Source

impl<'a, R, T> Deref for otter_nodejs_tests::parking_lot::lock_api::RwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: 'a + ?Sized,

Source

impl<'a, R, T> Deref for RwLockUpgradableReadGuard<'a, R, T>
where R: RawRwLockUpgrade + 'a, T: 'a + ?Sized,

Source

impl<'a, R, T> Deref for otter_nodejs_tests::parking_lot::lock_api::RwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: 'a + ?Sized,

Source

impl<'a, S> Deref for ANSIGenericString<'a, S>
where S: 'a + ToOwned + ?Sized, <S as ToOwned>::Owned: Debug,

Source

impl<'a, T> Deref for tokio::sync::mutex::MappedMutexGuard<'a, T>
where T: ?Sized,

Source

impl<'a, T> Deref for Locked<'a, T>

Source

impl<'a, T> Deref for ZeroVec<'a, T>
where T: AsULE,

Source

impl<'a, T, A> Deref for alloc::vec::peek_mut::PeekMut<'a, T, A>
where A: Allocator,

Source

impl<'a, T, F> Deref for PoolGuard<'a, T, F>
where T: Send, F: Fn() -> T,

Source

impl<'a, V> Deref for VarZeroCow<'a, V>
where V: VarULE + ?Sized,

Source

impl<'g, T> Deref for otter_nodejs_tests::otter_support::debugmutex::MutexGuard<'g, T>
where T: DebugIdentify,

Source

impl<'input, Endian> Deref for EndianSlice<'input, Endian>
where Endian: Endianity,

Source

impl<'s> Deref for socket2::sockref::SockRef<'s>

Source

impl<'s> Deref for socket2::sockref::SockRef<'s>

Source

impl<A> Deref for SmallVec<A>
where A: Array,

Source

type Target = [<A as Array>::Item]

1.0.0 · Source

impl<B> Deref for Cow<'_, B>
where B: ToOwned + ?Sized,

Source

impl<B, T> Deref for zerocopy::ref::def::Ref<B, T>

Source

impl<C0, C1, T> Deref for EitherCart<C0, C1>
where C0: Deref<Target = T>, C1: Deref<Target = T>, T: ?Sized,

Source

impl<I> Deref for SubImage<I>
where I: Deref,

Source

type Target = SubImageInner<I>

Source

impl<I, A> Deref for IndexVec<I, A>
where I: Idx,

Source

impl<L, R> Deref for Either<L, R>
where L: Deref, R: Deref<Target = <L as Deref>::Target>,

Source

type Target = <L as Deref>::Target

Source

impl<P, Container> Deref for ImageBuffer<P, Container>
where P: Pixel, Container: Deref<Target = [<P as Pixel>::Subpixel]>,

Source

type Target = [<P as Pixel>::Subpixel]

1.33.0 (const: unstable) · Source

impl<Ptr> Deref for Pin<Ptr>
where Ptr: Deref,

Source

type Target = <Ptr as Deref>::Target

Source

impl<S> Deref for UniCase<S>

Source

impl<S> Deref for Ascii<S>

1.0.0 (const: unstable) · Source

impl<T> Deref for &T
where T: ?Sized,

1.0.0 (const: unstable) · Source

impl<T> Deref for &mut T
where T: ?Sized,

Source

impl<T> Deref for Serde<T>

1.0.0 (const: unstable) · Source

impl<T> Deref for otter_nodejs_tests::inventory::core::cell::Ref<'_, T>
where T: ?Sized,

1.0.0 (const: unstable) · Source

impl<T> Deref for RefMut<'_, T>
where T: ?Sized,

1.9.0 (const: unstable) · Source

impl<T> Deref for AssertUnwindSafe<T>

Source

impl<T> Deref for NotNan<T>
where T: Float,

1.20.0 (const: unstable) · Source

impl<T> Deref for ManuallyDrop<T>
where T: ?Sized,

Source

impl<T> Deref for OrderedFloat<T>
where T: Float,

Source

impl<T> Deref for ThinBox<T>
where T: ?Sized,

Source

impl<T> Deref for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: ?Sized,

Source

impl<T> Deref for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: ?Sized,

Source

impl<T> Deref for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: ?Sized,

Source

impl<T> Deref for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> Deref for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: ?Sized,

Source

impl<T> Deref for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> Deref for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> Deref for std::sync::poison::mutex::MutexGuard<'_, T>
where T: ?Sized,

Source

impl<T> Deref for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: ?Sized,

Source

impl<T> Deref for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> Deref for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> Deref for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> Deref for ReentrantLockGuard<'_, T>
where T: ?Sized,

Source

impl<T> Deref for Owned<T>
where T: Pointable + ?Sized,

Source

impl<T> Deref for CachePadded<T>

Source

impl<T> Deref for ShardedLockReadGuard<'_, T>
where T: ?Sized,

Source

impl<T> Deref for ShardedLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> Deref for futures_util::lock::mutex::MutexGuard<'_, T>
where T: ?Sized,

Source

impl<T> Deref for futures_util::lock::mutex::OwnedMutexGuard<T>
where T: ?Sized,

Source

impl<T> Deref for Dh<T>

Source

impl<T> Deref for Dsa<T>

Source

impl<T> Deref for EcKey<T>

Source

impl<T> Deref for PKey<T>

Source

impl<T> Deref for PkeyCtx<T>

Source

impl<T> Deref for Rsa<T>

Source

impl<T> Deref for Stack<T>
where T: Stackable,

Source

impl<T> Deref for X509Lookup<T>

Source

impl<T> Deref for X509LookupMethod<T>

Source

impl<T> Deref for tokio::sync::mutex::MutexGuard<'_, T>
where T: ?Sized,

Source

impl<T> Deref for tokio::sync::mutex::OwnedMutexGuard<T>
where T: ?Sized,

Source

impl<T> Deref for OwnedRwLockWriteGuard<T>
where T: ?Sized,

Source

impl<T> Deref for tokio::sync::rwlock::read_guard::RwLockReadGuard<'_, T>
where T: ?Sized,

Source

impl<T> Deref for tokio::sync::rwlock::write_guard::RwLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> Deref for RwLockMappedWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> Deref for tokio::sync::watch::Ref<'_, T>

Source

impl<T> Deref for ReadOnly<T>
where T: Immutable + ?Sized,

Source

impl<T> Deref for Unalign<T>
where T: Unaligned,

1.0.0 · Source

impl<T, A> Deref for Arc<T, A>
where A: Allocator, T: ?Sized,

1.0.0 · Source

impl<T, A> Deref for Box<T, A>
where A: Allocator, T: ?Sized,

1.12.0 · Source

impl<T, A> Deref for alloc::collections::binary_heap::PeekMut<'_, T, A>
where T: Ord, A: Allocator,

1.0.0 · Source

impl<T, A> Deref for Rc<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T, A> Deref for UniqueRc<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T, A> Deref for UniqueArc<T, A>
where A: Allocator, T: ?Sized,

1.0.0 (const: unstable) · Source

impl<T, A> Deref for Vec<T, A>
where A: Allocator,

1.80.0 · Source

impl<T, F> Deref for LazyCell<T, F>
where F: FnOnce() -> T,

Source

impl<T, F> Deref for otter_nodejs_tests::lazy_regex::Lazy<T, F>
where F: FnOnce() -> T,

Source

impl<T, F> Deref for otter_nodejs_tests::once_cell::unsync::Lazy<T, F>
where F: FnOnce() -> T,

Source

impl<T, F> Deref for DropGuard<T, F>
where F: FnOnce(T),

Source

impl<T, F> Deref for Thunk<T, F>
where T: Sync, F: Sync + FnOnce() -> T,

1.80.0 · Source

impl<T, F> Deref for LazyLock<T, F>
where F: FnOnce() -> T,

Source

impl<T, F> Deref for regex_automata::util::lazy::Lazy<T, F>
where F: Fn() -> T,

Source

impl<T, F> Deref for VarZeroVec<'_, T, F>
where T: VarULE + ?Sized, F: VarZeroVecFormat,

Source

impl<T, F, S> Deref for ScopeGuard<T, F, S>
where F: FnOnce(T), S: Strategy,

Source

impl<T, N> Deref for GenericArray<T, N>
where N: ArrayLength<T>,

Source

impl<T, U> Deref for futures_util::lock::mutex::MappedMutexGuard<'_, T, U>
where T: ?Sized, U: ?Sized,

Source

impl<T, U> Deref for OwnedMappedMutexGuard<T, U>
where T: ?Sized, U: ?Sized,

Source

impl<T, U> Deref for OwnedRwLockReadGuard<T, U>
where T: ?Sized, U: ?Sized,

Source

impl<T, U> Deref for OwnedRwLockMappedWriteGuard<T, U>
where T: ?Sized, U: ?Sized,

Source

impl<T, const CAP: usize> Deref for ArrayVec<T, CAP>

Source

impl<const CAP: usize> Deref for ArrayString<CAP>

Source

impl<const N: usize> Deref for CcidEndpoints<N>

Available on crate feature all and Linux only.
Source

impl<const N: usize> Deref for TinyAsciiStr<N>