pub struct MetadataBuilder<'a> { /* private fields */ }Expand description
Builder for Metadata.
Typically should only be used by log library creators or for testing and “shim loggers”.
The MetadataBuilder can set the different parameters of a Metadata object, and returns
the created object when build is called.
Example
let target = "myApp";
use log::{Level, MetadataBuilder};
let metadata = MetadataBuilder::new()
.level(Level::Debug)
.target(target)
.build();Implementations
Sourceimpl<'a> MetadataBuilder<'a>
impl<'a> MetadataBuilder<'a>
Sourcepub fn new() -> MetadataBuilder<'a>
pub fn new() -> MetadataBuilder<'a>
Construct a new MetadataBuilder.
The default options are:
level:Level::Infotarget:""
Sourcepub fn level(&mut self, arg: Level) -> &mut MetadataBuilder<'a>
pub fn level(&mut self, arg: Level) -> &mut MetadataBuilder<'a>
Setter for level.
Sourcepub fn target(&mut self, target: &'a str) -> &mut MetadataBuilder<'a>
pub fn target(&mut self, target: &'a str) -> &mut MetadataBuilder<'a>
Setter for target.