pub enum TryRecvError {
Empty,
Disconnected,
}Expand description
This enumeration is the list of the possible reasons that try_recv could
not return data when called. This can occur with both a channel and
a sync_channel.
Variants
Empty
This channel is currently empty, but the Sender(s) have not yet disconnected, so data may yet become available.
Disconnected
The channel’s sending half has become disconnected, and there will never be any more data received on it.