Dir

Struct Dir 

pub struct Dir(/* private fields */);
An open directory.

This is a lower-level interface than std::fs::ReadDir. Notable differences:

  • can be opened from a file descriptor (as returned by openat, perhaps before knowing if the path represents a file or directory).
  • implements AsRawFd, so it can be passed to fstat, openat, etc. The file descriptor continues to be owned by the Dir, so callers must not keep a RawFd after the Dir is dropped.
  • can be iterated through multiple times without closing and reopening the file descriptor. Each iteration rewinds when finished.
  • returns entries for . (current directory) and .. (parent directory).
  • returns entries’ names as a CStr (no allocation or conversion beyond whatever libc does).

Implementations

Source

impl Dir

pub fn open<P>(path: &P, oflag: OFlag, mode: Mode) -> Result<Dir, Errno>
where P: NixPath + ?Sized,

Opens the given path as with fcntl::open.

pub fn openat<P>( dirfd: i32, path: &P, oflag: OFlag, mode: Mode, ) -> Result<Dir, Errno>
where P: NixPath + ?Sized,

Opens the given path as with fcntl::openat.

pub fn from<F>(fd: F) -> Result<Dir, Errno>
where F: IntoRawFd,

Converts from a descriptor-based object, closing the descriptor on success or failure.

pub fn from_fd(fd: i32) -> Result<Dir, Errno>

Converts from a file descriptor, closing it on success or failure.

pub fn iter(&mut self) -> Iter<'_>

Returns an iterator of Result<Entry> which rewinds when finished.