Module errno
otter_
nodejs_
tests
1.2.1
Module errno
Module Items
Enums
Constants
Traits
Functions
In otter_
nodejs_
tests::
nix
otter_nodejs_tests
::
nix
Module
errno
Enums

Errno
Constants

EDEADLOCK
Deprecated
ENOTSUP
Deprecated
EWOULDBLOCK
Deprecated
Traits

Errno
Sentinel
The sentinel value indicates that a function failed and more detailed information about the error can be found in
errno
Functions

errno
Returns the platform-specific value of errno
from_
i32