pub struct OFlag { /* private fields */ }Expand description
Configuration options for opened files.
Implementations
Sourceimpl OFlag
impl OFlag
Sourcepub const O_CLOEXEC: OFlag
pub const O_CLOEXEC: OFlag
Closes the file descriptor once an execve call is made.
Also sets the file offset to the beginning of the file.
Sourcepub const O_DIRECTORY: OFlag
pub const O_DIRECTORY: OFlag
If the specified path isn’t a directory, fail.
Sourcepub const O_LARGEFILE: OFlag
pub const O_LARGEFILE: OFlag
Allow files whose sizes can’t be represented in an off_t to be opened.
Sourcepub const O_NOFOLLOW: OFlag
pub const O_NOFOLLOW: OFlag
open() will fail if the given path is a symbolic link.
Sourcepub const O_NONBLOCK: OFlag
pub const O_NONBLOCK: OFlag
When possible, open the file in nonblocking mode.
Sourcepub const O_PATH: OFlag
pub const O_PATH: OFlag
Obtain a file descriptor for low-level access.
The file itself is not opened and other file operations will fail.
Sourcepub const O_RDONLY: OFlag
pub const O_RDONLY: OFlag
Only allow reading.
This should not be combined with O_WRONLY or O_RDWR.
Sourcepub const O_RDWR: OFlag
pub const O_RDWR: OFlag
Allow both reading and writing.
This should not be combined with O_WRONLY or O_RDONLY.
Sourcepub const O_WRONLY: OFlag
pub const O_WRONLY: OFlag
Only allow writing.
This should not be combined with O_RDONLY or O_RDWR.
Sourcepub const fn from_bits(bits: i32) -> Option<OFlag>
pub const fn from_bits(bits: i32) -> Option<OFlag>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: i32) -> OFlag
pub const fn from_bits_truncate(bits: i32) -> OFlag
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: i32) -> OFlag
pub const unsafe fn from_bits_unchecked(bits: i32) -> OFlag
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: OFlag) -> bool
pub const fn intersects(&self, other: OFlag) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: OFlag) -> bool
pub const fn contains(&self, other: OFlag) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn set(&mut self, other: OFlag, value: bool)
pub fn set(&mut self, other: OFlag, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: OFlag) -> OFlag
pub const fn intersection(self, other: OFlag) -> OFlag
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: OFlag) -> OFlag
pub const fn union(self, other: OFlag) -> OFlag
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: OFlag) -> OFlag
pub const fn difference(self, other: OFlag) -> OFlag
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: OFlag) -> OFlag
pub const fn symmetric_difference(self, other: OFlag) -> OFlag
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> OFlag
pub const fn complement(self) -> OFlag
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.