pub struct MsFlags { /* private fields */ }Implementations
Sourceimpl MsFlags
impl MsFlags
Sourcepub const MS_SYNCHRONOUS: MsFlags
pub const MS_SYNCHRONOUS: MsFlags
Writes are synced at once
Sourcepub const MS_REMOUNT: MsFlags
pub const MS_REMOUNT: MsFlags
Alter flags of a mounted FS
Sourcepub const MS_MANDLOCK: MsFlags
pub const MS_MANDLOCK: MsFlags
Allow mandatory locks on a FS
Sourcepub const MS_DIRSYNC: MsFlags
pub const MS_DIRSYNC: MsFlags
Directory modifications are synchronous
Sourcepub const MS_NOATIME: MsFlags
pub const MS_NOATIME: MsFlags
Do not update access times
Sourcepub const MS_NODIRATIME: MsFlags
pub const MS_NODIRATIME: MsFlags
Do not update directory access times
pub const MS_MOVE: MsFlags
pub const MS_REC: MsFlags
pub const MS_SILENT: MsFlags
pub const MS_POSIXACL: MsFlags
pub const MS_UNBINDABLE: MsFlags
pub const MS_PRIVATE: MsFlags
pub const MS_SLAVE: MsFlags
pub const MS_SHARED: MsFlags
pub const MS_RELATIME: MsFlags
pub const MS_KERNMOUNT: MsFlags
pub const MS_I_VERSION: MsFlags
pub const MS_STRICTATIME: MsFlags
pub const MS_LAZYTIME: MsFlags
pub const MS_ACTIVE: MsFlags
pub const MS_NOUSER: MsFlags
pub const MS_RMT_MASK: MsFlags
pub const MS_MGC_VAL: MsFlags
pub const MS_MGC_MSK: MsFlags
Sourcepub const fn from_bits(bits: u64) -> Option<MsFlags>
pub const fn from_bits(bits: u64) -> Option<MsFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u64) -> MsFlags
pub const fn from_bits_truncate(bits: u64) -> MsFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u64) -> MsFlags
pub const unsafe fn from_bits_unchecked(bits: u64) -> MsFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: MsFlags) -> bool
pub const fn intersects(&self, other: MsFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: MsFlags) -> bool
pub const fn contains(&self, other: MsFlags) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn set(&mut self, other: MsFlags, value: bool)
pub fn set(&mut self, other: MsFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: MsFlags) -> MsFlags
pub const fn intersection(self, other: MsFlags) -> MsFlags
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: MsFlags) -> MsFlags
pub const fn union(self, other: MsFlags) -> MsFlags
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: MsFlags) -> MsFlags
pub const fn difference(self, other: MsFlags) -> MsFlags
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: MsFlags) -> MsFlags
pub const fn symmetric_difference(self, other: MsFlags) -> MsFlags
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> MsFlags
pub const fn complement(self) -> MsFlags
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.