pub struct MQ_OFlag { /* private fields */ }Implementations
Sourceimpl MQ_OFlag
impl MQ_OFlag
pub const O_RDONLY: MQ_OFlag
pub const O_WRONLY: MQ_OFlag
pub const O_RDWR: MQ_OFlag
pub const O_CREAT: MQ_OFlag
pub const O_EXCL: MQ_OFlag
pub const O_NONBLOCK: MQ_OFlag
pub const O_CLOEXEC: MQ_OFlag
Sourcepub const fn from_bits(bits: i32) -> Option<MQ_OFlag>
pub const fn from_bits(bits: i32) -> Option<MQ_OFlag>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: i32) -> MQ_OFlag
pub const fn from_bits_truncate(bits: i32) -> MQ_OFlag
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: i32) -> MQ_OFlag
pub const unsafe fn from_bits_unchecked(bits: i32) -> MQ_OFlag
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: MQ_OFlag) -> bool
pub const fn intersects(&self, other: MQ_OFlag) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: MQ_OFlag) -> bool
pub const fn contains(&self, other: MQ_OFlag) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn set(&mut self, other: MQ_OFlag, value: bool)
pub fn set(&mut self, other: MQ_OFlag, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: MQ_OFlag) -> MQ_OFlag
pub const fn intersection(self, other: MQ_OFlag) -> MQ_OFlag
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: MQ_OFlag) -> MQ_OFlag
pub const fn union(self, other: MQ_OFlag) -> MQ_OFlag
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: MQ_OFlag) -> MQ_OFlag
pub const fn difference(self, other: MQ_OFlag) -> MQ_OFlag
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: MQ_OFlag) -> MQ_OFlag
pub const fn symmetric_difference(self, other: MQ_OFlag) -> MQ_OFlag
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> MQ_OFlag
pub const fn complement(self) -> MQ_OFlag
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.