Module poll
otter_
nodejs_
tests
1.2.1
Module poll
Module Items
Structs
Functions
In otter_
nodejs_
tests::
nix
otter_nodejs_tests
::
nix
Module
poll
Wait for events to trigger on specific file descriptors
Structs

PollFd
This is a wrapper around
libc::pollfd
.
Poll
Flags
These flags define the different events that can be monitored by
poll
and
ppoll
Functions

poll
poll
waits for one of a set of file descriptors to become ready to perform I/O. (
poll(2)
)
ppoll
ppoll()
allows an application to safely wait until either a file descriptor becomes ready or until a signal is caught. (
poll(2)
)