pub struct PollFlags { /* private fields */ }Expand description
These flags define the different events that can be monitored by poll and ppoll
Implementations
Sourceimpl PollFlags
impl PollFlags
Sourcepub const POLLPRI: PollFlags
pub const POLLPRI: PollFlags
There is some exceptional condition on the file descriptor.
Possibilities include:
- There is out-of-band data on a TCP socket (see tcp(7)).
- A pseudoterminal master in packet mode has seen a state change on the slave (see ioctl_tty(2)).
- A cgroup.events file has been modified (see cgroups(7)).
Sourcepub const POLLOUT: PollFlags
pub const POLLOUT: PollFlags
Writing is now possible, though a write larger that the
available space in a socket or pipe will still block (unless
O_NONBLOCK is set).
Sourcepub const POLLRDNORM: PollFlags
pub const POLLRDNORM: PollFlags
Equivalent to POLLIN
Sourcepub const POLLWRNORM: PollFlags
pub const POLLWRNORM: PollFlags
Equivalent to POLLOUT
Sourcepub const POLLRDBAND: PollFlags
pub const POLLRDBAND: PollFlags
Priority band data can be read (generally unused on Linux).
Sourcepub const POLLWRBAND: PollFlags
pub const POLLWRBAND: PollFlags
Priority data may be written.
Sourcepub const POLLERR: PollFlags
pub const POLLERR: PollFlags
Error condition (only returned in
PollFd::revents;
ignored in PollFd::new).
This bit is also set for a file descriptor referring to the
write end of a pipe when the read end has been closed.
Sourcepub const POLLHUP: PollFlags
pub const POLLHUP: PollFlags
Hang up (only returned in PollFd::revents;
ignored in PollFd::new).
Note that when reading from a channel such as a pipe or a stream
socket, this event merely indicates that the peer closed its
end of the channel. Subsequent reads from the channel will
return 0 (end of file) only after all outstanding data in the
channel has been consumed.
Sourcepub const POLLNVAL: PollFlags
pub const POLLNVAL: PollFlags
Invalid request: fd not open (only returned in
PollFd::revents;
ignored in PollFd::new).
Sourcepub const fn from_bits(bits: i16) -> Option<PollFlags>
pub const fn from_bits(bits: i16) -> Option<PollFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: i16) -> PollFlags
pub const fn from_bits_truncate(bits: i16) -> PollFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: i16) -> PollFlags
pub const unsafe fn from_bits_unchecked(bits: i16) -> PollFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: PollFlags) -> bool
pub const fn intersects(&self, other: PollFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: PollFlags) -> bool
pub const fn contains(&self, other: PollFlags) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn set(&mut self, other: PollFlags, value: bool)
pub fn set(&mut self, other: PollFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: PollFlags) -> PollFlags
pub const fn intersection(self, other: PollFlags) -> PollFlags
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: PollFlags) -> PollFlags
pub const fn union(self, other: PollFlags) -> PollFlags
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: PollFlags) -> PollFlags
pub const fn difference(self, other: PollFlags) -> PollFlags
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: PollFlags) -> PollFlags
pub const fn symmetric_difference(self, other: PollFlags) -> PollFlags
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> PollFlags
pub const fn complement(self) -> PollFlags
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.