PtyMaster

Struct PtyMaster 

pub struct PtyMaster(/* private fields */);
Representation of the Master device in a master/slave pty pair

While this datatype is a thin wrapper around RawFd, it enforces that the available PTY functions are given the correct file descriptor. Additionally this type implements Drop, so that when it’s consumed or goes out of scope, it’s automatically cleaned-up.