pub struct CloneFlags { /* private fields */ }Expand description
Options for use with clone
Implementations
Sourceimpl CloneFlags
impl CloneFlags
Sourcepub const CLONE_VM: CloneFlags
pub const CLONE_VM: CloneFlags
The calling process and the child process run in the same memory space.
Sourcepub const CLONE_FS: CloneFlags
pub const CLONE_FS: CloneFlags
The caller and the child process share the same filesystem information.
Sourcepub const CLONE_FILES: CloneFlags
pub const CLONE_FILES: CloneFlags
The calling process and the child process share the same file descriptor table.
Sourcepub const CLONE_SIGHAND: CloneFlags
pub const CLONE_SIGHAND: CloneFlags
The calling process and the child process share the same table of signal handlers.
Sourcepub const CLONE_PTRACE: CloneFlags
pub const CLONE_PTRACE: CloneFlags
If the calling process is being traced, then trace the child also.
Sourcepub const CLONE_VFORK: CloneFlags
pub const CLONE_VFORK: CloneFlags
The execution of the calling process is suspended until the child releases its virtual memory resources via a call to execve(2) or _exit(2) (as with vfork(2)).
Sourcepub const CLONE_PARENT: CloneFlags
pub const CLONE_PARENT: CloneFlags
The parent of the new child (as returned by getppid(2)) will be the same as that of the calling process.
Sourcepub const CLONE_THREAD: CloneFlags
pub const CLONE_THREAD: CloneFlags
The child is placed in the same thread group as the calling process.
Sourcepub const CLONE_NEWNS: CloneFlags
pub const CLONE_NEWNS: CloneFlags
The cloned child is started in a new mount namespace.
Sourcepub const CLONE_SYSVSEM: CloneFlags
pub const CLONE_SYSVSEM: CloneFlags
The child and the calling process share a single list of System V semaphore adjustment values
Sourcepub const CLONE_DETACHED: CloneFlags
👎Deprecated since 0.23.0: Deprecated by Linux 2.6.2
pub const CLONE_DETACHED: CloneFlags
Deprecated by Linux 2.6.2
Unused since Linux 2.6.2
Sourcepub const CLONE_UNTRACED: CloneFlags
pub const CLONE_UNTRACED: CloneFlags
A tracing process cannot force CLONE_PTRACE on this child
process.
Sourcepub const CLONE_NEWCGROUP: CloneFlags
pub const CLONE_NEWCGROUP: CloneFlags
Create the process in a new cgroup namespace.
Sourcepub const CLONE_NEWUTS: CloneFlags
pub const CLONE_NEWUTS: CloneFlags
Create the process in a new UTS namespace.
Sourcepub const CLONE_NEWIPC: CloneFlags
pub const CLONE_NEWIPC: CloneFlags
Create the process in a new IPC namespace.
Sourcepub const CLONE_NEWUSER: CloneFlags
pub const CLONE_NEWUSER: CloneFlags
Create the process in a new user namespace.
Sourcepub const CLONE_NEWPID: CloneFlags
pub const CLONE_NEWPID: CloneFlags
Create the process in a new PID namespace.
Sourcepub const CLONE_NEWNET: CloneFlags
pub const CLONE_NEWNET: CloneFlags
Create the process in a new network namespace.
Sourcepub const CLONE_IO: CloneFlags
pub const CLONE_IO: CloneFlags
The new process shares an I/O context with the calling process.
Sourcepub const fn empty() -> CloneFlags
pub const fn empty() -> CloneFlags
Returns an empty set of flags.
Sourcepub const fn all() -> CloneFlags
pub const fn all() -> CloneFlags
Returns the set containing all flags.
Sourcepub const fn from_bits(bits: i32) -> Option<CloneFlags>
pub const fn from_bits(bits: i32) -> Option<CloneFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: i32) -> CloneFlags
pub const fn from_bits_truncate(bits: i32) -> CloneFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: i32) -> CloneFlags
pub const unsafe fn from_bits_unchecked(bits: i32) -> CloneFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: CloneFlags) -> bool
pub const fn intersects(&self, other: CloneFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: CloneFlags) -> bool
pub const fn contains(&self, other: CloneFlags) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: CloneFlags)
pub fn insert(&mut self, other: CloneFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: CloneFlags)
pub fn remove(&mut self, other: CloneFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: CloneFlags)
pub fn toggle(&mut self, other: CloneFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: CloneFlags, value: bool)
pub fn set(&mut self, other: CloneFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: CloneFlags) -> CloneFlags
pub const fn intersection(self, other: CloneFlags) -> CloneFlags
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: CloneFlags) -> CloneFlags
pub const fn union(self, other: CloneFlags) -> CloneFlags
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: CloneFlags) -> CloneFlags
pub const fn difference(self, other: CloneFlags) -> CloneFlags
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: CloneFlags) -> CloneFlags
pub const fn symmetric_difference(self, other: CloneFlags) -> CloneFlags
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> CloneFlags
pub const fn complement(self) -> CloneFlags
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.