#[non_exhaustive]#[repr(i32)]pub enum LioOpcode {
LIO_NOP = 2,
LIO_WRITE = 1,
LIO_READ = 0,
}Expand description
When used with lio_listio, determines whether a
given aiocb should be used for a read operation, a write operation, or
ignored. Has no effect for any other aio functions.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LIO_NOP = 2
No operation
LIO_WRITE = 1
Write data as if by a call to AioCb::write
LIO_READ = 0
Write data as if by a call to AioCb::read