pub struct LioCbBuilder<'a> {
pub aiocbs: Vec<AioCb<'a>>,
}Expand description
Used to construct LioCb
Fields
aiocbs: Vec<AioCb<'a>>A collection of AioCbs.
Implementations
Sourceimpl<'a> LioCbBuilder<'a>
impl<'a> LioCbBuilder<'a>
Sourcepub fn with_capacity(capacity: usize) -> LioCbBuilder<'a>
pub fn with_capacity(capacity: usize) -> LioCbBuilder<'a>
Initialize an empty LioCb
Sourcepub fn emplace_slice(
self,
fd: i32,
offs: i64,
buf: &'a [u8],
prio: i32,
sigev_notify: SigevNotify,
opcode: LioOpcode,
) -> LioCbBuilder<'a>
pub fn emplace_slice( self, fd: i32, offs: i64, buf: &'a [u8], prio: i32, sigev_notify: SigevNotify, opcode: LioOpcode, ) -> LioCbBuilder<'a>
Add a new operation on an immutable slice to the LioCb under
construction.
Arguments are the same as for AioCb::from_slice
Sourcepub fn emplace_mut_slice(
self,
fd: i32,
offs: i64,
buf: &'a mut [u8],
prio: i32,
sigev_notify: SigevNotify,
opcode: LioOpcode,
) -> LioCbBuilder<'a>
pub fn emplace_mut_slice( self, fd: i32, offs: i64, buf: &'a mut [u8], prio: i32, sigev_notify: SigevNotify, opcode: LioOpcode, ) -> LioCbBuilder<'a>
Add a new operation on a mutable slice to the LioCb under
construction.
Arguments are the same as for AioCb::from_mut_slice
Sourcepub fn finish(self) -> LioCb<'a>
pub fn finish(self) -> LioCb<'a>
Finalize this LioCb.
Afterwards it will be possible to issue the operations with
LioCb::listio. Conversely, it will no longer be possible to add new
operations with LioCbBuilder::emplace_slice or
LioCbBuilder::emplace_mut_slice.