pub struct AddWatchFlags { /* private fields */ }Expand description
Configuration options for inotify_add_watch.
Implementations
Sourceimpl AddWatchFlags
impl AddWatchFlags
Sourcepub const IN_ACCESS: AddWatchFlags
pub const IN_ACCESS: AddWatchFlags
File was accessed.
Sourcepub const IN_MODIFY: AddWatchFlags
pub const IN_MODIFY: AddWatchFlags
File was modified.
Sourcepub const IN_ATTRIB: AddWatchFlags
pub const IN_ATTRIB: AddWatchFlags
Metadata changed.
Sourcepub const IN_CLOSE_WRITE: AddWatchFlags
pub const IN_CLOSE_WRITE: AddWatchFlags
Writable file was closed.
Sourcepub const IN_CLOSE_NOWRITE: AddWatchFlags
pub const IN_CLOSE_NOWRITE: AddWatchFlags
Nonwritable file was closed.
Sourcepub const IN_OPEN: AddWatchFlags
pub const IN_OPEN: AddWatchFlags
File was opened.
Sourcepub const IN_MOVED_FROM: AddWatchFlags
pub const IN_MOVED_FROM: AddWatchFlags
File was moved from X.
Sourcepub const IN_MOVED_TO: AddWatchFlags
pub const IN_MOVED_TO: AddWatchFlags
File was moved to Y.
Sourcepub const IN_CREATE: AddWatchFlags
pub const IN_CREATE: AddWatchFlags
Subfile was created.
Sourcepub const IN_DELETE: AddWatchFlags
pub const IN_DELETE: AddWatchFlags
Subfile was deleted.
Sourcepub const IN_DELETE_SELF: AddWatchFlags
pub const IN_DELETE_SELF: AddWatchFlags
Self was deleted.
Sourcepub const IN_MOVE_SELF: AddWatchFlags
pub const IN_MOVE_SELF: AddWatchFlags
Self was moved.
Sourcepub const IN_UNMOUNT: AddWatchFlags
pub const IN_UNMOUNT: AddWatchFlags
Backing filesystem was unmounted.
Sourcepub const IN_Q_OVERFLOW: AddWatchFlags
pub const IN_Q_OVERFLOW: AddWatchFlags
Event queue overflowed.
Sourcepub const IN_IGNORED: AddWatchFlags
pub const IN_IGNORED: AddWatchFlags
File was ignored.
Sourcepub const IN_CLOSE: AddWatchFlags
pub const IN_CLOSE: AddWatchFlags
Combination of IN_CLOSE_WRITE and IN_CLOSE_NOWRITE.
Sourcepub const IN_MOVE: AddWatchFlags
pub const IN_MOVE: AddWatchFlags
Combination of IN_MOVED_FROM and IN_MOVED_TO.
Sourcepub const IN_ONLYDIR: AddWatchFlags
pub const IN_ONLYDIR: AddWatchFlags
Only watch the path if it is a directory.
Sourcepub const IN_DONT_FOLLOW: AddWatchFlags
pub const IN_DONT_FOLLOW: AddWatchFlags
Don’t follow symlinks.
Sourcepub const IN_ISDIR: AddWatchFlags
pub const IN_ISDIR: AddWatchFlags
Event occurred against directory.
Sourcepub const IN_ONESHOT: AddWatchFlags
pub const IN_ONESHOT: AddWatchFlags
Only send event once.
Sourcepub const IN_ALL_EVENTS: AddWatchFlags
pub const IN_ALL_EVENTS: AddWatchFlags
All of the events.
Sourcepub const fn empty() -> AddWatchFlags
pub const fn empty() -> AddWatchFlags
Returns an empty set of flags.
Sourcepub const fn all() -> AddWatchFlags
pub const fn all() -> AddWatchFlags
Returns the set containing all flags.
Sourcepub const fn from_bits(bits: u32) -> Option<AddWatchFlags>
pub const fn from_bits(bits: u32) -> Option<AddWatchFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> AddWatchFlags
pub const fn from_bits_truncate(bits: u32) -> AddWatchFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> AddWatchFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> AddWatchFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: AddWatchFlags) -> bool
pub const fn intersects(&self, other: AddWatchFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: AddWatchFlags) -> bool
pub const fn contains(&self, other: AddWatchFlags) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: AddWatchFlags)
pub fn insert(&mut self, other: AddWatchFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: AddWatchFlags)
pub fn remove(&mut self, other: AddWatchFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: AddWatchFlags)
pub fn toggle(&mut self, other: AddWatchFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: AddWatchFlags, value: bool)
pub fn set(&mut self, other: AddWatchFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: AddWatchFlags) -> AddWatchFlags
pub const fn intersection(self, other: AddWatchFlags) -> AddWatchFlags
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: AddWatchFlags) -> AddWatchFlags
pub const fn union(self, other: AddWatchFlags) -> AddWatchFlags
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: AddWatchFlags) -> AddWatchFlags
pub const fn difference(self, other: AddWatchFlags) -> AddWatchFlags
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: AddWatchFlags) -> AddWatchFlags
pub const fn symmetric_difference(self, other: AddWatchFlags) -> AddWatchFlags
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> AddWatchFlags
pub const fn complement(self) -> AddWatchFlags
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.