pub struct WatchDescriptor { /* private fields */ }Expand description
This object is returned when you create a new watch on an inotify instance. It is then returned as part of an event once triggered. It allows you to know which watch triggered which event.