pub struct MemFdCreateFlag { /* private fields */ }Expand description
Options that change the behavior of memfd_create.
Implementations
Sourceimpl MemFdCreateFlag
impl MemFdCreateFlag
Sourcepub const MFD_CLOEXEC: MemFdCreateFlag
pub const MFD_CLOEXEC: MemFdCreateFlag
Set the close-on-exec (FD_CLOEXEC) flag on the new file descriptor.
By default, the new file descriptor is set to remain open across an execve
(the FD_CLOEXEC flag is initially disabled). This flag can be used to change
this default. The file offset is set to the beginning of the file (see lseek).
See also the description of the O_CLOEXEC flag in open(2).
Sourcepub const MFD_ALLOW_SEALING: MemFdCreateFlag
pub const MFD_ALLOW_SEALING: MemFdCreateFlag
Allow sealing operations on this file.
See also the file sealing notes given in memfd_create(2).
Sourcepub const fn empty() -> MemFdCreateFlag
pub const fn empty() -> MemFdCreateFlag
Returns an empty set of flags.
Sourcepub const fn all() -> MemFdCreateFlag
pub const fn all() -> MemFdCreateFlag
Returns the set containing all flags.
Sourcepub const fn from_bits(bits: u32) -> Option<MemFdCreateFlag>
pub const fn from_bits(bits: u32) -> Option<MemFdCreateFlag>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> MemFdCreateFlag
pub const fn from_bits_truncate(bits: u32) -> MemFdCreateFlag
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> MemFdCreateFlag
pub const unsafe fn from_bits_unchecked(bits: u32) -> MemFdCreateFlag
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: MemFdCreateFlag) -> bool
pub const fn intersects(&self, other: MemFdCreateFlag) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: MemFdCreateFlag) -> bool
pub const fn contains(&self, other: MemFdCreateFlag) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: MemFdCreateFlag)
pub fn insert(&mut self, other: MemFdCreateFlag)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: MemFdCreateFlag)
pub fn remove(&mut self, other: MemFdCreateFlag)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: MemFdCreateFlag)
pub fn toggle(&mut self, other: MemFdCreateFlag)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: MemFdCreateFlag, value: bool)
pub fn set(&mut self, other: MemFdCreateFlag, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: MemFdCreateFlag) -> MemFdCreateFlag
pub const fn intersection(self, other: MemFdCreateFlag) -> MemFdCreateFlag
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: MemFdCreateFlag) -> MemFdCreateFlag
pub const fn union(self, other: MemFdCreateFlag) -> MemFdCreateFlag
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: MemFdCreateFlag) -> MemFdCreateFlag
pub const fn difference(self, other: MemFdCreateFlag) -> MemFdCreateFlag
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(
self,
other: MemFdCreateFlag,
) -> MemFdCreateFlag
pub const fn symmetric_difference( self, other: MemFdCreateFlag, ) -> MemFdCreateFlag
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> MemFdCreateFlag
pub const fn complement(self) -> MemFdCreateFlag
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.