pub struct MapFlags { /* private fields */ }Expand description
Additional parameters for mmap.
Implementations
Sourceimpl MapFlags
impl MapFlags
Sourcepub const MAP_SHARED: MapFlags
pub const MAP_SHARED: MapFlags
Share this mapping. Mutually exclusive with MAP_PRIVATE.
Sourcepub const MAP_PRIVATE: MapFlags
pub const MAP_PRIVATE: MapFlags
Create a private copy-on-write mapping. Mutually exclusive with MAP_SHARED.
Sourcepub const MAP_FIXED_NOREPLACE: MapFlags
pub const MAP_FIXED_NOREPLACE: MapFlags
Place the mapping at exactly the address specified in addr, but never clobber an existing range.
Sourcepub const MAP_ANONYMOUS: MapFlags
pub const MAP_ANONYMOUS: MapFlags
The mapping is not backed by any file.
Sourcepub const MAP_GROWSDOWN: MapFlags
pub const MAP_GROWSDOWN: MapFlags
Used for stacks; indicates to the kernel that the mapping should extend downward in memory.
Sourcepub const MAP_DENYWRITE: MapFlags
pub const MAP_DENYWRITE: MapFlags
Compatibility flag. Ignored.
Sourcepub const MAP_EXECUTABLE: MapFlags
pub const MAP_EXECUTABLE: MapFlags
Compatibility flag. Ignored.
Sourcepub const MAP_LOCKED: MapFlags
pub const MAP_LOCKED: MapFlags
Mark the mmaped region to be locked in the same way as mlock(2).
Sourcepub const MAP_NORESERVE: MapFlags
pub const MAP_NORESERVE: MapFlags
Do not reserve swap space for this mapping.
This was removed in FreeBSD 11 and is unused in DragonFlyBSD.
Sourcepub const MAP_POPULATE: MapFlags
pub const MAP_POPULATE: MapFlags
Populate page tables for a mapping.
Sourcepub const MAP_NONBLOCK: MapFlags
pub const MAP_NONBLOCK: MapFlags
Only meaningful when used with MAP_POPULATE. Don’t perform read-ahead.
Sourcepub const MAP_HUGETLB: MapFlags
pub const MAP_HUGETLB: MapFlags
Allocate the mapping using “huge pages.”
Sourcepub const MAP_HUGE_64KB: MapFlags
pub const MAP_HUGE_64KB: MapFlags
Make use of 64KB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_512KB: MapFlags
pub const MAP_HUGE_512KB: MapFlags
Make use of 512KB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_1MB: MapFlags
pub const MAP_HUGE_1MB: MapFlags
Make use of 1MB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_2MB: MapFlags
pub const MAP_HUGE_2MB: MapFlags
Make use of 2MB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_8MB: MapFlags
pub const MAP_HUGE_8MB: MapFlags
Make use of 8MB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_16MB: MapFlags
pub const MAP_HUGE_16MB: MapFlags
Make use of 16MB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_32MB: MapFlags
pub const MAP_HUGE_32MB: MapFlags
Make use of 32MB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_256MB: MapFlags
pub const MAP_HUGE_256MB: MapFlags
Make use of 256MB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_512MB: MapFlags
pub const MAP_HUGE_512MB: MapFlags
Make use of 512MB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_1GB: MapFlags
pub const MAP_HUGE_1GB: MapFlags
Make use of 1GB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_2GB: MapFlags
pub const MAP_HUGE_2GB: MapFlags
Make use of 2GB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_16GB: MapFlags
pub const MAP_HUGE_16GB: MapFlags
Make use of 16GB huge page (must be supported by the system)
Sourcepub const fn from_bits(bits: i32) -> Option<MapFlags>
pub const fn from_bits(bits: i32) -> Option<MapFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: i32) -> MapFlags
pub const fn from_bits_truncate(bits: i32) -> MapFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: i32) -> MapFlags
pub const unsafe fn from_bits_unchecked(bits: i32) -> MapFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: MapFlags) -> bool
pub const fn intersects(&self, other: MapFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: MapFlags) -> bool
pub const fn contains(&self, other: MapFlags) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn set(&mut self, other: MapFlags, value: bool)
pub fn set(&mut self, other: MapFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: MapFlags) -> MapFlags
pub const fn intersection(self, other: MapFlags) -> MapFlags
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: MapFlags) -> MapFlags
pub const fn union(self, other: MapFlags) -> MapFlags
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: MapFlags) -> MapFlags
pub const fn difference(self, other: MapFlags) -> MapFlags
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: MapFlags) -> MapFlags
pub const fn symmetric_difference(self, other: MapFlags) -> MapFlags
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> MapFlags
pub const fn complement(self) -> MapFlags
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.