pub struct ProtFlags { /* private fields */ }Expand description
Desired memory protection of a memory mapping.
Implementations
Sourceimpl ProtFlags
impl ProtFlags
Sourcepub const PROT_WRITE: ProtFlags
pub const PROT_WRITE: ProtFlags
Pages can be written.
Sourcepub const PROT_GROWSDOWN: ProtFlags
pub const PROT_GROWSDOWN: ProtFlags
Apply protection up to the end of a mapping that grows upwards.
Sourcepub const PROT_GROWSUP: ProtFlags
pub const PROT_GROWSUP: ProtFlags
Apply protection down to the beginning of a mapping that grows downwards.
Sourcepub const fn from_bits(bits: i32) -> Option<ProtFlags>
pub const fn from_bits(bits: i32) -> Option<ProtFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: i32) -> ProtFlags
pub const fn from_bits_truncate(bits: i32) -> ProtFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: i32) -> ProtFlags
pub const unsafe fn from_bits_unchecked(bits: i32) -> ProtFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: ProtFlags) -> bool
pub const fn intersects(&self, other: ProtFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: ProtFlags) -> bool
pub const fn contains(&self, other: ProtFlags) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn set(&mut self, other: ProtFlags, value: bool)
pub fn set(&mut self, other: ProtFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: ProtFlags) -> ProtFlags
pub const fn intersection(self, other: ProtFlags) -> ProtFlags
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: ProtFlags) -> ProtFlags
pub const fn union(self, other: ProtFlags) -> ProtFlags
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: ProtFlags) -> ProtFlags
pub const fn difference(self, other: ProtFlags) -> ProtFlags
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: ProtFlags) -> ProtFlags
pub const fn symmetric_difference(self, other: ProtFlags) -> ProtFlags
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> ProtFlags
pub const fn complement(self) -> ProtFlags
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.