Persona

Struct Persona 

pub struct Persona { /* private fields */ }
Flags used and returned by get() and set().

Implementations

Source

impl Persona

pub const ADDR_COMPAT_LAYOUT: Persona

Provide the legacy virtual address space layout.

pub const ADDR_NO_RANDOMIZE: Persona

Disable address-space-layout randomization.

pub const ADDR_LIMIT_32BIT: Persona

Limit the address space to 32 bits.

pub const ADDR_LIMIT_3GB: Persona

Use 0xc0000000 as the offset at which to search a virtual memory chunk on mmap(2), otherwise use 0xffffe000.

pub const FDPIC_FUNCPTRS: Persona

User-space function pointers to signal handlers point to descriptors.

pub const MMAP_PAGE_ZERO: Persona

Map page 0 as read-only.

pub const READ_IMPLIES_EXEC: Persona

PROT_READ implies PROT_EXEC for mmap(2).

pub const SHORT_INODE: Persona

No effects.

pub const STICKY_TIMEOUTS: Persona

select(2), pselect(2), and ppoll(2) do not modify the returned timeout argument when interrupted by a signal handler.

pub const UNAME26: Persona

Have uname(2) report a 2.6.40+ version number rather than a 3.x version number.

pub const WHOLE_SECONDS: Persona

No effects.

pub const fn empty() -> Persona

Returns an empty set of flags.

pub const fn all() -> Persona

Returns the set containing all flags.

pub const fn bits(&self) -> i32

Returns the raw value of the flags currently stored.

pub const fn from_bits(bits: i32) -> Option<Persona>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub const fn from_bits_truncate(bits: i32) -> Persona

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub const unsafe fn from_bits_unchecked(bits: i32) -> Persona

Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).

Safety

The caller of the bitflags! macro can chose to allow or disallow extra bits for their bitflags type.

The caller of from_bits_unchecked() has to ensure that all bits correspond to a defined flag or that extra bits are valid for this bitflags type.

pub const fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

pub const fn is_all(&self) -> bool

Returns true if all flags are currently set.

pub const fn intersects(&self, other: Persona) -> bool

Returns true if there are flags common to both self and other.

pub const fn contains(&self, other: Persona) -> bool

Returns true if all of the flags in other are contained within self.

pub fn insert(&mut self, other: Persona)

Inserts the specified flags in-place.

pub fn remove(&mut self, other: Persona)

Removes the specified flags in-place.

pub fn toggle(&mut self, other: Persona)

Toggles the specified flags in-place.

pub fn set(&mut self, other: Persona, value: bool)

Inserts or removes the specified flags depending on the passed value.

pub const fn intersection(self, other: Persona) -> Persona

Returns the intersection between the flags in self and other.

Specifically, the returned set contains only the flags which are present in both self and other.

This is equivalent to using the & operator (e.g. ops::BitAnd), as in flags & other.

pub const fn union(self, other: Persona) -> Persona

Returns the union of between the flags in self and other.

Specifically, the returned set contains all flags which are present in either self or other, including any which are present in both (see Self::symmetric_difference if that is undesirable).

This is equivalent to using the | operator (e.g. ops::BitOr), as in flags | other.

pub const fn difference(self, other: Persona) -> Persona

Returns the difference between the flags in self and other.

Specifically, the returned set contains all flags present in self, except for the ones present in other.

It is also conceptually equivalent to the “bit-clear” operation: flags & !other (and this syntax is also supported).

This is equivalent to using the - operator (e.g. ops::Sub), as in flags - other.

pub const fn symmetric_difference(self, other: Persona) -> Persona

Returns the symmetric difference between the flags in self and other.

Specifically, the returned set contains the flags present which are present in self or other, but that are not present in both. Equivalently, it contains the flags present in exactly one of the sets self and other.

This is equivalent to using the ^ operator (e.g. ops::BitXor), as in flags ^ other.

pub const fn complement(self) -> Persona

Returns the complement of this set of flags.

Specifically, the returned set contains all the flags which are not set in self, but which are allowed for this type.

Alternatively, it can be thought of as the set difference between Self::all() and self (e.g. Self::all() - self)

This is equivalent to using the ! operator (e.g. ops::Not), as in !flags.