#[non_exhaustive]#[repr(i32)]pub enum Event {
PTRACE_EVENT_FORK = 1,
PTRACE_EVENT_VFORK = 2,
PTRACE_EVENT_CLONE = 3,
PTRACE_EVENT_EXEC = 4,
PTRACE_EVENT_VFORK_DONE = 5,
PTRACE_EVENT_EXIT = 6,
PTRACE_EVENT_SECCOMP = 7,
PTRACE_EVENT_STOP = 128,
}Expand description
Using the ptrace options the tracer can configure the tracee to stop
at certain events. This enum is used to define those events as defined
in man ptrace.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PTRACE_EVENT_FORK = 1
Event that stops before a return from fork or clone.
PTRACE_EVENT_VFORK = 2
Event that stops before a return from vfork or clone.
PTRACE_EVENT_CLONE = 3
Event that stops before a return from clone.
PTRACE_EVENT_EXEC = 4
Event that stops before a return from execve.
PTRACE_EVENT_VFORK_DONE = 5
Event for a return from vfork.
PTRACE_EVENT_EXIT = 6
Event for a stop before an exit. Unlike the waitpid Exit status program. registers can still be examined
PTRACE_EVENT_SECCOMP = 7
Stop triggered by a seccomp rule on a tracee.
PTRACE_EVENT_STOP = 128
Stop triggered by the INTERRUPT syscall, or a group stop,
or when a new child is attached.