syscall

Function syscall 

pub fn syscall<T>(pid: Pid, sig: T) -> Result<(), Errno>
where T: Into<Option<Signal>>,
Continue execution until the next syscall, as with ptrace(PTRACE_SYSCALL, ...)

Arranges for the tracee to be stopped at the next entry to or exit from a system call, optionally delivering a signal specified by sig.