pub struct Options { /* private fields */ }Expand description
Ptrace options used in conjunction with the PTRACE_SETOPTIONS request.
See man ptrace for more details.
Implementations
Sourceimpl Options
impl Options
Sourcepub const PTRACE_O_TRACESYSGOOD: Options
pub const PTRACE_O_TRACESYSGOOD: Options
When delivering system call traps set a bit to allow tracer to distinguish between normal stops or syscall stops. May not work on all systems.
Sourcepub const PTRACE_O_TRACEFORK: Options
pub const PTRACE_O_TRACEFORK: Options
Stop tracee at next fork and start tracing the forked process.
Sourcepub const PTRACE_O_TRACEVFORK: Options
pub const PTRACE_O_TRACEVFORK: Options
Stop tracee at next vfork call and trace the vforked process.
Sourcepub const PTRACE_O_TRACECLONE: Options
pub const PTRACE_O_TRACECLONE: Options
Stop tracee at next clone call and trace the cloned process.
Sourcepub const PTRACE_O_TRACEEXEC: Options
pub const PTRACE_O_TRACEEXEC: Options
Stop tracee at next execve call.
Sourcepub const PTRACE_O_TRACEVFORKDONE: Options
pub const PTRACE_O_TRACEVFORKDONE: Options
Stop tracee at vfork completion.
Sourcepub const PTRACE_O_TRACEEXIT: Options
pub const PTRACE_O_TRACEEXIT: Options
Stop tracee at next exit call. Stops before exit commences allowing tracer to see location of exit and register states.
Sourcepub const PTRACE_O_TRACESECCOMP: Options
pub const PTRACE_O_TRACESECCOMP: Options
Stop tracee when a SECCOMP_RET_TRACE rule is triggered. See man seccomp for more
details.
Sourcepub const PTRACE_O_EXITKILL: Options
pub const PTRACE_O_EXITKILL: Options
Send a SIGKILL to the tracee if the tracer exits. This is useful for ptrace jailers to prevent tracees from escaping their control.
Sourcepub const fn from_bits(bits: i32) -> Option<Options>
pub const fn from_bits(bits: i32) -> Option<Options>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: i32) -> Options
pub const fn from_bits_truncate(bits: i32) -> Options
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: i32) -> Options
pub const unsafe fn from_bits_unchecked(bits: i32) -> Options
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: Options) -> bool
pub const fn intersects(&self, other: Options) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: Options) -> bool
pub const fn contains(&self, other: Options) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn set(&mut self, other: Options, value: bool)
pub fn set(&mut self, other: Options, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: Options) -> Options
pub const fn intersection(self, other: Options) -> Options
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: Options) -> Options
pub const fn union(self, other: Options) -> Options
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: Options) -> Options
pub const fn difference(self, other: Options) -> Options
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: Options) -> Options
pub const fn symmetric_difference(self, other: Options) -> Options
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> Options
pub const fn complement(self) -> Options
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.