pub struct QuotaValidFlags { /* private fields */ }Expand description
Indicates the quota fields that are valid to read from.
Implementations
Sourceimpl QuotaValidFlags
impl QuotaValidFlags
Sourcepub const QIF_BLIMITS: QuotaValidFlags
pub const QIF_BLIMITS: QuotaValidFlags
The block hard & soft limit fields.
Sourcepub const QIF_SPACE: QuotaValidFlags
pub const QIF_SPACE: QuotaValidFlags
The current space field.
Sourcepub const QIF_ILIMITS: QuotaValidFlags
pub const QIF_ILIMITS: QuotaValidFlags
The inode hard & soft limit fields.
Sourcepub const QIF_INODES: QuotaValidFlags
pub const QIF_INODES: QuotaValidFlags
The current inodes field.
Sourcepub const QIF_BTIME: QuotaValidFlags
pub const QIF_BTIME: QuotaValidFlags
The disk use time limit field.
Sourcepub const QIF_ITIME: QuotaValidFlags
pub const QIF_ITIME: QuotaValidFlags
The file quote time limit field.
Sourcepub const QIF_LIMITS: QuotaValidFlags
pub const QIF_LIMITS: QuotaValidFlags
All block & inode limits.
Sourcepub const QIF_USAGE: QuotaValidFlags
pub const QIF_USAGE: QuotaValidFlags
The space & inodes usage fields.
Sourcepub const QIF_TIMES: QuotaValidFlags
pub const QIF_TIMES: QuotaValidFlags
The time limit fields.
Sourcepub const QIF_ALL: QuotaValidFlags
pub const QIF_ALL: QuotaValidFlags
All fields.
Sourcepub const fn empty() -> QuotaValidFlags
pub const fn empty() -> QuotaValidFlags
Returns an empty set of flags.
Sourcepub const fn all() -> QuotaValidFlags
pub const fn all() -> QuotaValidFlags
Returns the set containing all flags.
Sourcepub const fn from_bits(bits: u32) -> Option<QuotaValidFlags>
pub const fn from_bits(bits: u32) -> Option<QuotaValidFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> QuotaValidFlags
pub const fn from_bits_truncate(bits: u32) -> QuotaValidFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> QuotaValidFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> QuotaValidFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: QuotaValidFlags) -> bool
pub const fn intersects(&self, other: QuotaValidFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: QuotaValidFlags) -> bool
pub const fn contains(&self, other: QuotaValidFlags) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: QuotaValidFlags)
pub fn insert(&mut self, other: QuotaValidFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: QuotaValidFlags)
pub fn remove(&mut self, other: QuotaValidFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: QuotaValidFlags)
pub fn toggle(&mut self, other: QuotaValidFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: QuotaValidFlags, value: bool)
pub fn set(&mut self, other: QuotaValidFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: QuotaValidFlags) -> QuotaValidFlags
pub const fn intersection(self, other: QuotaValidFlags) -> QuotaValidFlags
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: QuotaValidFlags) -> QuotaValidFlags
pub const fn union(self, other: QuotaValidFlags) -> QuotaValidFlags
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: QuotaValidFlags) -> QuotaValidFlags
pub const fn difference(self, other: QuotaValidFlags) -> QuotaValidFlags
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(
self,
other: QuotaValidFlags,
) -> QuotaValidFlags
pub const fn symmetric_difference( self, other: QuotaValidFlags, ) -> QuotaValidFlags
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> QuotaValidFlags
pub const fn complement(self) -> QuotaValidFlags
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.