#[non_exhaustive]#[repr(i32)]pub enum RebootMode {
RB_HALT_SYSTEM = -839_974_621,
RB_KEXEC = 1_163_412_803,
RB_POWER_OFF = 1_126_301_404,
RB_AUTOBOOT = 19_088_743,
RB_SW_SUSPEND = -805_241_630,
}Expand description
How exactly should the system be rebooted.
See set_cad_enabled() for
enabling/disabling Ctrl-Alt-Delete.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RB_HALT_SYSTEM = -839_974_621
Halt the system.
RB_KEXEC = 1_163_412_803
Execute a kernel that has been loaded earlier with
kexec_load(2).
RB_POWER_OFF = 1_126_301_404
Stop the system and switch off power, if possible.
RB_AUTOBOOT = 19_088_743
Restart the system.
RB_SW_SUSPEND = -805_241_630
Suspend the system using software suspend.