#[non_exhaustive]#[repr(u32)]pub enum Resource {
Show 16 variants
RLIMIT_AS = 9,
RLIMIT_CORE = 4,
RLIMIT_CPU = 0,
RLIMIT_DATA = 2,
RLIMIT_FSIZE = 1,
RLIMIT_NOFILE = 7,
RLIMIT_STACK = 3,
RLIMIT_LOCKS = 10,
RLIMIT_MEMLOCK = 8,
RLIMIT_MSGQUEUE = 12,
RLIMIT_NICE = 13,
RLIMIT_NPROC = 6,
RLIMIT_RSS = 5,
RLIMIT_RTPRIO = 14,
RLIMIT_RTTIME = 15,
RLIMIT_SIGPENDING = 11,
}Expand description
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
RLIMIT_AS = 9
The maximum amount (in bytes) of virtual memory the process is allowed to map.
RLIMIT_CORE = 4
The largest size (in bytes) core(5) file that may be created.
RLIMIT_CPU = 0
The maximum amount of cpu time (in seconds) to be used by each process.
RLIMIT_DATA = 2
The maximum size (in bytes) of the data segment for a process
RLIMIT_FSIZE = 1
The largest size (in bytes) file that may be created.
RLIMIT_NOFILE = 7
The maximum number of open files for this process.
RLIMIT_STACK = 3
The maximum size (in bytes) of the stack segment for a process.
RLIMIT_LOCKS = 10
A limit on the combined number of flock locks and fcntl leases that this process may establish.
RLIMIT_MEMLOCK = 8
The maximum size (in bytes) which a process may lock into memory using the mlock(2) system call.
RLIMIT_MSGQUEUE = 12
A limit on the number of bytes that can be allocated for POSIX message queues for the real user ID of the calling process.
RLIMIT_NICE = 13
A ceiling to which the process’s nice value can be raised using setpriority or nice.
RLIMIT_NPROC = 6
The maximum number of simultaneous processes for this user id.
RLIMIT_RSS = 5
When there is memory pressure and swap is available, prioritize eviction of a process’ resident pages beyond this amount (in bytes).
RLIMIT_RTPRIO = 14
A ceiling on the real-time priority that may be set for this process using sched_setscheduler and sched_set‐ param.
RLIMIT_RTTIME = 15
A limit (in microseconds) on the amount of CPU time that a process scheduled under a real-time scheduling policy may con‐ sume without making a blocking system call.
RLIMIT_SIGPENDING = 11
A limit on the number of signals that may be queued for the real user ID of the calling process.