Module select
otter_
nodejs_
tests
1.2.1
Module select
Module Items
Structs
Constants
Functions
In otter_
nodejs_
tests::
nix::
sys
otter_nodejs_tests
::
nix
::
sys
Module
select
Portably monitor a group of file descriptors for readiness.
Structs

FdSet
Contains a set of file descriptors used by
select
Fds
Iterator over
FdSet
.
Constants

FD_
SETSIZE
Functions

pselect
Monitors file descriptors for readiness with an altered signal mask.
select
Monitors file descriptors for readiness