pub struct FdSet(/* private fields */);Expand description
Contains a set of file descriptors used by select
Implementations
Sourceimpl FdSet
impl FdSet
Sourcepub fn contains(&self, fd: i32) -> bool
pub fn contains(&self, fd: i32) -> bool
Test an FdSet for the presence of a certain file descriptor.
Sourcepub fn fds(&self, highest: Option<i32>) -> Fds<'_> ⓘ
pub fn fds(&self, highest: Option<i32>) -> Fds<'_> ⓘ
Returns an iterator over the file descriptors in the set.
For performance, it takes an optional higher bound: the iterator will not return any elements of the set greater than the given file descriptor.
Examples
let mut set = FdSet::new();
set.insert(4);
set.insert(9);
let fds: Vec<RawFd> = set.fds(None).collect();
assert_eq!(fds, vec![4, 9]);Trait Implementations
impl Copy for FdSet
impl Eq for FdSet
impl StructuralPartialEq for FdSet