pub enum SigHandler {
SigDfl,
SigIgn,
Handler(extern "C" fn(i32)),
SigAction(extern "C" fn(i32, *mut siginfo_t, *mut c_void)),
}Expand description
A signal handler.
Variants
SigDfl
Default signal handling.
SigIgn
Request that the signal be ignored.
Handler(extern "C" fn(i32))
Use the given signal-catching function, which takes in the signal.
SigAction(extern "C" fn(i32, *mut siginfo_t, *mut c_void))
Use the given signal-catching function, which takes in the signal, information about how
the signal was generated, and a pointer to the threads ucontext_t.