#[non_exhaustive]#[repr(i32)]pub enum SigmaskHow {
SIG_BLOCK = 0,
SIG_UNBLOCK = 1,
SIG_SETMASK = 2,
}Expand description
Specifies how certain functions should manipulate a signal mask
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SIG_BLOCK = 0
The new mask is the union of the current mask and the specified set.
SIG_UNBLOCK = 1
The new mask is the intersection of the current mask and the complement of the specified set.
SIG_SETMASK = 2
The current mask is replaced by the specified set.