pub struct SaFlags { /* private fields */ }Expand description
Controls the behavior of a SigAction
Implementations
Sourceimpl SaFlags
impl SaFlags
Sourcepub const SA_NOCLDSTOP: SaFlags
pub const SA_NOCLDSTOP: SaFlags
When catching a Signal::SIGCHLD signal, the signal will be
generated only when a child process exits, not when a child process
stops.
Sourcepub const SA_NOCLDWAIT: SaFlags
pub const SA_NOCLDWAIT: SaFlags
When catching a Signal::SIGCHLD signal, the system will not
create zombie processes when children of the calling process exit.
Sourcepub const SA_NODEFER: SaFlags
pub const SA_NODEFER: SaFlags
Further occurrences of the delivered signal are not masked during the execution of the handler.
Sourcepub const SA_ONSTACK: SaFlags
pub const SA_ONSTACK: SaFlags
The system will deliver the signal to the process on a signal stack, specified by each thread with sigaltstack(2).
Sourcepub const SA_RESETHAND: SaFlags
pub const SA_RESETHAND: SaFlags
The handler is reset back to the default at the moment the signal is delivered.
Sourcepub const SA_RESTART: SaFlags
pub const SA_RESTART: SaFlags
Requests that certain system calls restart if interrupted by this signal. See the man page for complete details.
Sourcepub const SA_SIGINFO: SaFlags
pub const SA_SIGINFO: SaFlags
This flag is controlled internally by Nix.
Sourcepub const fn from_bits(bits: i32) -> Option<SaFlags>
pub const fn from_bits(bits: i32) -> Option<SaFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: i32) -> SaFlags
pub const fn from_bits_truncate(bits: i32) -> SaFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: i32) -> SaFlags
pub const unsafe fn from_bits_unchecked(bits: i32) -> SaFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: SaFlags) -> bool
pub const fn intersects(&self, other: SaFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: SaFlags) -> bool
pub const fn contains(&self, other: SaFlags) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn set(&mut self, other: SaFlags, value: bool)
pub fn set(&mut self, other: SaFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: SaFlags) -> SaFlags
pub const fn intersection(self, other: SaFlags) -> SaFlags
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: SaFlags) -> SaFlags
pub const fn union(self, other: SaFlags) -> SaFlags
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: SaFlags) -> SaFlags
pub const fn difference(self, other: SaFlags) -> SaFlags
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: SaFlags) -> SaFlags
pub const fn symmetric_difference(self, other: SaFlags) -> SaFlags
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> SaFlags
pub const fn complement(self) -> SaFlags
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.