pub struct SigEvent { /* private fields */ }Expand description
Used to request asynchronous notification of the completion of certain events, such as POSIX AIO and timers.
Implementations
Sourceimpl SigEvent
impl SigEvent
Sourcepub fn new(sigev_notify: SigevNotify) -> SigEvent
pub fn new(sigev_notify: SigevNotify) -> SigEvent
Note: this constructor does not allow the user to set the
sigev_notify_kevent_flags field. That’s considered ok because on FreeBSD
at least those flags don’t do anything useful. That field is part of a
union that shares space with the more genuinely useful fields.
Note: This constructor also doesn’t allow the caller to set the
sigev_notify_function or sigev_notify_attributes fields, which are
required for SIGEV_THREAD. That’s considered ok because on no operating
system is SIGEV_THREAD the most efficient way to deliver AIO
notification. FreeBSD and DragonFly BSD programs should prefer SIGEV_KEVENT.
Linux, Solaris, and portable programs should prefer SIGEV_THREAD_ID or
SIGEV_SIGNAL. That field is part of a union that shares space with the
more genuinely useful sigev_notify_thread_id
Sourcepub fn as_mut_ptr(&mut self) -> *mut sigevent
pub fn as_mut_ptr(&mut self) -> *mut sigevent
Returns a mutable pointer to the sigevent wrapped by self