SigSet

Struct SigSet 

pub struct SigSet { /* private fields */ }
Specifies a set of Signals that may be blocked, waited for, etc.

Implementations

Source

impl SigSet

pub fn all() -> SigSet

Initialize to include all signals.

pub fn empty() -> SigSet

Initialize to include nothing.

pub fn add(&mut self, signal: Signal)

Add the specified signal to the set.

pub fn clear(&mut self)

Remove all signals from this set.

pub fn remove(&mut self, signal: Signal)

Remove the specified signal from this set.

pub fn contains(&self, signal: Signal) -> bool

Return whether this set includes the specified signal.

pub fn iter(&self) -> SigSetIter<'_>

Returns an iterator that yields the signals contained in this set.

pub fn thread_get_mask() -> Result<SigSet, Errno>

Gets the currently blocked (masked) set of signals for the calling thread.

pub fn thread_set_mask(&self) -> Result<(), Errno>

Sets the set of signals as the signal mask for the calling thread.

pub fn thread_block(&self) -> Result<(), Errno>

Adds the set of signals to the signal mask for the calling thread.

pub fn thread_unblock(&self) -> Result<(), Errno>

Removes the set of signals from the signal mask for the calling thread.

pub fn thread_swap_mask(&self, how: SigmaskHow) -> Result<SigSet, Errno>

Sets the set of signals as the signal mask, and returns the old mask.

pub fn wait(&self) -> Result<Signal, Errno>

Suspends execution of the calling thread until one of the signals in the signal mask becomes pending, and returns the accepted signal.