ControlMessageOwned

Enum ControlMessageOwned 

#[non_exhaustive]
pub enum ControlMessageOwned { ScmRights(Vec<i32>), ScmCredentials(UnixCredentials), ScmTimestamp(TimeVal), ScmTimestampsns(Timestamps), ScmTimestampns(TimeSpec), Ipv4PacketInfo(in_pktinfo), Ipv6PacketInfo(in6_pktinfo), UdpGroSegments(u16), RxqOvfl(u32), Ipv4RecvErr(sock_extended_err, Option<sockaddr_in>), Ipv6RecvErr(sock_extended_err, Option<sockaddr_in6>), }
A type-safe wrapper around a single control message, as used with recvmsg.

Further reading

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ScmRights(Vec<i32>)

Received version of ControlMessage::ScmRights



ScmCredentials(UnixCredentials)

Received version of ControlMessage::ScmCredentials



ScmTimestamp(TimeVal)

A message of type SCM_TIMESTAMP, containing the time the packet was received by the kernel.

See the kernel’s explanation in “SO_TIMESTAMP” of networking/timestamping.

Examples

// Set up
let message = "Ohayō!".as_bytes();
let in_socket = socket(
    AddressFamily::Inet,
    SockType::Datagram,
    SockFlag::empty(),
    None).unwrap();
setsockopt(in_socket, sockopt::ReceiveTimestamp, &true).unwrap();
let localhost = SockaddrIn::from_str("127.0.0.1:0").unwrap();
bind(in_socket, &localhost);
let address: SockaddrIn = getsockname(in_socket).unwrap();
// Get initial time
let time0 = SystemTime::now();
// Send the message
let iov = [IoSlice::new(message)];
let flags = MsgFlags::empty();
let l = sendmsg(in_socket, &iov, &[], flags, Some(&address)).unwrap();
assert_eq!(message.len(), l);
// Receive the message
let mut buffer = vec![0u8; message.len()];
let mut cmsgspace = cmsg_space!(TimeVal);
let mut iov = [IoSliceMut::new(&mut buffer)];
let r = recvmsg::<SockaddrIn>(in_socket, &mut iov, Some(&mut cmsgspace), flags)
    .unwrap();
let rtime = match r.cmsgs().next() {
    Some(ControlMessageOwned::ScmTimestamp(rtime)) => rtime,
    Some(_) => panic!("Unexpected control message"),
    None => panic!("No control message")
};
// Check the final time
let time1 = SystemTime::now();
// the packet's received timestamp should lie in-between the two system
// times, unless the system clock was adjusted in the meantime.
let rduration = Duration::new(rtime.tv_sec() as u64,
                              rtime.tv_usec() as u32 * 1000);
assert!(time0.duration_since(UNIX_EPOCH).unwrap() <= rduration);
assert!(rduration <= time1.duration_since(UNIX_EPOCH).unwrap());
// Close socket
nix::unistd::close(in_socket).unwrap();


ScmTimestampsns(Timestamps)

A set of nanosecond resolution timestamps

Further reading



ScmTimestampns(TimeSpec)

Nanoseconds resolution timestamp

Further reading



Ipv4PacketInfo(in_pktinfo)



Ipv6PacketInfo(in6_pktinfo)



UdpGroSegments(u16)

UDP Generic Receive Offload (GRO) allows receiving multiple UDP packets from a single sender. Fixed-size payloads are following one by one in a receive buffer. This Control Message indicates the size of all smaller packets, except, maybe, the last one.

UdpGroSegment socket option should be enabled on a socket to allow receiving GRO packets.



RxqOvfl(u32)

SO_RXQ_OVFL indicates that an unsigned 32 bit value ancilliary msg (cmsg) should be attached to recieved skbs indicating the number of packets dropped by the socket between the last recieved packet and this received packet.

RxqOvfl socket option should be enabled on a socket to allow receiving the drop counter.



Ipv4RecvErr(sock_extended_err, Option<sockaddr_in>)

Socket error queue control messages read with the MSG_ERRQUEUE flag.



Ipv6RecvErr(sock_extended_err, Option<sockaddr_in6>)

Socket error queue control messages read with the MSG_ERRQUEUE flag.