#[non_exhaustive]#[repr(i32)]pub enum SockProtocol {
Show 16 variants
Tcp = 6,
Udp = 17,
NetlinkRoute = 0,
NetlinkUserSock = 2,
NetlinkSockDiag = 4,
NetlinkSELinux = 7,
NetlinkISCSI = 8,
NetlinkAudit = 9,
NetlinkFIBLookup = 10,
NetlinkNetFilter = 12,
NetlinkSCSITransport = 18,
NetlinkRDMA = 20,
NetlinkIPv6Firewall = 13,
NetlinkDECNetRoutingMessage = 14,
NetlinkKObjectUEvent = 15,
NetlinkCrypto = 21,
}Expand description
Constants used in socket and socketpair
to specify the protocol to use.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Tcp = 6
TCP protocol (ip(7))
Udp = 17
UDP protocol (ip(7))
NetlinkRoute = 0
Receives routing and link updates and may be used to modify the routing tables (both IPv4 and IPv6), IP addresses, link (ref)
NetlinkUserSock = 2
Reserved for user-mode socket protocols (ref)
NetlinkSockDiag = 4
Query information about sockets of various protocol families from the kernel (ref)
NetlinkSELinux = 7
SELinux event notifications. (ref)
NetlinkISCSI = 8
Open-iSCSI (ref)
NetlinkAudit = 9
Auditing (ref)
NetlinkFIBLookup = 10
Access to FIB lookup from user space (ref)
NetlinkNetFilter = 12
Netfilter subsystem (ref)
NetlinkSCSITransport = 18
SCSI Transports (ref)
NetlinkRDMA = 20
Infiniband RDMA (ref)
NetlinkIPv6Firewall = 13
Transport IPv6 packets from netfilter to user space. Used by ip6_queue kernel module. (ref)
NetlinkDECNetRoutingMessage = 14
DECnet routing messages (ref)
NetlinkKObjectUEvent = 15
Kernel messages to user space (ref)
NetlinkCrypto = 21
Netlink interface to request information about ciphers registered with the kernel crypto API as well as allow configuration of the kernel crypto API. (ref)