pub fn getpeername<T>(fd: i32) -> Result<T, Errno>where
T: SockaddrLike,Expand description
Get the address of the peer connected to the socket fd.
pub fn getpeername<T>(fd: i32) -> Result<T, Errno>where
T: SockaddrLike,Get the address of the peer connected to the socket fd.