pub fn getsockname<T>(fd: i32) -> Result<T, Errno>where
T: SockaddrLike,Expand description
Get the current address to which the socket fd is bound.
pub fn getsockname<T>(fd: i32) -> Result<T, Errno>where
T: SockaddrLike,Get the current address to which the socket fd is bound.