pub fn getsockopt<O>(fd: i32, opt: O) -> Result<<O as GetSockOpt>::Val, Errno>where
O: GetSockOpt,Expand description
Get the current value for the requested socket option
pub fn getsockopt<O>(fd: i32, opt: O) -> Result<<O as GetSockOpt>::Val, Errno>where
O: GetSockOpt,Get the current value for the requested socket option