pub struct MsgFlags { /* private fields */ }Expand description
Flags for send/recv and their relatives
Implementations
Sourceimpl MsgFlags
impl MsgFlags
Sourcepub const MSG_OOB: MsgFlags
pub const MSG_OOB: MsgFlags
Sends or requests out-of-band data on sockets that support this notion
(e.g., of type Stream); the underlying protocol must also
support out-of-band data.
Sourcepub const MSG_PEEK: MsgFlags
pub const MSG_PEEK: MsgFlags
Peeks at an incoming message. The data is treated as unread and the next
recv()
or similar function shall still return this data.
Sourcepub const MSG_WAITALL: MsgFlags
pub const MSG_WAITALL: MsgFlags
Receive operation blocks until the full amount of data can be returned. The function may return smaller amount of data if a signal is caught, an error or disconnect occurs.
Sourcepub const MSG_DONTWAIT: MsgFlags
pub const MSG_DONTWAIT: MsgFlags
Enables nonblocking operation; if the operation would block,
EAGAIN or EWOULDBLOCK is returned. This provides similar
behavior to setting the O_NONBLOCK flag
(via the fcntl
F_SETFL operation), but differs in that MSG_DONTWAIT is a per-
call option, whereas O_NONBLOCK is a setting on the open file
description (see open(2)),
which will affect all threads in
the calling process and as well as other processes that hold
file descriptors referring to the same open file description.
Sourcepub const MSG_CTRUNC: MsgFlags
pub const MSG_CTRUNC: MsgFlags
Receive flags: Control Data was discarded (buffer too small)
Sourcepub const MSG_TRUNC: MsgFlags
pub const MSG_TRUNC: MsgFlags
For raw (Packet), Internet datagram
(since Linux 2.4.27/2.6.8),
netlink (since Linux 2.6.22) and UNIX datagram (since Linux 3.4)
sockets: return the real length of the packet or datagram, even
when it was longer than the passed buffer. Not implemented for UNIX
domain (unix(7)) sockets.
For use with Internet stream sockets, see tcp(7).
Sourcepub const MSG_EOR: MsgFlags
pub const MSG_EOR: MsgFlags
Terminates a record (when this notion is supported, as for
sockets of type SeqPacket).
Sourcepub const MSG_ERRQUEUE: MsgFlags
pub const MSG_ERRQUEUE: MsgFlags
This flag specifies that queued errors should be received from the socket error queue. (For more details, see recvfrom(2))
Sourcepub const MSG_CMSG_CLOEXEC: MsgFlags
pub const MSG_CMSG_CLOEXEC: MsgFlags
Sourcepub const MSG_NOSIGNAL: MsgFlags
pub const MSG_NOSIGNAL: MsgFlags
Requests not to send SIGPIPE errors when the other end breaks the connection.
(For more details, see send(2)).
Sourcepub const fn from_bits(bits: i32) -> Option<MsgFlags>
pub const fn from_bits(bits: i32) -> Option<MsgFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: i32) -> MsgFlags
pub const fn from_bits_truncate(bits: i32) -> MsgFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: i32) -> MsgFlags
pub const unsafe fn from_bits_unchecked(bits: i32) -> MsgFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: MsgFlags) -> bool
pub const fn intersects(&self, other: MsgFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: MsgFlags) -> bool
pub const fn contains(&self, other: MsgFlags) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn set(&mut self, other: MsgFlags, value: bool)
pub fn set(&mut self, other: MsgFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: MsgFlags) -> MsgFlags
pub const fn intersection(self, other: MsgFlags) -> MsgFlags
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: MsgFlags) -> MsgFlags
pub const fn union(self, other: MsgFlags) -> MsgFlags
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: MsgFlags) -> MsgFlags
pub const fn difference(self, other: MsgFlags) -> MsgFlags
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: MsgFlags) -> MsgFlags
pub const fn symmetric_difference(self, other: MsgFlags) -> MsgFlags
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> MsgFlags
pub const fn complement(self) -> MsgFlags
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.