pub struct TimestampingFlag { /* private fields */ }Expand description
Configuration flags for SO_TIMESTAMPING interface
For use with Timestamping.
Further reading
Implementations
Sourceimpl TimestampingFlag
impl TimestampingFlag
Sourcepub const SOF_TIMESTAMPING_SOFTWARE: TimestampingFlag
pub const SOF_TIMESTAMPING_SOFTWARE: TimestampingFlag
Report any software timestamps when available.
Sourcepub const SOF_TIMESTAMPING_RAW_HARDWARE: TimestampingFlag
pub const SOF_TIMESTAMPING_RAW_HARDWARE: TimestampingFlag
Report hardware timestamps as generated by SOF_TIMESTAMPING_TX_HARDWARE when available.
Sourcepub const SOF_TIMESTAMPING_TX_HARDWARE: TimestampingFlag
pub const SOF_TIMESTAMPING_TX_HARDWARE: TimestampingFlag
Collect transmiting timestamps as reported by hardware
Sourcepub const SOF_TIMESTAMPING_TX_SOFTWARE: TimestampingFlag
pub const SOF_TIMESTAMPING_TX_SOFTWARE: TimestampingFlag
Collect transmiting timestamps as reported by software
Sourcepub const SOF_TIMESTAMPING_RX_HARDWARE: TimestampingFlag
pub const SOF_TIMESTAMPING_RX_HARDWARE: TimestampingFlag
Collect receiving timestamps as reported by hardware
Sourcepub const SOF_TIMESTAMPING_RX_SOFTWARE: TimestampingFlag
pub const SOF_TIMESTAMPING_RX_SOFTWARE: TimestampingFlag
Collect receiving timestamps as reported by software
Sourcepub const fn empty() -> TimestampingFlag
pub const fn empty() -> TimestampingFlag
Returns an empty set of flags.
Sourcepub const fn all() -> TimestampingFlag
pub const fn all() -> TimestampingFlag
Returns the set containing all flags.
Sourcepub const fn from_bits(bits: u32) -> Option<TimestampingFlag>
pub const fn from_bits(bits: u32) -> Option<TimestampingFlag>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> TimestampingFlag
pub const fn from_bits_truncate(bits: u32) -> TimestampingFlag
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> TimestampingFlag
pub const unsafe fn from_bits_unchecked(bits: u32) -> TimestampingFlag
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: TimestampingFlag) -> bool
pub const fn intersects(&self, other: TimestampingFlag) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: TimestampingFlag) -> bool
pub const fn contains(&self, other: TimestampingFlag) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: TimestampingFlag)
pub fn insert(&mut self, other: TimestampingFlag)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: TimestampingFlag)
pub fn remove(&mut self, other: TimestampingFlag)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: TimestampingFlag)
pub fn toggle(&mut self, other: TimestampingFlag)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: TimestampingFlag, value: bool)
pub fn set(&mut self, other: TimestampingFlag, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: TimestampingFlag) -> TimestampingFlag
pub const fn intersection(self, other: TimestampingFlag) -> TimestampingFlag
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: TimestampingFlag) -> TimestampingFlag
pub const fn union(self, other: TimestampingFlag) -> TimestampingFlag
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: TimestampingFlag) -> TimestampingFlag
pub const fn difference(self, other: TimestampingFlag) -> TimestampingFlag
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(
self,
other: TimestampingFlag,
) -> TimestampingFlag
pub const fn symmetric_difference( self, other: TimestampingFlag, ) -> TimestampingFlag
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> TimestampingFlag
pub const fn complement(self) -> TimestampingFlag
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.