pub struct Statvfs(/* private fields */);Expand description
Wrapper around the POSIX statvfs struct
For more information see the statvfs(3) man pages.
Implementations
Sourceimpl Statvfs
impl Statvfs
Sourcepub fn block_size(&self) -> u64
pub fn block_size(&self) -> u64
get the file system block size
Sourcepub fn fragment_size(&self) -> u64
pub fn fragment_size(&self) -> u64
Get the fundamental file system block size
Sourcepub fn blocks_free(&self) -> u64
pub fn blocks_free(&self) -> u64
Get the number of free blocks in the file system
Sourcepub fn blocks_available(&self) -> u64
pub fn blocks_available(&self) -> u64
Get the number of free blocks for unprivileged users
Sourcepub fn files_free(&self) -> u64
pub fn files_free(&self) -> u64
Get the number of free file inodes
Sourcepub fn files_available(&self) -> u64
pub fn files_available(&self) -> u64
Get the number of free file inodes for unprivileged users
Sourcepub fn filesystem_id(&self) -> u64
pub fn filesystem_id(&self) -> u64
Get the file system id