pub struct SysInfo(/* private fields */);Expand description
System info structure returned by sysinfo.
Implementations
Sourceimpl SysInfo
impl SysInfo
Sourcepub fn load_average(&self) -> (f64, f64, f64)
pub fn load_average(&self) -> (f64, f64, f64)
Returns the load average tuple.
The returned values represent the load average over time intervals of 1, 5, and 15 minutes, respectively.
Sourcepub fn process_count(&self) -> u16
pub fn process_count(&self) -> u16
Current number of processes.
Sourcepub fn swap_total(&self) -> u64
pub fn swap_total(&self) -> u64
Returns the amount of swap memory in Bytes.
Sourcepub fn ram_unused(&self) -> u64
pub fn ram_unused(&self) -> u64
Returns the amount of completely unused RAM in Bytes.
“Unused” in this context means that the RAM in neither actively used by programs, nor by the operating system as disk cache or buffer. It is “wasted” RAM since it currently serves no purpose.