#[non_exhaustive]#[repr(i32)]pub enum FlushArg {
TCIFLUSH = 0,
TCOFLUSH = 1,
TCIOFLUSH = 2,
}Expand description
Specify a combination of the input and output buffers to flush
Used as an argument to tcflush().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TCIFLUSH = 0
Flush data that was received but not read
TCOFLUSH = 1
Flush data written but not transmitted
TCIOFLUSH = 2
Flush both received data not read and written data not transmitted