pub struct OutputFlags { /* private fields */ }Expand description
Flags for configuring the output mode of a terminal
Implementations
Sourceimpl OutputFlags
impl OutputFlags
pub const OPOST: OutputFlags
pub const OLCUC: OutputFlags
pub const ONLCR: OutputFlags
pub const OCRNL: OutputFlags
pub const ONOCR: OutputFlags
pub const ONLRET: OutputFlags
pub const OFILL: OutputFlags
pub const OFDEL: OutputFlags
pub const NL0: OutputFlags
pub const NL1: OutputFlags
pub const CR0: OutputFlags
pub const CR1: OutputFlags
pub const CR2: OutputFlags
pub const CR3: OutputFlags
pub const TAB0: OutputFlags
pub const TAB1: OutputFlags
pub const TAB2: OutputFlags
pub const TAB3: OutputFlags
pub const XTABS: OutputFlags
pub const BS0: OutputFlags
pub const BS1: OutputFlags
pub const VT0: OutputFlags
pub const VT1: OutputFlags
pub const FF0: OutputFlags
pub const FF1: OutputFlags
pub const NLDLY: OutputFlags
pub const CRDLY: OutputFlags
pub const TABDLY: OutputFlags
pub const BSDLY: OutputFlags
pub const VTDLY: OutputFlags
pub const FFDLY: OutputFlags
Sourcepub const fn empty() -> OutputFlags
pub const fn empty() -> OutputFlags
Returns an empty set of flags.
Sourcepub const fn all() -> OutputFlags
pub const fn all() -> OutputFlags
Returns the set containing all flags.
Sourcepub const fn from_bits(bits: u32) -> Option<OutputFlags>
pub const fn from_bits(bits: u32) -> Option<OutputFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> OutputFlags
pub const fn from_bits_truncate(bits: u32) -> OutputFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> OutputFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> OutputFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: OutputFlags) -> bool
pub const fn intersects(&self, other: OutputFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: OutputFlags) -> bool
pub const fn contains(&self, other: OutputFlags) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: OutputFlags)
pub fn insert(&mut self, other: OutputFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: OutputFlags)
pub fn remove(&mut self, other: OutputFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: OutputFlags)
pub fn toggle(&mut self, other: OutputFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: OutputFlags, value: bool)
pub fn set(&mut self, other: OutputFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: OutputFlags) -> OutputFlags
pub const fn intersection(self, other: OutputFlags) -> OutputFlags
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: OutputFlags) -> OutputFlags
pub const fn union(self, other: OutputFlags) -> OutputFlags
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: OutputFlags) -> OutputFlags
pub const fn difference(self, other: OutputFlags) -> OutputFlags
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: OutputFlags) -> OutputFlags
pub const fn symmetric_difference(self, other: OutputFlags) -> OutputFlags
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> OutputFlags
pub const fn complement(self) -> OutputFlags
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.