Termios

Struct Termios 

pub struct Termios {
    pub input_flags: InputFlags,
    pub output_flags: OutputFlags,
    pub control_flags: ControlFlags,
    pub local_flags: LocalFlags,
    pub control_chars: [u8; 32],
    /* private fields */
}
Stores settings for the termios API

This is a wrapper around the libc::termios struct that provides a safe interface for the standard fields. The only safe way to obtain an instance of this struct is to extract it from an open port using tcgetattr().

Fields

input_flags: InputFlags

Input mode flags (see termios.c_iflag documentation)

output_flags: OutputFlags

Output mode flags (see termios.c_oflag documentation)

control_flags: ControlFlags

Control mode flags (see termios.c_cflag documentation)

local_flags: LocalFlags

Local mode flags (see termios.c_lflag documentation)

control_chars: [u8; 32]

Control characters (see termios.c_cc documentation)