#[non_exhaustive]#[repr(i32)]pub enum ClockId {
CLOCK_REALTIME = 0,
CLOCK_MONOTONIC = 1,
CLOCK_BOOTTIME = 7,
CLOCK_REALTIME_ALARM = 8,
CLOCK_BOOTTIME_ALARM = 9,
}Expand description
The type of the clock used to mark the progress of the timer. For more details on each kind of clock, please refer to timerfd_create(2).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CLOCK_REALTIME = 0
A settable system-wide real-time clock.
CLOCK_MONOTONIC = 1
A non-settable monotonically increasing clock.
Does not change after system startup. Does not measure time while the system is suspended.
CLOCK_BOOTTIME = 7
Like CLOCK_MONOTONIC, except that CLOCK_BOOTTIME includes the time
that the system was suspended.
CLOCK_REALTIME_ALARM = 8
Like CLOCK_REALTIME, but will wake the system if it is suspended.
CLOCK_BOOTTIME_ALARM = 9
Like CLOCK_BOOTTIME, but will wake the system if it is suspended.