pub enum Expiration {
OneShot(TimeSpec),
IntervalDelayed(TimeSpec, TimeSpec),
Interval(TimeSpec),
}Expand description
An enumeration allowing the definition of the expiration time of an alarm, recurring or not.
Variants
OneShot(TimeSpec)
Alarm will trigger once after the time given in TimeSpec
IntervalDelayed(TimeSpec, TimeSpec)
Alarm will trigger after a specified delay and then every interval of time.
Interval(TimeSpec)
Alarm will trigger every specified interval of time.