#[repr(C)]pub struct RemoteIoVec {
pub base: usize,
pub len: usize,
}Expand description
A slice of memory in a remote process, starting at address base
and consisting of len bytes.
This is the same underlying C structure as IoSlice,
except that it refers to memory in some other process, and is
therefore not represented in Rust by an actual slice as IoSlice is. It
is used with process_vm_readv
and process_vm_writev.
Fields
base: usizeThe starting address of this slice (iov_base).
len: usizeThe number of bytes in this slice (iov_len).