pub fn wait() -> Result<WaitStatus, Errno>Expand description
Wait for any child process to change status or a signal is received.
See also wait(2)
pub fn wait() -> Result<WaitStatus, Errno>Wait for any child process to change status or a signal is received.
See also wait(2)