pub struct WaitPidFlag { /* private fields */ }Expand description
Controls the behavior of waitpid.
Implementations
Sourceimpl WaitPidFlag
impl WaitPidFlag
Sourcepub const WNOHANG: WaitPidFlag
pub const WNOHANG: WaitPidFlag
Do not block when there are no processes wishing to report status.
Sourcepub const WUNTRACED: WaitPidFlag
pub const WUNTRACED: WaitPidFlag
Sourcepub const WEXITED: WaitPidFlag
pub const WEXITED: WaitPidFlag
Report the status of selected processes which have terminated.
Sourcepub const WCONTINUED: WaitPidFlag
pub const WCONTINUED: WaitPidFlag
Report the status of selected processes that have continued from a
job control stop by receiving a
SIGCONT signal.
Sourcepub const WSTOPPED: WaitPidFlag
pub const WSTOPPED: WaitPidFlag
An alias for WUNTRACED.
Sourcepub const WNOWAIT: WaitPidFlag
pub const WNOWAIT: WaitPidFlag
Don’t reap, just poll status.
Sourcepub const __WNOTHREAD: WaitPidFlag
pub const __WNOTHREAD: WaitPidFlag
Don’t wait on children of other threads in this group
Sourcepub const __WALL: WaitPidFlag
pub const __WALL: WaitPidFlag
Wait on all children, regardless of type
Sourcepub const __WCLONE: WaitPidFlag
pub const __WCLONE: WaitPidFlag
Wait for “clone” children only.
Sourcepub const fn empty() -> WaitPidFlag
pub const fn empty() -> WaitPidFlag
Returns an empty set of flags.
Sourcepub const fn all() -> WaitPidFlag
pub const fn all() -> WaitPidFlag
Returns the set containing all flags.
Sourcepub const fn from_bits(bits: i32) -> Option<WaitPidFlag>
pub const fn from_bits(bits: i32) -> Option<WaitPidFlag>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: i32) -> WaitPidFlag
pub const fn from_bits_truncate(bits: i32) -> WaitPidFlag
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: i32) -> WaitPidFlag
pub const unsafe fn from_bits_unchecked(bits: i32) -> WaitPidFlag
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: WaitPidFlag) -> bool
pub const fn intersects(&self, other: WaitPidFlag) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: WaitPidFlag) -> bool
pub const fn contains(&self, other: WaitPidFlag) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: WaitPidFlag)
pub fn insert(&mut self, other: WaitPidFlag)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: WaitPidFlag)
pub fn remove(&mut self, other: WaitPidFlag)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: WaitPidFlag)
pub fn toggle(&mut self, other: WaitPidFlag)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: WaitPidFlag, value: bool)
pub fn set(&mut self, other: WaitPidFlag, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: WaitPidFlag) -> WaitPidFlag
pub const fn intersection(self, other: WaitPidFlag) -> WaitPidFlag
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: WaitPidFlag) -> WaitPidFlag
pub const fn union(self, other: WaitPidFlag) -> WaitPidFlag
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: WaitPidFlag) -> WaitPidFlag
pub const fn difference(self, other: WaitPidFlag) -> WaitPidFlag
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: WaitPidFlag) -> WaitPidFlag
pub const fn symmetric_difference(self, other: WaitPidFlag) -> WaitPidFlag
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> WaitPidFlag
pub const fn complement(self) -> WaitPidFlag
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.