Gid

Struct Gid 

pub struct Gid(/* private fields */);
Group identifier

Newtype pattern around gid_t (which is just alias). It prevents bugs caused by accidentally passing wrong value.

Implementations

Source

impl Gid

pub const fn from_raw(gid: u32) -> Gid

Creates Gid from raw gid_t.

pub fn current() -> Gid

Returns Gid of calling process. This is practically a more Rusty alias for getgid.

pub fn effective() -> Gid

Returns effective Gid of calling process. This is practically a more Rusty alias for getegid.

pub const fn as_raw(self) -> u32

Get the raw gid_t wrapped by self.