pub enum EitherOrBoth<A, B> {
Both(A, B),
Left(A),
Right(B),
}Expand description
Value that either holds a single A or B, or both.
Variants
Both(A, B)
Both values are present.
Left(A)
Only the left value of type A is present.
Right(B)
Only the right value of type B is present.
Implementations
Sourceimpl<A, B> EitherOrBoth<A, B>
impl<A, B> EitherOrBoth<A, B>
Sourcepub fn is_left(&self) -> bool
pub fn is_left(&self) -> bool
If Left, return true otherwise, return false.
Exclusive version of has_left.
Sourcepub fn is_right(&self) -> bool
pub fn is_right(&self) -> bool
If Right, return true otherwise, return false.
Exclusive version of has_right.
Sourcepub fn is_both(&self) -> bool
pub fn is_both(&self) -> bool
If Right, return true otherwise, return false.
Equivalent to self.as_ref().both().is_some().
Sourcepub fn left(self) -> Option<A>
pub fn left(self) -> Option<A>
If Left, or Both, return Some with the left value, otherwise, return None.
Sourcepub fn right(self) -> Option<B>
pub fn right(self) -> Option<B>
If Right, or Both, return Some with the right value, otherwise, return None.
Sourcepub fn as_ref(&self) -> EitherOrBoth<&A, &B>
pub fn as_ref(&self) -> EitherOrBoth<&A, &B>
Converts from &EitherOrBoth<A, B> to EitherOrBoth<&A, &B>.
Sourcepub fn as_mut(&mut self) -> EitherOrBoth<&mut A, &mut B>
pub fn as_mut(&mut self) -> EitherOrBoth<&mut A, &mut B>
Converts from &mut EitherOrBoth<A, B> to EitherOrBoth<&mut A, &mut B>.
Sourcepub fn flip(self) -> EitherOrBoth<B, A>
pub fn flip(self) -> EitherOrBoth<B, A>
Convert EitherOrBoth<A, B> to EitherOrBoth<B, A>.
Sourcepub fn map_left<F, M>(self, f: F) -> EitherOrBoth<M, B>where
F: FnOnce(A) -> M,
pub fn map_left<F, M>(self, f: F) -> EitherOrBoth<M, B>where
F: FnOnce(A) -> M,
Apply the function f on the value a in Left(a) or Both(a, b) variants. If it is
present rewrapping the result in self’s original variant.
Sourcepub fn map_right<F, M>(self, f: F) -> EitherOrBoth<A, M>where
F: FnOnce(B) -> M,
pub fn map_right<F, M>(self, f: F) -> EitherOrBoth<A, M>where
F: FnOnce(B) -> M,
Apply the function f on the value b in Right(b) or Both(a, b) variants.
If it is present rewrapping the result in self’s original variant.
Sourcepub fn map_any<F, L, G, R>(self, f: F, g: G) -> EitherOrBoth<L, R>
pub fn map_any<F, L, G, R>(self, f: F, g: G) -> EitherOrBoth<L, R>
Apply the functions f and g on the value a and b respectively;
found in Left(a), Right(b), or Both(a, b) variants.
The Result is rewrapped self’s original variant.
Sourcepub fn left_and_then<F, L>(self, f: F) -> EitherOrBoth<L, B>where
F: FnOnce(A) -> EitherOrBoth<L, B>,
pub fn left_and_then<F, L>(self, f: F) -> EitherOrBoth<L, B>where
F: FnOnce(A) -> EitherOrBoth<L, B>,
Apply the function f on the value a in Left(a) or Both(a, _) variants if it is
present.
Sourcepub fn right_and_then<F, R>(self, f: F) -> EitherOrBoth<A, R>where
F: FnOnce(B) -> EitherOrBoth<A, R>,
pub fn right_and_then<F, R>(self, f: F) -> EitherOrBoth<A, R>where
F: FnOnce(B) -> EitherOrBoth<A, R>,
Apply the function f on the value b
in Right(b) or Both(_, b) variants if it is present.
Sourcepub fn or(self, l: A, r: B) -> (A, B)
pub fn or(self, l: A, r: B) -> (A, B)
Returns a tuple consisting of the l and r in Both(l, r), if present.
Otherwise, returns the wrapped value for the present element, and the supplied
value for the other. The first (l) argument is used for a missing Left
value. The second (r) argument is used for a missing Right value.
Arguments passed to or are eagerly evaluated; if you are passing
the result of a function call, it is recommended to use or_else,
which is lazily evaluated.
Examples
assert_eq!(EitherOrBoth::Both("tree", 1).or("stone", 5), ("tree", 1));
assert_eq!(EitherOrBoth::Left("tree").or("stone", 5), ("tree", 5));
assert_eq!(EitherOrBoth::Right(1).or("stone", 5), ("stone", 1));Sourcepub fn or_default(self) -> (A, B)
pub fn or_default(self) -> (A, B)
Returns a tuple consisting of the l and r in Both(l, r), if present.
Otherwise, returns the wrapped value for the present element, and the default
for the other.
Sourcepub fn or_else<L, R>(self, l: L, r: R) -> (A, B)
pub fn or_else<L, R>(self, l: L, r: R) -> (A, B)
Returns a tuple consisting of the l and r in Both(l, r), if present.
Otherwise, returns the wrapped value for the present element, and computes the
missing value with the supplied closure. The first argument (l) is used for a
missing Left value. The second argument (r) is used for a missing Right value.
Examples
let k = 10;
assert_eq!(EitherOrBoth::Both("tree", 1).or_else(|| "stone", || 2 * k), ("tree", 1));
assert_eq!(EitherOrBoth::Left("tree").or_else(|| "stone", || 2 * k), ("tree", 20));
assert_eq!(EitherOrBoth::Right(1).or_else(|| "stone", || 2 * k), ("stone", 1));Trait Implementations
Sourceimpl<A, B> Clone for EitherOrBoth<A, B>
impl<A, B> Clone for EitherOrBoth<A, B>
Sourcefn clone(&self) -> EitherOrBoth<A, B>
fn clone(&self) -> EitherOrBoth<A, B>
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<A, B> Debug for EitherOrBoth<A, B>
impl<A, B> Debug for EitherOrBoth<A, B>
Sourceimpl<A, B> Hash for EitherOrBoth<A, B>
impl<A, B> Hash for EitherOrBoth<A, B>
Sourceimpl<A, B> PartialEq for EitherOrBoth<A, B>
impl<A, B> PartialEq for EitherOrBoth<A, B>
Sourcefn eq(&self, other: &EitherOrBoth<A, B>) -> bool
fn eq(&self, other: &EitherOrBoth<A, B>) -> bool
self and other values to be equal, and is used by ==.impl<A, B> Eq for EitherOrBoth<A, B>
impl<A, B> StructuralPartialEq for EitherOrBoth<A, B>