pub enum Position<T> {
First(T),
Middle(T),
Last(T),
Only(T),
}Expand description
A value yielded by WithPosition.
Indicates the position of this element in the iterator results.
See .with_position() for more information.
Variants
First(T)
This is the first element.
Middle(T)
This is neither the first nor the last element.
Last(T)
This is the last element.
Only(T)
This is the only element.
Implementations
Sourceimpl<T> Position<T>
impl<T> Position<T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Return the inner value.