pub struct IntoChunks<I>where
I: Iterator,{ /* private fields */ }Expand description
ChunkLazy is the storage for a lazy chunking operation.
IntoChunks behaves just like GroupBy: it is iterable, and
it only buffers if several chunk iterators are alive at the same time.
This type implements IntoIterator (it is not an iterator
itself), because the chunk iterators need to borrow from this
value. It should be stored in a local variable or temporary and
iterated.
Iterator element type is Chunk, each chunk’s iterator.
See .chunks() for more information.