pub struct Impossible<Ok, Error> { /* private fields */ }Expand description
Helper type for implementing a Serializer that does not support
serializing one of the compound types.
This type cannot be instantiated, but implements every one of the traits
corresponding to the Serializer compound types: SerializeSeq,
SerializeTuple, SerializeTupleStruct, SerializeTupleVariant,
SerializeMap, SerializeStruct, and SerializeStructVariant.
ⓘ
impl Serializer for MySerializer {
type Ok = ();
type Error = Error;
type SerializeSeq = Impossible<(), Error>;
/* other associated types */
/// This data format does not support serializing sequences.
fn serialize_seq(self,
len: Option<usize>)
-> Result<Self::SerializeSeq, Error> {
// Given Impossible cannot be instantiated, the only
// thing we can do here is to return an error.
Err(...)
}
/* other Serializer methods */
}Trait Implementations
Sourceimpl<Ok, Error> SerializeMap for Impossible<Ok, Error>where
Error: Error,
impl<Ok, Error> SerializeMap for Impossible<Ok, Error>where
Error: Error,
Sourceimpl<Ok, Error> SerializeSeq for Impossible<Ok, Error>where
Error: Error,
impl<Ok, Error> SerializeSeq for Impossible<Ok, Error>where
Error: Error,
Sourceimpl<Ok, Error> SerializeStruct for Impossible<Ok, Error>where
Error: Error,
impl<Ok, Error> SerializeStruct for Impossible<Ok, Error>where
Error: Error,
Sourceimpl<Ok, Error> SerializeStructVariant for Impossible<Ok, Error>where
Error: Error,
impl<Ok, Error> SerializeStructVariant for Impossible<Ok, Error>where
Error: Error,
Sourceimpl<Ok, Error> SerializeTuple for Impossible<Ok, Error>where
Error: Error,
impl<Ok, Error> SerializeTuple for Impossible<Ok, Error>where
Error: Error,
Sourceimpl<Ok, Error> SerializeTupleStruct for Impossible<Ok, Error>where
Error: Error,
impl<Ok, Error> SerializeTupleStruct for Impossible<Ok, Error>where
Error: Error,
Sourceimpl<Ok, Error> SerializeTupleVariant for Impossible<Ok, Error>where
Error: Error,
impl<Ok, Error> SerializeTupleVariant for Impossible<Ok, Error>where
Error: Error,