pub enum Entry<'a> {
Vacant(VacantEntry<'a>),
Occupied(OccupiedEntry<'a>),
}Expand description
Variants
Implementations
Sourceimpl<'a> Entry<'a>
impl<'a> Entry<'a>
Sourcepub fn key(&self) -> &String
pub fn key(&self) -> &String
Returns a reference to this entry’s key.
Examples
let mut map = serde_json::Map::new();
assert_eq!(map.entry("serde").key(), &"serde");Sourcepub fn or_insert(self, default: Value) -> &'a mut Value
pub fn or_insert(self, default: Value) -> &'a mut Value
Ensures a value is in the entry by inserting the default if empty, and returns a mutable reference to the value in the entry.
Examples
let mut map = serde_json::Map::new();
map.entry("serde").or_insert(json!(12));
assert_eq!(map["serde"], 12);Sourcepub fn or_insert_with<F>(self, default: F) -> &'a mut Value
pub fn or_insert_with<F>(self, default: F) -> &'a mut Value
Ensures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.
Examples
let mut map = serde_json::Map::new();
map.entry("serde").or_insert_with(|| json!("hoho"));
assert_eq!(map["serde"], "hoho".to_owned());Sourcepub fn and_modify<F>(self, f: F) -> Entry<'a>
pub fn and_modify<F>(self, f: F) -> Entry<'a>
Provides in-place mutable access to an occupied entry before any potential inserts into the map.
Examples
let mut map = serde_json::Map::new();
map.entry("serde")
.and_modify(|e| *e = json!("rust"))
.or_insert(json!("cpp"));
assert_eq!(map["serde"], "cpp");
map.entry("serde")
.and_modify(|e| *e = json!("rust"))
.or_insert(json!("cpp"));
assert_eq!(map["serde"], "rust");Auto Trait Implementations
impl<'a> Freeze for Entry<'a>
impl<'a> RefUnwindSafe for Entry<'a>
impl<'a> Send for Entry<'a>
impl<'a> Sync for Entry<'a>
impl<'a> Unpin for Entry<'a>
impl<'a> UnsafeUnpin for Entry<'a>
impl<'a> !UnwindSafe for Entry<'a>