RwLockUpgradableReadGuard

Struct RwLockUpgradableReadGuard 

pub struct RwLockUpgradableReadGuard<'a, R, T>
where R: RawRwLockUpgrade, T: ?Sized,
{ /* private fields */ }
RAII structure used to release the upgradable read access of a lock when dropped.

Implementations

Source

impl<'a, R, T> RwLockUpgradableReadGuard<'a, R, T>
where R: RawRwLockUpgrade + 'a, T: 'a + ?Sized,

pub fn rwlock(s: &RwLockUpgradableReadGuard<'a, R, T>) -> &'a RwLock<R, T>

Returns a reference to the original reader-writer lock object.

pub fn unlocked<F, U>(s: &mut RwLockUpgradableReadGuard<'a, R, T>, f: F) -> U
where F: FnOnce() -> U,

Temporarily unlocks the RwLock to execute the given function.

This is safe because &mut guarantees that there exist no other references to the data protected by the RwLock.

pub fn upgrade( s: RwLockUpgradableReadGuard<'a, R, T>, ) -> RwLockWriteGuard<'a, R, T>

Atomically upgrades an upgradable read lock lock into an exclusive write lock, blocking the current thread until it can be acquired.

pub fn try_upgrade( s: RwLockUpgradableReadGuard<'a, R, T>, ) -> Result<RwLockWriteGuard<'a, R, T>, RwLockUpgradableReadGuard<'a, R, T>>

Tries to atomically upgrade an upgradable read lock into an exclusive write lock.

If the access could not be granted at this time, then the current guard is returned.

Source

impl<'a, R, T> RwLockUpgradableReadGuard<'a, R, T>
where R: RawRwLockUpgradeFair + 'a, T: 'a + ?Sized,

pub fn unlock_fair(s: RwLockUpgradableReadGuard<'a, R, T>)

Unlocks the RwLock using a fair unlock protocol.

By default, RwLock is unfair and allow the current thread to re-lock the RwLock before another has the chance to acquire the lock, even if that thread has been blocked on the RwLock for a long time. This is the default because it allows much higher throughput as it avoids forcing a context switch on every RwLock unlock. This can result in one thread acquiring a RwLock many more times than other threads.

However in some cases it can be beneficial to ensure fairness by forcing the lock to pass on to a waiting thread if there is one. This is done by using this method instead of dropping the RwLockUpgradableReadGuard normally.

pub fn unlocked_fair<F, U>( s: &mut RwLockUpgradableReadGuard<'a, R, T>, f: F, ) -> U
where F: FnOnce() -> U,

Temporarily unlocks the RwLock to execute the given function.

The RwLock is unlocked a fair unlock protocol.

This is safe because &mut guarantees that there exist no other references to the data protected by the RwLock.

pub fn bump(s: &mut RwLockUpgradableReadGuard<'a, R, T>)

Temporarily yields the RwLock to a waiting thread if there is one.

This method is functionally equivalent to calling unlock_fair followed by upgradable_read, however it can be much more efficient in the case where there are no waiting threads.

Source

impl<'a, R, T> RwLockUpgradableReadGuard<'a, R, T>
where R: RawRwLockUpgradeDowngrade + 'a, T: 'a + ?Sized,

pub fn downgrade( s: RwLockUpgradableReadGuard<'a, R, T>, ) -> RwLockReadGuard<'a, R, T>

Atomically downgrades an upgradable read lock lock into a shared read lock without allowing any writers to take exclusive access of the lock in the meantime.

Note that if there are any writers currently waiting to take the lock then other readers may not be able to acquire the lock even if it was downgraded.

pub fn with_upgraded<Ret, F>(&mut self, f: F) -> Ret
where F: FnOnce(&mut T) -> Ret,

First, atomically upgrades an upgradable read lock lock into an exclusive write lock, blocking the current thread until it can be acquired.

Then, calls the provided closure with an exclusive reference to the lock’s data.

Finally, atomically downgrades the lock back to an upgradable read lock. The closure’s return value is wrapped in Some and returned.

This function only requires a mutable reference to the guard, unlike upgrade which takes the guard by value.

pub fn try_with_upgraded<Ret, F>(&mut self, f: F) -> Option<Ret>
where F: FnOnce(&mut T) -> Ret,

First, tries to atomically upgrade an upgradable read lock into an exclusive write lock.

If the access could not be granted at this time, then None is returned.

Otherwise, calls the provided closure with an exclusive reference to the lock’s data, and finally downgrades the lock back to an upgradable read lock. The closure’s return value is wrapped in Some and returned.

This function only requires a mutable reference to the guard, unlike try_upgrade which takes the guard by value.

Source

impl<'a, R, T> RwLockUpgradableReadGuard<'a, R, T>
where R: RawRwLockUpgradeTimed + 'a, T: 'a + ?Sized,

pub fn try_upgrade_for( s: RwLockUpgradableReadGuard<'a, R, T>, timeout: <R as RawRwLockTimed>::Duration, ) -> Result<RwLockWriteGuard<'a, R, T>, RwLockUpgradableReadGuard<'a, R, T>>

Tries to atomically upgrade an upgradable read lock into an exclusive write lock, until a timeout is reached.

If the access could not be granted before the timeout expires, then the current guard is returned.

pub fn try_upgrade_until( s: RwLockUpgradableReadGuard<'a, R, T>, timeout: <R as RawRwLockTimed>::Instant, ) -> Result<RwLockWriteGuard<'a, R, T>, RwLockUpgradableReadGuard<'a, R, T>>

Tries to atomically upgrade an upgradable read lock into an exclusive write lock, until a timeout is reached.

If the access could not be granted before the timeout expires, then the current guard is returned.

Source

impl<'a, R, T> RwLockUpgradableReadGuard<'a, R, T>

pub fn try_with_upgraded_for<Ret, F>( &mut self, timeout: <R as RawRwLockTimed>::Duration, f: F, ) -> Option<Ret>
where F: FnOnce(&mut T) -> Ret,

Tries to atomically upgrade an upgradable read lock into an exclusive write lock, until a timeout is reached.

If the access could not be granted before the timeout expires, then None is returned.

Otherwise, calls the provided closure with an exclusive reference to the lock’s data, and finally downgrades the lock back to an upgradable read lock. The closure’s return value is wrapped in Some and returned.

This function only requires a mutable reference to the guard, unlike try_upgrade_for which takes the guard by value.

pub fn try_with_upgraded_until<Ret, F>( &mut self, timeout: <R as RawRwLockTimed>::Instant, f: F, ) -> Option<Ret>
where F: FnOnce(&mut T) -> Ret,

Tries to atomically upgrade an upgradable read lock into an exclusive write lock, until a timeout is reached.

If the access could not be granted before the timeout expires, then None is returned.

Otherwise, calls the provided closure with an exclusive reference to the lock’s data, and finally downgrades the lock back to an upgradable read lock. The closure’s return value is wrapped in Some and returned.

This function only requires a mutable reference to the guard, unlike try_upgrade_until which takes the guard by value.