pub struct DistMap<D, F, T, S> { /* private fields */ }Expand description
A distribution of values of type S derived from the distribution D
by mapping its output of type T through the closure F.
This struct is created by the Distribution::map method.
See its documentation for more.