pub struct NoExpand<'s>(pub &'s [u8]);Expand description
A helper type for forcing literal string replacement.
It can be used with routines like Regex::replace and
Regex::replace_all to do a literal string replacement without expanding
$name to their corresponding capture groups. This can be both convenient
(to avoid escaping $, for example) and faster (since capture groups
don’t need to be found).
's is the lifetime of the literal string to use.
Example
use regex::bytes::{NoExpand, Regex};
let re = Regex::new(r"(?<last>[^,\s]+),\s+(\S+)").unwrap();
let result = re.replace(b"Springsteen, Bruce", NoExpand(b"$2 $last"));
assert_eq!(result, &b"$2 $last"[..]);Tuple Fields
0: &'s [u8]Trait Implementations
Sourceimpl<'s> Replacer for NoExpand<'s>
impl<'s> Replacer for NoExpand<'s>
Sourcefn replace_append(&mut self, _: &Captures<'_>, dst: &mut Vec<u8>)
fn replace_append(&mut self, _: &Captures<'_>, dst: &mut Vec<u8>)
Appends possibly empty data to
dst to replace the current match. Read moreSourcefn no_expansion(&mut self) -> Option<Cow<'_, [u8]>>
fn no_expansion(&mut self) -> Option<Cow<'_, [u8]>>
Return a fixed unchanging replacement byte string. Read more
Sourcefn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
fn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>