pub struct StructMapConfig<C>(/* private fields */);Expand description
Config wrapper, that overrides struct serialization by packing as a map with field names.
MessagePack specification does not tell how to serialize structs. This trait allows you to extend serialization to match your app’s requirements.
Default Serializer implementation writes structs as a tuple, i.e. only its length is encoded,
because it is the most compact representation.
Implementations
Sourceimpl<C> StructMapConfig<C>
impl<C> StructMapConfig<C>
Sourcepub const fn new(inner: C) -> StructMapConfig<C>
pub const fn new(inner: C) -> StructMapConfig<C>
Creates a StructMapConfig inheriting unchanged configuration options from the given configuration.