pub enum Error {
InvalidMarkerRead(Error),
InvalidDataRead(Error),
TypeMismatch(Marker),
OutOfRange,
LengthMismatch(u32),
Uncategorized(String),
Syntax(String),
Utf8Error(Utf8Error),
DepthLimitExceeded,
}Expand description
Enum representing errors that can occur while decoding MessagePack data.
Variants
InvalidMarkerRead(Error)
The enclosed I/O error occurred while trying to read a MessagePack marker.
InvalidDataRead(Error)
The enclosed I/O error occurred while trying to read the encoded MessagePack data.
TypeMismatch(Marker)
A mismatch occurred between the decoded and expected value types.
OutOfRange
A numeric cast failed due to an out-of-range error.
LengthMismatch(u32)
A decoded array did not have the enclosed expected length.
Uncategorized(String)
An otherwise uncategorized error occurred. See the enclosed String for
details.
Syntax(String)
A general error occurred while deserializing the expected type. See the
enclosed String for details.
Utf8Error(Utf8Error)
An encoded string could not be parsed as UTF-8.
DepthLimitExceeded
The depth limit was exceeded.