pub enum Error {
InvalidValueWrite(ValueWriteError),
UnknownLength,
InvalidDataModel(&'static str),
DepthLimitExceeded,
Syntax(String),
}Expand description
This type represents all possible errors that can occur when serializing or deserializing MessagePack data.
Variants
InvalidValueWrite(ValueWriteError)
Failed to write a MessagePack value.
UnknownLength
Failed to serialize struct, sequence or map, because its length is unknown.
InvalidDataModel(&'static str)
Invalid Data model, i.e. Serialize trait is not implmented correctly
DepthLimitExceeded
Depth limit exceeded
Syntax(String)
Catchall for syntax error messages.