pub struct ExtFieldSerializer<'a, W> { /* private fields */ }Trait Implementations
Sourceimpl<'a, W> Debug for ExtFieldSerializer<'a, W>where
W: Debug,
impl<'a, W> Debug for ExtFieldSerializer<'a, W>where
W: Debug,
Sourceimpl<'a, W> Serializer for &mut ExtFieldSerializer<'a, W>where
W: Write + 'a,
impl<'a, W> Serializer for &mut ExtFieldSerializer<'a, W>where
W: Write + 'a,
Sourcetype Ok = ()
type Ok = ()
The output type produced by this
Serializer during successful
serialization. Most serializers that produce text or binary output
should set Ok = () and serialize into an io::Write or buffer
contained within the Serializer instance. Serializers that build
in-memory data structures may be simplified by using Ok to propagate
the data structure around.Sourcetype SerializeMap = Impossible<(), Error>
type SerializeMap = Impossible<(), Error>
Type returned from
serialize_map for serializing the content of the
map.Sourcetype SerializeSeq = Impossible<(), Error>
type SerializeSeq = Impossible<(), Error>
Type returned from
serialize_seq for serializing the content of the
sequence.Sourcetype SerializeStruct = Impossible<(), Error>
type SerializeStruct = Impossible<(), Error>
Type returned from
serialize_struct for serializing the content of
the struct.Sourcetype SerializeStructVariant = Impossible<(), Error>
type SerializeStructVariant = Impossible<(), Error>
Type returned from
serialize_struct_variant for serializing the
content of the struct variant.Sourcetype SerializeTuple = Impossible<(), Error>
type SerializeTuple = Impossible<(), Error>
Type returned from
serialize_tuple for serializing the content of
the tuple.Sourcetype SerializeTupleStruct = Impossible<(), Error>
type SerializeTupleStruct = Impossible<(), Error>
Type returned from
serialize_tuple_struct for serializing the
content of the tuple struct.Sourcetype SerializeTupleVariant = Impossible<(), Error>
type SerializeTupleVariant = Impossible<(), Error>
Type returned from
serialize_tuple_variant for serializing the
content of the tuple variant.Sourcefn serialize_i8(
self,
value: i8,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_i8( self, value: i8, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Serialize an
i8 value. Read moreSourcefn serialize_bytes(
self,
val: &[u8],
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_bytes( self, val: &[u8], ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Serialize a chunk of raw byte data. Read more
Sourcefn serialize_bool(
self,
_val: bool,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_bool( self, _val: bool, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Serialize a
bool value. Read moreSourcefn serialize_i16(
self,
_val: i16,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_i16( self, _val: i16, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Serialize an
i16 value. Read moreSourcefn serialize_i32(
self,
_val: i32,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_i32( self, _val: i32, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Serialize an
i32 value. Read moreSourcefn serialize_i64(
self,
_val: i64,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_i64( self, _val: i64, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Serialize an
i64 value. Read moreSourcefn serialize_u8(
self,
_val: u8,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_u8( self, _val: u8, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Serialize a
u8 value. Read moreSourcefn serialize_u16(
self,
_val: u16,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_u16( self, _val: u16, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Serialize a
u16 value. Read moreSourcefn serialize_u32(
self,
_val: u32,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_u32( self, _val: u32, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Serialize a
u32 value. Read moreSourcefn serialize_u64(
self,
_val: u64,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_u64( self, _val: u64, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Serialize a
u64 value. Read moreSourcefn serialize_f32(
self,
_val: f32,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_f32( self, _val: f32, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Serialize an
f32 value. Read moreSourcefn serialize_f64(
self,
_val: f64,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_f64( self, _val: f64, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Serialize an
f64 value. Read moreSourcefn serialize_char(
self,
_val: char,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_char( self, _val: char, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Serialize a character. Read more
Sourcefn serialize_str(
self,
_val: &str,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_str( self, _val: &str, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Serialize a
&str. Read moreSourcefn serialize_unit(
self,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_unit( self, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Serialize a
() value. Read moreSourcefn serialize_unit_struct(
self,
_name: &'static str,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_unit_struct( self, _name: &'static str, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Sourcefn serialize_unit_variant(
self,
_name: &'static str,
_idx: u32,
_variant: &'static str,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_unit_variant( self, _name: &'static str, _idx: u32, _variant: &'static str, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Sourcefn serialize_newtype_struct<T>(
self,
_name: &'static str,
_value: &T,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_newtype_struct<T>( self, _name: &'static str, _value: &T, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Serialize a newtype struct like
struct Millimeters(u8). Read moreSourcefn serialize_newtype_variant<T>(
self,
_name: &'static str,
_idx: u32,
_variant: &'static str,
_value: &T,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_newtype_variant<T>( self, _name: &'static str, _idx: u32, _variant: &'static str, _value: &T, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Sourcefn serialize_none(
self,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_none( self, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Sourcefn serialize_some<T>(
self,
_value: &T,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_some<T>( self, _value: &T, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::Ok, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Sourcefn serialize_seq(
self,
_len: Option<usize>,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::SerializeSeq, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
fn serialize_seq( self, _len: Option<usize>, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::SerializeSeq, <&mut ExtFieldSerializer<'a, W> as Serializer>::Error>
Begin to serialize a variably sized sequence. This call must be
followed by zero or more calls to
serialize_element, then a call to
end. Read moreSourcefn serialize_tuple(
self,
_len: usize,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::SerializeTuple, Error>
fn serialize_tuple( self, _len: usize, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::SerializeTuple, Error>
Begin to serialize a statically sized sequence whose length will be
known at deserialization time without looking at the serialized data.
This call must be followed by zero or more calls to
serialize_element,
then a call to end. Read moreSourcefn serialize_tuple_struct(
self,
_name: &'static str,
_len: usize,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::SerializeTupleStruct, Error>
fn serialize_tuple_struct( self, _name: &'static str, _len: usize, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::SerializeTupleStruct, Error>
Begin to serialize a tuple struct like
struct Rgb(u8, u8, u8). This
call must be followed by zero or more calls to serialize_field, then a
call to end. Read moreSourcefn serialize_tuple_variant(
self,
_name: &'static str,
_idx: u32,
_variant: &'static str,
_len: usize,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::SerializeTupleVariant, Error>
fn serialize_tuple_variant( self, _name: &'static str, _idx: u32, _variant: &'static str, _len: usize, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::SerializeTupleVariant, Error>
Begin to serialize a tuple variant like
E::T in enum E { T(u8, u8) }. This call must be followed by zero or more calls to
serialize_field, then a call to end. Read moreSourcefn serialize_map(
self,
_len: Option<usize>,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::SerializeMap, Error>
fn serialize_map( self, _len: Option<usize>, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::SerializeMap, Error>
Begin to serialize a map. This call must be followed by zero or more
calls to
serialize_key and serialize_value, then a call to end. Read moreSourcefn serialize_struct(
self,
_name: &'static str,
_len: usize,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::SerializeStruct, Error>
fn serialize_struct( self, _name: &'static str, _len: usize, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::SerializeStruct, Error>
Begin to serialize a struct like
struct Rgb { r: u8, g: u8, b: u8 }.
This call must be followed by zero or more calls to serialize_field,
then a call to end. Read moreSourcefn serialize_struct_variant(
self,
_name: &'static str,
_idx: u32,
_variant: &'static str,
_len: usize,
) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::SerializeStructVariant, Error>
fn serialize_struct_variant( self, _name: &'static str, _idx: u32, _variant: &'static str, _len: usize, ) -> Result<<&mut ExtFieldSerializer<'a, W> as Serializer>::SerializeStructVariant, Error>
Begin to serialize a struct variant like
E::S in enum E { S { r: u8, g: u8, b: u8 } }. This call must be followed by zero or more calls to
serialize_field, then a call to end. Read moreSourcefn serialize_i128(self, v: i128) -> Result<Self::Ok, Self::Error>
fn serialize_i128(self, v: i128) -> Result<Self::Ok, Self::Error>
Serialize an
i128 value. Read moreSourcefn serialize_u128(self, v: u128) -> Result<Self::Ok, Self::Error>
fn serialize_u128(self, v: u128) -> Result<Self::Ok, Self::Error>
Serialize a
u128 value. Read moreSourcefn collect_seq<I>(self, iter: I) -> Result<Self::Ok, Self::Error>
fn collect_seq<I>(self, iter: I) -> Result<Self::Ok, Self::Error>
Collect an iterator as a sequence. Read more
Sourcefn collect_map<K, V, I>(self, iter: I) -> Result<Self::Ok, Self::Error>
fn collect_map<K, V, I>(self, iter: I) -> Result<Self::Ok, Self::Error>
Collect an iterator as a map. Read more
Sourcefn collect_str<T>(self, value: &T) -> Result<Self::Ok, Self::Error>
fn collect_str<T>(self, value: &T) -> Result<Self::Ok, Self::Error>
Serialize a string produced by an implementation of
Display. Read moreSourcefn is_human_readable(&self) -> bool
fn is_human_readable(&self) -> bool
Determine whether
Serialize implementations should serialize in
human-readable form. Read moreAuto Trait Implementations
impl<'a, W> Freeze for ExtFieldSerializer<'a, W>
impl<'a, W> RefUnwindSafe for ExtFieldSerializer<'a, W>where
W: RefUnwindSafe,
impl<'a, W> Send for ExtFieldSerializer<'a, W>where
W: Send,
impl<'a, W> Sync for ExtFieldSerializer<'a, W>where
W: Sync,
impl<'a, W> Unpin for ExtFieldSerializer<'a, W>
impl<'a, W> UnsafeUnpin for ExtFieldSerializer<'a, W>
impl<'a, W> !UnwindSafe for ExtFieldSerializer<'a, W>