pub enum Entry<'a, K, V>where
K: Key,{
Occupied(OccupiedEntry<'a, K, V>),
Vacant(VacantEntry<'a, K, V>),
}Expand description
A view into a single entry in a SparseSecondaryMap, which may either be
vacant or occupied.
This enum is constructed using SparseSecondaryMap::entry.
Variants
Implementations
Sourceimpl<'a, K, V> Entry<'a, K, V>where
K: Key,
impl<'a, K, V> Entry<'a, K, V>where
K: Key,
Sourcepub fn or_insert(self, default: V) -> &'a mut V
pub fn or_insert(self, default: V) -> &'a mut V
Ensures a value is in the entry by inserting the default if empty, and returns a mutable reference to the value in the entry.
Examples
let mut sm = SlotMap::new();
let mut sec = SparseSecondaryMap::new();
let k = sm.insert("poneyland");
let v = sec.entry(k).unwrap().or_insert(10);
assert_eq!(*v, 10);
*sec.entry(k).unwrap().or_insert(1) *= 2;
assert_eq!(sec[k], 20);Sourcepub fn or_insert_with<F>(self, default: F) -> &'a mut Vwhere
F: FnOnce() -> V,
pub fn or_insert_with<F>(self, default: F) -> &'a mut Vwhere
F: FnOnce() -> V,
Ensures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.
Examples
let mut sm = SlotMap::new();
let mut sec = SparseSecondaryMap::new();
let k = sm.insert(1);
let v = sec.entry(k).unwrap().or_insert_with(|| "foobar".to_string());
assert_eq!(v, &"foobar");Sourcepub fn key(&self) -> K
pub fn key(&self) -> K
Returns this entry’s key.
Examples
let mut sm = SlotMap::new();
let mut sec: SparseSecondaryMap<_, ()> = SparseSecondaryMap::new();
let k = sm.insert(1);
let entry = sec.entry(k).unwrap();
assert_eq!(entry.key(), k);Sourcepub fn and_modify<F>(self, f: F) -> Entry<'a, K, V>
pub fn and_modify<F>(self, f: F) -> Entry<'a, K, V>
Provides in-place mutable access to an occupied entry before any potential inserts into the map.
Examples
let mut sm = SlotMap::new();
let mut sec = SparseSecondaryMap::new();
let k = sm.insert(1);
sec.insert(k, 0);
sec.entry(k).unwrap().and_modify(|x| *x = 1);
assert_eq!(sec[k], 1)Sourceimpl<'a, K, V> Entry<'a, K, V>
impl<'a, K, V> Entry<'a, K, V>
Sourcepub fn or_default(self) -> &'a mut V
pub fn or_default(self) -> &'a mut V
Ensures a value is in the entry by inserting the default value if empty, and returns a mutable reference to the value in the entry.
Examples
let mut sm = SlotMap::new();
let mut sec: SparseSecondaryMap<_, Option<i32>> = SparseSecondaryMap::new();
let k = sm.insert(1);
sec.entry(k).unwrap().or_default();
assert_eq!(sec[k], None)Trait Implementations