pub struct VacantEntry<'a, K, V>where
K: Key,{ /* private fields */ }Expand description
A view into a vacant entry in a SparseSecondaryMap. It is part of the
Entry enum.
Implementations
Sourceimpl<'a, K, V> VacantEntry<'a, K, V>where
K: Key,
impl<'a, K, V> VacantEntry<'a, K, V>where
K: Key,
Sourcepub fn key(&self) -> K
pub fn key(&self) -> K
Gets the key that would be used when inserting a value through the
VacantEntry.
Examples
let mut sm = SlotMap::new();
let mut sec: SparseSecondaryMap<_, ()> = SparseSecondaryMap::new();
let k = sm.insert(1);
if let Entry::Vacant(v) = sec.entry(k).unwrap() {
assert_eq!(v.key(), k);
}Sourcepub fn insert(self, value: V) -> &'a mut V
pub fn insert(self, value: V) -> &'a mut V
Sets the value of the entry with the VacantEntry’s key, and returns
a mutable reference to it.
Examples
let mut sm = SlotMap::new();
let mut sec = SparseSecondaryMap::new();
let k = sm.insert(1);
if let Entry::Vacant(v) = sec.entry(k).unwrap() {
let new_val = v.insert(3);
assert_eq!(new_val, &mut 3);
}Trait Implementations