pub struct KeyData { /* private fields */ }Expand description
Implementations
Sourceimpl KeyData
impl KeyData
Sourcepub fn as_ffi(self) -> u64
pub fn as_ffi(self) -> u64
Returns the key data as a 64-bit integer. No guarantees about its value
are made other than that passing it to from_ffi
will return a key equal to the original.
With this you can easily pass slot map keys as opaque handles to foreign code. After you get them back you can confidently use them in your slot map without worrying about unsafe behavior as you would with passing and receiving back references or pointers.
This is not a substitute for proper serialization, use serde for
that. If you are not doing FFI, you almost surely do not need this
function.