pub enum SearchStep {
Match(usize, usize),
Reject(usize, usize),
Done,
}๐ฌThis is a nightly-only experimental API. (
pattern)Expand description
Result of calling Searcher::next() or ReverseSearcher::next_back().
Variants
Match(usize, usize)
๐ฌThis is a nightly-only experimental API. (
pattern)Expresses that a match of the pattern has been found at
haystack[a..b].
Reject(usize, usize)
๐ฌThis is a nightly-only experimental API. (
pattern)Expresses that haystack[a..b] has been rejected as a possible match
of the pattern.
Note that there might be more than one Reject between two Matches,
there is no requirement for them to be combined into one.
Done
๐ฌThis is a nightly-only experimental API. (
pattern)Expresses that every byte of the haystack has been visited, ending the iteration.