pub struct AccountId(/* private fields */);Trait Implementations
Sourceimpl AccountNameOrId for AccountId
impl AccountNameOrId for AccountId
Sourceimpl<'de> Deserialize<'de> for AccountId
impl<'de> Deserialize<'de> for AccountId
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<AccountId, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<AccountId, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Key for AccountId
impl Key for AccountId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for AccountId
impl Ord for AccountId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for AccountId
impl PartialOrd for AccountId
Sourceimpl Serialize for AccountId
impl Serialize for AccountId
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for AccountId
impl Eq for AccountId
impl StructuralPartialEq for AccountId