pub struct CircleOutline {
pub diam: f64,
}Fields
diam: f64Trait Implementations
Sourceimpl Clone for CircleOutline
impl Clone for CircleOutline
Sourcefn clone(&self) -> CircleOutline
fn clone(&self) -> CircleOutline
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CircleOutline
impl Debug for CircleOutline
Sourceimpl<'de> Deserialize<'de> for CircleOutline
impl<'de> Deserialize<'de> for CircleOutline
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CircleOutline, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CircleOutline, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DynCast<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config> for CircleOutline
impl DynCast<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config> for CircleOutline
Sourcefn dyn_cast_ref(
&self,
) -> Result<&<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Target, &<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Source>
fn dyn_cast_ref( &self, ) -> Result<&<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Target, &<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Source>
Cast a shared reference of this trait object to another trait object.
Sourcefn dyn_cast_mut(
&mut self,
) -> Result<&mut <<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Target, &mut <<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Source>
fn dyn_cast_mut( &mut self, ) -> Result<&mut <<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Target, &mut <<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Source>
Cast a mutable/unique reference of this trait object to another trait object.
Sourcefn dyn_cast_boxed(
self: Box<CircleOutline>,
) -> Result<Box<<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Target>, Box<<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Source>>
fn dyn_cast_boxed( self: Box<CircleOutline>, ) -> Result<Box<<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Target>, Box<<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Source>>
Cast a boxed trait object to another trait object.
Sourcefn dyn_cast_rc(
self: Rc<CircleOutline>,
) -> Result<Rc<<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Target>, Rc<<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Source>>
fn dyn_cast_rc( self: Rc<CircleOutline>, ) -> Result<Rc<<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Target>, Rc<<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Source>>
Cast a reference counted trait object to another trait object.
Sourcefn dyn_cast_arc(
self: Arc<CircleOutline>,
) -> Result<Arc<<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Target>, Arc<<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Source>>
fn dyn_cast_arc( self: Arc<CircleOutline>, ) -> Result<Arc<<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Target>, Arc<<<dyn OutlineTrait as GetDynCastConfig<dyn OutlineTrait>>::Config as DynCastConfig>::Source>>
Cast an atomically reference counted trait object to another trait object.
Sourceimpl From<CircleOutline> for Outline
impl From<CircleOutline> for Outline
Sourcefn from(v: CircleOutline) -> Outline
fn from(v: CircleOutline) -> Outline
Converts to this type from the input type.
Sourceimpl OutlineTrait for CircleOutline
impl OutlineTrait for CircleOutline
fn outline_path(&self, scale: f64) -> Result<Html, InternalError>
fn thresh_dragraise(&self) -> Result<Option<i32>, InternalError>
fn bbox_approx(&self) -> Result<RectC<i32>, InternalError>
fn shape(&self) -> Option<Shape>
fn surround_path(&self) -> Result<Html, InternalError>
Sourceimpl Serialize for CircleOutline
impl Serialize for CircleOutline
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TryInto<CircleOutline> for Outline
impl TryInto<CircleOutline> for Outline
impl Copy for CircleOutline