pub struct FaceId { /* private fields */ }Implementations
Sourceimpl FaceId
impl FaceId
Sourcepub const MAX_INDEX: usize
pub const MAX_INDEX: usize
If Self::CHECKS_MAX_INDEX is true, we’ll assert if trying to
produce a value larger than this in any of the ctors that don’t
have unchecked in their name.
Sourcepub const CHECKS_MAX_INDEX: bool
pub const CHECKS_MAX_INDEX: bool
Does this index type assert if asked to construct an index larger than MAX_INDEX?
Sourcepub fn new(value: usize) -> FaceId
pub fn new(value: usize) -> FaceId
Construct this index type from a usize. Alias for from_usize.
Sourcepub fn from_foreign<F>(value: F) -> FaceIdwhere
F: Idx,
pub fn from_foreign<F>(value: F) -> FaceIdwhere
F: Idx,
Construct this index type from one in a different domain
Sourcepub const fn from_usize_unchecked(value: usize) -> FaceId
pub const fn from_usize_unchecked(value: usize) -> FaceId
Construct from a usize without any checks.
Sourcepub const fn from_raw_unchecked(raw: u8) -> FaceId
pub const fn from_raw_unchecked(raw: u8) -> FaceId
Construct from the underlying type without any checks.
Sourcepub fn from_usize(value: usize) -> FaceId
pub fn from_usize(value: usize) -> FaceId
Construct this index type from a usize.
Sourcepub fn check_index(v: usize)
pub fn check_index(v: usize)
Asserts v <= Self::MAX_INDEX unless Self::CHECKS_MAX_INDEX is false.