pub struct FutureInstant(pub Instant);Tuple Fields
0: InstantTrait Implementations
Sourceimpl Clone for FutureInstant
impl Clone for FutureInstant
Sourcefn clone(&self) -> FutureInstant
fn clone(&self) -> FutureInstant
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FutureInstant
impl Debug for FutureInstant
Sourceimpl<'de> Deserialize<'de> for FutureInstant
impl<'de> Deserialize<'de> for FutureInstant
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<FutureInstant, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<FutureInstant, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<FutureInstant> for Instant
impl From<FutureInstant> for Instant
Sourcefn from(original: FutureInstant) -> Instant
fn from(original: FutureInstant) -> Instant
Converts to this type from the input type.
Sourceimpl From<Instant> for FutureInstant
impl From<Instant> for FutureInstant
Sourcefn from(original: Instant) -> FutureInstant
fn from(original: Instant) -> FutureInstant
Converts to this type from the input type.
Sourceimpl Into<Duration> for FutureInstant
impl Into<Duration> for FutureInstant
Sourceimpl Ord for FutureInstant
impl Ord for FutureInstant
Sourcefn cmp(&self, other: &FutureInstant) -> Ordering
fn cmp(&self, other: &FutureInstant) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FutureInstant
impl PartialEq for FutureInstant
Sourcefn eq(&self, other: &FutureInstant) -> bool
fn eq(&self, other: &FutureInstant) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for FutureInstant
impl PartialOrd for FutureInstant
Sourceimpl Serialize for FutureInstant
impl Serialize for FutureInstant
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TryFrom<Duration> for FutureInstant
impl TryFrom<Duration> for FutureInstant
Sourcetype Error = FutureInstantOutOfRange
type Error = FutureInstantOutOfRange
The type returned in the event of a conversion error.
Sourcefn try_from(
duration: Duration,
) -> Result<FutureInstant, FutureInstantOutOfRange>
fn try_from( duration: Duration, ) -> Result<FutureInstant, FutureInstantOutOfRange>
Performs the conversion.
impl Copy for FutureInstant
impl Eq for FutureInstant
impl StructuralPartialEq for FutureInstant