pub struct IFastSplits { /* private fields */ }Implementations
Sourceimpl IFastSplits
impl IFastSplits
Sourcepub fn new_original(
&mut self,
ilks: &mut OccultIlks,
ipc: IPiece,
) -> (IPiece, FastSplitId)
pub fn new_original( &mut self, ilks: &mut OccultIlks, ipc: IPiece, ) -> (IPiece, FastSplitId)
During piece addition: make this into a new fastsplit piece family
Do not just drop the result, because it contains an OwningOccultIlkId
Sourcepub fn recover_ipc(
&self,
ilks: &mut OccultIlks,
fsid: FastSplitId,
) -> Option<IPiece>
pub fn recover_ipc( &self, ilks: &mut OccultIlks, fsid: FastSplitId, ) -> Option<IPiece>
During game load: recover a proper IPiece for a fastsplit piece
Just dropping the result on error is ok, despite it containing an OwningOccultIlkId, because in that case the whole game is toast.
Sourcepub fn cleanup(&mut self, ilks: &mut OccultIlks)
pub fn cleanup(&mut self, ilks: &mut OccultIlks)
During save: free up any now-unused family records