pub struct InstanceName {
pub account: AccountName,
pub game: String,
}Fields
account: AccountNamegame: StringTrait Implementations
Sourceimpl Clone for InstanceName
impl Clone for InstanceName
Sourcefn clone(&self) -> InstanceName
fn clone(&self) -> InstanceName
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstanceName
impl Debug for InstanceName
Sourceimpl<'de> Deserialize<'de> for InstanceName
impl<'de> Deserialize<'de> for InstanceName
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<InstanceName, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<InstanceName, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for InstanceName
impl Display for InstanceName
Sourceimpl FromStr for InstanceName
impl FromStr for InstanceName
Sourcetype Err = InvalidScopedName
type Err = InvalidScopedName
The associated error which can be returned from parsing.
Sourcefn from_str(s: &str) -> Result<InstanceName, InvalidScopedName>
fn from_str(s: &str) -> Result<InstanceName, InvalidScopedName>
Parses a string
s to return a value of this type. Read moreSourceimpl Hash for InstanceName
impl Hash for InstanceName
Sourceimpl<'e> HtmlFormat<'e> for InstanceName
impl<'e> HtmlFormat<'e> for InstanceName
type Encoded = &'e InstanceName
fn html_format<'f>(&'f self) -> <InstanceName as HtmlFormat<'e>>::Encodedwhere
'f: 'e,
Sourceimpl Ord for InstanceName
impl Ord for InstanceName
Sourcefn cmp(&self, other: &InstanceName) -> Ordering
fn cmp(&self, other: &InstanceName) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for InstanceName
impl PartialEq for InstanceName
Sourcefn eq(&self, other: &InstanceName) -> bool
fn eq(&self, other: &InstanceName) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for InstanceName
impl PartialOrd for InstanceName
Sourceimpl Serialize for InstanceName
impl Serialize for InstanceName
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for InstanceName
impl StructuralPartialEq for InstanceName