pub struct OccId(pub KeyData);Tuple Fields
0: KeyDataTrait Implementations
Sourceimpl<'de> Deserialize<'de> for OccId
impl<'de> Deserialize<'de> for OccId
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<OccId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<OccId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'e> HtmlFormat<'e> for OccId
impl<'e> HtmlFormat<'e> for OccId
type Encoded = &'e OccId
fn html_format<'f>(&'f self) -> <OccId as HtmlFormat<'e>>::Encodedwhere
'f: 'e,
Sourceimpl Key for OccId
impl Key for OccId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for OccId
impl Ord for OccId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for OccId
impl PartialOrd for OccId
Sourceimpl Serialize for OccId
impl Serialize for OccId
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for OccId
impl Eq for OccId
impl StructuralPartialEq for OccId