pub struct OccultIlkId(/* private fields */);Trait Implementations
Sourceimpl Borrow<OccultIlkId> for OccultIlkOwningId
impl Borrow<OccultIlkId> for OccultIlkOwningId
Sourcefn borrow(&self) -> &OccultIlkId
fn borrow(&self) -> &OccultIlkId
Immutably borrows from an owned value. Read more
Sourceimpl Clone for OccultIlkId
impl Clone for OccultIlkId
Sourcefn clone(&self) -> OccultIlkId
fn clone(&self) -> OccultIlkId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OccultIlkId
impl Debug for OccultIlkId
Sourceimpl Default for OccultIlkId
impl Default for OccultIlkId
Sourcefn default() -> OccultIlkId
fn default() -> OccultIlkId
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for OccultIlkId
impl<'de> Deserialize<'de> for OccultIlkId
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<OccultIlkId, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<OccultIlkId, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<KeyData> for OccultIlkId
impl From<KeyData> for OccultIlkId
Sourcefn from(k: KeyData) -> OccultIlkId
fn from(k: KeyData) -> OccultIlkId
Converts to this type from the input type.
Sourceimpl Hash for OccultIlkId
impl Hash for OccultIlkId
Sourceimpl Key for OccultIlkId
impl Key for OccultIlkId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for OccultIlkId
impl Ord for OccultIlkId
Sourcefn cmp(&self, other: &OccultIlkId) -> Ordering
fn cmp(&self, other: &OccultIlkId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OccultIlkId
impl PartialEq for OccultIlkId
Sourcefn eq(&self, other: &OccultIlkId) -> bool
fn eq(&self, other: &OccultIlkId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for OccultIlkId
impl PartialOrd for OccultIlkId
Sourceimpl Serialize for OccultIlkId
impl Serialize for OccultIlkId
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for OccultIlkId
impl Eq for OccultIlkId
impl StructuralPartialEq for OccultIlkId