pub struct PieceId(/* private fields */);Trait Implementations
Sourceimpl<'de> Deserialize<'de> for PieceId
impl<'de> Deserialize<'de> for PieceId
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<PieceId, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<PieceId, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl IdForById for PieceId
impl IdForById for PieceId
const ERROR: Inapplicable = Ia::PieceGone
type Error = Inapplicable
Sourceimpl Key for PieceId
impl Key for PieceId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for PieceId
impl Ord for PieceId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for PieceId
impl PartialOrd for PieceId
Sourceimpl Serialize for PieceId
impl Serialize for PieceId
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for PieceId
impl Eq for PieceId
impl StructuralPartialEq for PieceId