pub struct PlayerId(pub KeyData);Tuple Fields
0: KeyDataTrait Implementations
Sourceimpl AccessId for PlayerId
impl AccessId for PlayerId
const ERROR: PlayerNotFound = PlayerNotFound
type Error = PlayerNotFound
fn global_tokens( _: PrivateCaller, ) -> &'static RwLock<RawRwLock, HashMap<RawToken, InstanceAccessDetails<PlayerId>>>
fn tokens_registry( ig: &mut Instance, _: PrivateCaller, ) -> &mut TokenRegistry<PlayerId>
Sourceimpl<'de> Deserialize<'de> for PlayerId
impl<'de> Deserialize<'de> for PlayerId
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<PlayerId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<PlayerId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'e> HtmlFormat<'e> for PlayerId
impl<'e> HtmlFormat<'e> for PlayerId
type Encoded = &'e PlayerId
fn html_format<'f>(&'f self) -> <PlayerId as HtmlFormat<'e>>::Encodedwhere
'f: 'e,
Sourceimpl Key for PlayerId
impl Key for PlayerId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for PlayerId
impl Ord for PlayerId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for PlayerId
impl PartialOrd for PlayerId
Sourceimpl Serialize for PlayerId
impl Serialize for PlayerId
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for PlayerId
impl Eq for PlayerId
impl StructuralPartialEq for PlayerId