StableIndexVecDeque

Struct StableIndexVecDeque 

pub struct StableIndexVecDeque<T, I>
where I: Offset,
{ /* private fields */ }
Double-ended queue with stable indices

Implementations

Source

impl<T, I> Deque<T, I>
where I: Offset,

pub fn new() -> Deque<T, I>

pub fn with_capacity(cap: usize) -> Deque<T, I>

Like VecDeque::with_capacity

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn front(&self) -> Option<&T>

pub fn back(&self) -> Option<&T>

pub fn front_mut(&mut self) -> Option<&mut T>

pub fn back_mut(&mut self) -> Option<&mut T>

pub fn get(&self, i: I) -> Option<&T>

Returns the element with index i, if it is still in the deque.

pub fn get_mut(&mut self, i: I) -> Option<&mut T>

pub fn push_front(&mut self, e: T) -> I

Panics on index overflow.

pub fn push_back(&mut self, e: T) -> I

Panics on index overflow.

pub fn pop_front(&mut self) -> Option<T>

Panics on index overflow.

pub fn pop_back(&mut self) -> Option<T>

Panics on index overflow.

pub fn swap_remove_front(&mut self, i: I) -> Option<T>

Removes the element with index i, by replacing it with the eleement from the front. Invalidates the index of the front element element (now i refers to that) but leaves other indices valid. Panics on index overflow.

pub fn swap_remove_back(&mut self, i: I) -> Option<T>

Removes the element with index i, by replacing it with the eleement from the back. Invalidates the index of the back element (now i refers to that), but leaves other indices valid. Panics on index overflow.

pub fn front_index(&self) -> I

The index of the first item the deque. If the queue is empty, this is the same as end_index.

pub fn end_index(&self) -> I

The index just after the end of the qeue. I.e., the index that would be assigned to a new element added with push_back. Panics on index overflow.

pub fn iter(&self) -> Iter<'_, T, I>

Returns a (front-to-back) iterator.

pub fn iter_mut(&mut self) -> IterMut<'_, T, I>

Returns a (front-to-back) iterator which returns mutable references.

pub fn counter(&self) -> &I

I is how many more times pop_front has been called than push_back.

pub fn counter_mut(&mut self) -> &mut I

Modifying this invalidates all indices.

pub fn inner(&self) -> &VecDeque<T>

Allos access to the VecDeque inside this Deque

pub fn inner_mut(&mut self) -> &mut VecDeque<T>

Mutable access to the VecDeque inside this Dequeu. Adding/removing elements at the front of of the VecDeque invalidates all indices.

pub fn into_parts(self) -> (I, VecDeque<T>)

pub fn from_parts(advanced: I, v: VecDeque<T>) -> Deque<T, I>

pub fn as_parts(&self) -> (&I, &VecDeque<T>)

pub fn as_mut_parts(&mut self) -> (&mut I, &mut VecDeque<T>)

Modifying the parts inconsistently will invalidate indices.