pub struct Uid(/* private fields */);Expand description
User identifier
Newtype pattern around uid_t (which is just alias). It prevents bugs caused by accidentally
passing wrong value.
Implementations
Sourceimpl Uid
impl Uid
Sourcepub fn current() -> Uid
pub fn current() -> Uid
Returns Uid of calling process. This is practically a more Rusty alias for getuid.
Sourcepub fn effective() -> Uid
pub fn effective() -> Uid
Returns effective Uid of calling process. This is practically a more Rusty alias for geteuid.