UniCase

Struct UniCase 

pub struct UniCase<S>(/* private fields */);
Case Insensitive wrapper of strings.

Implementations

Source

impl<S> UniCase<S>
where S: AsRef<str>,

pub fn new(s: S) -> UniCase<S>

Creates a new UniCase.

Note: This scans the text to determine if it is all ASCII or not.

pub fn to_folded_case(&self) -> String

Returns a copy of this string where each character is mapped to its Unicode CaseFolding equivalent.

Note

Unicode Case Folding is meant for string storage and matching, not for display.

Source

impl<S> UniCase<S>

pub const fn unicode(s: S) -> UniCase<S>

Creates a new UniCase, skipping the ASCII check.

pub const fn ascii(s: S) -> UniCase<S>

Creates a new UniCase which performs only ASCII case folding.

pub fn is_ascii(&self) -> bool

Return true if this instance will only perform ASCII case folding.

pub fn into_inner(self) -> S

Unwraps the inner value held by this UniCase.