pub struct SpooledTempFile { /* private fields */ }Expand description
An object that behaves like a regular temporary file, but keeps data in memory until it reaches a configured size, at which point the data is written to a temporary file on disk, and further operations use the file on disk.
Implementations
Sourceimpl SpooledTempFile
impl SpooledTempFile
Sourcepub fn new(max_size: usize) -> SpooledTempFile ⓘ
pub fn new(max_size: usize) -> SpooledTempFile ⓘ
Construct a new SpooledTempFile.
Sourcepub fn new_in<P>(max_size: usize, dir: P) -> SpooledTempFile ⓘ
pub fn new_in<P>(max_size: usize, dir: P) -> SpooledTempFile ⓘ
Construct a new SpooledTempFile, backed by a file in the specified directory.
Sourcepub fn roll(&mut self) -> Result<(), Error>
pub fn roll(&mut self) -> Result<(), Error>
Rolls over to a file on disk, regardless of current size. Does nothing if already rolled over.
Sourcepub fn set_len(&mut self, size: u64) -> Result<(), Error>
pub fn set_len(&mut self, size: u64) -> Result<(), Error>
Truncate the file to the specified size.
Sourcepub fn into_inner(self) -> SpooledData
pub fn into_inner(self) -> SpooledData
Consumes and returns the inner SpooledData type.