pub struct Expr {
pub val: ExprVal,
pub negated: bool,
pub filters: Vec<FunctionCall>,
}Expand description
An expression is a value that can be negated and followed by optional filters
Fields
val: ExprValThe expression we are evaluating
negated: boolIs it using not?
filters: Vec<FunctionCall>List of filters used on that value
Implementations
Sourceimpl Expr
impl Expr
Sourcepub fn new_negated(val: ExprVal) -> Expr
pub fn new_negated(val: ExprVal) -> Expr
Create a new negated Expr
Sourcepub fn with_filters(val: ExprVal, filters: Vec<FunctionCall>) -> Expr
pub fn with_filters(val: ExprVal, filters: Vec<FunctionCall>) -> Expr
Create a new basic Expr with some filters
Sourcepub fn has_default_filter(&self) -> bool
pub fn has_default_filter(&self) -> bool
Check if the expr has a default filter as first filter
Sourcepub fn is_marked_safe(&self) -> bool
pub fn is_marked_safe(&self) -> bool
Check if the last filter is safe