pub struct Forloop {
pub key: Option<String>,
pub value: String,
pub container: Expr,
pub body: Vec<Node>,
pub empty_body: Option<Vec<Node>>,
}Expand description
A forloop: can be over values or key/values
Fields
key: Option<String>Name of the key in the loop (only when iterating on map-like objects)
value: StringName of the local variable for the value in the loop
container: ExprExpression being iterated on
body: Vec<Node>What’s in the forloop itself
empty_body: Option<Vec<Node>>The body to execute in case of an empty object