#[non_exhaustive]pub enum Error {
UnsupportedType,
KeyNotString,
ValueAfterTable,
DateInvalid,
NumberInvalid,
UnsupportedNone,
Custom(String),
}Expand description
Errors that can occur when serializing a type.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedType
Indicates that a Rust type was requested to be serialized but it was not supported.
Currently the TOML format does not support serializing types such as enums, tuples and tuple structs.
KeyNotString
The key of all TOML maps must be strings, but serialization was attempted where the key of a map was not a string.
ValueAfterTable
All values in a TOML table must be emitted before further tables are emitted. If a value is emitted after a table then this error is generated.
DateInvalid
A serialized date was invalid.
NumberInvalid
A serialized number was invalid.
UnsupportedNone
None was attempted to be serialized, but it’s not supported.
Custom(String)
A custom error which could be generated when serializing a particular type.