pub struct Spanned<T> { /* private fields */ }Expand description
A spanned value, indicating the range at which it is defined in the source.
use serde_derive::Deserialize;
use toml::Spanned;
#[derive(Deserialize)]
struct Value {
s: Spanned<String>,
}
let t = "s = \"value\"\n";
let u: Value = toml::from_str(t).unwrap();
assert_eq!(u.s.start(), 4);
assert_eq!(u.s.end(), 11);
assert_eq!(u.s.get_ref(), "value");
assert_eq!(u.s.into_inner(), String::from("value"));Implementations
Sourceimpl<T> Spanned<T>
impl<T> Spanned<T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes the spanned value and returns the contained value.