pub trait Index: Sealed { }Expand description
Types that can be used to index a toml::Value
Currently this is implemented for usize to index arrays and str to index
tables.
This trait is sealed and not intended for implementation outside of the
toml crate.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".