APOE

Type Alias APOE 

pub type APOE = ApiPieceOpError;

Aliased Type

pub enum APOE {
    Fatal(Fatal),
    Inapplicable(Inapplicable),
    PartiallyProcessed(Inapplicable, Vec<LogEntry>),
}

Variants



Fatal(Fatal)



Inapplicable(Inapplicable)



PartiallyProcessed(Inapplicable, Vec<LogEntry>)

This error is always generated in the context of a piece operation by a particular client. It corresponds roughly to a PieceUpdateFromOp for other clients of (Unpredicable, PieceUpdateOp::Modify, ..). For this client it is that but also an error report.