UnicodeWidthChar

Trait UnicodeWidthChar 

pub trait UnicodeWidthChar: Sealed {
    // Required methods
    fn width(self) -> Option<usize>;
    fn width_cjk(self) -> Option<usize>;
}
Methods for determining displayed width of Unicode characters.

Required Methods

fn width(self) -> Option<usize>

Returns the character’s displayed width in columns, or None if the character is a control character.

This function treats characters in the Ambiguous category according to Unicode Standard Annex #11 as 1 column wide. This is consistent with the recommendations for non-CJK contexts, or when the context cannot be reliably determined.

fn width_cjk(self) -> Option<usize>

Returns the character’s displayed width in columns, or None if the character is a control character.

This function treats characters in the Ambiguous category according to Unicode Standard Annex #11 as 2 columns wide. This is consistent with the recommendations for CJK contexts.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl UnicodeWidthChar for char

Implementors