pub struct UCred {
pub uid: u32,
pub gid: u32,
pub pid: Option<i32>,
}๐ฌThis is a nightly-only experimental API. (
peer_credentials_unix_socket)Expand description
Credentials for a UNIX process for credentials passing.
Fields
uid: u32๐ฌThis is a nightly-only experimental API. (
peer_credentials_unix_socket)The UID part of the peer credential. This is the effective UID of the process at the domain socketโs endpoint.
gid: u32๐ฌThis is a nightly-only experimental API. (
peer_credentials_unix_socket)The GID part of the peer credential. This is the effective GID of the process at the domain socketโs endpoint.
pid: Option<i32>๐ฌThis is a nightly-only experimental API. (
peer_credentials_unix_socket)The PID part of the peer credential. This field is optional because the PID part of the peer credentials is not supported on every platform. On platforms where the mechanism to discover the PID exists, this field will be populated to the PID of the process at the domain socketโs endpoint. Otherwise, it will be set to None.