#[non_exhaustive]pub enum CompressionMethod {
Stored,
Deflated,
Bzip2,
Aes,
Zstd,
Unsupported(u16),
}Expand description
Identifies the storage format used to compress a file within a ZIP archive.
Each file’s compression method is stored alongside it, allowing the contents to be read without context.
When creating ZIP files, you may choose the method to use with
crate::write::FileOptions::compression_method
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Stored
Store the file as is
Deflated
Compress the file using Deflate
Bzip2
Compress the file using BZIP2
Aes
Encrypted using AES.
The actual compression method has to be taken from the AES extra data field
or from ZipFileData.
Zstd
Compress the file using ZStandard
Unsupported(u16)
👎Deprecated since 0.5.7:
use the constants instead
Unsupported compression method
Implementations
Sourceimpl CompressionMethod
All compression methods defined for the ZIP format
impl CompressionMethod
All compression methods defined for the ZIP format
pub const STORE: CompressionMethod = CompressionMethod::Stored
pub const SHRINK: CompressionMethod
pub const REDUCE_1: CompressionMethod
pub const REDUCE_2: CompressionMethod
pub const REDUCE_3: CompressionMethod
pub const REDUCE_4: CompressionMethod
pub const IMPLODE: CompressionMethod
pub const DEFLATE: CompressionMethod = CompressionMethod::Deflated
pub const DEFLATE64: CompressionMethod
pub const PKWARE_IMPLODE: CompressionMethod
pub const BZIP2: CompressionMethod = CompressionMethod::Bzip2
pub const LZMA: CompressionMethod
pub const IBM_ZOS_CMPSC: CompressionMethod
pub const IBM_TERSE: CompressionMethod
pub const ZSTD_DEPRECATED: CompressionMethod
pub const ZSTD: CompressionMethod = CompressionMethod::Zstd
pub const MP3: CompressionMethod
pub const XZ: CompressionMethod
pub const JPEG: CompressionMethod
pub const WAVPACK: CompressionMethod
pub const PPMD: CompressionMethod
pub const AES: CompressionMethod = CompressionMethod::Aes
Sourceimpl CompressionMethod
impl CompressionMethod
Sourcepub fn from_u16(val: u16) -> CompressionMethod
👎Deprecated since 0.5.7: use a constant to construct a compression method
pub fn from_u16(val: u16) -> CompressionMethod
use a constant to construct a compression method
Converts an u16 to its corresponding CompressionMethod