ZipArchive

Struct ZipArchive 

pub struct ZipArchive<R> { /* private fields */ }
ZIP archive reader

At the moment, this type is cheap to clone if this is the case for the reader it uses. However, this is not guaranteed by this crate and it may change in the future.

use std::io::prelude::*;
fn list_zip_contents(reader: impl Read + Seek) -> zip::result::ZipResult<()> {
    let mut zip = zip::ZipArchive::new(reader)?;

    for i in 0..zip.len() {
        let mut file = zip.by_index(i)?;
        println!("Filename: {}", file.name());
        std::io::copy(&mut file, &mut std::io::stdout());
    }

    Ok(())
}

Implementations

Source

impl<R> ZipArchive<R>
where R: Read + Seek,

pub fn new(reader: R) -> Result<ZipArchive<R>, ZipError>

Read a ZIP archive, collecting the files it contains

This uses the central directory record of the ZIP file, and ignores local file headers

pub fn extract<P>(&mut self, directory: P) -> Result<(), ZipError>
where P: AsRef<Path>,

Extract a Zip archive into a directory, overwriting files if they already exist. Paths are sanitized with ZipFile::enclosed_name.

Extraction is not atomic; If an error is encountered, some of the files may be left on disk.

pub fn len(&self) -> usize

Number of files contained in this zip.

pub fn is_empty(&self) -> bool

Whether this zip archive contains no files

pub fn offset(&self) -> u64

Get the offset from the beginning of the underlying reader that this zip begins at, in bytes.

Normally this value is zero, but if the zip has arbitrary data prepended to it, then this value will be the size of that prepended data.

pub fn comment(&self) -> &[u8]

Get the comment of the zip archive.

pub fn file_names(&self) -> impl Iterator<Item = &str>

Returns an iterator over all the file and directory names in this archive.

pub fn by_name_decrypt<'a>( &'a mut self, name: &str, password: &[u8], ) -> Result<Result<ZipFile<'a>, InvalidPassword>, ZipError>

Search for a file entry by name, decrypt with given password

Warning

The implementation of the cryptographic algorithms has not gone through a correctness review, and you should assume it is insecure: passwords used with this API may be compromised.

This function sometimes accepts wrong password. This is because the ZIP spec only allows us to check for a 1/256 chance that the password is correct. There are many passwords out there that will also pass the validity checks we are able to perform. This is a weakness of the ZipCrypto algorithm, due to its fairly primitive approach to cryptography.

pub fn by_name<'a>(&'a mut self, name: &str) -> Result<ZipFile<'a>, ZipError>

Search for a file entry by name

pub fn by_index_decrypt<'a>( &'a mut self, file_number: usize, password: &[u8], ) -> Result<Result<ZipFile<'a>, InvalidPassword>, ZipError>

Get a contained file by index, decrypt with given password

Warning

The implementation of the cryptographic algorithms has not gone through a correctness review, and you should assume it is insecure: passwords used with this API may be compromised.

This function sometimes accepts wrong password. This is because the ZIP spec only allows us to check for a 1/256 chance that the password is correct. There are many passwords out there that will also pass the validity checks we are able to perform. This is a weakness of the ZipCrypto algorithm, due to its fairly primitive approach to cryptography.

pub fn by_index(&mut self, file_number: usize) -> Result<ZipFile<'_>, ZipError>

Get a contained file by index

pub fn by_index_raw( &mut self, file_number: usize, ) -> Result<ZipFile<'_>, ZipError>

Get a contained file by index without decompressing it

pub fn into_inner(self) -> R

Unwrap and return the inner reader object

The position of the reader is undefined.