pub trait Ord: Eq + PartialOrd {
// Required method
fn cmp(&self, other: &Self) -> Ordering;
// Provided methods
fn max(self, other: Self) -> Self
where Self: Sized { ... }
fn min(self, other: Self) -> Self
where Self: Sized { ... }
fn clamp(self, min: Self, max: Self) -> Self
where Self: Sized { ... }
}Expand description
Trait for types that form a total order.
Implementations must be consistent with the PartialOrd implementation, and ensure max,
min, and clamp are consistent with cmp:
partial_cmp(a, b) == Some(cmp(a, b)).max(a, b) == max_by(a, b, cmp)(ensured by the default implementation).min(a, b) == min_by(a, b, cmp)(ensured by the default implementation).- For
a.clamp(min, max), see the method docs (ensured by the default implementation).
Violating these requirements is a logic error. The behavior resulting from a logic error is not
specified, but users of the trait must ensure that such logic errors do not result in
undefined behavior. This means that unsafe code must not rely on the correctness of these
methods.
Corollaries
From the above and the requirements of PartialOrd, it follows that for all a, b and c:
- exactly one of
a < b,a == bora > bis true; and <is transitive:a < bandb < cimpliesa < c. The same must hold for both==and>.
Mathematically speaking, the < operator defines a strict weak order. In cases where ==
conforms to mathematical equality, it also defines a strict total order.
Derivable
This trait can be used with #[derive].
When derived on structs, it will produce a
lexicographic ordering based on the
top-to-bottom declaration order of the struct’s members.
When derived on enums, variants are ordered primarily by their discriminants. Secondarily,
they are ordered by their fields. By default, the discriminant is smallest for variants at the
top, and largest for variants at the bottom. Here’s an example:
#[derive(PartialEq, Eq, PartialOrd, Ord)]
enum E {
Top,
Bottom,
}
assert!(E::Top < E::Bottom);However, manually setting the discriminants can override this default behavior:
#[derive(PartialEq, Eq, PartialOrd, Ord)]
enum E {
Top = 2,
Bottom = 1,
}
assert!(E::Bottom < E::Top);Lexicographical comparison
Lexicographical comparison is an operation with the following properties:
- Two sequences are compared element by element.
- The first mismatching element defines which sequence is lexicographically less or greater than the other.
- If one sequence is a prefix of another, the shorter sequence is lexicographically less than the other.
- If two sequences have equivalent elements and are of the same length, then the sequences are lexicographically equal.
- An empty sequence is lexicographically less than any non-empty sequence.
- Two empty sequences are lexicographically equal.
How can I implement Ord?
Ord requires that the type also be PartialOrd, PartialEq, and Eq.
Because Ord implies a stronger ordering relationship than PartialOrd, and both Ord and
PartialOrd must agree, you must choose how to implement Ord first. You can choose to
derive it, or implement it manually. If you derive it, you should derive all four traits. If you
implement it manually, you should manually implement all four traits, based on the
implementation of Ord.
Here’s an example where you want to define the Character comparison by health and
experience only, disregarding the field mana:
use std::cmp::Ordering;
struct Character {
health: u32,
experience: u32,
mana: f32,
}
impl Ord for Character {
fn cmp(&self, other: &Self) -> Ordering {
self.experience
.cmp(&other.experience)
.then(self.health.cmp(&other.health))
}
}
impl PartialOrd for Character {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
Some(self.cmp(other))
}
}
impl PartialEq for Character {
fn eq(&self, other: &Self) -> bool {
self.health == other.health && self.experience == other.experience
}
}
impl Eq for Character {}If all you need is to slice::sort a type by a field value, it can be simpler to use
slice::sort_by_key.
Examples of incorrect Ord implementations
use std::cmp::Ordering;
#[derive(Debug)]
struct Character {
health: f32,
}
impl Ord for Character {
fn cmp(&self, other: &Self) -> std::cmp::Ordering {
if self.health < other.health {
Ordering::Less
} else if self.health > other.health {
Ordering::Greater
} else {
Ordering::Equal
}
}
}
impl PartialOrd for Character {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
Some(self.cmp(other))
}
}
impl PartialEq for Character {
fn eq(&self, other: &Self) -> bool {
self.health == other.health
}
}
impl Eq for Character {}
let a = Character { health: 4.5 };
let b = Character { health: f32::NAN };
// Mistake: floating-point values do not form a total order and using the built-in comparison
// operands to implement `Ord` irregardless of that reality does not change it. Use
// `f32::total_cmp` if you need a total order for floating-point values.
// Reflexivity requirement of `Ord` is not given.
assert!(a == a);
assert!(b != b);
// Antisymmetry requirement of `Ord` is not given. Only one of a < c and c < a is allowed to be
// true, not both or neither.
assert_eq!((a < b) as u8 + (b < a) as u8, 0);use std::cmp::Ordering;
#[derive(Debug)]
struct Character {
health: u32,
experience: u32,
}
impl PartialOrd for Character {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
Some(self.cmp(other))
}
}
impl Ord for Character {
fn cmp(&self, other: &Self) -> std::cmp::Ordering {
if self.health < 50 {
self.health.cmp(&other.health)
} else {
self.experience.cmp(&other.experience)
}
}
}
// For performance reasons implementing `PartialEq` this way is not the idiomatic way, but it
// ensures consistent behavior between `PartialEq`, `PartialOrd` and `Ord` in this example.
impl PartialEq for Character {
fn eq(&self, other: &Self) -> bool {
self.cmp(other) == Ordering::Equal
}
}
impl Eq for Character {}
let a = Character {
health: 3,
experience: 5,
};
let b = Character {
health: 10,
experience: 77,
};
let c = Character {
health: 143,
experience: 2,
};
// Mistake: The implementation of `Ord` compares different fields depending on the value of
// `self.health`, the resulting order is not total.
// Transitivity requirement of `Ord` is not given. If a is smaller than b and b is smaller than
// c, by transitive property a must also be smaller than c.
assert!(a < b && b < c && c < a);
// Antisymmetry requirement of `Ord` is not given. Only one of a < c and c < a is allowed to be
// true, not both or neither.
assert_eq!((a < c) as u8 + (c < a) as u8, 2);The documentation of PartialOrd contains further examples, for example it’s wrong for
PartialOrd and PartialEq to disagree.
Required Methods
1.0.0 (const: unstable) · Sourcefn cmp(&self, other: &Self) -> Ordering
fn cmp(&self, other: &Self) -> Ordering
This method returns an Ordering between self and other.
By convention, self.cmp(&other) returns the ordering matching the expression
self <operator> other if true.
Examples
use std::cmp::Ordering;
assert_eq!(5.cmp(&10), Ordering::Less);
assert_eq!(10.cmp(&5), Ordering::Greater);
assert_eq!(5.cmp(&5), Ordering::Equal);Provided Methods
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values.
Returns the second argument if the comparison determines them to be equal.
Examples
assert_eq!(1.max(2), 2);
assert_eq!(2.max(2), 2);use std::cmp::Ordering;
#[derive(Eq)]
struct Equal(&'static str);
impl PartialEq for Equal {
fn eq(&self, other: &Self) -> bool { true }
}
impl PartialOrd for Equal {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> { Some(Ordering::Equal) }
}
impl Ord for Equal {
fn cmp(&self, other: &Self) -> Ordering { Ordering::Equal }
}
assert_eq!(Equal("self").max(Equal("other")).0, "other");1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values.
Returns the first argument if the comparison determines them to be equal.
Examples
assert_eq!(1.min(2), 1);
assert_eq!(2.min(2), 2);use std::cmp::Ordering;
#[derive(Eq)]
struct Equal(&'static str);
impl PartialEq for Equal {
fn eq(&self, other: &Self) -> bool { true }
}
impl PartialOrd for Equal {
fn partial_cmp(&self, other: &Self) -> Option<Ordering> { Some(Ordering::Equal) }
}
impl Ord for Equal {
fn cmp(&self, other: &Self) -> Ordering { Ordering::Equal }
}
assert_eq!(Equal("self").min(Equal("other")).0, "self");Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl Ord for Kind
impl Ord for Month
impl Ord for AccountScope
impl Ord for otter_nodejs_tests::BigEndian
impl Ord for ErrorKind
impl Ord for Infallible
impl Ord for IpAddr
impl Ord for LinkKind
impl Ord for otter_nodejs_tests::LittleEndian
impl Ord for OccultationKindGeneral<(OccDisplacement, ZCoord)>
impl Ord for Ordering
impl Ord for PieceMoveable
impl Ord for ProgressUpdateMode
impl Ord for SocketAddr
impl Ord for TablePermission
impl Ord for otter_nodejs_tests::flexi_logger::Level
impl Ord for otter_nodejs_tests::flexi_logger::LevelFilter
impl Ord for AsciiChar
impl Ord for CharCase
impl Ord for Ipv6MulticastScope
impl Ord for PosixFadviseAdvice
impl Ord for AioFsyncMode
impl Ord for LioMode
impl Ord for LioOpcode
impl Ord for MmapAdvise
impl Ord for Event
impl Ord for Request
impl Ord for QuotaFmt
impl Ord for QuotaType
impl Ord for RebootMode
impl Ord for Resource
impl Ord for SigmaskHow
impl Ord for Signal
impl Ord for BaudRate
impl Ord for FlowArg
impl Ord for FlushArg
impl Ord for SetArg
impl Ord for SpecialCharacterIndices
impl Ord for otter_nodejs_tests::nix::sys::timerfd::ClockId
impl Ord for otter_nodejs_tests::nix::sys::wait::Id
impl Ord for LineEnding
impl Ord for console::utils::Attribute
impl Ord for SectionId
impl Ord for ColumnType
impl Ord for ExtensionType
impl Ord for GeneralCategory
impl Ord for IpAddrRange
impl Ord for IpNet
impl Ord for IpSubnets
impl Ord for RecursiveMode
impl Ord for Sign
impl Ord for StaticUser
impl Ord for Encoding
impl Ord for Algorithm
impl Ord for Utf8Sequence
impl Ord for Direction
impl Ord for zerocopy::byteorder::BigEndian
impl Ord for zerocopy::byteorder::LittleEndian
impl Ord for bool
impl Ord for char
impl Ord for i8
impl Ord for i16
impl Ord for i32
impl Ord for i64
impl Ord for i128
impl Ord for isize
impl Ord for !
impl Ord for str
Implements ordering of strings.
Strings are ordered lexicographically by their byte values. This orders Unicode code
points based on their positions in the code charts. This is not necessarily the same as
“alphabetical” order, which varies by language and locale. Sorting strings according to
culturally-accepted standards requires locale-specific data that is outside the scope of
the str type.
impl Ord for u8
impl Ord for u16
impl Ord for u32
impl Ord for u64
impl Ord for u128
impl Ord for ()
impl Ord for usize
impl Ord for otter_nodejs_tests::bundles::Id
impl Ord for Index
impl Ord for LibInBundleI
impl Ord for ZipIndex
impl Ord for NaiveDateDaysIterator
impl Ord for NaiveDateWeeksIterator
impl Ord for Days
impl Ord for IsoWeek
impl Ord for Months
impl Ord for NaiveDate
impl Ord for NaiveDateTime
impl Ord for NaiveTime
impl Ord for TimeDelta
impl Ord for WeekdaySet
impl Ord for ATerm
impl Ord for B0
impl Ord for B1
impl Ord for Equal
impl Ord for Greater
impl Ord for Less
impl Ord for UTerm
impl Ord for Z0
impl Ord for Error
impl Ord for MatchOptions
impl Ord for Pattern
impl Ord for otter_nodejs_tests::humantime::Duration
impl Ord for otter_nodejs_tests::humantime::Timestamp
impl Ord for TypeId
impl Ord for CpuidResult
impl Ord for ByteStr
impl Ord for CStr
impl Ord for PhantomPinned
impl Ord for SocketAddrV4
impl Ord for SocketAddrV6
impl Ord for Location<'_>
impl Ord for Unsupported
impl Ord for otter_nodejs_tests::materials_format::Version
impl Ord for AtFlags
impl Ord for FallocateFlags
impl Ord for otter_nodejs_tests::nix::fcntl::FdFlag
impl Ord for OFlag
impl Ord for RenameFlags
impl Ord for SealFlag
impl Ord for SpliceFFlags
impl Ord for DeleteModuleFlags
impl Ord for ModuleInitFlags
impl Ord for MntFlags
impl Ord for otter_nodejs_tests::nix::mount::MsFlags
impl Ord for otter_nodejs_tests::nix::mqueue::FdFlag
impl Ord for MQ_OFlag
impl Ord for InterfaceFlags
impl Ord for PollFlags
impl Ord for CloneFlags
impl Ord for EpollCreateFlags
impl Ord for EpollFlags
impl Ord for EfdFlags
impl Ord for AddWatchFlags
impl Ord for InitFlags
impl Ord for WatchDescriptor
impl Ord for MemFdCreateFlag
impl Ord for MRemapFlags
impl Ord for MapFlags
impl Ord for MlockAllFlags
impl Ord for otter_nodejs_tests::nix::sys::mman::MsFlags
impl Ord for ProtFlags
impl Ord for Persona
impl Ord for Options
impl Ord for QuotaValidFlags
impl Ord for SaFlags
impl Ord for SfdFlags
impl Ord for MsgFlags
impl Ord for SockFlag
impl Ord for TimestampingFlag
impl Ord for Mode
impl Ord for SFlag
impl Ord for FsFlags
impl Ord for ControlFlags
impl Ord for InputFlags
impl Ord for LocalFlags
impl Ord for OutputFlags
impl Ord for TimeVal
impl Ord for TimerFlags
impl Ord for TimerSetTimeFlags
impl Ord for WaitPidFlag
impl Ord for otter_nodejs_tests::nix::time::ClockId
impl Ord for AccessFlags
impl Ord for Pid
impl Ord for Alignment
impl Ord for DescId
impl Ord for SvgId
impl Ord for DefaultKey
impl Ord for KeyData
impl Ord for Fingerprint
impl Ord for otter_nodejs_tests::sshkeys::Id
impl Ord for KeySpec
impl Ord for Nonce
impl Ord for AccountId
impl Ord for AccountName
impl Ord for AccountNotFound
impl Ord for ClientId
impl Ord for otter_nodejs_tests::Duration
impl Ord for FaceId
impl Ord for FastSplitId
impl Ord for FutureInstant
impl Ord for Generation
impl Ord for GoodItemName
impl Ord for Html
impl Ord for HtmlLit
impl Ord for HtmlStr
impl Ord for InstanceName
impl Ord for otter_nodejs_tests::Instant
impl Ord for Ipv4Addr
impl Ord for Ipv6Addr
impl Ord for ItemEnquiryData
impl Ord for LibraryEnquiryData
impl Ord for Notch
impl Ord for OccId
impl Ord for OccultIlkId
impl Ord for OsStr
impl Ord for PathBuf
impl Ord for PieceId
impl Ord for PlayerId
impl Ord for PlayerNotFound
impl Ord for RawToken
impl Ord for RawTokenVal
impl Ord for SpecDepth
impl Ord for TimeSpec
impl Ord for otter_nodejs_tests::Timestamp
impl Ord for TokenRevelationKey
impl Ord for UpdateId
impl Ord for Url
URLs compare like their serialization.
impl Ord for UrlSpec
impl Ord for VisiblePieceId
impl Ord for ZCoord
impl Ord for ZLevel
impl Ord for SystemTime
impl Ord for LimbVal
impl Ord for ByteString
impl Ord for CString
impl Ord for String
impl Ord for OsString
impl Ord for Components<'_>
impl Ord for Path
impl Ord for PrefixComponent<'_>
impl Ord for aho_corasick::util::primitives::PatternID
impl Ord for aho_corasick::util::primitives::StateID
impl Ord for Base64Bcrypt
impl Ord for Base64Crypt
impl Ord for Base64Pbkdf2
impl Ord for Base64ShaCrypt
impl Ord for Base64
impl Ord for Base64Unpadded
impl Ord for Base64Url
impl Ord for Base64UrlUnpadded
impl Ord for BStr
impl Ord for BString
impl Ord for bytes::bytes::Bytes
impl Ord for BytesMut
impl Ord for FileTime
impl Ord for Register
impl Ord for DwAccess
impl Ord for DwAddr
impl Ord for DwAt
impl Ord for DwAte
impl Ord for DwCc
impl Ord for DwCfa
impl Ord for DwChildren
impl Ord for DwDefaulted
impl Ord for DwDs
impl Ord for DwDsc
impl Ord for DwEhPe
impl Ord for DwEnd
impl Ord for DwForm
impl Ord for DwId
impl Ord for DwIdx
impl Ord for DwInl
impl Ord for DwLang
impl Ord for DwLle
impl Ord for DwLnct
impl Ord for DwLne
impl Ord for DwLns
impl Ord for DwMacinfo
impl Ord for DwMacro
impl Ord for DwOp
impl Ord for DwOrd
impl Ord for DwRle
impl Ord for DwSect
impl Ord for DwSectV2
impl Ord for DwTag
impl Ord for DwUt
impl Ord for DwVirtuality
impl Ord for DwVis
impl Ord for ArangeEntry
impl Ord for Range
impl Ord for HeaderValue
impl Ord for StatusCode
impl Ord for http::version::Version
impl Ord for ReasonPhrase
impl Ord for Other
impl Ord for icu_locale_core::extensions::private::other::Subtag
impl Ord for Private
impl Ord for Fields
impl Ord for icu_locale_core::extensions::transform::key::Key
impl Ord for icu_locale_core::extensions::transform::value::Value
impl Ord for icu_locale_core::extensions::unicode::attribute::Attribute
impl Ord for Attributes
impl Ord for icu_locale_core::extensions::unicode::key::Key
impl Ord for Keywords
impl Ord for SubdivisionId
impl Ord for SubdivisionSuffix
impl Ord for icu_locale_core::extensions::unicode::value::Value
impl Ord for Language
impl Ord for Region
impl Ord for icu_locale_core::subtags::script::Script
impl Ord for icu_locale_core::subtags::Subtag
impl Ord for Variant
impl Ord for Variants
impl Ord for GeneralCategoryULE
impl Ord for BidiClass
impl Ord for CanonicalCombiningClass
impl Ord for EastAsianWidth
impl Ord for GeneralCategoryOutOfBoundsError
impl Ord for GraphemeClusterBreak
impl Ord for HangulSyllableType
impl Ord for IndicConjunctBreak
impl Ord for IndicSyllabicCategory
impl Ord for JoiningGroup
impl Ord for JoiningType
impl Ord for LineBreak
impl Ord for NumericType
impl Ord for icu_properties::props::Script
impl Ord for SentenceBreak
impl Ord for VerticalOrientation
impl Ord for WordBreak
impl Ord for DataMarkerId
impl Ord for DataMarkerIdHash
impl Ord for DataMarkerInfo
impl Ord for DataMarkerAttributes
impl Ord for DataRequestMetadata
impl Ord for EventMask
impl Ord for WatchMask
impl Ord for Ipv4AddrRange
impl Ord for Ipv6AddrRange
impl Ord for Ipv4Net
impl Ord for Ipv4Subnets
impl Ord for Ipv6Net
impl Ord for Ipv6Subnets
impl Ord for Mime
impl Ord for PollOpt
impl Ord for mio::event_imp::Ready
impl Ord for mio::interest::Interest
impl Ord for mio::interest::Interest
impl Ord for UnixReady
impl Ord for mio::token::Token
impl Ord for mio::token::Token
impl Ord for mio::token::Token
impl Ord for Op
impl Ord for BigInt
impl Ord for BigUint
impl Ord for Asn1Integer
impl Ord for Asn1IntegerRef
impl Ord for BigNum
impl Ord for BigNumRef
impl Ord for CMSOptions
impl Ord for OcspFlag
impl Ord for Pkcs7Flags
impl Ord for ExtensionContext
impl Ord for ShutdownState
impl Ord for SslMode
impl Ord for SslOptions
impl Ord for SslSessionCacheMode
impl Ord for SslVerifyMode
impl Ord for X509
impl Ord for X509Ref
impl Ord for X509CheckFlags
impl Ord for X509VerifyFlags
impl Ord for PIA
impl Ord for PIB
impl Ord for Transformations
impl Ord for PotentialCodePoint
impl Ord for PotentialUtf8
impl Ord for PotentialUtf16
impl Ord for LazyStateID
impl Ord for Unit
impl Ord for NonMaxUsize
impl Ord for regex_automata::util::primitives::PatternID
impl Ord for SmallIndex
impl Ord for regex_automata::util::primitives::StateID
impl Ord for regex_syntax::ast::Position
impl Ord for Span
impl Ord for Literal
impl Ord for ClassBytesRange
impl Ord for ClassUnicodeRange
impl Ord for Utf8Range
impl Ord for reqwest::tls::Version
impl Ord for ByteBuf
impl Ord for Timespec
impl Ord for CommaSeparator
impl Ord for SpaceSeparator
impl Ord for time::date::Date
impl Ord for time::duration::Duration
impl Ord for time::instant::Instant
impl Ord for OffsetDateTime
impl Ord for PrimitiveDateTime
impl Ord for Time
impl Ord for UtcOffset
impl Ord for AnyDelimiterCodec
impl Ord for BytesCodec
impl Ord for LinesCodec
impl Ord for tokio::io::ready::Ready
impl Ord for tokio::runtime::task::id::Id
impl Ord for tokio::time::instant::Instant
impl Ord for tracing_core::metadata::Level
impl Ord for tracing_core::metadata::LevelFilter
impl Ord for UncasedStr
impl Ord for CharULE
impl Ord for Index8
impl Ord for Index16
impl Ord for Index32
impl<'a> Ord for Component<'a>
impl<'a> Ord for Prefix<'a>
impl<'a> Ord for PhantomContravariantLifetime<'a>
impl<'a> Ord for PhantomCovariantLifetime<'a>
impl<'a> Ord for PhantomInvariantLifetime<'a>
impl<'a> Ord for Metadata<'a>
impl<'a> Ord for MetadataBuilder<'a>
impl<'a> Ord for Name<'a>
impl<'a> Ord for Ident<'a>
impl<'a> Ord for password_hash::value::Value<'a>
impl<'a> Ord for rmp::decode::bytes::Bytes<'a>
impl<'a, T> Ord for ZeroVec<'a, T>
impl<'a, T, F> Ord for VarZeroVec<'a, T, F>
impl<'a, V> Ord for VarZeroCow<'a, V>
impl<'i> Ord for pest::position::Position<'i>
impl<'s> Ord for TomlQuote<'s>
impl<A> Ord for &A
impl<A> Ord for &mut A
impl<A> Ord for SmallVec<A>
impl<A, B> Ord for Tuple2ULE<A, B>
impl<A, B> Ord for VarTuple<A, B>
impl<A, B, C> Ord for Tuple3ULE<A, B, C>
impl<A, B, C, D> Ord for Tuple4ULE<A, B, C, D>
impl<A, B, C, D, E> Ord for Tuple5ULE<A, B, C, D, E>
impl<A, B, C, D, E, F> Ord for Tuple6ULE<A, B, C, D, E, F>
impl<A, B, C, D, E, F, Format> Ord for Tuple6VarULE<A, B, C, D, E, F, Format>
impl<A, B, C, D, E, Format> Ord for Tuple5VarULE<A, B, C, D, E, Format>
impl<A, B, C, D, Format> Ord for Tuple4VarULE<A, B, C, D, Format>
impl<A, B, C, Format> Ord for Tuple3VarULE<A, B, C, Format>
impl<A, B, Format> Ord for Tuple2VarULE<A, B, Format>
impl<A, V> Ord for VarTupleULE<A, V>
impl<B> Ord for Cow<'_, B>
impl<Dyn> Ord for DynMetadata<Dyn>where
Dyn: ?Sized,
impl<E> Ord for I16Bytes<E>
impl<E> Ord for I32Bytes<E>
impl<E> Ord for I64Bytes<E>
impl<E> Ord for U16Bytes<E>
impl<E> Ord for U32Bytes<E>
impl<E> Ord for U64Bytes<E>
impl<EntryData> Ord for VecList<EntryData>where
EntryData: Ord,
impl<F> Ord for Fwhere
F: FnPtr,
impl<I, T> Ord for IndexSlice<I, [T]>
impl<I, T> Ord for IndexVec<I, T>
impl<K, V> Ord for EnumMap<K, V>
impl<K, V> Ord for indexmap::map::slice::Slice<K, V>
impl<K, V, A> Ord for BTreeMap<K, V, A>
impl<K, V, S> Ord for LiteMap<K, V, S>
impl<L, R> Ord for Either<L, R>
impl<O> Ord for I16<O>where
O: ByteOrder,
impl<O> Ord for I32<O>where
O: ByteOrder,
impl<O> Ord for I64<O>where
O: ByteOrder,
impl<O> Ord for I128<O>where
O: ByteOrder,
impl<O> Ord for Isize<O>where
O: ByteOrder,
impl<O> Ord for U16<O>where
O: ByteOrder,
impl<O> Ord for U32<O>where
O: ByteOrder,
impl<O> Ord for U64<O>where
O: ByteOrder,
impl<O> Ord for U128<O>where
O: ByteOrder,
impl<O> Ord for Usize<O>where
O: ByteOrder,
impl<Ptr> Ord for Pin<Ptr>
impl<S> Ord for Host<S>where
S: Ord,
impl<Sep, T> Ord for StringWithSeparator<Sep, T>
impl<Storage> Ord for __BindgenBitfieldUnit<Storage>where
Storage: Ord,
impl<T> Ord for RegionC<T>
impl<T> Ord for Option<T>where
T: Ord,
impl<T> Ord for Poll<T>where
T: Ord,
impl<T> Ord for UnitSectionOffset<T>where
T: Ord,
impl<T> Ord for *const Twhere
T: ?Sized,
Pointer comparison is by address, as produced by the [<*const T>::addr](pointer::addr) method.
impl<T> Ord for *mut Twhere
T: ?Sized,
Pointer comparison is by address, as produced by the <*mut T>::addr method.
impl<T> Ord for [T]where
T: Ord,
Implements comparison of slices lexicographically.
impl<T> Ord for (T₁, T₂, …, Tₙ)where
T: Ord,
This trait is implemented for tuples up to twelve items long.
impl<T> Ord for Cell<T>
impl<T> Ord for RefCell<T>
impl<T> Ord for PhantomContravariant<T>where
T: ?Sized,
impl<T> Ord for PhantomCovariant<T>where
T: ?Sized,
impl<T> Ord for PhantomInvariant<T>where
T: ?Sized,
impl<T> Ord for NonZero<T>where
T: ZeroablePrimitive + Ord,
impl<T> Ord for Saturating<T>where
T: Ord,
impl<T> Ord for SyncView<T>
impl<T> Ord for NotNan<T>where
T: Float,
impl<T> Ord for CapacityError<T>where
T: Ord,
impl<T> Ord for ManuallyDrop<T>
impl<T> Ord for IsHtmlFormatted<T>
impl<T> Ord for OrderedFloat<T>where
T: Float,
impl<T> Ord for PhantomData<T>where
T: ?Sized,
impl<T> Ord for PosC<T>where
T: Ord,
impl<T> Ord for RectC<T>where
T: Ord,
impl<T> Ord for UniCase<T>
impl<T> Ord for Wrapping<T>where
T: Ord,
impl<T> Ord for Spanned<T>where
T: Ord,
impl<T> Ord for NonNull<T>where
T: ?Sized,
impl<T> Ord for AllowStdIo<T>where
T: Ord,
impl<T> Ord for DebugInfoOffset<T>where
T: Ord,
impl<T> Ord for DebugTypesOffset<T>where
T: Ord,
impl<T> Ord for UnitOffset<T>where
T: Ord,
impl<T> Ord for indexmap::set::slice::Slice<T>where
T: Ord,
impl<T> Ord for Ratio<T>
impl<T> Ord for Ascii<T>
impl<T> Ord for TryWriteableInfallibleAsWriteable<T>where
T: Ord,
impl<T> Ord for WriteableAsTryWriteableInfallible<T>where
T: Ord,
impl<T> Ord for Unalign<T>
impl<T> Ord for ZeroSlice<T>
impl<T> Ord for Reverse<T>where
T: Ord,
impl<T, A> Ord for Arc<T, A>
impl<T, A> Ord for BTreeSet<T, A>
impl<T, A> Ord for VecDeque<T, A>
impl<T, A> Ord for Box<T, A>
impl<T, A> Ord for LinkedList<T, A>
impl<T, A> Ord for Rc<T, A>
impl<T, A> Ord for UniqueRc<T, A>
impl<T, A> Ord for UniqueArc<T, A>
impl<T, A> Ord for Vec<T, A>
Implements ordering of vectors, lexicographically.
impl<T, B> Ord for Ref<B, T>
impl<T, E> Ord for Result<T, E>
impl<T, F> Ord for VarZeroSlice<T, F>
impl<T, N> Ord for GenericArray<T, N>where
T: Ord,
N: ArrayLength<T>,
impl<T, const CAP: usize> Ord for ArrayVec<T, CAP>where
T: Ord,
impl<T, const N: usize> Ord for [T; N]where
T: Ord,
Implements comparison of arrays lexicographically.
impl<T, const N: usize> Ord for Simd<T, N>where
T: SimdElement + Ord,
Lexicographic order. For the SIMD elementwise minimum and maximum, use simd_min and simd_max instead.