pub enum OOTG<A, T, E> {
Immediate(T),
Reborrow(Box<dyn FnOnce(&mut InstanceGuard<'_>, A) -> Result<T, E>>),
}Variants
Immediate(T)
Reborrow(Box<dyn FnOnce(&mut InstanceGuard<'_>, A) -> Result<T, E>>)
Allows an operation full mutable access to the whole Instance.
Use with care! Eg, you might have to call save_game_and_aux_later.
Adding and removing pieces during play (rather than management)
is complicated, because we want to avoid having to rewrite the aux.
file during routine game saves. fastsplit.rs has machinery that
can achieve this.
Implementations
Sourceimpl<A, T, E> OpOutcomeThunkGeneric<A, T, E>
impl<A, T, E> OpOutcomeThunkGeneric<A, T, E>
pub fn resolve(self, ig: &mut InstanceGuard<'_>, args: A) -> Result<T, E>