pub enum AdaptiveFormat {
Default,
Detailed,
Opt,
WithThread,
Custom(fn(&mut dyn Write, &mut DeferredNow, &Record<'_>) -> Result<(), Error>, fn(&mut dyn Write, &mut DeferredNow, &Record<'_>) -> Result<(), Error>),
}Expand description
Can be used in
Logger::adaptive_format_for_stderr and
Logger::adaptive_format_for_stdout
to use coloring only if the output goes to a tty.
This is helpful if the output is sometimes piped into other programs, which usually do not expect color control byte sequences.
Variants
Default
Chooses between default_format
and colored_default_format.
Detailed
Chooses between detailed_format
and colored_detailed_format.
Opt
Chooses between opt_format
and colored_opt_format.
WithThread
Chooses between with_thread
and colored_with_thread.
Custom(fn(&mut dyn Write, &mut DeferredNow, &Record<'_>) -> Result<(), Error>, fn(&mut dyn Write, &mut DeferredNow, &Record<'_>) -> Result<(), Error>)
Chooses between the first format function (which is supposed to be uncolored) and the second (which is supposed to be colored).
Allows providing own format functions, with freely choosable coloring technique, and making use of the tty detection.