OccupiedError

Struct OccupiedError 

#[non_exhaustive]
pub struct OccupiedError<'a, K, V, A = Global>
where K: 'a, V: 'a, A: Allocator,
{ pub entry: OccupiedEntry<'a, K, V, A>, pub key: K, pub value: V, }
๐Ÿ”ฌThis is a nightly-only experimental API. (map_try_insert)
The error returned by try_insert when the key already exists.

Contains the occupied entry, key, and the value that was not inserted.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
entry: OccupiedEntry<'a, K, V, A>
๐Ÿ”ฌThis is a nightly-only experimental API. (map_try_insert)

The entry in the map that was already occupied.

key: K
๐Ÿ”ฌThis is a nightly-only experimental API. (map_try_insert)

The key which was not inserted, because the entry was already occupied.

value: V
๐Ÿ”ฌThis is a nightly-only experimental API. (map_try_insert)

The value which was not inserted, because the entry was already occupied.