pub enum CharCase {
Lower = 0,
Title = 2,
Upper = 3,
}๐ฌThis is a nightly-only experimental API. (
titlecase)Expand description
The case of a cased character,
as returned by char::case.
Titlecase characters conceptually are composed of an uppercase portion followed by a lowercase portion. The variant discriminants represent this: the most significant bit represents whether the case conceptually starts as uppercase, while the least significant bit represents whether it conceptually ends as uppercase.
Variants
Lower = 0
๐ฌThis is a nightly-only experimental API. (
titlecase)Lowercase. Corresponds to the Lowercase Unicode property.
Title = 2
๐ฌThis is a nightly-only experimental API. (
titlecase)Titlecase. Corresponds to the Titlecase_Letter Unicode general category.
Upper = 3
๐ฌThis is a nightly-only experimental API. (
titlecase)Uppercase. Corresponds to the Uppercase Unicode property.