pub enum OneSidedRangeBound {
StartInclusive,
End,
EndInclusive,
}๐ฌThis is a nightly-only experimental API. (
one_sided_range)Expand description
An internal helper for split_off functions indicating
which end a OneSidedRange is bounded on.
Variants
StartInclusive
๐ฌThis is a nightly-only experimental API. (
one_sided_range)The range is bounded inclusively from below and is unbounded above.
End
๐ฌThis is a nightly-only experimental API. (
one_sided_range)The range is bounded exclusively from above and is unbounded below.
EndInclusive
๐ฌThis is a nightly-only experimental API. (
one_sided_range)The range is bounded inclusively from above and is unbounded below.