pub struct Dir(/* private fields */);Expand description
An open directory.
This is a lower-level interface than std::fs::ReadDir. Notable differences:
- can be opened from a file descriptor (as returned by
openat, perhaps before knowing if the path represents a file or directory). - implements
AsRawFd, so it can be passed tofstat,openat, etc. The file descriptor continues to be owned by theDir, so callers must not keep aRawFdafter theDiris dropped. - can be iterated through multiple times without closing and reopening the file descriptor. Each iteration rewinds when finished.
- returns entries for
.(current directory) and..(parent directory). - returns entries’ names as a
CStr(no allocation or conversion beyond whatever libc does).
Implementations
Sourceimpl Dir
impl Dir
Sourcepub fn open<P>(path: &P, oflag: OFlag, mode: Mode) -> Result<Dir, Errno>
pub fn open<P>(path: &P, oflag: OFlag, mode: Mode) -> Result<Dir, Errno>
Opens the given path as with fcntl::open.
Sourcepub fn openat<P>(
dirfd: i32,
path: &P,
oflag: OFlag,
mode: Mode,
) -> Result<Dir, Errno>
pub fn openat<P>( dirfd: i32, path: &P, oflag: OFlag, mode: Mode, ) -> Result<Dir, Errno>
Opens the given path as with fcntl::openat.
Sourcepub fn from<F>(fd: F) -> Result<Dir, Errno>where
F: IntoRawFd,
pub fn from<F>(fd: F) -> Result<Dir, Errno>where
F: IntoRawFd,
Converts from a descriptor-based object, closing the descriptor on success or failure.