pub struct InterfaceFlags { /* private fields */ }Expand description
Standard interface flags, used by getifaddrs
Implementations
Sourceimpl InterfaceFlags
impl InterfaceFlags
Sourcepub const IFF_UP: InterfaceFlags
pub const IFF_UP: InterfaceFlags
Interface is running. (see
netdevice(7))
Sourcepub const IFF_BROADCAST: InterfaceFlags
pub const IFF_BROADCAST: InterfaceFlags
Valid broadcast address set. (see
netdevice(7))
Sourcepub const IFF_DEBUG: InterfaceFlags
pub const IFF_DEBUG: InterfaceFlags
Internal debugging flag. (see
netdevice(7))
Sourcepub const IFF_LOOPBACK: InterfaceFlags
pub const IFF_LOOPBACK: InterfaceFlags
Interface is a loopback interface. (see
netdevice(7))
Sourcepub const IFF_POINTOPOINT: InterfaceFlags
pub const IFF_POINTOPOINT: InterfaceFlags
Interface is a point-to-point link. (see
netdevice(7))
Sourcepub const IFF_NOTRAILERS: InterfaceFlags
pub const IFF_NOTRAILERS: InterfaceFlags
Avoid use of trailers. (see
netdevice(7))
Sourcepub const IFF_RUNNING: InterfaceFlags
pub const IFF_RUNNING: InterfaceFlags
Resources allocated. (see
netdevice(7))
Sourcepub const IFF_NOARP: InterfaceFlags
pub const IFF_NOARP: InterfaceFlags
No arp protocol, L2 destination address not set. (see
netdevice(7))
Sourcepub const IFF_PROMISC: InterfaceFlags
pub const IFF_PROMISC: InterfaceFlags
Interface is in promiscuous mode. (see
netdevice(7))
Sourcepub const IFF_ALLMULTI: InterfaceFlags
pub const IFF_ALLMULTI: InterfaceFlags
Receive all multicast packets. (see
netdevice(7))
Sourcepub const IFF_MASTER: InterfaceFlags
pub const IFF_MASTER: InterfaceFlags
Master of a load balancing bundle. (see
netdevice(7))
Sourcepub const IFF_SLAVE: InterfaceFlags
pub const IFF_SLAVE: InterfaceFlags
Slave of a load balancing bundle. (see
netdevice(7))
Sourcepub const IFF_MULTICAST: InterfaceFlags
pub const IFF_MULTICAST: InterfaceFlags
Supports multicast. (see
netdevice(7))
Sourcepub const IFF_PORTSEL: InterfaceFlags
pub const IFF_PORTSEL: InterfaceFlags
Is able to select media type via ifmap. (see
netdevice(7))
Sourcepub const IFF_AUTOMEDIA: InterfaceFlags
pub const IFF_AUTOMEDIA: InterfaceFlags
Auto media selection active. (see
netdevice(7))
Sourcepub const IFF_DYNAMIC: InterfaceFlags
pub const IFF_DYNAMIC: InterfaceFlags
The addresses are lost when the interface goes down. (see
netdevice(7))
Sourcepub const IFF_LOWER_UP: InterfaceFlags
pub const IFF_LOWER_UP: InterfaceFlags
Driver signals L1 up. Volatile.
Sourcepub const IFF_DORMANT: InterfaceFlags
pub const IFF_DORMANT: InterfaceFlags
Driver signals dormant. Volatile.
Sourcepub const IFF_ECHO: InterfaceFlags
pub const IFF_ECHO: InterfaceFlags
Echo sent packets. Volatile.
Sourcepub const IFF_NO_PI: InterfaceFlags
pub const IFF_NO_PI: InterfaceFlags
Do not provide packet information
Sourcepub const IFF_TUN: InterfaceFlags
pub const IFF_TUN: InterfaceFlags
TUN device (no Ethernet headers)
Sourcepub const IFF_TAP: InterfaceFlags
pub const IFF_TAP: InterfaceFlags
TAP device
Sourcepub const fn empty() -> InterfaceFlags
pub const fn empty() -> InterfaceFlags
Returns an empty set of flags.
Sourcepub const fn all() -> InterfaceFlags
pub const fn all() -> InterfaceFlags
Returns the set containing all flags.
Sourcepub const fn from_bits(bits: i32) -> Option<InterfaceFlags>
pub const fn from_bits(bits: i32) -> Option<InterfaceFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: i32) -> InterfaceFlags
pub const fn from_bits_truncate(bits: i32) -> InterfaceFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: i32) -> InterfaceFlags
pub const unsafe fn from_bits_unchecked(bits: i32) -> InterfaceFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: InterfaceFlags) -> bool
pub const fn intersects(&self, other: InterfaceFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: InterfaceFlags) -> bool
pub const fn contains(&self, other: InterfaceFlags) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: InterfaceFlags)
pub fn insert(&mut self, other: InterfaceFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: InterfaceFlags)
pub fn remove(&mut self, other: InterfaceFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: InterfaceFlags)
pub fn toggle(&mut self, other: InterfaceFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: InterfaceFlags, value: bool)
pub fn set(&mut self, other: InterfaceFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: InterfaceFlags) -> InterfaceFlags
pub const fn intersection(self, other: InterfaceFlags) -> InterfaceFlags
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: InterfaceFlags) -> InterfaceFlags
pub const fn union(self, other: InterfaceFlags) -> InterfaceFlags
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: InterfaceFlags) -> InterfaceFlags
pub const fn difference(self, other: InterfaceFlags) -> InterfaceFlags
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: InterfaceFlags) -> InterfaceFlags
pub const fn symmetric_difference(self, other: InterfaceFlags) -> InterfaceFlags
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> InterfaceFlags
pub const fn complement(self) -> InterfaceFlags
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.