pub struct SigSet { /* private fields */ }Expand description
Specifies a set of Signals that may be blocked, waited for, etc.
Implementations
Sourceimpl SigSet
impl SigSet
Sourcepub fn contains(&self, signal: Signal) -> bool
pub fn contains(&self, signal: Signal) -> bool
Return whether this set includes the specified signal.
Sourcepub fn iter(&self) -> SigSetIter<'_> ⓘ
pub fn iter(&self) -> SigSetIter<'_> ⓘ
Returns an iterator that yields the signals contained in this set.
Sourcepub fn thread_get_mask() -> Result<SigSet, Errno>
pub fn thread_get_mask() -> Result<SigSet, Errno>
Gets the currently blocked (masked) set of signals for the calling thread.
Sourcepub fn thread_set_mask(&self) -> Result<(), Errno>
pub fn thread_set_mask(&self) -> Result<(), Errno>
Sets the set of signals as the signal mask for the calling thread.
Sourcepub fn thread_block(&self) -> Result<(), Errno>
pub fn thread_block(&self) -> Result<(), Errno>
Adds the set of signals to the signal mask for the calling thread.
Sourcepub fn thread_unblock(&self) -> Result<(), Errno>
pub fn thread_unblock(&self) -> Result<(), Errno>
Removes the set of signals from the signal mask for the calling thread.
Sourcepub fn thread_swap_mask(&self, how: SigmaskHow) -> Result<SigSet, Errno>
pub fn thread_swap_mask(&self, how: SigmaskHow) -> Result<SigSet, Errno>
Sets the set of signals as the signal mask, and returns the old mask.