Modules
- arrayvec
- arrayvec provides the types
ArrayVecandArrayString: array-backed vector and string types, which store their contents inline. - derive_
more derive_more- extend
- Create extensions for types you don’t own with extension traits but without the boilerplate.
- htmlescape
- if_
chain - This crate provides a single macro called
if_chain!. - itertools
- Extra iterator adaptors, functions and macros.
- num_
derive - Procedural macros to derive numeric traits in Rust.
- serde
- Serde
- serde_
json - Serde JSON
- thiserror
- github crates-io docs-rs
- void
- Void