pub struct UniformFloat<X> { /* private fields */ }Expand description
The back-end implementing UniformSampler for floating-point types.
Unless you are implementing UniformSampler for your own type, this type
should not be used directly, use Uniform instead.
Implementation notes
Instead of generating a float in the [0, 1) range using Standard, the
UniformFloat implementation converts the output of an PRNG itself. This
way one or two steps can be optimized out.
The floats are first converted to a value in the [1, 2) interval using a
transmute-based method, and then mapped to the expected range with a
multiply and addition. Values produced this way have what equals 23 bits of
random digits for an f32, and 52 for an f64.