pub struct InstanceGuard<'g> {
pub c: MutexGuard<'g, RawMutex, InstanceContainer>,
pub gref: InstanceRef,
}Fields
c: MutexGuard<'g, RawMutex, InstanceContainer>gref: InstanceRefImplementations
Sourceimpl InstanceGuard<'_>
impl InstanceGuard<'_>
Sourcepub fn fastsplit_split<I>(
&mut self,
player: PlayerId,
tpiece: PieceId,
_: ShowUnocculted,
tpc_new_z: ShouldSetZLevel,
implementation: I,
) -> Result<(PieceUpdate, Vec<Box<dyn for<'r> FnOnce(&'r mut PrepareUpdatesBuffer<'_>)>>), ApiPieceOpError>where
I: FnOnce(&IOccults, &GOccults, &GPlayer, &mut GPiece, &IPiece, &mut GPiece) -> Result<(PieceUpdate, Vec<Box<dyn for<'r> FnOnce(&'r mut PrepareUpdatesBuffer<'_>)>>), ApiPieceOpError>,
pub fn fastsplit_split<I>(
&mut self,
player: PlayerId,
tpiece: PieceId,
_: ShowUnocculted,
tpc_new_z: ShouldSetZLevel,
implementation: I,
) -> Result<(PieceUpdate, Vec<Box<dyn for<'r> FnOnce(&'r mut PrepareUpdatesBuffer<'_>)>>), ApiPieceOpError>where
I: FnOnce(&IOccults, &GOccults, &GPlayer, &mut GPiece, &IPiece, &mut GPiece) -> Result<(PieceUpdate, Vec<Box<dyn for<'r> FnOnce(&'r mut PrepareUpdatesBuffer<'_>)>>), ApiPieceOpError>,
The new piece will be below the old one
pub fn fastsplit_delete( &mut self, piece: PieceId, _proof_that_caller_handles_logging: &Vec<LogEntry>, ) -> Result<(PieceUpdateOp<(), ()>, Vec<Box<dyn for<'r> FnOnce(&'r mut PrepareUpdatesBuffer<'_>)>>), InternalError>
Sourceimpl<'ig> InstanceGuard<'ig>
impl<'ig> InstanceGuard<'ig>
Sourcepub fn delete_piece<H, T>(
&mut self,
modperm: ModifyingPieces,
to_permute: &mut ToRecalculate,
piece: PieceId,
hook: H,
) -> Result<(T, PieceUpdateOp<(), ()>, Vec<Box<dyn for<'r> FnOnce(&'r mut PrepareUpdatesBuffer<'_>)>>), InternalError>
pub fn delete_piece<H, T>( &mut self, modperm: ModifyingPieces, to_permute: &mut ToRecalculate, piece: PieceId, hook: H, ) -> Result<(T, PieceUpdateOp<(), ()>, Vec<Box<dyn for<'r> FnOnce(&'r mut PrepareUpdatesBuffer<'_>)>>), InternalError>
Core of piece deletion
Caller is completely responsible for the necessary log entries.
Idempotent (so does not detect if the piece didn’t exist,
other than by passing Nones to the callback.
Sourcepub fn player_new(
&mut self,
gnew: GPlayer,
inew: IPlayer,
account: Arc<AccountName>,
logentry: LogEntry,
) -> Result<(PlayerId, PreparedUpdateEntry, LogEntry), MgmtError>
pub fn player_new( &mut self, gnew: GPlayer, inew: IPlayer, account: Arc<AccountName>, logentry: LogEntry, ) -> Result<(PlayerId, PreparedUpdateEntry, LogEntry), MgmtError>
caller is responsible for logging; threading it through proves the caller has a log entry.
pub fn check_new_nick(&mut self, new_nick: &str) -> Result<(), MgmtError>
pub fn prepare_set_player_update( &self, player: PlayerId, ) -> Result<PreparedUpdateEntry, InternalError>
pub fn remove_clients( &mut self, players: &HashSet<PlayerId>, signal: ErrorSignaledViaUpdate<PreparedUpdateEntry_Piece, String>, )
pub fn players_remove( &mut self, old_players_set: &HashSet<PlayerId>, ) -> Result<Vec<(Option<GPlayer>, Option<IPlayer>, PreparedUpdateEntry)>, InternalError>
pub fn invalidate_tokens( &mut self, player: PlayerId, ) -> Result<(), InternalError>
pub fn player_access_reset( &mut self, accounts: &mut AccountsGuard, player: PlayerId, auth: Authorisation<AccountName>, ) -> Result<AccessTokenReport, MgmtError>
pub fn player_access_redeliver( &mut self, accounts: &mut AccountsGuard, player: PlayerId, auth: Authorisation<AccountName>, ) -> Result<AccessTokenReport, MgmtError>
pub fn modify_pieces(&mut self) -> ModifyingPieces
pub fn modify_pieces_not_necessarily_saving_aux(&mut self) -> ModifyingPieces
Sourceimpl InstanceGuard<'_>
impl InstanceGuard<'_>
pub fn save_game_now(&mut self) -> Result<(), InternalError>
pub fn save_aux_now(&mut self) -> Result<(), InternalError>
Sourceimpl InstanceGuard<'_>
impl InstanceGuard<'_>
pub fn save_game_later(&mut self)
pub fn save_game_and_aux_later(&mut self)
Methods from Deref<Target = Instance>
pub fn player_info_pane(&self) -> Result<Html, InternalError>
pub fn all_shapelibs(&self) -> AllRegistries<'_>