pub struct UniCase<S>(/* private fields */);Expand description
Case Insensitive wrapper of strings.
Implementations
Sourceimpl<S> UniCase<S>
impl<S> UniCase<S>
Sourcepub fn new(s: S) -> UniCase<S>
pub fn new(s: S) -> UniCase<S>
Creates a new UniCase.
Note: This scans the text to determine if it is all ASCII or not.
Sourcepub fn to_folded_case(&self) -> String
pub fn to_folded_case(&self) -> String
Returns a copy of this string where each character is mapped to its Unicode CaseFolding equivalent.
Note
Unicode Case Folding is meant for string storage and matching, not for display.
Sourceimpl<S> UniCase<S>
impl<S> UniCase<S>