Serializer

Struct Serializer 

pub struct Serializer<'a> { /* private fields */ }
Serialization implementation for TOML.

This structure implements serialization support for TOML to serialize an arbitrary type to TOML. Note that the TOML format does not support all datatypes in Rust, such as enums, tuples, and tuple structs. These types will generate an error when serialized.

Currently a serializer always writes its output to an in-memory String, which is passed in when creating the serializer itself.

Implementations

Source

impl<'a> Serializer<'a>

pub fn new(dst: &'a mut String) -> Serializer<'a>

Creates a new serializer which will emit TOML into the buffer provided.

The serializer can then be used to serialize a type after which the data will be present in dst.

pub fn pretty(dst: &'a mut String) -> Serializer<'a>

Instantiate a “pretty” formatter

By default this will use:

  • pretty strings: strings with newlines will use the ''' syntax. See Serializer::pretty_string
  • pretty arrays: each item in arrays will be on a newline, have an indentation of 4 and have a trailing comma. See Serializer::pretty_array
pub fn pretty_string(&mut self, value: bool) -> &mut Serializer<'a>

Enable or Disable pretty strings

If enabled, literal strings will be used when possible and strings with one or more newlines will use triple quotes (i.e.: ''' or """)

Examples

Instead of:

single = "no newlines"
text = "\nfoo\nbar\n"

You will have:

single = 'no newlines'
text = '''
foo
bar
'''
pub fn pretty_string_literal(&mut self, value: bool) -> &mut Serializer<'a>

Enable or Disable Literal strings for pretty strings

If enabled, literal strings will be used when possible and strings with one or more newlines will use triple quotes (i.e.: ''' or """)

If disabled, literal strings will NEVER be used and strings with one or more newlines will use """

Examples

Instead of:

single = "no newlines"
text = "\nfoo\nbar\n"

You will have:

single = "no newlines"
text = """
foo
bar
"""
pub fn pretty_array(&mut self, value: bool) -> &mut Serializer<'a>

Enable or Disable pretty arrays

If enabled, arrays will always have each item on their own line.

Some specific features can be controlled via other builder methods:

  • Serializer::pretty_array_indent: set the indent to a value other than 4.
  • Serializer::pretty_array_trailing_comma: enable/disable the trailing comma on the last item.
Examples

Instead of:

array = ["foo", "bar"]

You will have:

array = [
    "foo",
    "bar",
]
pub fn pretty_array_indent(&mut self, value: usize) -> &mut Serializer<'a>

Set the indent for pretty arrays

See Serializer::pretty_array for more details.

pub fn pretty_array_trailing_comma( &mut self, value: bool, ) -> &mut Serializer<'a>

Specify whether to use a trailing comma when serializing pretty arrays

See Serializer::pretty_array for more details.