pub trait Hash {
// Required method
fn hash<H>(&self, state: &mut H)
where H: Hasher;
// Provided method
fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher,
Self: Sized { ... }
}Expand description
A hashable type.
Types implementing Hash are able to be hashed with an instance of
Hasher.
Implementing Hash
You can derive Hash with #[derive(Hash)] if all fields implement Hash.
The resulting hash will be the combination of the values from calling
hash on each field.
#[derive(Hash)]
struct Rustacean {
name: String,
country: String,
}If you need more control over how a value is hashed, you can of course
implement the Hash trait yourself:
use std::hash::{Hash, Hasher};
struct Person {
id: u32,
name: String,
phone: u64,
}
impl Hash for Person {
fn hash<H: Hasher>(&self, state: &mut H) {
self.id.hash(state);
self.phone.hash(state);
}
}Hash and Eq
When implementing both Hash and Eq, it is important that the following
property holds:
k1 == k2 -> hash(k1) == hash(k2)In other words, if two keys are equal, their hashes must also be equal.
HashMap and HashSet both rely on this behavior.
Thankfully, you won’t need to worry about upholding this property when
deriving both Eq and Hash with #[derive(PartialEq, Eq, Hash)].
Violating this property is a logic error. The behavior resulting from a logic error is not
specified, but users of the trait must ensure that such logic errors do not result in
undefined behavior. This means that unsafe code must not rely on the correctness of these
methods.
Prefix collisions
Implementations of hash should ensure that the data they
pass to the Hasher are prefix-free. That is,
values which are not equal should cause two different sequences of values to be written,
and neither of the two sequences should be a prefix of the other.
For example, the standard implementation of Hash for &str passes an extra
0xFF byte to the Hasher so that the values ("ab", "c") and ("a", "bc") hash differently.
Portability
Due to differences in endianness and type sizes, data fed by Hash to a Hasher
should not be considered portable across platforms. Additionally the data passed by most
standard library types should not be considered stable between compiler versions.
This means tests shouldn’t probe hard-coded hash values or data fed to a Hasher and
instead should check consistency with Eq.
Serialization formats intended to be portable between platforms or compiler versions should
either avoid encoding hashes or only rely on Hash and Hasher implementations that
provide additional guarantees.
Required Methods
Provided Methods
1.3.0 · Sourcefn hash_slice<H>(data: &[Self], state: &mut H)
fn hash_slice<H>(data: &[Self], state: &mut H)
Feeds a slice of this type into the given Hasher.
This method is meant as a convenience, but its implementation is
also explicitly left unspecified. It isn’t guaranteed to be
equivalent to repeated calls of hash and implementations of
Hash should keep that in mind and call hash themselves
if the slice isn’t treated as a whole unit in the PartialEq
implementation.
For example, a VecDeque implementation might naïvely call
as_slices and then hash_slice on each slice, but this
is wrong since the two slices can change with a call to
make_contiguous without affecting the PartialEq
result. Since these slices aren’t treated as singular
units, and instead part of a larger deque, this method cannot
be used.
Examples
use std::hash::{DefaultHasher, Hash, Hasher};
let mut hasher = DefaultHasher::new();
let numbers = [6, 28, 496, 8128];
Hash::hash_slice(&numbers, &mut hasher);
println!("Hash is {:x}!", hasher.finish());Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl Hash for Kind
impl Hash for otter_nodejs_tests::chrono::Month
impl Hash for SecondsFormat
impl Hash for otter_nodejs_tests::chrono::Weekday
impl Hash for Colons
impl Hash for Fixed
impl Hash for Numeric
impl Hash for OffsetPrecision
impl Hash for Pad
impl Hash for ParseErrorKind
impl Hash for otter_nodejs_tests::chrono_tz::Tz
impl Hash for AccountScope
impl Hash for otter_nodejs_tests::BigEndian
impl Hash for ErrorKind
impl Hash for Infallible
impl Hash for otter_nodejs_tests::IpAddr
impl Hash for LinkKind
impl Hash for otter_nodejs_tests::LittleEndian
impl Hash for OccDisplacement
impl Hash for OccultationKindAlwaysOk
impl Hash for OldNewIndex
impl Hash for otter_nodejs_tests::Ordering
impl Hash for SocketAddr
impl Hash for TablePermission
impl Hash for WriteStyle
impl Hash for otter_nodejs_tests::flexi_logger::Level
impl Hash for otter_nodejs_tests::flexi_logger::LevelFilter
impl Hash for CheckedCastError
impl Hash for PodCastError
impl Hash for chrono_tz::timezones::Tz
impl Hash for console::kb::Key
impl Hash for PollNext
impl Hash for Format
impl Hash for SectionId
impl Hash for RunTimeEndian
impl Hash for ExtensionType
impl Hash for CalendarAlgorithm
impl Hash for HijriCalendarAlgorithm
impl Hash for CollationCaseFirst
impl Hash for CollationNumericOrdering
impl Hash for CollationType
impl Hash for CurrencyFormatStyle
impl Hash for EmojiPresentationStyle
impl Hash for FirstDay
impl Hash for HourCycle
impl Hash for LineBreakStyle
impl Hash for LineBreakWordHandling
impl Hash for MeasurementSystem
impl Hash for MeasurementUnitOverride
impl Hash for SentenceBreakSupressions
impl Hash for CommonVariantType
impl Hash for GeneralCategory
impl Hash for BufferFormat
impl Hash for ColorType
impl Hash for ExtendedColorType
impl Hash for ImageFormatHint
impl Hash for LimitErrorKind
impl Hash for ParameterErrorKind
impl Hash for UnsupportedErrorKind
impl Hash for image::flat::Error
impl Hash for NormalForm
impl Hash for ImageFormat
impl Hash for IpAddrRange
impl Hash for IpNet
impl Hash for IpSubnets
impl Hash for ColorTransform
impl Hash for UnsupportedFeature
impl Hash for fsconfig_command
impl Hash for membarrier_cmd
impl Hash for membarrier_cmd_flag
impl Hash for procfs_ino
impl Hash for procmap_query_flags
impl Hash for CompressionStrategy
impl Hash for TDEFLFlush
impl Hash for TDEFLStatus
impl Hash for CompressionLevel
impl Hash for DataFormat
impl Hash for MZError
impl Hash for MZFlush
impl Hash for MZStatus
impl Hash for TINFLStatus
impl Hash for Sign
impl Hash for AddressSize
impl Hash for Architecture
impl Hash for BinaryFormat
impl Hash for ComdatKind
impl Hash for FileFlags
impl Hash for RelocationEncoding
impl Hash for RelocationFlags
impl Hash for RelocationKind
impl Hash for SectionFlags
impl Hash for SectionKind
impl Hash for SegmentFlags
impl Hash for SubArchitecture
impl Hash for SymbolKind
impl Hash for SymbolScope
impl Hash for Endianness
impl Hash for ArchiveKind
impl Hash for ImportType
impl Hash for CompressionFormat
impl Hash for FileKind
impl Hash for ObjectKind
impl Hash for RelocationTarget
impl Hash for SymbolSection
impl Hash for Curve
impl Hash for Algorithm
impl Hash for InputLocation
impl Hash for LineColLocation
impl Hash for Direction
impl Hash for strum::ParseError
impl Hash for time::month::Month
impl Hash for time::weekday::Weekday
impl Hash for Origin
impl Hash for xmlparser::error::Error
impl Hash for StreamError
impl Hash for zerocopy::byteorder::BigEndian
impl Hash for zerocopy::byteorder::LittleEndian
impl Hash for ZSTD_EndDirective
impl Hash for ZSTD_ErrorCode
impl Hash for ZSTD_ResetDirective
impl Hash for ZSTD_cParameter
impl Hash for ZSTD_dParameter
impl Hash for ZSTD_strategy
impl Hash for AsciiChar
impl Hash for CharCase
impl Hash for Locality
impl Hash for Ipv6MulticastScope
impl Hash for IntErrorKind
impl Hash for otter_nodejs_tests::inventory::core::sync::atomic::Ordering
impl Hash for tpacket_versions
impl Hash for Type
impl Hash for FlockArg
impl Hash for PosixFadviseAdvice
impl Hash for AioCancelStat
impl Hash for AioFsyncMode
impl Hash for LioMode
impl Hash for LioOpcode
impl Hash for EpollOp
impl Hash for MmapAdvise
impl Hash for Event
impl Hash for Request
impl Hash for QuotaFmt
impl Hash for QuotaType
impl Hash for RebootMode
impl Hash for Resource
impl Hash for SigHandler
impl Hash for SigevNotify
impl Hash for SigmaskHow
impl Hash for Signal
impl Hash for AddressFamily
impl Hash for InetAddr
impl Hash for otter_nodejs_tests::nix::sys::socket::IpAddr
impl Hash for Shutdown
impl Hash for otter_nodejs_tests::nix::sys::socket::SockAddr
impl Hash for SockProtocol
impl Hash for BaudRate
impl Hash for FlowArg
impl Hash for FlushArg
impl Hash for SetArg
impl Hash for SpecialCharacterIndices
impl Hash for otter_nodejs_tests::nix::sys::timerfd::ClockId
impl Hash for otter_nodejs_tests::nix::sys::wait::Id
impl Hash for WaitStatus
impl Hash for PathconfVar
impl Hash for SysconfVar
impl Hash for otter_nodejs_tests::tera::Value
impl Hash for bool
impl Hash for char
impl Hash for i8
impl Hash for i16
impl Hash for i32
impl Hash for i64
impl Hash for i128
impl Hash for isize
impl Hash for !
impl Hash for str
impl Hash for u8
impl Hash for u16
impl Hash for u32
impl Hash for u64
impl Hash for u128
impl Hash for ()
impl Hash for usize
impl Hash for Hash
impl Hash for otter_nodejs_tests::bundles::Id
impl Hash for otter_nodejs_tests::bundles::Index
impl Hash for LibInBundleI
impl Hash for ZipIndex
impl Hash for InternalFixed
impl Hash for InternalNumeric
impl Hash for OffsetFormat
impl Hash for Parsed
impl Hash for NaiveDateDaysIterator
impl Hash for NaiveDateWeeksIterator
impl Hash for Days
impl Hash for FixedOffset
impl Hash for IsoWeek
impl Hash for Months
impl Hash for NaiveDate
impl Hash for NaiveDateTime
impl Hash for NaiveTime
impl Hash for NaiveWeek
impl Hash for OutOfRange
impl Hash for otter_nodejs_tests::chrono::ParseError
impl Hash for TimeDelta
impl Hash for Utc
impl Hash for WeekdaySet
impl Hash for ATerm
impl Hash for B0
impl Hash for B1
impl Hash for Equal
impl Hash for Greater
impl Hash for Less
impl Hash for UTerm
impl Hash for Z0
impl Hash for otter_nodejs_tests::fmt::Error
impl Hash for FsStats
impl Hash for FileType
impl Hash for MatchOptions
impl Hash for Pattern
impl Hash for ByteString
impl Hash for CString
impl Hash for String
impl Hash for OsString
impl Hash for Path
impl Hash for PrefixComponent<'_>
impl Hash for aho_corasick::util::primitives::PatternID
impl Hash for aho_corasick::util::primitives::StateID
impl Hash for aho_corasick::util::search::Match
impl Hash for aho_corasick::util::search::Span
impl Hash for Base64Bcrypt
impl Hash for Base64Crypt
impl Hash for Base64Pbkdf2
impl Hash for Base64ShaCrypt
impl Hash for Base64
impl Hash for Base64Unpadded
impl Hash for Base64Url
impl Hash for Base64UrlUnpadded
impl Hash for BStr
impl Hash for BString
impl Hash for bytes::bytes::Bytes
impl Hash for BytesMut
impl Hash for encoding_rs::Encoding
impl Hash for FileTime
impl Hash for DebugTypeSignature
impl Hash for DwoId
impl Hash for gimli::common::Encoding
impl Hash for LineEncoding
impl Hash for Register
impl Hash for DwAccess
impl Hash for DwAddr
impl Hash for DwAt
impl Hash for DwAte
impl Hash for DwCc
impl Hash for DwCfa
impl Hash for DwChildren
impl Hash for DwDefaulted
impl Hash for DwDs
impl Hash for DwDsc
impl Hash for DwEhPe
impl Hash for DwEnd
impl Hash for DwForm
impl Hash for DwId
impl Hash for DwIdx
impl Hash for DwInl
impl Hash for DwLang
impl Hash for DwLle
impl Hash for DwLnct
impl Hash for DwLne
impl Hash for DwLns
impl Hash for DwMacinfo
impl Hash for DwMacro
impl Hash for DwOp
impl Hash for DwOrd
impl Hash for DwRle
impl Hash for DwSect
impl Hash for DwSectV2
impl Hash for DwTag
impl Hash for DwUt
impl Hash for DwVirtuality
impl Hash for DwVis
impl Hash for gimli::endianity::BigEndian
impl Hash for gimli::endianity::LittleEndian
impl Hash for gimli::read::rnglists::Range
impl Hash for Glob
impl Hash for StreamId
impl Hash for HeaderName
impl Hash for HeaderValue
impl Hash for Method
impl Hash for StatusCode
impl Hash for Authority
Case-insensitive hashing
Examples
let a: Authority = "HELLO.com".parse().unwrap();
let b: Authority = "hello.coM".parse().unwrap();
let mut s = DefaultHasher::new();
a.hash(&mut s);
let a = s.finish();
let mut s = DefaultHasher::new();
b.hash(&mut s);
let b = s.finish();
assert_eq!(a, b);impl Hash for PathAndQuery
impl Hash for Scheme
Case-insensitive hashing
impl Hash for Uri
impl Hash for Version
impl Hash for hyper::client::connect::dns::Name
impl Hash for ReasonPhrase
impl Hash for DataLocale
impl Hash for Other
impl Hash for icu_locale_core::extensions::private::other::Subtag
impl Hash for Private
impl Hash for Extensions
impl Hash for Fields
impl Hash for icu_locale_core::extensions::transform::key::Key
impl Hash for Transform
impl Hash for icu_locale_core::extensions::transform::value::Value
impl Hash for Attribute
impl Hash for Attributes
impl Hash for icu_locale_core::extensions::unicode::key::Key
impl Hash for Keywords
impl Hash for Unicode
impl Hash for SubdivisionId
impl Hash for SubdivisionSuffix
impl Hash for icu_locale_core::extensions::unicode::value::Value
impl Hash for LanguageIdentifier
impl Hash for Locale
impl Hash for CurrencyType
impl Hash for NumberingSystem
impl Hash for RegionOverride
impl Hash for RegionalSubdivision
impl Hash for TimeZoneShortId
impl Hash for LocalePreferences
impl Hash for Language
impl Hash for Region
impl Hash for icu_locale_core::subtags::script::Script
impl Hash for icu_locale_core::subtags::Subtag
impl Hash for Variant
impl Hash for Variants
impl Hash for BidiClass
impl Hash for CanonicalCombiningClass
impl Hash for EastAsianWidth
impl Hash for GeneralCategoryOutOfBoundsError
impl Hash for GraphemeClusterBreak
impl Hash for HangulSyllableType
impl Hash for IndicConjunctBreak
impl Hash for IndicSyllabicCategory
impl Hash for JoiningGroup
impl Hash for JoiningType
impl Hash for LineBreak
impl Hash for NumericType
impl Hash for icu_properties::props::Script
impl Hash for SentenceBreak
impl Hash for VerticalOrientation
impl Hash for WordBreak
impl Hash for DataMarkerId
impl Hash for DataMarkerIdHash
impl Hash for DataMarkerInfo
impl Hash for DataMarkerAttributes
impl Hash for SampleLayout
impl Hash for LimitSupport
impl Hash for Limits
impl Hash for Rect
impl Hash for EventMask
impl Hash for inotify::watches::WatchDescriptor
impl Hash for WatchMask
impl Hash for Ipv4AddrRange
impl Hash for Ipv6AddrRange
impl Hash for Ipv4Net
impl Hash for Ipv4Subnets
impl Hash for Ipv6Net
impl Hash for Ipv6Subnets
impl Hash for Mime
impl Hash for StreamResult
impl Hash for mio::token::Token
impl Hash for mio::token::Token
impl Hash for mio::token::Token
impl Hash for Op
impl Hash for BigInt
impl Hash for BigUint
impl Hash for object::endian::BigEndian
impl Hash for object::endian::LittleEndian
impl Hash for CompressedFileRange
impl Hash for SectionIndex
impl Hash for SymbolIndex
impl Hash for TimeDiff
impl Hash for CMSOptions
impl Hash for Nid
impl Hash for OcspFlag
impl Hash for KeyIvPair
impl Hash for Pkcs7Flags
impl Hash for ExtensionContext
impl Hash for ShutdownState
impl Hash for SslMode
impl Hash for SslOptions
impl Hash for SslSessionCacheMode
impl Hash for SslVerifyMode
impl Hash for X509CheckFlags
impl Hash for X509VerifyFlags
impl Hash for PIA
impl Hash for PIB
impl Hash for SshFingerprint
impl Hash for Position<'_>
impl Hash for pest::span::Span<'_>
impl Hash for ChunkType
impl Hash for Transformations
impl Hash for PotentialCodePoint
impl Hash for LazyStateID
impl Hash for Transition
impl Hash for NonMaxUsize
impl Hash for regex_automata::util::primitives::PatternID
impl Hash for SmallIndex
impl Hash for regex_automata::util::primitives::StateID
impl Hash for HalfMatch
impl Hash for regex_automata::util::search::Match
impl Hash for regex_automata::util::search::Span
impl Hash for ByteBuf
impl Hash for CreateFlags
impl Hash for ReadFlags
impl Hash for WatchFlags
impl Hash for Access
impl Hash for rustix::backend::fs::types::AtFlags
impl Hash for rustix::backend::fs::types::FallocateFlags
impl Hash for MemfdFlags
impl Hash for rustix::backend::fs::types::Mode
impl Hash for OFlags
impl Hash for rustix::backend::fs::types::RenameFlags
impl Hash for ResolveFlags
impl Hash for SealFlags
impl Hash for StatVfsMountFlags
impl Hash for Errno
impl Hash for DupFlags
impl Hash for FdFlags
impl Hash for ReadWriteFlags
impl Hash for IFlags
impl Hash for StatxAttributes
impl Hash for StatxFlags
impl Hash for XattrFlags
impl Hash for rustix::ugid::Gid
impl Hash for rustix::ugid::Uid
impl Hash for Handle
impl Hash for CommaSeparator
impl Hash for SpaceSeparator
impl Hash for socket2::sockaddr::SockAddr
impl Hash for socket2::sockaddr::SockAddr
impl Hash for time::date::Date
impl Hash for time::duration::Duration
impl Hash for ComponentRange
impl Hash for time::instant::Instant
impl Hash for OffsetDateTime
impl Hash for PrimitiveDateTime
impl Hash for Time
impl Hash for UtcOffset
impl Hash for AnyDelimiterCodec
impl Hash for BytesCodec
impl Hash for LinesCodec
impl Hash for tokio::net::unix::ucred::UCred
impl Hash for tokio::runtime::id::Id
impl Hash for tokio::runtime::task::id::Id
impl Hash for tokio::time::instant::Instant
impl Hash for Identifier
impl Hash for Field
impl Hash for tracing_core::metadata::Level
impl Hash for tracing_core::metadata::LevelFilter
impl Hash for tracing_core::span::Id
impl Hash for tracing::span::Span
impl Hash for UncasedStr
impl Hash for OpaqueOrigin
impl Hash for TextPos
impl Hash for CharULE
impl Hash for Index8
impl Hash for Index16
impl Hash for Index32
impl Hash for otter_nodejs_tests::humantime::Duration
impl Hash for Timestamp
impl Hash for Layout
impl Hash for TypeId
impl Hash for ByteStr
impl Hash for CStr
impl Hash for PhantomPinned
impl Hash for SocketAddrV4
impl Hash for SocketAddrV6
impl Hash for RangeFull
impl Hash for Location<'_>
impl Hash for Dl_info
impl Hash for Elf32_Chdr
impl Hash for Elf32_Ehdr
impl Hash for Elf32_Phdr
impl Hash for Elf32_Shdr
impl Hash for Elf32_Sym
impl Hash for Elf64_Chdr
impl Hash for Elf64_Ehdr
impl Hash for Elf64_Phdr
impl Hash for Elf64_Shdr
impl Hash for Elf64_Sym
impl Hash for __c_anonymous__kernel_fsid_t
impl Hash for __c_anonymous_elf32_rel
impl Hash for __c_anonymous_elf32_rela
impl Hash for __c_anonymous_elf64_rel
impl Hash for __c_anonymous_elf64_rela
impl Hash for __c_anonymous_ifru_map
impl Hash for __c_anonymous_ptrace_syscall_info_entry
impl Hash for __c_anonymous_ptrace_syscall_info_exit
impl Hash for __c_anonymous_ptrace_syscall_info_seccomp
impl Hash for __c_anonymous_sockaddr_can_j1939
impl Hash for __c_anonymous_sockaddr_can_tp
impl Hash for __exit_status
impl Hash for __timeval
impl Hash for _libc_fpstate
impl Hash for _libc_fpxreg
impl Hash for _libc_xmmreg
impl Hash for addrinfo
impl Hash for af_alg_iv
extra_traits only.impl Hash for aiocb
impl Hash for arpd_request
impl Hash for arphdr
impl Hash for arpreq
impl Hash for arpreq_old
impl Hash for bcm_msg_head
impl Hash for bcm_timeval
impl Hash for can_berr_counter
impl Hash for can_bittiming
impl Hash for can_bittiming_const
impl Hash for can_clock
impl Hash for can_ctrlmode
impl Hash for can_device_stats
impl Hash for can_filter
impl Hash for can_frame
impl Hash for canfd_frame
impl Hash for canxl_frame
impl Hash for clone_args
impl Hash for cmsghdr
impl Hash for cpu_set_t
impl Hash for dirent64
impl Hash for dirent
impl Hash for dl_phdr_info
impl Hash for dmabuf_cmsg
impl Hash for dmabuf_token
impl Hash for dqblk
impl Hash for epoll_event
extra_traits and non-L4Re only.impl Hash for epoll_params
impl Hash for fanotify_event_info_error
impl Hash for fanotify_event_info_fid
impl Hash for fanotify_event_info_header
impl Hash for fanotify_event_info_pidfd
impl Hash for fanotify_event_metadata
impl Hash for fanotify_response
impl Hash for fanout_args
impl Hash for fd_set
impl Hash for ff_condition_effect
impl Hash for ff_constant_effect
impl Hash for ff_effect
impl Hash for ff_envelope
impl Hash for ff_periodic_effect
impl Hash for ff_ramp_effect
impl Hash for ff_replay
impl Hash for ff_rumble_effect
impl Hash for ff_trigger
impl Hash for file_clone_range
impl Hash for file_handle
impl Hash for flock64
impl Hash for flock
impl Hash for fpos64_t
impl Hash for fpos_t
impl Hash for fsid_t
impl Hash for genlmsghdr
impl Hash for glob64_t
impl Hash for glob_t
impl Hash for group
impl Hash for hostent
impl Hash for hwtstamp_config
impl Hash for if_nameindex
impl Hash for ifaddrs
impl Hash for ifinfomsg
impl Hash for in6_addr
impl Hash for in6_ifreq
impl Hash for in6_pktinfo
impl Hash for in6_rtmsg
impl Hash for in_addr
impl Hash for in_pktinfo
impl Hash for inotify_event
impl Hash for input_absinfo
impl Hash for input_event
impl Hash for input_id
impl Hash for input_keymap_entry
impl Hash for input_mask
impl Hash for iocb
impl Hash for iovec
impl Hash for ip_mreq
impl Hash for ip_mreq_source
impl Hash for ip_mreqn
impl Hash for ipc_perm
impl Hash for ipv6_mreq
impl Hash for itimerspec
impl Hash for itimerval
impl Hash for iw_discarded
impl Hash for iw_encode_ext
impl Hash for iw_freq
impl Hash for iw_michaelmicfailure
impl Hash for iw_missed
impl Hash for iw_mlme
impl Hash for iw_param
impl Hash for iw_pmkid_cand
impl Hash for iw_pmksa
impl Hash for iw_point
impl Hash for iw_priv_args
impl Hash for iw_quality
impl Hash for iw_range
impl Hash for iw_scan_req
impl Hash for iw_statistics
impl Hash for iw_thrspy
impl Hash for j1939_filter
impl Hash for lconv
impl Hash for linger
impl Hash for mallinfo2
impl Hash for mallinfo
impl Hash for mbstate_t
impl Hash for mcontext_t
impl Hash for mmsghdr
impl Hash for mnt_ns_info
impl Hash for mntent
impl Hash for mount_attr
impl Hash for mq_attr
impl Hash for msghdr
impl Hash for msginfo
impl Hash for msqid_ds
impl Hash for nl_mmap_hdr
impl Hash for nl_mmap_req
impl Hash for nl_pktinfo
impl Hash for nlattr
impl Hash for nlmsgerr
impl Hash for nlmsghdr
impl Hash for ntptimeval
impl Hash for open_how
impl Hash for option
impl Hash for packet_mreq
impl Hash for passwd
impl Hash for pidfd_info
impl Hash for pollfd
impl Hash for posix_spawn_file_actions_t
impl Hash for posix_spawnattr_t
impl Hash for protoent
impl Hash for pthread_attr_t
impl Hash for pthread_barrier_t
impl Hash for pthread_barrierattr_t
impl Hash for pthread_cond_t
impl Hash for pthread_condattr_t
impl Hash for pthread_mutex_t
impl Hash for pthread_mutexattr_t
impl Hash for pthread_rwlock_t
impl Hash for pthread_rwlockattr_t
impl Hash for ptp_clock_caps
impl Hash for ptp_clock_time
impl Hash for ptp_extts_event
impl Hash for ptp_extts_request
impl Hash for ptp_pin_desc
impl Hash for ptp_sys_offset
impl Hash for ptp_sys_offset_extended
impl Hash for ptp_sys_offset_precise
impl Hash for ptrace_peeksiginfo_args
impl Hash for ptrace_rseq_configuration
impl Hash for ptrace_sud_config
impl Hash for ptrace_syscall_info
impl Hash for regex_t
impl Hash for regmatch_t
impl Hash for rlimit64
impl Hash for rlimit
impl Hash for rtentry
impl Hash for rusage
impl Hash for sched_attr
impl Hash for sched_param
impl Hash for sctp_authinfo
impl Hash for sctp_initmsg
impl Hash for sctp_nxtinfo
impl Hash for sctp_prinfo
impl Hash for sctp_rcvinfo
impl Hash for sctp_sndinfo
impl Hash for sctp_sndrcvinfo
impl Hash for seccomp_data
impl Hash for seccomp_notif
impl Hash for seccomp_notif_addfd
impl Hash for seccomp_notif_resp
impl Hash for seccomp_notif_sizes
impl Hash for sem_t
impl Hash for sembuf
impl Hash for semid_ds
impl Hash for seminfo
impl Hash for servent
impl Hash for shmid_ds
impl Hash for sigaction
impl Hash for sigevent
extra_traits and non-L4Re only.impl Hash for siginfo_t
impl Hash for signalfd_siginfo
impl Hash for sigset_t
impl Hash for sigval
impl Hash for sock_extended_err
impl Hash for sock_filter
impl Hash for sock_fprog
impl Hash for sockaddr
impl Hash for sockaddr_alg
impl Hash for sockaddr_in6
impl Hash for sockaddr_in
impl Hash for sockaddr_ll
impl Hash for sockaddr_nl
impl Hash for sockaddr_pkt
impl Hash for sockaddr_storage
impl Hash for sockaddr_un
impl Hash for sockaddr_vm
impl Hash for sockaddr_xdp
impl Hash for spwd
impl Hash for stack_t
impl Hash for stat64
impl Hash for stat
impl Hash for statfs64
impl Hash for statfs
impl Hash for statvfs64
impl Hash for statvfs
impl Hash for statx
impl Hash for statx_timestamp
impl Hash for sysinfo
impl Hash for tcp_info
impl Hash for termios2
impl Hash for termios
impl Hash for timespec
impl Hash for timeval
impl Hash for timex
impl Hash for tls12_crypto_info_aes_ccm_128
impl Hash for tls12_crypto_info_aes_gcm_128
impl Hash for tls12_crypto_info_aes_gcm_256
impl Hash for tls12_crypto_info_aria_gcm_128
impl Hash for tls12_crypto_info_aria_gcm_256
impl Hash for tls12_crypto_info_chacha20_poly1305
impl Hash for tls12_crypto_info_sm4_ccm
impl Hash for tls12_crypto_info_sm4_gcm
impl Hash for tls_crypto_info
impl Hash for tm
impl Hash for tms
impl Hash for tpacket2_hdr
impl Hash for tpacket3_hdr
impl Hash for tpacket_auxdata
impl Hash for tpacket_bd_ts
impl Hash for tpacket_hdr
impl Hash for tpacket_hdr_v1
impl Hash for tpacket_hdr_variant1
impl Hash for tpacket_req3
impl Hash for tpacket_req
impl Hash for tpacket_rollover_stats
impl Hash for tpacket_stats
impl Hash for tpacket_stats_v3
impl Hash for ucontext_t
impl Hash for ucred
impl Hash for uinput_abs_setup
impl Hash for uinput_ff_erase
impl Hash for uinput_ff_upload
impl Hash for uinput_setup
impl Hash for uinput_user_dev
impl Hash for user
impl Hash for user_fpregs_struct
impl Hash for user_regs_struct
impl Hash for utimbuf
impl Hash for utmpx
impl Hash for utsname
impl Hash for winsize
impl Hash for xdp_desc
impl Hash for xdp_mmap_offsets
impl Hash for xdp_mmap_offsets_v1
impl Hash for xdp_options
impl Hash for xdp_ring_offset
impl Hash for xdp_ring_offset_v1
impl Hash for xdp_statistics
impl Hash for xdp_statistics_v1
impl Hash for xdp_umem_reg
impl Hash for xdp_umem_reg_v1
impl Hash for xsk_tx_metadata_completion
impl Hash for xsk_tx_metadata_request
impl Hash for Dir
impl Hash for Entry
impl Hash for OwningIter
impl Hash for otter_nodejs_tests::nix::fcntl::AtFlags
impl Hash for otter_nodejs_tests::nix::fcntl::FallocateFlags
impl Hash for otter_nodejs_tests::nix::fcntl::FdFlag
impl Hash for OFlag
impl Hash for otter_nodejs_tests::nix::fcntl::RenameFlags
impl Hash for SealFlag
impl Hash for SpliceFFlags
impl Hash for InterfaceAddress
impl Hash for InterfaceAddressIterator
impl Hash for DeleteModuleFlags
impl Hash for ModuleInitFlags
impl Hash for MntFlags
impl Hash for otter_nodejs_tests::nix::mount::MsFlags
impl Hash for otter_nodejs_tests::nix::mqueue::FdFlag
impl Hash for MQ_OFlag
impl Hash for MqAttr
impl Hash for InterfaceFlags
impl Hash for PollFd
impl Hash for PollFlags
impl Hash for OpenptyResult
impl Hash for PtyMaster
impl Hash for CloneFlags
impl Hash for CpuSet
impl Hash for EpollCreateFlags
impl Hash for EpollEvent
impl Hash for EpollFlags
impl Hash for EfdFlags
impl Hash for AddWatchFlags
impl Hash for InitFlags
impl Hash for otter_nodejs_tests::nix::sys::inotify::WatchDescriptor
impl Hash for MemFdCreateFlag
impl Hash for MRemapFlags
impl Hash for MapFlags
impl Hash for MlockAllFlags
impl Hash for otter_nodejs_tests::nix::sys::mman::MsFlags
impl Hash for ProtFlags
impl Hash for Persona
impl Hash for Options
impl Hash for Dqblk
impl Hash for QuotaValidFlags
impl Hash for FdSet
impl Hash for SaFlags
impl Hash for SigAction
impl Hash for SigEvent
impl Hash for SigSet
impl Hash for SignalIterator
impl Hash for SfdFlags
impl Hash for SignalFd
impl Hash for AcceptConn
impl Hash for BindToDevice
impl Hash for Broadcast
impl Hash for Ip6tOriginalDst
impl Hash for IpAddMembership
impl Hash for IpDropMembership
impl Hash for IpFreebind
impl Hash for IpMulticastLoop
impl Hash for IpMulticastTtl
impl Hash for IpTransparent
impl Hash for Ipv4PacketInfo
impl Hash for Ipv4RecvErr
impl Hash for Ipv4Ttl
impl Hash for Ipv6AddMembership
impl Hash for Ipv6DontFrag
impl Hash for Ipv6DropMembership
impl Hash for Ipv6RecvErr
impl Hash for Ipv6RecvPacketInfo
impl Hash for Ipv6Ttl
impl Hash for Ipv6V6Only
impl Hash for KeepAlive
impl Hash for Linger
impl Hash for Mark
impl Hash for OobInline
impl Hash for OriginalDst
impl Hash for PassCred
impl Hash for PeerCredentials
impl Hash for RcvBuf
impl Hash for RcvBufForce
impl Hash for ReceiveTimeout
impl Hash for ReceiveTimestamp
impl Hash for ReceiveTimestampns
impl Hash for ReuseAddr
impl Hash for ReusePort
impl Hash for RxqOvfl
impl Hash for SendTimeout
impl Hash for SndBuf
impl Hash for SndBufForce
impl Hash for SockType
impl Hash for SocketError
impl Hash for TcpCongestion
impl Hash for TcpKeepCount
impl Hash for TcpKeepIdle
impl Hash for TcpKeepInterval
impl Hash for TcpMaxSeg
impl Hash for TcpNoDelay
impl Hash for TcpRepair
impl Hash for TcpUserTimeout
impl Hash for Timestamping
impl Hash for TxTime
impl Hash for UdpGroSegment
impl Hash for UdpGsoSegment
impl Hash for AlgAddr
impl Hash for otter_nodejs_tests::nix::sys::socket::Ipv4Addr
impl Hash for otter_nodejs_tests::nix::sys::socket::Ipv6Addr
impl Hash for LinkAddr
impl Hash for MsgFlags
impl Hash for NetlinkAddr
impl Hash for SockFlag
impl Hash for SockaddrIn6
impl Hash for SockaddrIn
impl Hash for TimestampingFlag
impl Hash for UnixAddr
impl Hash for VsockAddr
impl Hash for otter_nodejs_tests::nix::sys::stat::Mode
impl Hash for SFlag
impl Hash for FsFlags
impl Hash for Statvfs
impl Hash for SysInfo
impl Hash for ControlFlags
impl Hash for InputFlags
impl Hash for LocalFlags
impl Hash for OutputFlags
impl Hash for TimeVal
impl Hash for TimerFlags
impl Hash for TimerSetTimeFlags
impl Hash for RemoteIoVec
impl Hash for UtsName
impl Hash for WaitPidFlag
impl Hash for otter_nodejs_tests::nix::time::ClockId
impl Hash for UContext
impl Hash for AccessFlags
impl Hash for otter_nodejs_tests::nix::unistd::Gid
impl Hash for Pid
impl Hash for Alignment
impl Hash for DescId
impl Hash for SvgId
impl Hash for DefaultKey
impl Hash for KeyData
impl Hash for AuthKeysManipError
impl Hash for Fingerprint
impl Hash for otter_nodejs_tests::sshkeys::Id
impl Hash for KeySpec
impl Hash for Nonce
impl Hash for AccountId
impl Hash for AccountName
impl Hash for AccountNotFound
impl Hash for ClientId
impl Hash for otter_nodejs_tests::Duration
impl Hash for FaceId
impl Hash for FastSplitId
impl Hash for GoodItemName
impl Hash for Html
impl Hash for HtmlLit
impl Hash for HtmlStr
impl Hash for InstanceName
impl Hash for otter_nodejs_tests::Instant
impl Hash for otter_nodejs_tests::Ipv4Addr
impl Hash for otter_nodejs_tests::Ipv6Addr
impl Hash for Notch
impl Hash for OccId
impl Hash for OccultIlkId
impl Hash for OsStr
impl Hash for PathBuf
impl Hash for PieceId
impl Hash for PlayerId
impl Hash for RawToken
impl Hash for RawTokenVal
impl Hash for TimeSpec
impl Hash for TokenRevelationKey
impl Hash for otter_nodejs_tests::Uid
impl Hash for Url
URLs hash like their serialization.
impl Hash for UrlSpec
impl Hash for VisiblePieceId
impl Hash for ZCoord
impl Hash for Map<String, Value>
impl Hash for Number
impl Hash for ThreadId
impl Hash for SystemTime
impl Hash for UnixSocketAddr
impl Hash for otter_nodejs_tests::unix::net::UCred
impl Hash for __c_anonymous_ptrace_syscall_info_data
extra_traits only.impl Hash for SockaddrStorage
impl<'a> Hash for Item<'a>
impl<'a> Hash for Component<'a>
impl<'a> Hash for Prefix<'a>
impl<'a> Hash for ElementEnd<'a>
impl<'a> Hash for EntityDefinition<'a>
impl<'a> Hash for ExternalId<'a>
impl<'a> Hash for xmlparser::Token<'a>
impl<'a> Hash for Reference<'a>
impl<'a> Hash for FcntlArg<'a>
impl<'a> Hash for AddrName<'a>
impl<'a> Hash for mime::Name<'a>
impl<'a> Hash for Ident<'a>
impl<'a> Hash for password_hash::value::Value<'a>
impl<'a> Hash for rmp::decode::bytes::Bytes<'a>
impl<'a> Hash for Stream<'a>
impl<'a> Hash for StrSpan<'a>
impl<'a> Hash for PhantomContravariantLifetime<'a>
impl<'a> Hash for PhantomCovariantLifetime<'a>
impl<'a> Hash for PhantomInvariantLifetime<'a>
impl<'a> Hash for Metadata<'a>
impl<'a> Hash for MetadataBuilder<'a>
impl<'d> Hash for Iter<'d>
impl<'data> Hash for CompressedData<'data>
impl<'data> Hash for ObjectMapEntry<'data>
impl<'data> Hash for ObjectMapFile<'data>
impl<'data> Hash for SymbolMapName<'data>
impl<'i, R> Hash for pest::token::Token<'i, R>where
R: Hash,
impl<'i, R> Hash for Pair<'i, R>where
R: Hash,
impl<'i, R> Hash for Pairs<'i, R>where
R: Hash,
impl<'input, Endian> Hash for EndianSlice<'input, Endian>
impl<A> Hash for SmallVec<A>
impl<A, B> Hash for EitherOrBoth<A, B>
impl<B> Hash for Cow<'_, B>
impl<B, C> Hash for ControlFlow<B, C>
impl<D> Hash for OccultationKindGeneral<D>where
D: Hash,
impl<DataStruct> Hash for ErasedMarker<DataStruct>
impl<Dyn> Hash for DynMetadata<Dyn>where
Dyn: ?Sized,
impl<E> Hash for I16Bytes<E>
impl<E> Hash for I32Bytes<E>
impl<E> Hash for I64Bytes<E>
impl<E> Hash for U16Bytes<E>
impl<E> Hash for U32Bytes<E>
impl<E> Hash for U64Bytes<E>
impl<EntryData> Hash for dlv_list::Index<EntryData>
impl<EntryData> Hash for VecList<EntryData>where
EntryData: Hash,
impl<F> Hash for Fwhere
F: FnPtr,
impl<I, T> Hash for IndexSlice<I, [T]>
impl<I, T> Hash for IndexVec<I, T>
impl<Idx> Hash for otter_nodejs_tests::inventory::core::ops::Range<Idx>where
Idx: Hash,
impl<Idx> Hash for otter_nodejs_tests::inventory::core::ops::RangeFrom<Idx>where
Idx: Hash,
impl<Idx> Hash for otter_nodejs_tests::inventory::core::ops::RangeInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for RangeTo<Idx>where
Idx: Hash,
impl<Idx> Hash for otter_nodejs_tests::inventory::core::ops::RangeToInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for otter_nodejs_tests::inventory::core::range::Range<Idx>where
Idx: Hash,
impl<Idx> Hash for otter_nodejs_tests::inventory::core::range::RangeFrom<Idx>where
Idx: Hash,
impl<Idx> Hash for otter_nodejs_tests::inventory::core::range::RangeInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for otter_nodejs_tests::inventory::core::range::RangeToInclusive<Idx>where
Idx: Hash,
impl<K, V> Hash for indexmap::map::slice::Slice<K, V>
impl<K, V> Hash for EnumMap<K, V>
impl<K, V, A> Hash for BTreeMap<K, V, A>
impl<K, V, S> Hash for LiteMap<K, V, S>
impl<L, R> Hash for Either<L, R>
impl<O> Hash for F32<O>where
O: Hash,
impl<O> Hash for F64<O>where
O: Hash,
impl<O> Hash for I16<O>where
O: Hash,
impl<O> Hash for I32<O>where
O: Hash,
impl<O> Hash for I64<O>where
O: Hash,
impl<O> Hash for I128<O>where
O: Hash,
impl<O> Hash for Isize<O>where
O: Hash,
impl<O> Hash for U16<O>where
O: Hash,
impl<O> Hash for U32<O>where
O: Hash,
impl<O> Hash for U64<O>where
O: Hash,
impl<O> Hash for U128<O>where
O: Hash,
impl<O> Hash for Usize<O>where
O: Hash,
impl<P, Container> Hash for ImageBuffer<P, Container>
impl<Ptr> Hash for Pin<Ptr>
impl<R> Hash for ErrorVariant<R>where
R: Hash,
impl<R> Hash for LocationListEntry<R>
impl<R> Hash for Expression<R>
impl<R> Hash for pest::error::Error<R>where
R: Hash,
impl<S> Hash for Host<S>where
S: Hash,
impl<S> Hash for Ascii<S>
impl<S> Hash for UniCase<S>
impl<Section, Symbol> Hash for SymbolFlags<Section, Symbol>
impl<Sep, T> Hash for StringWithSeparator<Sep, T>
impl<Storage> Hash for __BindgenBitfieldUnit<Storage>where
Storage: Hash,
impl<T> Hash for LocalResult<T>where
T: Hash,
impl<T> Hash for UnitSectionOffset<T>where
T: Hash,
impl<T> Hash for Bound<T>where
T: Hash,
impl<T> Hash for Option<T>where
T: Hash,
impl<T> Hash for Poll<T>where
T: Hash,
impl<T> Hash for *const Twhere
T: ?Sized,
impl<T> Hash for *mut Twhere
T: ?Sized,
impl<T> Hash for &T
impl<T> Hash for &mut T
impl<T> Hash for [T]where
T: Hash,
impl<T> Hash for (T₁, T₂, …, Tₙ)where
T: Hash,
This trait is implemented for tuples up to twelve items long.
impl<T> Hash for Reverse<T>where
T: Hash,
impl<T> Hash for NonNull<T>where
T: ?Sized,
impl<T> Hash for CachePadded<T>where
T: Hash,
impl<T> Hash for AllowStdIo<T>where
T: Hash,
impl<T> Hash for DebugAbbrevOffset<T>where
T: Hash,
impl<T> Hash for DebugFrameOffset<T>where
T: Hash,
impl<T> Hash for DebugInfoOffset<T>where
T: Hash,
impl<T> Hash for DebugMacinfoOffset<T>where
T: Hash,
impl<T> Hash for DebugMacroOffset<T>where
T: Hash,
impl<T> Hash for DebugTypesOffset<T>where
T: Hash,
impl<T> Hash for EhFrameOffset<T>where
T: Hash,
impl<T> Hash for LocationListsOffset<T>where
T: Hash,
impl<T> Hash for RangeListsOffset<T>where
T: Hash,
impl<T> Hash for RawRangeListsOffset<T>where
T: Hash,
impl<T> Hash for UnitOffset<T>where
T: Hash,
impl<T> Hash for Luma<T>where
T: Hash,
impl<T> Hash for LumaA<T>where
T: Hash,
impl<T> Hash for Rgb<T>where
T: Hash,
impl<T> Hash for Rgba<T>where
T: Hash,
impl<T> Hash for indexmap::set::slice::Slice<T>where
T: Hash,
impl<T> Hash for Complex<T>where
T: Hash,
impl<T> Hash for Ratio<T>
impl<T> Hash for TryWriteableInfallibleAsWriteable<T>where
T: Hash,
impl<T> Hash for WriteableAsTryWriteableInfallible<T>where
T: Hash,
impl<T> Hash for Unalign<T>
impl<T> Hash for Serde<T>where
T: Hash,
impl<T> Hash for PhantomContravariant<T>where
T: ?Sized,
impl<T> Hash for PhantomCovariant<T>where
T: ?Sized,
impl<T> Hash for PhantomInvariant<T>where
T: ?Sized,
impl<T> Hash for NonZero<T>where
T: ZeroablePrimitive + Hash,
impl<T> Hash for Saturating<T>where
T: Hash,
impl<T> Hash for SyncView<T>
impl<T> Hash for IoVec<T>where
T: Hash,
impl<T> Hash for NotNan<T>where
T: Float,
impl<T> Hash for Discriminant<T>
impl<T> Hash for ManuallyDrop<T>
impl<T> Hash for IsHtmlFormatted<T>
impl<T> Hash for OldNew<T>where
T: Hash,
impl<T> Hash for OrderedFloat<T>where
T: Float,
impl<T> Hash for PhantomData<T>where
T: ?Sized,
impl<T> Hash for PosC<T>where
T: Hash,
impl<T> Hash for RectC<T>where
T: Hash,
impl<T> Hash for Wrapping<T>where
T: Hash,
impl<T> Hash for Spanned<T>where
T: Hash,
impl<T, A> Hash for Box<T, A>
impl<T, A> Hash for LinkedList<T, A>
impl<T, A> Hash for Rc<T, A>
impl<T, A> Hash for UniqueRc<T, A>
impl<T, A> Hash for UniqueArc<T, A>
impl<T, A> Hash for Vec<T, A>
The hash of a vector is the same as that of the corresponding slice,
as required by the core::borrow::Borrow implementation.
use std::hash::BuildHasher;
let b = std::hash::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));impl<T, A> Hash for Arc<T, A>
impl<T, A> Hash for BTreeSet<T, A>
impl<T, A> Hash for VecDeque<T, A>
impl<T, E> Hash for Result<T, E>
impl<T, I> Hash for Deque<T, I>
impl<T, N> Hash for GenericArray<T, N>where
T: Hash,
N: ArrayLength<T>,
impl<T, const CAP: usize> Hash for ArrayVec<T, CAP>where
T: Hash,
impl<T, const N: usize> Hash for [T; N]where
T: Hash,
The hash of an array is the same as that of the corresponding slice,
as required by the Borrow implementation.
use std::hash::BuildHasher;
let b = std::hash::RandomState::new();
let a: [u8; 3] = [0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(a), b.hash_one(s));