pub trait Index<Idx>where
Idx: ?Sized,{
type Output: ?Sized;
// Required method
fn index(&self, index: Idx) -> &Self::Output;
}Expand description
Used for indexing operations (container[index]) in immutable contexts.
container[index] is actually syntactic sugar for *container.index(index),
but only when used as an immutable value. If a mutable value is requested,
IndexMut is used instead. This allows nice things such as
let value = v[index] if the type of value implements Copy.
Examples
The following example implements Index on a read-only NucleotideCount
container, enabling individual counts to be retrieved with index syntax.
use std::ops::Index;
enum Nucleotide {
A,
C,
G,
T,
}
struct NucleotideCount {
a: usize,
c: usize,
g: usize,
t: usize,
}
impl Index<Nucleotide> for NucleotideCount {
type Output = usize;
fn index(&self, nucleotide: Nucleotide) -> &Self::Output {
match nucleotide {
Nucleotide::A => &self.a,
Nucleotide::C => &self.c,
Nucleotide::G => &self.g,
Nucleotide::T => &self.t,
}
}
}
let nucleotide_count = NucleotideCount {a: 14, c: 9, g: 10, t: 12};
assert_eq!(nucleotide_count[Nucleotide::A], 14);
assert_eq!(nucleotide_count[Nucleotide::C], 9);
assert_eq!(nucleotide_count[Nucleotide::G], 10);
assert_eq!(nucleotide_count[Nucleotide::T], 12);Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
Sourceimpl Index<Range<usize>> for UninitSlice
impl Index<Range<usize>> for UninitSlice
type Output = UninitSlice
Sourceimpl Index<RangeFrom<usize>> for UninitSlice
impl Index<RangeFrom<usize>> for UninitSlice
type Output = UninitSlice
Sourceimpl Index<RangeFull> for UninitSlice
impl Index<RangeFull> for UninitSlice
type Output = UninitSlice
Sourceimpl Index<RangeInclusive<usize>> for ByteString
impl Index<RangeInclusive<usize>> for ByteString
Sourceimpl Index<RangeInclusive<usize>> for UninitSlice
impl Index<RangeInclusive<usize>> for UninitSlice
type Output = UninitSlice
Sourceimpl Index<RangeTo<usize>> for UninitSlice
impl Index<RangeTo<usize>> for UninitSlice
type Output = UninitSlice
Sourceimpl Index<RangeToInclusive<usize>> for ByteString
impl Index<RangeToInclusive<usize>> for ByteString
Sourceimpl Index<RangeToInclusive<usize>> for UninitSlice
impl Index<RangeToInclusive<usize>> for UninitSlice
type Output = UninitSlice
Sourceimpl<'a, K, V, T> Index<&'a T> for OrderedMap<K, V>
impl<'a, K, V, T> Index<&'a T> for OrderedMap<K, V>
Sourceimpl<'a, Q> Index<&'a Q> for otter_nodejs_tests::toml::map::Map<String, Value>
Access an element of this map. Panics if the given key is not present in the
map.
impl<'a, Q> Index<&'a Q> for otter_nodejs_tests::toml::map::Map<String, Value>
Access an element of this map. Panics if the given key is not present in the map.
Sourceimpl<'h> Index<usize> for otter_nodejs_tests::regex::bytes::Captures<'h>
Get a matching capture group’s haystack substring by index.
impl<'h> Index<usize> for otter_nodejs_tests::regex::bytes::Captures<'h>
Get a matching capture group’s haystack substring by index.
The haystack substring returned can’t outlive the Captures object if this
method is used, because of how Index is defined (normally a[i] is part
of a and can’t outlive it). To work around this limitation, do that, use
Captures::get instead.
'h is the lifetime of the matched haystack, but the lifetime of the
&str returned by this implementation is the lifetime of the Captures
value itself.
Panics
If there is no matching group at the given index.
Sourceimpl<'h> Index<usize> for otter_nodejs_tests::regex::Captures<'h>
Get a matching capture group’s haystack substring by index.
impl<'h> Index<usize> for otter_nodejs_tests::regex::Captures<'h>
Get a matching capture group’s haystack substring by index.
The haystack substring returned can’t outlive the Captures object if this
method is used, because of how Index is defined (normally a[i] is part
of a and can’t outlive it). To work around this limitation, do that, use
Captures::get instead.
'h is the lifetime of the matched haystack, but the lifetime of the
&str returned by this implementation is the lifetime of the Captures
value itself.
Panics
If there is no matching group at the given index.
Sourceimpl<'h, 'n> Index<&'n str> for otter_nodejs_tests::regex::bytes::Captures<'h>
Get a matching capture group’s haystack substring by name.
impl<'h, 'n> Index<&'n str> for otter_nodejs_tests::regex::bytes::Captures<'h>
Get a matching capture group’s haystack substring by name.
The haystack substring returned can’t outlive the Captures object if this
method is used, because of how Index is defined (normally a[i] is part
of a and can’t outlive it). To work around this limitation, do that, use
Captures::name instead.
'h is the lifetime of the matched haystack, but the lifetime of the
&str returned by this implementation is the lifetime of the Captures
value itself.
'n is the lifetime of the group name used to index the Captures value.
Panics
If there is no matching group at the given name.
Sourceimpl<'h, 'n> Index<&'n str> for otter_nodejs_tests::regex::Captures<'h>
Get a matching capture group’s haystack substring by name.
impl<'h, 'n> Index<&'n str> for otter_nodejs_tests::regex::Captures<'h>
Get a matching capture group’s haystack substring by name.
The haystack substring returned can’t outlive the Captures object if this
method is used, because of how Index is defined (normally a[i] is part
of a and can’t outlive it). To work around this limitation, do that, use
Captures::name instead.
'h is the lifetime of the matched haystack, but the lifetime of the
&str returned by this implementation is the lifetime of the Captures
value itself.
'n is the lifetime of the group name used to index the Captures value.
Panics
If there is no matching group at the given name.
Sourceimpl<I> Index<I> for UncasedStr
impl<I> Index<I> for UncasedStr
type Output = UncasedStr
Sourceimpl<I, R, T> Index<R> for IndexSlice<I, [T]>where
I: Idx,
R: IdxSliceIndex<I, T>,
impl<I, R, T> Index<R> for IndexSlice<I, [T]>where
I: Idx,
R: IdxSliceIndex<I, T>,
type Output = <R as IdxSliceIndex<I, T>>::Output
Sourceimpl<K, V> Index<usize> for Keys<'_, K, V>
Access IndexMap keys at indexed positions.
impl<K, V> Index<usize> for Keys<'_, K, V>
Access IndexMap keys at indexed positions.
While Index<usize> for IndexMap accesses a map’s values,
indexing through IndexMap::keys offers an alternative to access a map’s
keys instead.
Since Keys is also an iterator, consuming items from the iterator will
offset the effective indices. Similarly, if Keys is obtained from
Slice::keys, indices will be interpreted relative to the position of
that slice.
Examples
use indexmap::IndexMap;
let mut map = IndexMap::new();
for word in "Lorem ipsum dolor sit amet".split_whitespace() {
map.insert(word.to_lowercase(), word.to_uppercase());
}
assert_eq!(map[0], "LOREM");
assert_eq!(map.keys()[0], "lorem");
assert_eq!(map[1], "IPSUM");
assert_eq!(map.keys()[1], "ipsum");
map.reverse();
assert_eq!(map.keys()[0], "amet");
assert_eq!(map.keys()[1], "sit");
map.sort_keys();
assert_eq!(map.keys()[0], "amet");
assert_eq!(map.keys()[1], "dolor");
// Advancing the iterator will offset the indexing
let mut keys = map.keys();
assert_eq!(keys[0], "amet");
assert_eq!(keys.next().map(|s| &**s), Some("amet"));
assert_eq!(keys[0], "dolor");
assert_eq!(keys[1], "ipsum");
// Slices may have an offset as well
let slice = &map[2..];
assert_eq!(slice[0], "IPSUM");
assert_eq!(slice.keys()[0], "ipsum");use indexmap::IndexMap;
let mut map = IndexMap::new();
map.insert("foo", 1);
println!("{:?}", map.keys()[10]); // panics!Sourceimpl<K, V, Q, S> Index<&Q> for indexmap::map::IndexMap<K, V, S>
Access IndexMap values corresponding to a key.
impl<K, V, Q, S> Index<&Q> for indexmap::map::IndexMap<K, V, S>
Access IndexMap values corresponding to a key.
Examples
use indexmap::IndexMap;
let mut map = IndexMap::new();
for word in "Lorem ipsum dolor sit amet".split_whitespace() {
map.insert(word.to_lowercase(), word.to_uppercase());
}
assert_eq!(map["lorem"], "LOREM");
assert_eq!(map["ipsum"], "IPSUM");use indexmap::IndexMap;
let mut map = IndexMap::new();
map.insert("foo", 1);
println!("{:?}", map["bar"]); // panics!Sourceimpl<K, V, Q, S> Index<&Q> for otter_nodejs_tests::IndexMap<K, V, S>
Access IndexMap values corresponding to a key.
impl<K, V, Q, S> Index<&Q> for otter_nodejs_tests::IndexMap<K, V, S>
Access IndexMap values corresponding to a key.
Examples
use indexmap::IndexMap;
let mut map = IndexMap::new();
for word in "Lorem ipsum dolor sit amet".split_whitespace() {
map.insert(word.to_lowercase(), word.to_uppercase());
}
assert_eq!(map["lorem"], "LOREM");
assert_eq!(map["ipsum"], "IPSUM");use indexmap::IndexMap;
let mut map = IndexMap::new();
map.insert("foo", 1);
println!("{:?}", map["bar"]); // panics!Sourceimpl<K, V, S> Index<usize> for indexmap::map::IndexMap<K, V, S>
Access IndexMap values at indexed positions.
impl<K, V, S> Index<usize> for indexmap::map::IndexMap<K, V, S>
Access IndexMap values at indexed positions.
See Index<usize> for Keys to access a map’s keys instead.
Examples
use indexmap::IndexMap;
let mut map = IndexMap::new();
for word in "Lorem ipsum dolor sit amet".split_whitespace() {
map.insert(word.to_lowercase(), word.to_uppercase());
}
assert_eq!(map[0], "LOREM");
assert_eq!(map[1], "IPSUM");
map.reverse();
assert_eq!(map[0], "AMET");
assert_eq!(map[1], "SIT");
map.sort_keys();
assert_eq!(map[0], "AMET");
assert_eq!(map[1], "DOLOR");use indexmap::IndexMap;
let mut map = IndexMap::new();
map.insert("foo", 1);
println!("{:?}", map[10]); // panics!Sourceimpl<K, V, S> Index<usize> for otter_nodejs_tests::IndexMap<K, V, S>
Access IndexMap values at indexed positions.
impl<K, V, S> Index<usize> for otter_nodejs_tests::IndexMap<K, V, S>
Access IndexMap values at indexed positions.
Examples
use indexmap::IndexMap;
let mut map = IndexMap::new();
for word in "Lorem ipsum dolor sit amet".split_whitespace() {
map.insert(word.to_lowercase(), word.to_uppercase());
}
assert_eq!(map[0], "LOREM");
assert_eq!(map[1], "IPSUM");
map.reverse();
assert_eq!(map[0], "AMET");
assert_eq!(map[1], "SIT");
map.sort_keys();
assert_eq!(map[0], "AMET");
assert_eq!(map[1], "DOLOR");use indexmap::IndexMap;
let mut map = IndexMap::new();
map.insert("foo", 1);
println!("{:?}", map[10]); // panics!Sourceimpl<K, V, S> Index<K> for SparseSecondaryMap<K, V, S>where
K: Key,
S: BuildHasher,
impl<K, V, S> Index<K> for SparseSecondaryMap<K, V, S>where
K: Key,
S: BuildHasher,
Sourceimpl<Q> Index<&Q> for otter_nodejs_tests::tera::Map<String, Value>
Access an element of this map. Panics if the given key is not present in the
map.
impl<Q> Index<&Q> for otter_nodejs_tests::tera::Map<String, Value>
Access an element of this map. Panics if the given key is not present in the map.
match val {
Value::String(s) => Some(s.as_str()),
Value::Array(arr) => arr[0].as_str(),
Value::Object(map) => map["type"].as_str(),
_ => None,
}Sourceimpl<T0, T1, T2, T3, T4, T5> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B0>> for (T0, T1, T2, T3, T4, T5)
impl<T0, T1, T2, T3, T4, T5> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B0>> for (T0, T1, T2, T3, T4, T5)
Sourceimpl<T0, T1, T2, T3, T4, T5> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B1>> for (T0, T1, T2, T3, T4, T5)
impl<T0, T1, T2, T3, T4, T5> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B1>> for (T0, T1, T2, T3, T4, T5)
Sourceimpl<T0, T1, T2, T3, T4, T5> Index<UTerm> for (T0, T1, T2, T3, T4, T5)
impl<T0, T1, T2, T3, T4, T5> Index<UTerm> for (T0, T1, T2, T3, T4, T5)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6)
impl<T0, T1, T2, T3, T4, T5, T6> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6)
impl<T0, T1, T2, T3, T4, T5, T6> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6)
impl<T0, T1, T2, T3, T4, T5, T6> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6> Index<UInt<UInt<UTerm, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6)
impl<T0, T1, T2, T3, T4, T5, T6> Index<UInt<UInt<UTerm, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6> Index<UInt<UInt<UTerm, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6)
impl<T0, T1, T2, T3, T4, T5, T6> Index<UInt<UInt<UTerm, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6> Index<UTerm> for (T0, T1, T2, T3, T4, T5, T6)
impl<T0, T1, T2, T3, T4, T5, T6> Index<UTerm> for (T0, T1, T2, T3, T4, T5, T6)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7)
impl<T0, T1, T2, T3, T4, T5, T6, T7> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7)
impl<T0, T1, T2, T3, T4, T5, T6, T7> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7)
impl<T0, T1, T2, T3, T4, T5, T6, T7> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7)
impl<T0, T1, T2, T3, T4, T5, T6, T7> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7> Index<UInt<UInt<UTerm, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7)
impl<T0, T1, T2, T3, T4, T5, T6, T7> Index<UInt<UInt<UTerm, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7> Index<UInt<UInt<UTerm, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7)
impl<T0, T1, T2, T3, T4, T5, T6, T7> Index<UInt<UInt<UTerm, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7> Index<UInt<UTerm, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7)
impl<T0, T1, T2, T3, T4, T5, T6, T7> Index<UInt<UTerm, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7> Index<UTerm> for (T0, T1, T2, T3, T4, T5, T6, T7)
impl<T0, T1, T2, T3, T4, T5, T6, T7> Index<UTerm> for (T0, T1, T2, T3, T4, T5, T6, T7)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UInt<UInt<UTerm, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UInt<UInt<UTerm, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UInt<UInt<UTerm, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UInt<UInt<UTerm, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UInt<UTerm, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UInt<UTerm, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UTerm> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8> Index<UTerm> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UInt<UTerm, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UInt<UTerm, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UInt<UTerm, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UInt<UTerm, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UTerm, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UInt<UTerm, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UTerm> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> Index<UTerm> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UTerm, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UTerm, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UTerm, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UInt<UTerm, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UTerm, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UInt<UTerm, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UTerm> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> Index<UTerm> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UInt<UTerm, B1>, B0>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UInt<UTerm, B1>, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UTerm, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UTerm, B1>, B0>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UTerm, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UInt<UTerm, B1>, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UTerm, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UInt<UTerm, B1>> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
Sourceimpl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UTerm> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
impl<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> Index<UTerm> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)
Sourceimpl<T> Index<usize> for StackRef<T>where
T: Stackable,
impl<T> Index<usize> for StackRef<T>where
T: Stackable,
type Output = <T as ForeignType>::Ref
Sourceimpl<T> Index<SmallIndex> for Vec<T>
Available on crate feature alloc only.
impl<T> Index<SmallIndex> for Vec<T>
alloc only.Sourceimpl<T, F> Index<usize> for VarZeroSlice<T, F>
impl<T, F> Index<usize> for VarZeroSlice<T, F>
Sourceimpl<T, S> Index<usize> for indexmap::set::IndexSet<T, S>
Access IndexSet values at indexed positions.
impl<T, S> Index<usize> for indexmap::set::IndexSet<T, S>
Access IndexSet values at indexed positions.
Examples
use indexmap::IndexSet;
let mut set = IndexSet::new();
for word in "Lorem ipsum dolor sit amet".split_whitespace() {
set.insert(word.to_string());
}
assert_eq!(set[0], "Lorem");
assert_eq!(set[1], "ipsum");
set.reverse();
assert_eq!(set[0], "amet");
assert_eq!(set[1], "sit");
set.sort();
assert_eq!(set[0], "Lorem");
assert_eq!(set[1], "amet");use indexmap::IndexSet;
let mut set = IndexSet::new();
set.insert("foo");
println!("{:?}", set[10]); // panics!Sourceimpl<T, S> Index<usize> for otter_nodejs_tests::IndexSet<T, S>
Access IndexSet values at indexed positions.
impl<T, S> Index<usize> for otter_nodejs_tests::IndexSet<T, S>
Access IndexSet values at indexed positions.
Examples
use indexmap::IndexSet;
let mut set = IndexSet::new();
for word in "Lorem ipsum dolor sit amet".split_whitespace() {
set.insert(word.to_string());
}
assert_eq!(set[0], "Lorem");
assert_eq!(set[1], "ipsum");
set.reverse();
assert_eq!(set[0], "amet");
assert_eq!(set[1], "sit");
set.sort();
assert_eq!(set[0], "Lorem");
assert_eq!(set[1], "amet");use indexmap::IndexSet;
let mut set = IndexSet::new();
set.insert("foo");
println!("{:?}", set[10]); // panics!