pub trait TryFrom<T>: Sized {
type Error;
// Required method
fn try_from(value: T) -> Result<Self, Self::Error>;
}Expand description
Simple and safe type conversions that may fail in a controlled
way under some circumstances. It is the reciprocal of TryInto.
This is useful when you are doing a type conversion that may
trivially succeed but may also need special handling.
For example, there is no way to convert an i64 into an i32
using the From trait, because an i64 may contain a value
that an i32 cannot represent and so the conversion would lose data.
This might be handled by truncating the i64 to an i32 or by
simply returning i32::MAX, or by some other method. The From
trait is intended for perfect conversions, so the TryFrom trait
informs the programmer when a type conversion could go bad and lets
them decide how to handle it.
Generic Implementations
TryFrom<T> for UimpliesTryInto<U> for Ttry_fromis reflexive, which means thatTryFrom<T> for Tis implemented and cannot fail – the associatedErrortype for callingT::try_from()on a value of typeTisInfallible. When the!type is stabilizedInfallibleand!will be equivalent.
Prefer using TryInto over TryFrom when specifying trait bounds on a generic function
to ensure that types that only implement TryInto can be used as well.
TryFrom<T> can be implemented as follows:
struct GreaterThanZero(i32);
impl TryFrom<i32> for GreaterThanZero {
type Error = &'static str;
fn try_from(value: i32) -> Result<Self, Self::Error> {
if value <= 0 {
Err("GreaterThanZero only accepts values greater than zero!")
} else {
Ok(GreaterThanZero(value))
}
}
}Examples
As described, i32 implements TryFrom<i64>:
let big_number = 1_000_000_000_000i64;
// Silently truncates `big_number`, requires detecting
// and handling the truncation after the fact.
let smaller_number = big_number as i32;
assert_eq!(smaller_number, -727379968);
// Returns an error because `big_number` is too big to
// fit in an `i32`.
let try_smaller_number = i32::try_from(big_number);
assert!(try_smaller_number.is_err());
// Returns `Ok(3)`.
let try_successful_smaller_number = i32::try_from(3);
assert!(try_successful_smaller_number.is_ok());Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
Sourceimpl TryFrom<&str> for PresentationLayout
impl TryFrom<&str> for PresentationLayout
type Error = ParseError
Sourceimpl TryFrom<&str> for LogSpecification
impl TryFrom<&str> for LogSpecification
type Error = FlexiLoggerError
Sourceimpl TryFrom<&String> for PathAndQuery
impl TryFrom<&String> for PathAndQuery
type Error = InvalidUri
Sourceimpl TryFrom<&String> for LogSpecification
impl TryFrom<&String> for LogSpecification
type Error = FlexiLoggerError
Sourceimpl TryFrom<&Value> for CalendarAlgorithm
impl TryFrom<&Value> for CalendarAlgorithm
Sourceimpl TryFrom<&Value> for CollationCaseFirst
impl TryFrom<&Value> for CollationCaseFirst
Sourceimpl TryFrom<&Value> for CollationNumericOrdering
impl TryFrom<&Value> for CollationNumericOrdering
Sourceimpl TryFrom<&Value> for CollationType
impl TryFrom<&Value> for CollationType
Sourceimpl TryFrom<&Value> for CurrencyFormatStyle
impl TryFrom<&Value> for CurrencyFormatStyle
Sourceimpl TryFrom<&Value> for EmojiPresentationStyle
impl TryFrom<&Value> for EmojiPresentationStyle
Sourceimpl TryFrom<&Value> for LineBreakStyle
impl TryFrom<&Value> for LineBreakStyle
Sourceimpl TryFrom<&Value> for LineBreakWordHandling
impl TryFrom<&Value> for LineBreakWordHandling
Sourceimpl TryFrom<&Value> for MeasurementSystem
impl TryFrom<&Value> for MeasurementSystem
Sourceimpl TryFrom<&Value> for MeasurementUnitOverride
impl TryFrom<&Value> for MeasurementUnitOverride
Sourceimpl TryFrom<&Value> for SentenceBreakSupressions
impl TryFrom<&Value> for SentenceBreakSupressions
Sourceimpl TryFrom<&Value> for CommonVariantType
impl TryFrom<&Value> for CommonVariantType
Sourceimpl TryFrom<&Value> for CurrencyType
impl TryFrom<&Value> for CurrencyType
Sourceimpl TryFrom<&Value> for NumberingSystem
impl TryFrom<&Value> for NumberingSystem
Sourceimpl TryFrom<&Value> for RegionOverride
impl TryFrom<&Value> for RegionOverride
Sourceimpl TryFrom<&Value> for RegionalSubdivision
impl TryFrom<&Value> for RegionalSubdivision
Sourceimpl TryFrom<&Value> for TimeZoneShortId
impl TryFrom<&Value> for TimeZoneShortId
Sourceimpl TryFrom<&ColourSpec> for Html
impl TryFrom<&ColourSpec> for Html
Sourceimpl TryFrom<Error> for InvalidFormatDescription
impl TryFrom<Error> for InvalidFormatDescription
type Error = DifferentVariant
Sourceimpl TryFrom<Error> for ParseFromDescription
impl TryFrom<Error> for ParseFromDescription
type Error = DifferentVariant
Sourceimpl TryFrom<Error> for TryFromParsed
impl TryFrom<Error> for TryFromParsed
type Error = DifferentVariant
Sourceimpl TryFrom<Error> for ComponentRange
impl TryFrom<Error> for ComponentRange
type Error = DifferentVariant
Sourceimpl TryFrom<Error> for ConversionRange
impl TryFrom<Error> for ConversionRange
type Error = DifferentVariant
Sourceimpl TryFrom<Error> for DifferentVariant
impl TryFrom<Error> for DifferentVariant
type Error = DifferentVariant
Sourceimpl TryFrom<Error> for IndeterminateOffset
impl TryFrom<Error> for IndeterminateOffset
type Error = DifferentVariant
Sourceimpl TryFrom<Error> for InvalidVariant
impl TryFrom<Error> for InvalidVariant
type Error = DifferentVariant
Sourceimpl TryFrom<Parse> for ParseFromDescription
impl TryFrom<Parse> for ParseFromDescription
type Error = DifferentVariant
Sourceimpl TryFrom<Parse> for TryFromParsed
impl TryFrom<Parse> for TryFromParsed
type Error = DifferentVariant
Sourceimpl TryFrom<TryFromParsed> for ComponentRange
impl TryFrom<TryFromParsed> for ComponentRange
type Error = DifferentVariant
Sourceimpl TryFrom<FormatItem<'_>> for Component
impl TryFrom<FormatItem<'_>> for Component
type Error = DifferentVariant
1.59.0 (const: unstable) · Sourceimpl TryFrom<char> for u8
Maps a char with a code point from U+0000 to U+00FF (inclusive) to a byte in 0x00..=0xFF with
the same value, failing if the code point is greater than U+00FF.
impl TryFrom<char> for u8
Maps a char with a code point from U+0000 to U+00FF (inclusive) to a byte in 0x00..=0xFF with
the same value, failing if the code point is greater than U+00FF.
See impl From<u8> for char for details on the encoding.
type Error = TryFromCharError
1.74.0 (const: unstable) · Sourceimpl TryFrom<char> for u16
Maps a char with a code point from U+0000 to U+FFFF (inclusive) to a u16 in 0x0000..=0xFFFF
with the same value, failing if the code point is greater than U+FFFF.
impl TryFrom<char> for u16
Maps a char with a code point from U+0000 to U+FFFF (inclusive) to a u16 in 0x0000..=0xFFFF
with the same value, failing if the code point is greater than U+FFFF.
This corresponds to the UCS-2 encoding, as specified in ISO/IEC 10646:2003.
type Error = TryFromCharError
1.94.0 (const: unstable) · Sourceimpl TryFrom<char> for usize
Maps a char with a code point from U+0000 to U+10FFFF (inclusive) to a usize in
0x0000..=0x10FFFF with the same value, failing if the final value is unrepresentable by
usize.
impl TryFrom<char> for usize
Maps a char with a code point from U+0000 to U+10FFFF (inclusive) to a usize in
0x0000..=0x10FFFF with the same value, failing if the final value is unrepresentable by
usize.
Generally speaking, this conversion can be seen as obtaining the character’s corresponding UTF-32 code point to the extent representable by pointer addresses.
type Error = TryFromCharError
1.46.0 (const: unstable) · Sourceimpl TryFrom<i8> for NonZero<i8>
impl TryFrom<i8> for NonZero<i8>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<i16> for NonZero<i16>
impl TryFrom<i16> for NonZero<i16>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<i32> for NonZero<i32>
impl TryFrom<i32> for NonZero<i32>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<i64> for NonZero<i64>
impl TryFrom<i64> for NonZero<i64>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<i128> for NonZero<i128>
impl TryFrom<i128> for NonZero<i128>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<isize> for NonZero<isize>
impl TryFrom<isize> for NonZero<isize>
type Error = TryFromIntError
Sourceimpl TryFrom<u8> for Weekday
Any weekday can be represented as an integer from 0 to 6, which equals to
Weekday::num_days_from_monday in this implementation.
Do not heavily depend on this though; use explicit methods whenever possible.
impl TryFrom<u8> for Weekday
Any weekday can be represented as an integer from 0 to 6, which equals to
Weekday::num_days_from_monday in this implementation.
Do not heavily depend on this though; use explicit methods whenever possible.
type Error = OutOfRange
Sourceimpl TryFrom<u8> for GeneralCategory
impl TryFrom<u8> for GeneralCategory
1.46.0 (const: unstable) · Sourceimpl TryFrom<u8> for NonZero<u8>
impl TryFrom<u8> for NonZero<u8>
type Error = TryFromIntError
Sourceimpl TryFrom<u16> for aho_corasick::util::primitives::PatternID
impl TryFrom<u16> for aho_corasick::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u16> for aho_corasick::util::primitives::StateID
impl TryFrom<u16> for aho_corasick::util::primitives::StateID
type Error = StateIDError
Sourceimpl TryFrom<u16> for StatusCode
impl TryFrom<u16> for StatusCode
type Error = InvalidStatusCode
Sourceimpl TryFrom<u16> for regex_automata::util::primitives::PatternID
impl TryFrom<u16> for regex_automata::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u16> for SmallIndex
impl TryFrom<u16> for SmallIndex
type Error = SmallIndexError
Sourceimpl TryFrom<u16> for regex_automata::util::primitives::StateID
impl TryFrom<u16> for regex_automata::util::primitives::StateID
type Error = StateIDError
1.46.0 (const: unstable) · Sourceimpl TryFrom<u16> for NonZero<u16>
impl TryFrom<u16> for NonZero<u16>
type Error = TryFromIntError
Sourceimpl TryFrom<u32> for aho_corasick::util::primitives::PatternID
impl TryFrom<u32> for aho_corasick::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u32> for aho_corasick::util::primitives::StateID
impl TryFrom<u32> for aho_corasick::util::primitives::StateID
type Error = StateIDError
Sourceimpl TryFrom<u32> for regex_automata::util::primitives::PatternID
impl TryFrom<u32> for regex_automata::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u32> for SmallIndex
impl TryFrom<u32> for SmallIndex
type Error = SmallIndexError
Sourceimpl TryFrom<u32> for regex_automata::util::primitives::StateID
impl TryFrom<u32> for regex_automata::util::primitives::StateID
type Error = StateIDError
1.46.0 (const: unstable) · Sourceimpl TryFrom<u32> for NonZero<u32>
impl TryFrom<u32> for NonZero<u32>
type Error = TryFromIntError
Sourceimpl TryFrom<u64> for aho_corasick::util::primitives::PatternID
impl TryFrom<u64> for aho_corasick::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u64> for aho_corasick::util::primitives::StateID
impl TryFrom<u64> for aho_corasick::util::primitives::StateID
type Error = StateIDError
Sourceimpl TryFrom<u64> for regex_automata::util::primitives::PatternID
impl TryFrom<u64> for regex_automata::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<u64> for SmallIndex
impl TryFrom<u64> for SmallIndex
type Error = SmallIndexError
Sourceimpl TryFrom<u64> for regex_automata::util::primitives::StateID
impl TryFrom<u64> for regex_automata::util::primitives::StateID
type Error = StateIDError
1.46.0 (const: unstable) · Sourceimpl TryFrom<u64> for NonZero<u64>
impl TryFrom<u64> for NonZero<u64>
type Error = TryFromIntError
1.46.0 (const: unstable) · Sourceimpl TryFrom<u128> for NonZero<u128>
impl TryFrom<u128> for NonZero<u128>
type Error = TryFromIntError
Sourceimpl TryFrom<usize> for aho_corasick::util::primitives::PatternID
impl TryFrom<usize> for aho_corasick::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<usize> for aho_corasick::util::primitives::StateID
impl TryFrom<usize> for aho_corasick::util::primitives::StateID
type Error = StateIDError
Sourceimpl TryFrom<usize> for regex_automata::util::primitives::PatternID
impl TryFrom<usize> for regex_automata::util::primitives::PatternID
type Error = PatternIDError
Sourceimpl TryFrom<usize> for SmallIndex
impl TryFrom<usize> for SmallIndex
type Error = SmallIndexError
Sourceimpl TryFrom<usize> for regex_automata::util::primitives::StateID
impl TryFrom<usize> for regex_automata::util::primitives::StateID
type Error = StateIDError
1.46.0 (const: unstable) · Sourceimpl TryFrom<usize> for NonZero<usize>
impl TryFrom<usize> for NonZero<usize>
type Error = TryFromIntError
Sourceimpl TryFrom<ByteString> for String
impl TryFrom<ByteString> for String
type Error = FromUtf8Error
Sourceimpl TryFrom<String> for HeaderName
impl TryFrom<String> for HeaderName
type Error = InvalidHeaderName
Sourceimpl TryFrom<String> for HeaderValue
impl TryFrom<String> for HeaderValue
type Error = InvalidHeaderValue
Sourceimpl TryFrom<String> for PathAndQuery
impl TryFrom<String> for PathAndQuery
type Error = InvalidUri
Sourceimpl TryFrom<String> for GoodItemName
impl TryFrom<String> for GoodItemName
type Error = LibraryLoadError
Sourceimpl TryFrom<Vec<u8>> for HeaderName
impl TryFrom<Vec<u8>> for HeaderName
type Error = InvalidHeaderName
Sourceimpl TryFrom<Vec<u8>> for HeaderValue
impl TryFrom<Vec<u8>> for HeaderValue
type Error = InvalidHeaderValue
Sourceimpl TryFrom<Vec<u32>> for FakeTimeSpec
impl TryFrom<Vec<u32>> for FakeTimeSpec
type Error = InvalidFakeTime
Sourceimpl TryFrom<TcpListener> for TcpListener
impl TryFrom<TcpListener> for TcpListener
Sourceimpl TryFrom<Value> for CurrencyType
impl TryFrom<Value> for CurrencyType
Sourceimpl TryFrom<Value> for NumberingSystem
impl TryFrom<Value> for NumberingSystem
Sourceimpl TryFrom<Value> for RegionOverride
impl TryFrom<Value> for RegionOverride
Sourceimpl TryFrom<Value> for RegionalSubdivision
impl TryFrom<Value> for RegionalSubdivision
Sourceimpl TryFrom<Value> for TimeZoneShortId
impl TryFrom<Value> for TimeZoneShortId
Sourceimpl TryFrom<PotentialCodePoint> for char
impl TryFrom<PotentialCodePoint> for char
type Error = CharTryFromError
Sourceimpl TryFrom<OffsetDateTime> for DateTime
Available on crate feature time only.
impl TryFrom<OffsetDateTime> for DateTime
time only.type Error = DateTimeRangeError
Sourceimpl TryFrom<Parsed> for OffsetDateTime
impl TryFrom<Parsed> for OffsetDateTime
type Error = TryFromParsed
Sourceimpl TryFrom<Parsed> for PrimitiveDateTime
impl TryFrom<Parsed> for PrimitiveDateTime
type Error = TryFromParsed
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<u8>
impl TryFrom<NonZero<i8>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<u16>
impl TryFrom<NonZero<i8>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<u32>
impl TryFrom<NonZero<i8>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<u64>
impl TryFrom<NonZero<i8>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<u128>
impl TryFrom<NonZero<i8>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i8>> for NonZero<usize>
impl TryFrom<NonZero<i8>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<i8>
impl TryFrom<NonZero<i16>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<u8>
impl TryFrom<NonZero<i16>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<u16>
impl TryFrom<NonZero<i16>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<u32>
impl TryFrom<NonZero<i16>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<u64>
impl TryFrom<NonZero<i16>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<u128>
impl TryFrom<NonZero<i16>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i16>> for NonZero<usize>
impl TryFrom<NonZero<i16>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<i8>
impl TryFrom<NonZero<i32>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<i16>
impl TryFrom<NonZero<i32>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<isize>
impl TryFrom<NonZero<i32>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<u8>
impl TryFrom<NonZero<i32>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<u16>
impl TryFrom<NonZero<i32>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<u32>
impl TryFrom<NonZero<i32>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<u64>
impl TryFrom<NonZero<i32>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<u128>
impl TryFrom<NonZero<i32>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i32>> for NonZero<usize>
impl TryFrom<NonZero<i32>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<i8>
impl TryFrom<NonZero<i64>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<i16>
impl TryFrom<NonZero<i64>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<i32>
impl TryFrom<NonZero<i64>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<isize>
impl TryFrom<NonZero<i64>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<u8>
impl TryFrom<NonZero<i64>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<u16>
impl TryFrom<NonZero<i64>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<u32>
impl TryFrom<NonZero<i64>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<u64>
impl TryFrom<NonZero<i64>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<u128>
impl TryFrom<NonZero<i64>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i64>> for NonZero<usize>
impl TryFrom<NonZero<i64>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<i8>
impl TryFrom<NonZero<i128>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<i16>
impl TryFrom<NonZero<i128>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<i32>
impl TryFrom<NonZero<i128>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<i64>
impl TryFrom<NonZero<i128>> for NonZero<i64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<isize>
impl TryFrom<NonZero<i128>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<u8>
impl TryFrom<NonZero<i128>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<u16>
impl TryFrom<NonZero<i128>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<u32>
impl TryFrom<NonZero<i128>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<u64>
impl TryFrom<NonZero<i128>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<u128>
impl TryFrom<NonZero<i128>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<i128>> for NonZero<usize>
impl TryFrom<NonZero<i128>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<i8>
impl TryFrom<NonZero<isize>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<i16>
impl TryFrom<NonZero<isize>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<i32>
impl TryFrom<NonZero<isize>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<i64>
impl TryFrom<NonZero<isize>> for NonZero<i64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<i128>
impl TryFrom<NonZero<isize>> for NonZero<i128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<u8>
impl TryFrom<NonZero<isize>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<u16>
impl TryFrom<NonZero<isize>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<u32>
impl TryFrom<NonZero<isize>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<u64>
impl TryFrom<NonZero<isize>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<u128>
impl TryFrom<NonZero<isize>> for NonZero<u128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<isize>> for NonZero<usize>
impl TryFrom<NonZero<isize>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u8>> for NonZero<i8>
impl TryFrom<NonZero<u8>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u16>> for NonZero<i8>
impl TryFrom<NonZero<u16>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u16>> for NonZero<i16>
impl TryFrom<NonZero<u16>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u16>> for NonZero<isize>
impl TryFrom<NonZero<u16>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u16>> for NonZero<u8>
impl TryFrom<NonZero<u16>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<i8>
impl TryFrom<NonZero<u32>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<i16>
impl TryFrom<NonZero<u32>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<i32>
impl TryFrom<NonZero<u32>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<isize>
impl TryFrom<NonZero<u32>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<u8>
impl TryFrom<NonZero<u32>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<u16>
impl TryFrom<NonZero<u32>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u32>> for NonZero<usize>
impl TryFrom<NonZero<u32>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<i8>
impl TryFrom<NonZero<u64>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<i16>
impl TryFrom<NonZero<u64>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<i32>
impl TryFrom<NonZero<u64>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<i64>
impl TryFrom<NonZero<u64>> for NonZero<i64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<isize>
impl TryFrom<NonZero<u64>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<u8>
impl TryFrom<NonZero<u64>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<u16>
impl TryFrom<NonZero<u64>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<u32>
impl TryFrom<NonZero<u64>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u64>> for NonZero<usize>
impl TryFrom<NonZero<u64>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<i8>
impl TryFrom<NonZero<u128>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<i16>
impl TryFrom<NonZero<u128>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<i32>
impl TryFrom<NonZero<u128>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<i64>
impl TryFrom<NonZero<u128>> for NonZero<i64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<i128>
impl TryFrom<NonZero<u128>> for NonZero<i128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<isize>
impl TryFrom<NonZero<u128>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<u8>
impl TryFrom<NonZero<u128>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<u16>
impl TryFrom<NonZero<u128>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<u32>
impl TryFrom<NonZero<u128>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<u64>
impl TryFrom<NonZero<u128>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<u128>> for NonZero<usize>
impl TryFrom<NonZero<u128>> for NonZero<usize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<i8>
impl TryFrom<NonZero<usize>> for NonZero<i8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<i16>
impl TryFrom<NonZero<usize>> for NonZero<i16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<i32>
impl TryFrom<NonZero<usize>> for NonZero<i32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<i64>
impl TryFrom<NonZero<usize>> for NonZero<i64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<i128>
impl TryFrom<NonZero<usize>> for NonZero<i128>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<isize>
impl TryFrom<NonZero<usize>> for NonZero<isize>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<u8>
impl TryFrom<NonZero<usize>> for NonZero<u8>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<u16>
impl TryFrom<NonZero<usize>> for NonZero<u16>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<u32>
impl TryFrom<NonZero<usize>> for NonZero<u32>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<u64>
impl TryFrom<NonZero<usize>> for NonZero<u64>
type Error = TryFromIntError
1.49.0 (const: unstable) · Sourceimpl TryFrom<NonZero<usize>> for NonZero<u128>
impl TryFrom<NonZero<usize>> for NonZero<u128>
type Error = TryFromIntError
Sourceimpl TryFrom<Duration> for FutureInstant
impl TryFrom<Duration> for FutureInstant
Sourceimpl TryFrom<UnixStream> for UnixStream
impl TryFrom<UnixStream> for UnixStream
Sourceimpl TryFrom<UnixDatagram> for UnixDatagram
impl TryFrom<UnixDatagram> for UnixDatagram
Sourceimpl TryFrom<UnixListener> for UnixListener
impl TryFrom<UnixListener> for UnixListener
Sourceimpl TryFrom<IOccultIlk_Compat> for IOccultIlk
impl TryFrom<IOccultIlk_Compat> for IOccultIlk
type Error = Infallible
Sourceimpl<'a> TryFrom<&'a str> for HeaderName
impl<'a> TryFrom<&'a str> for HeaderName
type Error = InvalidHeaderName
Sourceimpl<'a> TryFrom<&'a str> for HeaderValue
impl<'a> TryFrom<&'a str> for HeaderValue
type Error = InvalidHeaderValue
Sourceimpl<'a> TryFrom<&'a str> for StatusCode
impl<'a> TryFrom<&'a str> for StatusCode
type Error = InvalidStatusCode
Sourceimpl<'a> TryFrom<&'a str> for PathAndQuery
impl<'a> TryFrom<&'a str> for PathAndQuery
type Error = InvalidUri
Sourceimpl<'a> TryFrom<&'a String> for HeaderName
impl<'a> TryFrom<&'a String> for HeaderName
type Error = InvalidHeaderName
Sourceimpl<'a> TryFrom<&'a String> for HeaderValue
impl<'a> TryFrom<&'a String> for HeaderValue
type Error = InvalidHeaderValue
Sourceimpl<'a> TryFrom<&'a [u8]> for HeaderName
impl<'a> TryFrom<&'a [u8]> for HeaderName
type Error = InvalidHeaderName
Sourceimpl<'a> TryFrom<&'a [u8]> for HeaderValue
impl<'a> TryFrom<&'a [u8]> for HeaderValue
type Error = InvalidHeaderValue
Sourceimpl<'a> TryFrom<&'a [u8]> for StatusCode
impl<'a> TryFrom<&'a [u8]> for StatusCode
type Error = InvalidStatusCode
Sourceimpl<'a> TryFrom<&'a [u8]> for PathAndQuery
impl<'a> TryFrom<&'a [u8]> for PathAndQuery
type Error = InvalidUri
Sourceimpl<'a> TryFrom<FormatItem<'a>> for &[FormatItem<'a>]
impl<'a> TryFrom<FormatItem<'a>> for &[FormatItem<'a>]
type Error = DifferentVariant
Sourceimpl<'a> TryFrom<Vec<u8>> for PathAndQuery
impl<'a> TryFrom<Vec<u8>> for PathAndQuery
type Error = InvalidUri
Sourceimpl<'a, K, V, T> TryFrom<&'a HashMap<K, V>> for HeaderMap<T>
Try to convert a HashMap into a HeaderMap.
impl<'a, K, V, T> TryFrom<&'a HashMap<K, V>> for HeaderMap<T>
Try to convert a HashMap into a HeaderMap.
Examples
use std::collections::HashMap;
use std::convert::TryInto;
use http::HeaderMap;
let mut map = HashMap::new();
map.insert("X-Custom-Header".to_string(), "my value".to_string());
let headers: HeaderMap = (&map).try_into().expect("valid headers");
assert_eq!(headers["X-Custom-Header"], "my value");1.34.0 (const: unstable) · Sourceimpl<'a, T, const N: usize> TryFrom<&'a [T]> for &'a [T; N]
Tries to create an array ref &[T; N] from a slice ref &[T]. Succeeds if
slice.len() == N.
impl<'a, T, const N: usize> TryFrom<&'a [T]> for &'a [T; N]
Tries to create an array ref &[T; N] from a slice ref &[T]. Succeeds if
slice.len() == N.
let bytes: [u8; 3] = [1, 0, 2];
let bytes_head: &[u8; 2] = <&[u8; 2]>::try_from(&bytes[0..2]).unwrap();
assert_eq!(1, u16::from_le_bytes(*bytes_head));
let bytes_tail: &[u8; 2] = bytes[1..3].try_into().unwrap();
assert_eq!(512, u16::from_le_bytes(*bytes_tail));type Error = TryFromSliceError
1.34.0 (const: unstable) · Sourceimpl<'a, T, const N: usize> TryFrom<&'a mut [T]> for &'a mut [T; N]
Tries to create a mutable array ref &mut [T; N] from a mutable slice ref
&mut [T]. Succeeds if slice.len() == N.
impl<'a, T, const N: usize> TryFrom<&'a mut [T]> for &'a mut [T; N]
Tries to create a mutable array ref &mut [T; N] from a mutable slice ref
&mut [T]. Succeeds if slice.len() == N.
let mut bytes: [u8; 3] = [1, 0, 2];
let bytes_head: &mut [u8; 2] = <&mut [u8; 2]>::try_from(&mut bytes[0..2]).unwrap();
assert_eq!(1, u16::from_le_bytes(*bytes_head));
let bytes_tail: &mut [u8; 2] = (&mut bytes[1..3]).try_into().unwrap();
assert_eq!(512, u16::from_le_bytes(*bytes_tail));type Error = TryFromSliceError
Sourceimpl<'a, const CAP: usize> TryFrom<&'a str> for ArrayString<CAP>
impl<'a, const CAP: usize> TryFrom<&'a str> for ArrayString<CAP>
type Error = CapacityError<&'a str>
Sourceimpl<'a, const CAP: usize> TryFrom<Arguments<'a>> for ArrayString<CAP>
impl<'a, const CAP: usize> TryFrom<Arguments<'a>> for ArrayString<CAP>
type Error = CapacityError<Error>
Sourceimpl<'trie, T> TryFrom<&'trie CodePointTrie<'trie, T>> for &'trie FastCodePointTrie<'trie, T>where
T: TrieValue,
impl<'trie, T> TryFrom<&'trie CodePointTrie<'trie, T>> for &'trie FastCodePointTrie<'trie, T>where
T: TrieValue,
Sourceimpl<'trie, T> TryFrom<&'trie CodePointTrie<'trie, T>> for &'trie SmallCodePointTrie<'trie, T>where
T: TrieValue,
impl<'trie, T> TryFrom<&'trie CodePointTrie<'trie, T>> for &'trie SmallCodePointTrie<'trie, T>where
T: TrieValue,
Sourceimpl<'trie, T> TryFrom<CodePointTrie<'trie, T>> for FastCodePointTrie<'trie, T>where
T: TrieValue,
impl<'trie, T> TryFrom<CodePointTrie<'trie, T>> for FastCodePointTrie<'trie, T>where
T: TrieValue,
Sourceimpl<'trie, T> TryFrom<CodePointTrie<'trie, T>> for SmallCodePointTrie<'trie, T>where
T: TrieValue,
impl<'trie, T> TryFrom<CodePointTrie<'trie, T>> for SmallCodePointTrie<'trie, T>where
T: TrieValue,
Sourceimpl<T> TryFrom<Dh<T>> for PKey<T>
Available on non-boringssl only.
impl<T> TryFrom<Dh<T>> for PKey<T>
boringssl only.type Error = ErrorStack
1.43.0 · Sourceimpl<T, A, const N: usize> TryFrom<Arc<[T], A>> for Arc<[T; N], A>where
A: Allocator,
impl<T, A, const N: usize> TryFrom<Arc<[T], A>> for Arc<[T; N], A>where
A: Allocator,
1.34.0 (const: unstable) · Sourceimpl<T, U> TryFrom<U> for Twhere
U: Into<T>,
impl<T, U> TryFrom<U> for Twhere
U: Into<T>,
type Error = Infallible
Sourceimpl<T, const CAP: usize> TryFrom<&[T]> for ArrayVec<T, CAP>where
T: Clone,
Try to create an ArrayVec from a slice. This will return an error if the slice was too big to
fit.
impl<T, const CAP: usize> TryFrom<&[T]> for ArrayVec<T, CAP>where
T: Clone,
Try to create an ArrayVec from a slice. This will return an error if the slice was too big to
fit.
use arrayvec::ArrayVec;
use std::convert::TryInto as _;
let array: ArrayVec<_, 4> = (&[1, 2, 3] as &[_]).try_into().unwrap();
assert_eq!(array.len(), 3);
assert_eq!(array.capacity(), 4);type Error = CapacityError
1.34.0 (const: unstable) · Sourceimpl<T, const N: usize> TryFrom<&[T]> for [T; N]where
T: Copy,
Tries to create an array [T; N] by copying from a slice &[T].
Succeeds if slice.len() == N.
impl<T, const N: usize> TryFrom<&[T]> for [T; N]where
T: Copy,
Tries to create an array [T; N] by copying from a slice &[T].
Succeeds if slice.len() == N.
let bytes: [u8; 3] = [1, 0, 2];
let bytes_head: [u8; 2] = <[u8; 2]>::try_from(&bytes[0..2]).unwrap();
assert_eq!(1, u16::from_le_bytes(bytes_head));
let bytes_tail: [u8; 2] = bytes[1..3].try_into().unwrap();
assert_eq!(512, u16::from_le_bytes(bytes_tail));type Error = TryFromSliceError
Sourceimpl<T, const N: usize> TryFrom<&[T]> for Simd<T, N>where
T: SimdElement,
impl<T, const N: usize> TryFrom<&[T]> for Simd<T, N>where
T: SimdElement,
type Error = TryFromSliceError
1.59.0 (const: unstable) · Sourceimpl<T, const N: usize> TryFrom<&mut [T]> for [T; N]where
T: Copy,
Tries to create an array [T; N] by copying from a mutable slice &mut [T].
Succeeds if slice.len() == N.
impl<T, const N: usize> TryFrom<&mut [T]> for [T; N]where
T: Copy,
Tries to create an array [T; N] by copying from a mutable slice &mut [T].
Succeeds if slice.len() == N.
let mut bytes: [u8; 3] = [1, 0, 2];
let bytes_head: [u8; 2] = <[u8; 2]>::try_from(&mut bytes[0..2]).unwrap();
assert_eq!(1, u16::from_le_bytes(bytes_head));
let bytes_tail: [u8; 2] = (&mut bytes[1..3]).try_into().unwrap();
assert_eq!(512, u16::from_le_bytes(bytes_tail));type Error = TryFromSliceError
Sourceimpl<T, const N: usize> TryFrom<&mut [T]> for Simd<T, N>where
T: SimdElement,
impl<T, const N: usize> TryFrom<&mut [T]> for Simd<T, N>where
T: SimdElement,
type Error = TryFromSliceError
1.66.0 · Sourceimpl<T, const N: usize> TryFrom<Vec<T>> for Box<[T; N]>
Available on non-no_global_oom_handling only.
impl<T, const N: usize> TryFrom<Vec<T>> for Box<[T; N]>
no_global_oom_handling only.